#include <uxUnidecode.h>

const uxLookupTable UNIDECODE_ASCII = {
  65536,  /*-- number of entries --*/
  {
   "\x0"   , "\x1"   , "\x2"   , "\x3"   , "\x4"   , "\x5"   , "\x6"   , "\x7"   ,  /*-- U+0000 .. U+0007 --*/
   "\x8"   , "\t"    , "\n"    , "\xb"   , "\xc"   , "\r"    , "\xe"   , "\xf"   ,  /*-- U+0008 .. U+000F --*/
   "\x10"  , "\x11"  , "\x12"  , "\x13"  , "\x14"  , "\x15"  , "\x16"  , "\x17"  ,  /*-- U+0010 .. U+0017 --*/
   "\x18"  , "\x19"  , "\x1a"  , "\x1b"  , "\x1c"  , "\x1d"  , "\x1e"  , "\x1f"  ,  /*-- U+0018 .. U+001F --*/
   " "     , "!"     , "\""    , "#"     , "$"     , "%"     , "&"     , "'"     ,  /*-- U+0020 .. U+0027 --*/
   "("     , ")"     , "*"     , "+"     , ","     , "-"     , "."     , "/"     ,  /*-- U+0028 .. U+002F --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+0030 .. U+0037 --*/
   "8"     , "9"     , ":"     , ";"     , "<"     , "="     , ">"     , "?"     ,  /*-- U+0038 .. U+003F --*/
   "@"     , "A"     , "B"     , "C"     , "D"     , "E"     , "F"     , "G"     ,  /*-- U+0040 .. U+0047 --*/
   "H"     , "I"     , "J"     , "K"     , "L"     , "M"     , "N"     , "O"     ,  /*-- U+0048 .. U+004F --*/
   "P"     , "Q"     , "R"     , "S"     , "T"     , "U"     , "V"     , "W"     ,  /*-- U+0050 .. U+0057 --*/
   "X"     , "Y"     , "Z"     , "]"     , "\\"    , "]"     , "^"     , "_"     ,  /*-- U+0058 .. U+005F --*/
   "`"     , "a"     , "b"     , "c"     , "d"     , "e"     , "f"     , "g"     ,  /*-- U+0060 .. U+0067 --*/
   "h"     , "i"     , "j"     , "k"     , "l"     , "m"     , "n"     , "o"     ,  /*-- U+0068 .. U+006F --*/
   "p"     , "q"     , "r"     , "s"     , "t"     , "u"     , "v"     , "w"     ,  /*-- U+0070 .. U+0077 --*/
   "x"     , "y"     , "z"     , "{"     , "|"     , "}"     , "~"     , "\x7f"  ,  /*-- U+0078 .. U+007F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0080 .. U+0087 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0088 .. U+008F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0090 .. U+0097 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0098 .. U+009F --*/
   " "     , "!"     , "C/"    , "PS"    , "$?"    , "Y="    , "|"     , "SS"    ,  /*-- U+00A0 .. U+00A7 --*/
   "\""    , "(c)"   , "a"     , "<<"    , "!"     , ""      , "(r)"   , "-"     ,  /*-- U+00A8 .. U+00AF --*/
   "deg"   , "+-"    , "2"     , "3"     , "'"     , "u"     , "P"     , "*"     ,  /*-- U+00B0 .. U+00B7 --*/
   ","     , "1"     , "o"     , ">>"    , "1/4"   , "1/2"   , "3/4"   , "?"     ,  /*-- U+00B8 .. U+00BF --*/
   "A"     , "A"     , "A"     , "A"     , "A"     , "A"     , "AE"    , "C"     ,  /*-- U+00C0 .. U+00C7 --*/
   "E"     , "E"     , "E"     , "E"     , "I"     , "I"     , "I"     , "I"     ,  /*-- U+00C8 .. U+00CF --*/
   "D"     , "N"     , "O"     , "O"     , "O"     , "O"     , "O"     , "x"     ,  /*-- U+00D0 .. U+00D7 --*/
   "O"     , "U"     , "U"     , "U"     , "U"     , "U"     , "Th"    , "ss"    ,  /*-- U+00D8 .. U+00DF --*/
   "a"     , "a"     , "a"     , "a"     , "a"     , "a"     , "ae"    , "c"     ,  /*-- U+00E0 .. U+00E7 --*/
   "e"     , "e"     , "e"     , "e"     , "i"     , "i"     , "i"     , "i"     ,  /*-- U+00E8 .. U+00EF --*/
   "d"     , "n"     , "o"     , "o"     , "o"     , "o"     , "o"     , "/"     ,  /*-- U+00F0 .. U+00F7 --*/
   "o"     , "u"     , "u"     , "u"     , "u"     , "y"     , "th"    , "y"     ,  /*-- U+00F8 .. U+00FF --*/
   "A"     , "a"     , "A"     , "a"     , "A"     , "a"     , "C"     , "c"     ,  /*-- U+0100 .. U+0107 --*/
   "C"     , "c"     , "C"     , "c"     , "C"     , "c"     , "D"     , "d"     ,  /*-- U+0108 .. U+010F --*/
   "D"     , "d"     , "E"     , "e"     , "E"     , "e"     , "E"     , "e"     ,  /*-- U+0110 .. U+0117 --*/
   "E"     , "e"     , "E"     , "e"     , "G"     , "g"     , "G"     , "g"     ,  /*-- U+0118 .. U+011F --*/
   "G"     , "g"     , "G"     , "g"     , "H"     , "h"     , "H"     , "h"     ,  /*-- U+0120 .. U+0127 --*/
   "I"     , "i"     , "I"     , "i"     , "I"     , "i"     , "I"     , "i"     ,  /*-- U+0128 .. U+012F --*/
   "I"     , "i"     , "IJ"    , ""      , "J"     , "j"     , "K"     , "k"     ,  /*-- U+0130 .. U+0137 --*/
   "k"     , "L"     , "l"     , "L"     , "l"     , "L"     , "l"     , "L"     ,  /*-- U+0138 .. U+013F --*/
   "l"     , "L"     , "l"     , "N"     , "n"     , "N"     , "n"     , "N"     ,  /*-- U+0140 .. U+0147 --*/
   "n"     , "'n"    , "ng"    , "NG"    , "O"     , "o"     , "O"     , "o"     ,  /*-- U+0148 .. U+014F --*/
   "O"     , "o"     , "OE"    , "oe"    , "R"     , "r"     , "R"     , "r"     ,  /*-- U+0150 .. U+0157 --*/
   "R"     , "r"     , "S"     , "s"     , "S"     , "s"     , "S"     , "s"     ,  /*-- U+0158 .. U+015F --*/
   "S"     , "s"     , "T"     , "t"     , "T"     , "t"     , "T"     , "t"     ,  /*-- U+0160 .. U+0167 --*/
   "U"     , "u"     , "U"     , "u"     , "U"     , "u"     , "U"     , "u"     ,  /*-- U+0168 .. U+016F --*/
   "U"     , "u"     , "U"     , "u"     , "W"     , "w"     , "Y"     , "y"     ,  /*-- U+0170 .. U+0177 --*/
   "Y"     , "Z"     , "z"     , "Z"     , "z"     , "Z"     , "z"     , "s"     ,  /*-- U+0178 .. U+017F --*/
   "b"     , "B"     , "B"     , "b"     , "6"     , "6"     , "O"     , "C"     ,  /*-- U+0180 .. U+0187 --*/
   "c"     , "D"     , "D"     , "D"     , "d"     , "d"     , "3"     , "@"     ,  /*-- U+0188 .. U+018F --*/
   "E"     , "F"     , "f"     , "G"     , "G"     , "hv"    , "I"     , "I"     ,  /*-- U+0190 .. U+0197 --*/
   "K"     , "k"     , "l"     , "l"     , "W"     , "N"     , "n"     , "O"     ,  /*-- U+0198 .. U+019F --*/
   "O"     , "o"     , "OI"    , "oi"    , "P"     , "p"     , "YR"    , "2"     ,  /*-- U+01A0 .. U+01A7 --*/
   "2"     , "SH"    , "sh"    , "t"     , "T"     , "t"     , "T"     , "U"     ,  /*-- U+01A8 .. U+01AF --*/
   "u"     , "Y"     , "V"     , "Y"     , "y"     , "Z"     , "z"     , "ZH"    ,  /*-- U+01B0 .. U+01B7 --*/
   "ZH"    , "zh"    , "zh"    , "2"     , "5"     , "5"     , "ts"    , "w"     ,  /*-- U+01B8 .. U+01BF --*/
   "|"     , "||"    , "|="    , "!"     , "DZ"    , "Dz"    , "dz"    , "LJ"    ,  /*-- U+01C0 .. U+01C7 --*/
   "Lj"    , "lj"    , "NJ"    , "Nj"    , "nj"    , "A"     , "a"     , "I"     ,  /*-- U+01C8 .. U+01CF --*/
   "i"     , "O"     , "o"     , "U"     , "u"     , "U"     , "u"     , "U"     ,  /*-- U+01D0 .. U+01D7 --*/
   "u"     , "U"     , "u"     , "U"     , "u"     , "@"     , "A"     , "a"     ,  /*-- U+01D8 .. U+01DF --*/
   "A"     , "a"     , "AE"    , "ae"    , "G"     , "g"     , "G"     , "g"     ,  /*-- U+01E0 .. U+01E7 --*/
   "K"     , "k"     , "O"     , "o"     , "O"     , "o"     , "ZH"    , "zh"    ,  /*-- U+01E8 .. U+01EF --*/
   "j"     , "DZ"    , "D"     , "dz"    , "G"     , "g"     , "HV"    , "W"     ,  /*-- U+01F0 .. U+01F7 --*/
   "N"     , "n"     , "A"     , "a"     , "AE"    , "ae"    , "O"     , "o"     ,  /*-- U+01F8 .. U+01FF --*/
   "A"     , "a"     , "A"     , "a"     , "E"     , "e"     , "E"     , "e"     ,  /*-- U+0200 .. U+0207 --*/
   "I"     , "i"     , "I"     , "i"     , "O"     , "o"     , "O"     , "o"     ,  /*-- U+0208 .. U+020F --*/
   "R"     , "r"     , "R"     , "r"     , "U"     , "u"     , "U"     , "u"     ,  /*-- U+0210 .. U+0217 --*/
   "S"     , "s"     , "T"     , "t"     , "Y"     , "y"     , "H"     , "h"     ,  /*-- U+0218 .. U+021F --*/
   ""      , ""      , "OU"    , "ou"    , "Z"     , "z"     , "A"     , "a"     ,  /*-- U+0220 .. U+0227 --*/
   "E"     , "e"     , "O"     , "o"     , "O"     , "o"     , "O"     , "o"     ,  /*-- U+0228 .. U+022F --*/
   "O"     , "o"     , "Y"     , "y"     , ""      , ""      , ""      , ""      ,  /*-- U+0230 .. U+0237 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0238 .. U+023F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0240 .. U+0247 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0248 .. U+024F --*/
   "a"     , "a"     , "a"     , "b"     , "o"     , "c"     , "d"     , "d"     ,  /*-- U+0250 .. U+0257 --*/
   "e"     , "@"     , "@"     , "e"     , "e"     , "e"     , "e"     , "j"     ,  /*-- U+0258 .. U+025F --*/
   "g"     , "g"     , "g"     , "g"     , "u"     , "Y"     , "h"     , "h"     ,  /*-- U+0260 .. U+0267 --*/
   "i"     , "i"     , "I"     , "l"     , "l"     , "l"     , "lZ"    , "W"     ,  /*-- U+0268 .. U+026F --*/
   "W"     , "m"     , "n"     , "n"     , "n"     , "o"     , "OE"    , "O"     ,  /*-- U+0270 .. U+0277 --*/
   "F"     , "R"     , "R"     , "R"     , "R"     , "r"     , "r"     , "R"     ,  /*-- U+0278 .. U+027F --*/
   "R"     , "R"     , "s"     , "S"     , "j"     , "S"     , "S"     , "t"     ,  /*-- U+0280 .. U+0287 --*/
   "t"     , "U"     , "U"     , "v"     , "^"     , "W"     , "Y"     , "Y"     ,  /*-- U+0288 .. U+028F --*/
   "z"     , "z"     , "Z"     , "Z"     , "?"     , "?"     , "?"     , "C"     ,  /*-- U+0290 .. U+0297 --*/
   "@"     , "B"     , "E"     , "G"     , "H"     , "j"     , "k"     , "L"     ,  /*-- U+0298 .. U+029F --*/
   "q"     , "?"     , "?"     , "dz"    , "dZ"    , "dz"    , "ts"    , "tS"    ,  /*-- U+02A0 .. U+02A7 --*/
   "tC"    , "fN"    , "ls"    , "lz"    , "WW"    , "]]"    , ""      , ""      ,  /*-- U+02A8 .. U+02AF --*/
   "k"     , "h"     , "j"     , "r"     , "r"     , "r"     , "r"     , "w"     ,  /*-- U+02B0 .. U+02B7 --*/
   "y"     , "'"     , "\""    , "`"     , "'"     , "`"     , "`"     , "'"     ,  /*-- U+02B8 .. U+02BF --*/
   "?"     , "?"     , "<"     , ">"     , "^"     , "V"     , "^"     , "V"     ,  /*-- U+02C0 .. U+02C7 --*/
   "'"     , "-"     , "/"     , "\\"    , ","     , "_"     , "\\"    , "/"     ,  /*-- U+02C8 .. U+02CF --*/
   ":"     , "."     , "`"     , "'"     , "^"     , "V"     , "+"     , "-"     ,  /*-- U+02D0 .. U+02D7 --*/
   "V"     , "."     , "@"     , ","     , "~"     , "\""    , "R"     , "X"     ,  /*-- U+02D8 .. U+02DF --*/
   "G"     , "l"     , "s"     , "x"     , "?"     , ""      , ""      , ""      ,  /*-- U+02E0 .. U+02E7 --*/
   ""      , ""      , ""      , ""      , "V"     , "="     , "\""    , ""      ,  /*-- U+02E8 .. U+02EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+02F0 .. U+02F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+02F8 .. U+02FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0300 .. U+0307 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0308 .. U+030F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0310 .. U+0317 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0318 .. U+031F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0320 .. U+0327 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0328 .. U+032F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0330 .. U+0337 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0338 .. U+033F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0340 .. U+0347 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0348 .. U+034F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0350 .. U+0357 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0358 .. U+035F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0360 .. U+0367 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0368 .. U+036F --*/
   ""      , ""      , ""      , ""      , "'"     , ","     , ""      , ""      ,  /*-- U+0370 .. U+0377 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , "?"     , ""      ,  /*-- U+0378 .. U+037F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , "A"     , ";"     ,  /*-- U+0380 .. U+0387 --*/
   "E"     , "E"     , "I"     , ""      , "O"     , ""      , "U"     , "O"     ,  /*-- U+0388 .. U+038F --*/
   "I"     , "A"     , "B"     , "G"     , "D"     , "E"     , "Z"     , "E"     ,  /*-- U+0390 .. U+0397 --*/
   "Th"    , "I"     , "K"     , "L"     , "M"     , "N"     , "Ks"    , "O"     ,  /*-- U+0398 .. U+039F --*/
   "P"     , "R"     , ""      , "S"     , "T"     , "U"     , "Ph"    , "Kh"    ,  /*-- U+03A0 .. U+03A7 --*/
   "Ps"    , "O"     , "I"     , "U"     , "a"     , "e"     , "e"     , "i"     ,  /*-- U+03A8 .. U+03AF --*/
   "u"     , "a"     , "b"     , "g"     , "d"     , "e"     , "z"     , "e"     ,  /*-- U+03B0 .. U+03B7 --*/
   "th"    , "i"     , "k"     , "l"     , "m"     , "n"     , "x"     , "o"     ,  /*-- U+03B8 .. U+03BF --*/
   "p"     , "r"     , "s"     , "s"     , "t"     , "u"     , "ph"    , "kh"    ,  /*-- U+03C0 .. U+03C7 --*/
   "ps"    , "o"     , "i"     , "u"     , "o"     , "u"     , "o"     , ""      ,  /*-- U+03C8 .. U+03CF --*/
   "b"     , "th"    , "U"     , "U"     , "U"     , "ph"    , "p"     , "&"     ,  /*-- U+03D0 .. U+03D7 --*/
   ""      , ""      , "St"    , "st"    , "W"     , "w"     , "Q"     , "q"     ,  /*-- U+03D8 .. U+03DF --*/
   "Sp"    , "sp"    , "Sh"    , "sh"    , "F"     , "f"     , "Kh"    , "kh"    ,  /*-- U+03E0 .. U+03E7 --*/
   "H"     , "h"     , "G"     , "g"     , "CH"    , "ch"    , "Ti"    , "ti"    ,  /*-- U+03E8 .. U+03EF --*/
   "k"     , "r"     , "c"     , "j"     , ""      , ""      , ""      , ""      ,  /*-- U+03F0 .. U+03F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+03F8 .. U+03FF --*/
   "Ie"    , "Io"    , "Dj"    , "Gj"    , "Ie"    , "Dz"    , "I"     , "Yi"    ,  /*-- U+0400 .. U+0407 --*/
   "J"     , "Lj"    , "Nj"    , "Tsh"   , "Kj"    , "I"     , "U"     , "Dzh"   ,  /*-- U+0408 .. U+040F --*/
   "A"     , "B"     , "V"     , "G"     , "D"     , "Ie"    , "Zh"    , "Z"     ,  /*-- U+0410 .. U+0417 --*/
   "I"     , "I"     , "K"     , "L"     , "M"     , "N"     , "O"     , "P"     ,  /*-- U+0418 .. U+041F --*/
   "R"     , "S"     , "T"     , "U"     , "F"     , "Kh"    , "Ts"    , "Ch"    ,  /*-- U+0420 .. U+0427 --*/
   "Sh"    , "Shch"  , ""      , "Y"     , "'"     , "E"     , "Iu"    , "Ia"    ,  /*-- U+0428 .. U+042F --*/
   "a"     , "b"     , "v"     , "gh"    , "d"     , "ie"    , "zh"    , "z"     ,  /*-- U+0430 .. U+0437 --*/
   "i"     , "i"     , "k"     , "l"     , "m"     , "n"     , "o"     , "p"     ,  /*-- U+0438 .. U+043F --*/
   "r"     , "s"     , "t"     , "u"     , "f"     , "kh"    , "ts"    , "ch"    ,  /*-- U+0440 .. U+0447 --*/
   "sh"    , "shch"  , ""      , "y"     , "'"     , "e"     , "iu"    , "ia"    ,  /*-- U+0448 .. U+044F --*/
   "ie"    , "io"    , "dj"    , "gj"    , "ie"    , "dz"    , "i"     , "yi"    ,  /*-- U+0450 .. U+0457 --*/
   "j"     , "lj"    , "nj"    , "tsh"   , "kj"    , "i"     , "u"     , "dzh"   ,  /*-- U+0458 .. U+045F --*/
   "O"     , "o"     , "E"     , "e"     , "Ie"    , "ie"    , "E"     , "e"     ,  /*-- U+0460 .. U+0467 --*/
   "Ie"    , "ie"    , "O"     , "o"     , "Io"    , "io"    , "Ks"    , "ks"    ,  /*-- U+0468 .. U+046F --*/
   "Ps"    , "ps"    , "F"     , "f"     , "Y"     , "y"     , "Y"     , "y"     ,  /*-- U+0470 .. U+0477 --*/
   "u"     , "u"     , "O"     , "o"     , "O"     , "o"     , "Ot"    , "ot"    ,  /*-- U+0478 .. U+047F --*/
   "Q"     , "q"     , "*1000*", ""      , ""      , ""      , ""      , ""      ,  /*-- U+0480 .. U+0487 --*/
   "*100.000*", "*1.000.000*", ""      , ""      , "\""    , "\""    , "R'"    , "r'"    ,  /*-- U+0488 .. U+048F --*/
   "G'"    , "g'"    , "G'"    , "g'"    , "G'"    , "g'"    , "Zh'"   , "zh'"   ,  /*-- U+0490 .. U+0497 --*/
   "Z'"    , "z'"    , "K'"    , "k'"    , "K'"    , "k'"    , "K'"    , "k'"    ,  /*-- U+0498 .. U+049F --*/
   "K'"    , "k'"    , "N'"    , "n'"    , "Ng"    , "ng"    , "P'"    , "p'"    ,  /*-- U+04A0 .. U+04A7 --*/
   "Kh"    , "kh"    , "S'"    , "s'"    , "T'"    , "t'"    , "U"     , "u"     ,  /*-- U+04A8 .. U+04AF --*/
   "U'"    , "u'"    , "Kh'"   , "kh'"   , "Tts"   , "tts"   , "Ch'"   , "ch'"   ,  /*-- U+04B0 .. U+04B7 --*/
   "Ch'"   , "ch'"   , "H"     , "h"     , "Ch"    , "ch"    , "Ch'"   , "ch'"   ,  /*-- U+04B8 .. U+04BF --*/
   "`"     , "Zh"    , "zh"    , "K'"    , "k'"    , ""      , ""      , "N'"    ,  /*-- U+04C0 .. U+04C7 --*/
   "n'"    , ""      , ""      , "Ch"    , "ch"    , ""      , ""      , ""      ,  /*-- U+04C8 .. U+04CF --*/
   "a"     , "a"     , "A"     , "a"     , "Ae"    , "ae"    , "Ie"    , "ie"    ,  /*-- U+04D0 .. U+04D7 --*/
   "@"     , "@"     , "@"     , "@"     , "Zh"    , "zh"    , "Z"     , "z"     ,  /*-- U+04D8 .. U+04DF --*/
   "Dz"    , "dz"    , "I"     , "i"     , "I"     , "i"     , "O"     , "o"     ,  /*-- U+04E0 .. U+04E7 --*/
   "O"     , "o"     , "O"     , "o"     , "E"     , "e"     , "U"     , "u"     ,  /*-- U+04E8 .. U+04EF --*/
   "U"     , "u"     , "U"     , "u"     , "Ch"    , "ch"    , ""      , ""      ,  /*-- U+04F0 .. U+04F7 --*/
   "Y"     , "y"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+04F8 .. U+04FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0500 .. U+0507 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0508 .. U+050F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0510 .. U+0517 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0518 .. U+051F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0520 .. U+0527 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0528 .. U+052F --*/
   ""      , "A"     , "B"     , "G"     , "D"     , "E"     , "Z"     , "E"     ,  /*-- U+0530 .. U+0537 --*/
   "E"     , "T`"    , "Zh"    , "I"     , "L"     , "Kh"    , "Ts"    , "K"     ,  /*-- U+0538 .. U+053F --*/
   "H"     , "Dz"    , "Gh"    , "Ch"    , "M"     , "Y"     , "N"     , "Sh"    ,  /*-- U+0540 .. U+0547 --*/
   "O"     , "Ch`"   , "P"     , "J"     , "Rh"    , "S"     , "V"     , "T"     ,  /*-- U+0548 .. U+054F --*/
   "R"     , "Ts`"   , "W"     , "P`"    , "K`"    , "O"     , "F"     , ""      ,  /*-- U+0550 .. U+0557 --*/
   ""      , "<"     , "'"     , "/"     , "!"     , ","     , "?"     , "."     ,  /*-- U+0558 .. U+055F --*/
   ""      , "a"     , "b"     , "g"     , "d"     , "e"     , "z"     , "e"     ,  /*-- U+0560 .. U+0567 --*/
   "e"     , "t`"    , "zh"    , "i"     , "l"     , "kh"    , "ts"    , "k"     ,  /*-- U+0568 .. U+056F --*/
   "h"     , "dz"    , "gh"    , "ch"    , "m"     , "y"     , "n"     , "sh"    ,  /*-- U+0570 .. U+0577 --*/
   "o"     , "ch`"   , "p"     , "j"     , "rh"    , "s"     , "v"     , "t"     ,  /*-- U+0578 .. U+057F --*/
   "r"     , "ts`"   , "w"     , "p`"    , "k`"    , "o"     , "f"     , "ew"    ,  /*-- U+0580 .. U+0587 --*/
   ""      , "."     , "-"     , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0588 .. U+058F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0590 .. U+0597 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0598 .. U+059F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+05A0 .. U+05A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+05A8 .. U+05AF --*/
   "@"     , "e"     , "a"     , "o"     , "i"     , "e"     , "e"     , "a"     ,  /*-- U+05B0 .. U+05B7 --*/
   "a"     , "o"     , ""      , "u"     , "'"     , ""      , ""      , ""      ,  /*-- U+05B8 .. U+05BF --*/
   ""      , ""      , ""      , ":"     , ""      , ""      , ""      , ""      ,  /*-- U+05C0 .. U+05C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+05C8 .. U+05CF --*/
   ""      , "b"     , "g"     , "d"     , "h"     , "v"     , "z"     , "kh"    ,  /*-- U+05D0 .. U+05D7 --*/
   "t"     , "y"     , "k"     , "k"     , "l"     , "m"     , "m"     , "n"     ,  /*-- U+05D8 .. U+05DF --*/
   "n"     , "s"     , "`"     , "p"     , "p"     , "ts"    , "ts"    , "q"     ,  /*-- U+05E0 .. U+05E7 --*/
   "r"     , "sh"    , "t"     , ""      , ""      , ""      , ""      , ""      ,  /*-- U+05E8 .. U+05EF --*/
   "V"     , "oy"    , "i"     , "'"     , "\""    , ""      , ""      , ""      ,  /*-- U+05F0 .. U+05F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+05F8 .. U+05FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0600 .. U+0607 --*/
   ""      , ""      , ""      , ""      , ","     , ""      , ""      , ""      ,  /*-- U+0608 .. U+060F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0610 .. U+0617 --*/
   ""      , ""      , ""      , ";"     , ""      , ""      , ""      , "?"     ,  /*-- U+0618 .. U+061F --*/
   ""      , ""      , "a"     , "'"     , "w'"    , ""      , "y'"    , ""      ,  /*-- U+0620 .. U+0627 --*/
   "b"     , "@"     , "t"     , "th"    , "j"     , "H"     , "kh"    , "d"     ,  /*-- U+0628 .. U+062F --*/
   "dh"    , "r"     , "z"     , "s"     , "sh"    , "S"     , "D"     , "T"     ,  /*-- U+0630 .. U+0637 --*/
   "Z"     , "`"     , "G"     , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0638 .. U+063F --*/
   ""      , "f"     , "q"     , "k"     , "l"     , "m"     , "n"     , "h"     ,  /*-- U+0640 .. U+0647 --*/
   "w"     , "~"     , "y"     , "an"    , "un"    , "in"    , "a"     , "u"     ,  /*-- U+0648 .. U+064F --*/
   "i"     , "W"     , ""      , ""      , "'"     , "'"     , ""      , ""      ,  /*-- U+0650 .. U+0657 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0658 .. U+065F --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+0660 .. U+0667 --*/
   "8"     , "9"     , "%"     , "."     , ","     , "*"     , ""      , ""      ,  /*-- U+0668 .. U+066F --*/
   ""      , "'"     , "'"     , "'"     , ""      , "'"     , "'w"    , "'u"    ,  /*-- U+0670 .. U+0677 --*/
   "'y"    , "tt"    , "tth"   , "b"     , "t"     , "T"     , "p"     , "th"    ,  /*-- U+0678 .. U+067F --*/
   "bh"    , "'h"    , "H"     , "ny"    , "dy"    , "H"     , "ch"    , "cch"   ,  /*-- U+0680 .. U+0687 --*/
   "dd"    , "D"     , "D"     , "Dt"    , "dh"    , "ddh"   , "d"     , "D"     ,  /*-- U+0688 .. U+068F --*/
   "D"     , "rr"    , "R"     , "R"     , "R"     , "R"     , "R"     , "R"     ,  /*-- U+0690 .. U+0697 --*/
   "j"     , "R"     , "S"     , "S"     , "S"     , "S"     , "S"     , "T"     ,  /*-- U+0698 .. U+069F --*/
   "GH"    , "F"     , "F"     , "F"     , "v"     , "f"     , "ph"    , "Q"     ,  /*-- U+06A0 .. U+06A7 --*/
   "Q"     , "kh"    , "k"     , "K"     , "K"     , "ng"    , "K"     , "g"     ,  /*-- U+06A8 .. U+06AF --*/
   "G"     , "N"     , "G"     , "G"     , "G"     , "L"     , "L"     , "L"     ,  /*-- U+06B0 .. U+06B7 --*/
   "L"     , "N"     , "N"     , "N"     , "N"     , "N"     , "h"     , "Ch"    ,  /*-- U+06B8 .. U+06BF --*/
   "hy"    , "h"     , "H"     , "@"     , "W"     , "oe"    , "oe"    , "u"     ,  /*-- U+06C0 .. U+06C7 --*/
   "yu"    , "yu"    , "W"     , "v"     , "y"     , "Y"     , "Y"     , "W"     ,  /*-- U+06C8 .. U+06CF --*/
   ""      , ""      , "y"     , "y'"    , "."     , "ae"    , ""      , ""      ,  /*-- U+06D0 .. U+06D7 --*/
   ""      , ""      , ""      , ""      , ""      , "@"     , "#"     , ""      ,  /*-- U+06D8 .. U+06DF --*/
   ""      , ""      , ""      , ""      , ""      , "'"     , ""      , ""      ,  /*-- U+06E0 .. U+06E7 --*/
   ""      , "^"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+06E8 .. U+06EF --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+06F0 .. U+06F7 --*/
   "8"     , "9"     , "Sh"    , "D"     , "Gh"    , "&"     , "+m"    , ""      ,  /*-- U+06F8 .. U+06FF --*/
   "//"    , "/"     , ","     , "!"     , "!"     , "-"     , ","     , ","     ,  /*-- U+0700 .. U+0707 --*/
   ";"     , "?"     , "~"     , "{"     , "}"     , "*"     , ""      , ""      ,  /*-- U+0708 .. U+070F --*/
   "'"     , ""      , "b"     , "g"     , "g"     , "d"     , "d"     , "h"     ,  /*-- U+0710 .. U+0717 --*/
   "w"     , "z"     , "H"     , "t"     , "t"     , "y"     , "yh"    , "k"     ,  /*-- U+0718 .. U+071F --*/
   "l"     , "m"     , "n"     , "s"     , "s"     , "`"     , "p"     , "p"     ,  /*-- U+0720 .. U+0727 --*/
   "S"     , "q"     , "r"     , "sh"    , "t"     , ""      , ""      , ""      ,  /*-- U+0728 .. U+072F --*/
   "a"     , "a"     , "a"     , "A"     , "A"     , "A"     , "e"     , "e"     ,  /*-- U+0730 .. U+0737 --*/
   "e"     , "E"     , "i"     , "i"     , "u"     , "u"     , "u"     , "o"     ,  /*-- U+0738 .. U+073F --*/
   ""      , "`"     , "'"     , ""      , ""      , "X"     , "Q"     , "@"     ,  /*-- U+0740 .. U+0747 --*/
   "@"     , "|"     , "+"     , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0748 .. U+074F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0750 .. U+0757 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0758 .. U+075F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0760 .. U+0767 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0768 .. U+076F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0770 .. U+0777 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0778 .. U+077F --*/
   "h"     , "sh"    , "n"     , "r"     , "b"     , "L"     , "k"     , "'"     ,  /*-- U+0780 .. U+0787 --*/
   "v"     , "m"     , "f"     , "dh"    , "th"    , "l"     , "g"     , "ny"    ,  /*-- U+0788 .. U+078F --*/
   "s"     , "d"     , "z"     , "t"     , "y"     , "p"     , "j"     , "ch"    ,  /*-- U+0790 .. U+0797 --*/
   "tt"    , "hh"    , "kh"    , "th"    , "z"     , "sh"    , "s"     , "d"     ,  /*-- U+0798 .. U+079F --*/
   "t"     , "z"     , "`"     , "gh"    , "q"     , "w"     , "a"     , "aa"    ,  /*-- U+07A0 .. U+07A7 --*/
   "i"     , "ee"    , "u"     , "oo"    , "e"     , "ey"    , "o"     , "oa"    ,  /*-- U+07A8 .. U+07AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07B0 .. U+07B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07B8 .. U+07BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07C0 .. U+07C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07C8 .. U+07CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07D0 .. U+07D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07D8 .. U+07DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07E0 .. U+07E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07E8 .. U+07EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07F0 .. U+07F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+07F8 .. U+07FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0800 .. U+0807 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0808 .. U+080F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0810 .. U+0817 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0818 .. U+081F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0820 .. U+0827 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0828 .. U+082F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0830 .. U+0837 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0838 .. U+083F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0840 .. U+0847 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0848 .. U+084F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0850 .. U+0857 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0858 .. U+085F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0860 .. U+0867 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0868 .. U+086F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0870 .. U+0877 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0878 .. U+087F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0880 .. U+0887 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0888 .. U+088F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0890 .. U+0897 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0898 .. U+089F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08A0 .. U+08A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08A8 .. U+08AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08B0 .. U+08B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08B8 .. U+08BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08C0 .. U+08C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08C8 .. U+08CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08D0 .. U+08D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08D8 .. U+08DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08E0 .. U+08E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08E8 .. U+08EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08F0 .. U+08F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+08F8 .. U+08FF --*/
   ""      , "N"     , "N"     , "H"     , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0900 .. U+0907 --*/
   "ii"    , "u"     , "uu"    , "R"     , "L"     , "eN"    , "e"     , "e"     ,  /*-- U+0908 .. U+090F --*/
   "ai"    , "oN"    , "o"     , "o"     , "au"    , "k"     , "kh"    , "g"     ,  /*-- U+0910 .. U+0917 --*/
   "gh"    , "ng"    , "c"     , "ch"    , "j"     , "jh"    , "ny"    , "tt"    ,  /*-- U+0918 .. U+091F --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "t"     , "th"    , "d"     , "dh"    ,  /*-- U+0920 .. U+0927 --*/
   "n"     , "nnn"   , "p"     , "ph"    , "b"     , "bh"    , "m"     , "y"     ,  /*-- U+0928 .. U+092F --*/
   "r"     , "rr"    , "l"     , "l"     , "lll"   , "v"     , "sh"    , "ss"    ,  /*-- U+0930 .. U+0937 --*/
   "s"     , "h"     , ""      , ""      , "'"     , "'"     , "aa"    , "i"     ,  /*-- U+0938 .. U+093F --*/
   "ii"    , "u"     , "uu"    , "R"     , "RR"    , "eN"    , "e"     , "e"     ,  /*-- U+0940 .. U+0947 --*/
   "ai"    , "oN"    , "o"     , "o"     , "au"    , ""      , ""      , ""      ,  /*-- U+0948 .. U+094F --*/
   "AUM"   , "'"     , "'"     , "`"     , "'"     , ""      , ""      , ""      ,  /*-- U+0950 .. U+0957 --*/
   "q"     , "khh"   , "ghh"   , "z"     , "dddh"  , "rh"    , "f"     , "yy"    ,  /*-- U+0958 .. U+095F --*/
   "RR"    , "LL"    , "L"     , "LL"    , " / "   , " // "  , "0"     , "1"     ,  /*-- U+0960 .. U+0967 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+0968 .. U+096F --*/
   "."     , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0970 .. U+0977 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0978 .. U+097F --*/
   ""      , "N"     , "N"     , "H"     , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0980 .. U+0987 --*/
   "ii"    , "u"     , "uu"    , "R"     , "RR"    , ""      , ""      , "e"     ,  /*-- U+0988 .. U+098F --*/
   "ai"    , ""      , ""      , "o"     , "au"    , "k"     , "kh"    , "g"     ,  /*-- U+0990 .. U+0997 --*/
   "gh"    , "ng"    , "c"     , "ch"    , "j"     , "jh"    , "ny"    , "tt"    ,  /*-- U+0998 .. U+099F --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "t"     , "th"    , "d"     , "dh"    ,  /*-- U+09A0 .. U+09A7 --*/
   "n"     , ""      , "p"     , "ph"    , "b"     , "bh"    , "m"     , "y"     ,  /*-- U+09A8 .. U+09AF --*/
   "r"     , ""      , "l"     , ""      , ""      , ""      , "sh"    , "ss"    ,  /*-- U+09B0 .. U+09B7 --*/
   "s"     , "h"     , ""      , ""      , "'"     , ""      , "aa"    , "i"     ,  /*-- U+09B8 .. U+09BF --*/
   "ii"    , "u"     , "uu"    , "R"     , "RR"    , ""      , ""      , "e"     ,  /*-- U+09C0 .. U+09C7 --*/
   "ai"    , ""      , ""      , "o"     , "au"    , ""      , ""      , ""      ,  /*-- U+09C8 .. U+09CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , "+"     ,  /*-- U+09D0 .. U+09D7 --*/
   ""      , ""      , ""      , ""      , "rr"    , "rh"    , ""      , "yy"    ,  /*-- U+09D8 .. U+09DF --*/
   "RR"    , "LL"    , "L"     , "LL"    , ""      , ""      , "0"     , "1"     ,  /*-- U+09E0 .. U+09E7 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+09E8 .. U+09EF --*/
   "r'"    , "r`"    , "Rs"    , "Rs"    , "1/"    , "2/"    , "3/"    , "4/"    ,  /*-- U+09F0 .. U+09F7 --*/
   " 1 - 1/", "/16"   , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+09F8 .. U+09FF --*/
   ""      , ""      , "N"     , ""      , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0A00 .. U+0A07 --*/
   "ii"    , "u"     , "uu"    , ""      , ""      , ""      , ""      , "ee"    ,  /*-- U+0A08 .. U+0A0F --*/
   "ai"    , ""      , ""      , "oo"    , "au"    , "k"     , "kh"    , "g"     ,  /*-- U+0A10 .. U+0A17 --*/
   "gh"    , "ng"    , "c"     , "ch"    , "j"     , "jh"    , "ny"    , "tt"    ,  /*-- U+0A18 .. U+0A1F --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "t"     , "th"    , "d"     , "dh"    ,  /*-- U+0A20 .. U+0A27 --*/
   "n"     , ""      , "p"     , "ph"    , "b"     , "bb"    , "m"     , "y"     ,  /*-- U+0A28 .. U+0A2F --*/
   "r"     , ""      , "l"     , "ll"    , ""      , "v"     , "sh"    , ""      ,  /*-- U+0A30 .. U+0A37 --*/
   "s"     , "h"     , ""      , ""      , "'"     , ""      , "aa"    , "i"     ,  /*-- U+0A38 .. U+0A3F --*/
   "ii"    , "u"     , "uu"    , ""      , ""      , ""      , ""      , "ee"    ,  /*-- U+0A40 .. U+0A47 --*/
   "ai"    , ""      , ""      , "oo"    , "au"    , ""      , ""      , ""      ,  /*-- U+0A48 .. U+0A4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0A50 .. U+0A57 --*/
   ""      , "khh"   , "ghh"   , "z"     , "rr"    , ""      , "f"     , ""      ,  /*-- U+0A58 .. U+0A5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , "0"     , "1"     ,  /*-- U+0A60 .. U+0A67 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+0A68 .. U+0A6F --*/
   "N"     , "H"     , ""      , ""      , "G.E.O.", ""      , ""      , ""      ,  /*-- U+0A70 .. U+0A77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0A78 .. U+0A7F --*/
   ""      , "N"     , "N"     , "H"     , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0A80 .. U+0A87 --*/
   "ii"    , "u"     , "uu"    , "R"     , ""      , "eN"    , ""      , "e"     ,  /*-- U+0A88 .. U+0A8F --*/
   "ai"    , "oN"    , ""      , "o"     , "au"    , "k"     , "kh"    , "g"     ,  /*-- U+0A90 .. U+0A97 --*/
   "gh"    , "ng"    , "c"     , "ch"    , "j"     , "jh"    , "ny"    , "tt"    ,  /*-- U+0A98 .. U+0A9F --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "t"     , "th"    , "d"     , "dh"    ,  /*-- U+0AA0 .. U+0AA7 --*/
   "n"     , ""      , "p"     , "ph"    , "b"     , "bh"    , "m"     , "ya"    ,  /*-- U+0AA8 .. U+0AAF --*/
   "r"     , ""      , "l"     , "ll"    , ""      , "v"     , "sh"    , "ss"    ,  /*-- U+0AB0 .. U+0AB7 --*/
   "s"     , "h"     , ""      , ""      , "'"     , "'"     , "aa"    , "i"     ,  /*-- U+0AB8 .. U+0ABF --*/
   "ii"    , "u"     , "uu"    , "R"     , "RR"    , "eN"    , ""      , "e"     ,  /*-- U+0AC0 .. U+0AC7 --*/
   "ai"    , "oN"    , ""      , "o"     , "au"    , ""      , ""      , ""      ,  /*-- U+0AC8 .. U+0ACF --*/
   "AUM"   , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0AD0 .. U+0AD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0AD8 .. U+0ADF --*/
   "RR"    , ""      , ""      , ""      , ""      , ""      , "0"     , "1"     ,  /*-- U+0AE0 .. U+0AE7 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+0AE8 .. U+0AEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0AF0 .. U+0AF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0AF8 .. U+0AFF --*/
   ""      , "N"     , "N"     , "H"     , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0B00 .. U+0B07 --*/
   "ii"    , "u"     , "uu"    , "R"     , "L"     , ""      , ""      , "e"     ,  /*-- U+0B08 .. U+0B0F --*/
   "ai"    , ""      , ""      , "o"     , "au"    , "k"     , "kh"    , "g"     ,  /*-- U+0B10 .. U+0B17 --*/
   "gh"    , "ng"    , "c"     , "ch"    , "j"     , "jh"    , "ny"    , "tt"    ,  /*-- U+0B18 .. U+0B1F --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "t"     , "th"    , "d"     , "dh"    ,  /*-- U+0B20 .. U+0B27 --*/
   "n"     , ""      , "p"     , "ph"    , "b"     , "bh"    , "m"     , "y"     ,  /*-- U+0B28 .. U+0B2F --*/
   "r"     , ""      , "l"     , "ll"    , ""      , ""      , "sh"    , "ss"    ,  /*-- U+0B30 .. U+0B37 --*/
   "s"     , "h"     , ""      , ""      , "'"     , "'"     , "aa"    , "i"     ,  /*-- U+0B38 .. U+0B3F --*/
   "ii"    , "u"     , "uu"    , "R"     , ""      , ""      , ""      , "e"     ,  /*-- U+0B40 .. U+0B47 --*/
   "ai"    , ""      , ""      , "o"     , "au"    , ""      , ""      , ""      ,  /*-- U+0B48 .. U+0B4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , "+"     , "+"     ,  /*-- U+0B50 .. U+0B57 --*/
   ""      , ""      , ""      , ""      , "rr"    , "rh"    , ""      , "yy"    ,  /*-- U+0B58 .. U+0B5F --*/
   "RR"    , "LL"    , ""      , ""      , ""      , ""      , "0"     , "1"     ,  /*-- U+0B60 .. U+0B67 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+0B68 .. U+0B6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0B70 .. U+0B77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0B78 .. U+0B7F --*/
   ""      , ""      , "N"     , "H"     , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0B80 .. U+0B87 --*/
   "ii"    , "u"     , "uu"    , ""      , ""      , ""      , "e"     , "ee"    ,  /*-- U+0B88 .. U+0B8F --*/
   "ai"    , ""      , "o"     , "oo"    , "au"    , "k"     , ""      , ""      ,  /*-- U+0B90 .. U+0B97 --*/
   ""      , "ng"    , "c"     , ""      , "j"     , ""      , "ny"    , "tt"    ,  /*-- U+0B98 .. U+0B9F --*/
   ""      , ""      , ""      , "nn"    , "t"     , ""      , ""      , ""      ,  /*-- U+0BA0 .. U+0BA7 --*/
   "n"     , "nnn"   , "p"     , ""      , ""      , ""      , "m"     , "y"     ,  /*-- U+0BA8 .. U+0BAF --*/
   "r"     , "rr"    , "l"     , "ll"    , "lll"   , "v"     , ""      , "ss"    ,  /*-- U+0BB0 .. U+0BB7 --*/
   "s"     , "h"     , ""      , ""      , ""      , ""      , "aa"    , "i"     ,  /*-- U+0BB8 .. U+0BBF --*/
   "ii"    , "u"     , "uu"    , ""      , ""      , ""      , "e"     , "ee"    ,  /*-- U+0BC0 .. U+0BC7 --*/
   "ai"    , ""      , "o"     , "oo"    , "au"    , ""      , ""      , ""      ,  /*-- U+0BC8 .. U+0BCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , "+"     ,  /*-- U+0BD0 .. U+0BD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0BD8 .. U+0BDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , "0"     , "1"     ,  /*-- U+0BE0 .. U+0BE7 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+0BE8 .. U+0BEF --*/
   "+10+"  , "+100+" , "+1000+", ""      , ""      , ""      , ""      , ""      ,  /*-- U+0BF0 .. U+0BF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0BF8 .. U+0BFF --*/
   ""      , "N"     , "N"     , "H"     , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0C00 .. U+0C07 --*/
   "ii"    , "u"     , "uu"    , "R"     , "L"     , ""      , "e"     , "ee"    ,  /*-- U+0C08 .. U+0C0F --*/
   "ai"    , ""      , "o"     , "oo"    , "au"    , "k"     , "kh"    , "g"     ,  /*-- U+0C10 .. U+0C17 --*/
   "gh"    , "ng"    , "c"     , "ch"    , "j"     , "jh"    , "ny"    , "tt"    ,  /*-- U+0C18 .. U+0C1F --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "t"     , "th"    , "d"     , "dh"    ,  /*-- U+0C20 .. U+0C27 --*/
   "n"     , ""      , "p"     , "ph"    , "b"     , "bh"    , "m"     , "y"     ,  /*-- U+0C28 .. U+0C2F --*/
   "r"     , "rr"    , "l"     , "ll"    , ""      , "v"     , "sh"    , "ss"    ,  /*-- U+0C30 .. U+0C37 --*/
   "s"     , "h"     , ""      , ""      , ""      , ""      , "aa"    , "i"     ,  /*-- U+0C38 .. U+0C3F --*/
   "ii"    , "u"     , "uu"    , "R"     , "RR"    , ""      , "e"     , "ee"    ,  /*-- U+0C40 .. U+0C47 --*/
   "ai"    , ""      , "o"     , "oo"    , "au"    , ""      , ""      , ""      ,  /*-- U+0C48 .. U+0C4F --*/
   ""      , ""      , ""      , ""      , ""      , "+"     , "+"     , ""      ,  /*-- U+0C50 .. U+0C57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0C58 .. U+0C5F --*/
   "RR"    , "LL"    , ""      , ""      , ""      , ""      , "0"     , "1"     ,  /*-- U+0C60 .. U+0C67 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+0C68 .. U+0C6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0C70 .. U+0C77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0C78 .. U+0C7F --*/
   ""      , ""      , "N"     , "H"     , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0C80 .. U+0C87 --*/
   "ii"    , "u"     , "uu"    , "R"     , "L"     , ""      , "e"     , "ee"    ,  /*-- U+0C88 .. U+0C8F --*/
   "ai"    , ""      , "o"     , "oo"    , "au"    , "k"     , "kh"    , "g"     ,  /*-- U+0C90 .. U+0C97 --*/
   "gh"    , "ng"    , "c"     , "ch"    , "j"     , "jh"    , "ny"    , "tt"    ,  /*-- U+0C98 .. U+0C9F --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "t"     , "th"    , "d"     , "dh"    ,  /*-- U+0CA0 .. U+0CA7 --*/
   "n"     , ""      , "p"     , "ph"    , "b"     , "bh"    , "m"     , "y"     ,  /*-- U+0CA8 .. U+0CAF --*/
   "r"     , "rr"    , "l"     , "ll"    , ""      , "v"     , "sh"    , "ss"    ,  /*-- U+0CB0 .. U+0CB7 --*/
   "s"     , "h"     , ""      , ""      , ""      , ""      , "aa"    , "i"     ,  /*-- U+0CB8 .. U+0CBF --*/
   "ii"    , "u"     , "uu"    , "R"     , "RR"    , ""      , "e"     , "ee"    ,  /*-- U+0CC0 .. U+0CC7 --*/
   "ai"    , ""      , "o"     , "oo"    , "au"    , ""      , ""      , ""      ,  /*-- U+0CC8 .. U+0CCF --*/
   ""      , ""      , ""      , ""      , ""      , "+"     , "+"     , ""      ,  /*-- U+0CD0 .. U+0CD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , "lll"   , ""      ,  /*-- U+0CD8 .. U+0CDF --*/
   "RR"    , "LL"    , ""      , ""      , ""      , ""      , "0"     , "1"     ,  /*-- U+0CE0 .. U+0CE7 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+0CE8 .. U+0CEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0CF0 .. U+0CF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0CF8 .. U+0CFF --*/
   ""      , ""      , "N"     , "H"     , ""      , "a"     , "aa"    , "i"     ,  /*-- U+0D00 .. U+0D07 --*/
   "ii"    , "u"     , "uu"    , "R"     , "L"     , ""      , "e"     , "ee"    ,  /*-- U+0D08 .. U+0D0F --*/
   "ai"    , ""      , "o"     , "oo"    , "au"    , "k"     , "kh"    , "g"     ,  /*-- U+0D10 .. U+0D17 --*/
   "gh"    , "ng"    , "c"     , "ch"    , "j"     , "jh"    , "ny"    , "tt"    ,  /*-- U+0D18 .. U+0D1F --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "t"     , "th"    , "d"     , "dh"    ,  /*-- U+0D20 .. U+0D27 --*/
   "n"     , ""      , "p"     , "ph"    , "b"     , "bh"    , "m"     , "y"     ,  /*-- U+0D28 .. U+0D2F --*/
   "r"     , "rr"    , "l"     , "ll"    , "lll"   , "v"     , "sh"    , "ss"    ,  /*-- U+0D30 .. U+0D37 --*/
   "s"     , "h"     , ""      , ""      , ""      , ""      , "aa"    , "i"     ,  /*-- U+0D38 .. U+0D3F --*/
   "ii"    , "u"     , "uu"    , "R"     , ""      , ""      , "e"     , "ee"    ,  /*-- U+0D40 .. U+0D47 --*/
   "ai"    , ""      , "o"     , "oo"    , "au"    , ""      , ""      , ""      ,  /*-- U+0D48 .. U+0D4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , "+"     ,  /*-- U+0D50 .. U+0D57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0D58 .. U+0D5F --*/
   "RR"    , "LL"    , ""      , ""      , ""      , ""      , "0"     , "1"     ,  /*-- U+0D60 .. U+0D67 --*/
   "2"     , "3"     , "4"     , "5"     , "6"     , "7"     , "8"     , "9"     ,  /*-- U+0D68 .. U+0D6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0D70 .. U+0D77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0D78 .. U+0D7F --*/
   ""      , ""      , "N"     , "H"     , ""      , "a"     , "aa"    , "ae"    ,  /*-- U+0D80 .. U+0D87 --*/
   "aae"   , "i"     , "ii"    , "u"     , "uu"    , "R"     , "RR"    , "L"     ,  /*-- U+0D88 .. U+0D8F --*/
   "LL"    , "e"     , "ee"    , "ai"    , "o"     , "oo"    , "au"    , ""      ,  /*-- U+0D90 .. U+0D97 --*/
   ""      , ""      , "k"     , "kh"    , "g"     , "gh"    , "ng"    , "nng"   ,  /*-- U+0D98 .. U+0D9F --*/
   "c"     , "ch"    , "j"     , "jh"    , "ny"    , "jny"   , "nyj"   , "tt"    ,  /*-- U+0DA0 .. U+0DA7 --*/
   "tth"   , "dd"    , "ddh"   , "nn"    , "nndd"  , "t"     , "th"    , "d"     ,  /*-- U+0DA8 .. U+0DAF --*/
   "dh"    , "n"     , ""      , "nd"    , "p"     , "ph"    , "b"     , "bh"    ,  /*-- U+0DB0 .. U+0DB7 --*/
   "m"     , "mb"    , "y"     , "r"     , ""      , "l"     , ""      , ""      ,  /*-- U+0DB8 .. U+0DBF --*/
   "v"     , "sh"    , "ss"    , "s"     , "h"     , "ll"    , "f"     , ""      ,  /*-- U+0DC0 .. U+0DC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , "aa"    ,  /*-- U+0DC8 .. U+0DCF --*/
   "ae"    , "aae"   , "i"     , "ii"    , "u"     , ""      , "uu"    , ""      ,  /*-- U+0DD0 .. U+0DD7 --*/
   "R"     , "e"     , "ee"    , "ai"    , "o"     , "oo"    , "au"    , "L"     ,  /*-- U+0DD8 .. U+0DDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0DE0 .. U+0DE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0DE8 .. U+0DEF --*/
   ""      , ""      , "RR"    , "LL"    , " . "   , ""      , ""      , ""      ,  /*-- U+0DF0 .. U+0DF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0DF8 .. U+0DFF --*/
   ""      , "k"     , "kh"    , "kh"    , "kh"    , "kh"    , "kh"    , "ng"    ,  /*-- U+0E00 .. U+0E07 --*/
   "cch"   , "ch"    , "ch"    , "ch"    , "ch"    , "y"     , "d"     , "t"     ,  /*-- U+0E08 .. U+0E0F --*/
   "th"    , "th"    , "th"    , "n"     , "d"     , "t"     , "th"    , "th"    ,  /*-- U+0E10 .. U+0E17 --*/
   "th"    , "n"     , "b"     , "p"     , "ph"    , "f"     , "ph"    , "f"     ,  /*-- U+0E18 .. U+0E1F --*/
   "ph"    , "m"     , "y"     , "r"     , "R"     , "l"     , "L"     , "w"     ,  /*-- U+0E20 .. U+0E27 --*/
   "s"     , "s"     , "s"     , "h"     , "l"     , "`"     , "h"     , "~"     ,  /*-- U+0E28 .. U+0E2F --*/
   "a"     , "a"     , "aa"    , "am"    , "i"     , "ii"    , "ue"    , "uue"   ,  /*-- U+0E30 .. U+0E37 --*/
   "u"     , "uu"    , "'"     , ""      , ""      , ""      , ""      , "Bh."   ,  /*-- U+0E38 .. U+0E3F --*/
   "e"     , "ae"    , "o"     , "ai"    , "ai"    , "ao"    , "+"     , ""      ,  /*-- U+0E40 .. U+0E47 --*/
   ""      , ""      , ""      , ""      , ""      , "M"     , ""      , " * "   ,  /*-- U+0E48 .. U+0E4F --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+0E50 .. U+0E57 --*/
   "8"     , "9"     , " // "  , " /// " , ""      , ""      , ""      , ""      ,  /*-- U+0E58 .. U+0E5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0E60 .. U+0E67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0E68 .. U+0E6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0E70 .. U+0E77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0E78 .. U+0E7F --*/
   ""      , "k"     , "kh"    , ""      , "kh"    , ""      , ""      , "ng"    ,  /*-- U+0E80 .. U+0E87 --*/
   "ch"    , ""      , "s"     , ""      , ""      , "ny"    , ""      , ""      ,  /*-- U+0E88 .. U+0E8F --*/
   ""      , ""      , ""      , ""      , "d"     , "h"     , "th"    , "th"    ,  /*-- U+0E90 .. U+0E97 --*/
   ""      , "n"     , "b"     , "p"     , "ph"    , "f"     , "ph"    , "f"     ,  /*-- U+0E98 .. U+0E9F --*/
   ""      , "m"     , "y"     , "r"     , ""      , "l"     , ""      , "w"     ,  /*-- U+0EA0 .. U+0EA7 --*/
   ""      , ""      , "s"     , "h"     , ""      , "`"     , ""      , "~"     ,  /*-- U+0EA8 .. U+0EAF --*/
   "a"     , ""      , "aa"    , "am"    , "i"     , "ii"    , "y"     , "yy"    ,  /*-- U+0EB0 .. U+0EB7 --*/
   "u"     , "uu"    , ""      , "o"     , "l"     , "ny"    , ""      , ""      ,  /*-- U+0EB8 .. U+0EBF --*/
   "e"     , "ei"    , "o"     , "ay"    , "ai"    , ""      , "+"     , ""      ,  /*-- U+0EC0 .. U+0EC7 --*/
   ""      , ""      , ""      , ""      , ""      , "M"     , ""      , ""      ,  /*-- U+0EC8 .. U+0ECF --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+0ED0 .. U+0ED7 --*/
   "8"     , "9"     , ""      , ""      , "hn"    , "hm"    , ""      , ""      ,  /*-- U+0ED8 .. U+0EDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0EE0 .. U+0EE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0EE8 .. U+0EEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0EF0 .. U+0EF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0EF8 .. U+0EFF --*/
   "AUM"   , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0F00 .. U+0F07 --*/
   " // "  , " * "   , ""      , "-"     , " / "   , " / "   , " // "  , " -/ "  ,  /*-- U+0F08 .. U+0F0F --*/
   " +/ "  , " X/ "  , " /XX/ ", " /X/ " , ", "    , ""      , ""      , ""      ,  /*-- U+0F10 .. U+0F17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0F18 .. U+0F1F --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+0F20 .. U+0F27 --*/
   "8"     , "9"     , ".5"    , "1.5"   , "2.5"   , "3.5"   , "4.5"   , "5.5"   ,  /*-- U+0F28 .. U+0F2F --*/
   "6.5"   , "7.5"   , "8.5"   , "-.5"   , "+"     , "*"     , "^"     , "_"     ,  /*-- U+0F30 .. U+0F37 --*/
   ""      , "~"     , ""      , "]"     , "[["    , "]]"    , ""      , ""      ,  /*-- U+0F38 .. U+0F3F --*/
   "k"     , "kh"    , "g"     , "gh"    , "ng"    , "c"     , "ch"    , "j"     ,  /*-- U+0F40 .. U+0F47 --*/
   ""      , "ny"    , "tt"    , "tth"   , "dd"    , "ddh"   , "nn"    , "t"     ,  /*-- U+0F48 .. U+0F4F --*/
   "th"    , "d"     , "dh"    , "n"     , "p"     , "ph"    , "b"     , "bh"    ,  /*-- U+0F50 .. U+0F57 --*/
   "m"     , "ts"    , "tsh"   , "dz"    , "dzh"   , "w"     , "zh"    , "z"     ,  /*-- U+0F58 .. U+0F5F --*/
   "'"     , "y"     , "r"     , "l"     , "sh"    , "ssh"   , "s"     , "h"     ,  /*-- U+0F60 .. U+0F67 --*/
   "a"     , "kss"   , "r"     , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0F68 .. U+0F6F --*/
   ""      , "aa"    , "i"     , "ii"    , "u"     , "uu"    , "R"     , "RR"    ,  /*-- U+0F70 .. U+0F77 --*/
   "L"     , "LL"    , "e"     , "ee"    , "o"     , "oo"    , "M"     , "H"     ,  /*-- U+0F78 .. U+0F7F --*/
   "i"     , "ii"    , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0F80 .. U+0F87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0F88 .. U+0F8F --*/
   "k"     , "kh"    , "g"     , "gh"    , "ng"    , "c"     , "ch"    , "j"     ,  /*-- U+0F90 .. U+0F97 --*/
   ""      , "ny"    , "tt"    , "tth"   , "dd"    , "ddh"   , "nn"    , "t"     ,  /*-- U+0F98 .. U+0F9F --*/
   "th"    , "d"     , "dh"    , "n"     , "p"     , "ph"    , "b"     , "bh"    ,  /*-- U+0FA0 .. U+0FA7 --*/
   "m"     , "ts"    , "tsh"   , "dz"    , "dzh"   , "w"     , "zh"    , "z"     ,  /*-- U+0FA8 .. U+0FAF --*/
   "'"     , "y"     , "r"     , "l"     , "sh"    , "ss"    , "s"     , "h"     ,  /*-- U+0FB0 .. U+0FB7 --*/
   "a"     , "kss"   , "w"     , "y"     , "r"     , ""      , "X"     , " :X: " ,  /*-- U+0FB8 .. U+0FBF --*/
   " /O/ " , " /o/ " , " \\o\\ ", " (O) " , ""      , ""      , ""      , ""      ,  /*-- U+0FC0 .. U+0FC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0FC8 .. U+0FCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0FD0 .. U+0FD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0FD8 .. U+0FDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0FE0 .. U+0FE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0FE8 .. U+0FEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0FF0 .. U+0FF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+0FF8 .. U+0FFF --*/
   "k"     , "kh"    , "g"     , "gh"    , "ng"    , "c"     , "ch"    , "j"     ,  /*-- U+1000 .. U+1007 --*/
   "jh"    , "ny"    , "nny"   , "tt"    , "tth"   , "dd"    , "ddh"   , "nn"    ,  /*-- U+1008 .. U+100F --*/
   "tt"    , "th"    , "d"     , "dh"    , "n"     , "p"     , "ph"    , "b"     ,  /*-- U+1010 .. U+1017 --*/
   "bh"    , "m"     , "y"     , "r"     , "l"     , "w"     , "s"     , "h"     ,  /*-- U+1018 .. U+101F --*/
   "ll"    , "a"     , ""      , "i"     , "ii"    , "u"     , "uu"    , "e"     ,  /*-- U+1020 .. U+1027 --*/
   ""      , "o"     , "au"    , ""      , "aa"    , "i"     , "ii"    , "u"     ,  /*-- U+1028 .. U+102F --*/
   "uu"    , "e"     , "ai"    , ""      , ""      , ""      , "N"     , "'"     ,  /*-- U+1030 .. U+1037 --*/
   ":"     , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1038 .. U+103F --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+1040 .. U+1047 --*/
   "8"     , "9"     , " / "   , " // "  , "n*"    , "r*"    , "l*"    , "e*"    ,  /*-- U+1048 .. U+104F --*/
   "sh"    , "ss"    , "R"     , "RR"    , "L"     , "LL"    , "R"     , "RR"    ,  /*-- U+1050 .. U+1057 --*/
   "L"     , "LL"    , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1058 .. U+105F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1060 .. U+1067 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1068 .. U+106F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1070 .. U+1077 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1078 .. U+107F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1080 .. U+1087 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1088 .. U+108F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1090 .. U+1097 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1098 .. U+109F --*/
   "A"     , "B"     , "G"     , "D"     , "E"     , "V"     , "Z"     , "T`"    ,  /*-- U+10A0 .. U+10A7 --*/
   "I"     , "K"     , "L"     , "M"     , "N"     , "O"     , "P"     , "Zh"    ,  /*-- U+10A8 .. U+10AF --*/
   "R"     , "S"     , "T"     , "U"     , "P`"    , "K`"    , "G'"    , "Q"     ,  /*-- U+10B0 .. U+10B7 --*/
   "Sh"    , "Ch`"   , "C`"    , "Z'"    , "C"     , "Ch"    , "X"     , "J"     ,  /*-- U+10B8 .. U+10BF --*/
   "H"     , "E"     , "Y"     , "W"     , "Xh"    , "OE"    , ""      , ""      ,  /*-- U+10C0 .. U+10C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+10C8 .. U+10CF --*/
   "a"     , "b"     , "g"     , "d"     , "e"     , "v"     , "z"     , "t`"    ,  /*-- U+10D0 .. U+10D7 --*/
   "i"     , "k"     , "l"     , "m"     , "n"     , "o"     , "p"     , "zh"    ,  /*-- U+10D8 .. U+10DF --*/
   "r"     , "s"     , "t"     , "u"     , "p`"    , "k`"    , "g'"    , "q"     ,  /*-- U+10E0 .. U+10E7 --*/
   "sh"    , "ch`"   , "c`"    , "z'"    , "c"     , "ch"    , "x"     , "j"     ,  /*-- U+10E8 .. U+10EF --*/
   "h"     , "e"     , "y"     , "w"     , "xh"    , "oe"    , "f"     , ""      ,  /*-- U+10F0 .. U+10F7 --*/
   ""      , ""      , ""      , " // "  , ""      , ""      , ""      , ""      ,  /*-- U+10F8 .. U+10FF --*/
   "g"     , "gg"    , "n"     , "d"     , "dd"    , "r"     , "m"     , "b"     ,  /*-- U+1100 .. U+1107 --*/
   "bb"    , "s"     , "ss"    , ""      , "j"     , "jj"    , "c"     , "k"     ,  /*-- U+1108 .. U+110F --*/
   "t"     , "p"     , "h"     , "ng"    , "nn"    , "nd"    , "nb"    , "dg"    ,  /*-- U+1110 .. U+1117 --*/
   "rn"    , "rr"    , "rh"    , "rN"    , "mb"    , "mN"    , "bg"    , "bn"    ,  /*-- U+1118 .. U+111F --*/
   ""      , "bs"    , "bsg"   , "bst"   , "bsb"   , "bss"   , "bsj"   , "bj"    ,  /*-- U+1120 .. U+1127 --*/
   "bc"    , "bt"    , "bp"    , "bN"    , "bbN"   , "sg"    , "sn"    , "sd"    ,  /*-- U+1128 .. U+112F --*/
   "sr"    , "sm"    , "sb"    , "sbg"   , "sss"   , "s"     , "sj"    , "sc"    ,  /*-- U+1130 .. U+1137 --*/
   "sk"    , "st"    , "sp"    , "sh"    , ""      , ""      , ""      , ""      ,  /*-- U+1138 .. U+113F --*/
   "Z"     , "g"     , "d"     , "m"     , "b"     , "s"     , "Z"     , ""      ,  /*-- U+1140 .. U+1147 --*/
   "j"     , "c"     , "t"     , "p"     , "N"     , "j"     , ""      , ""      ,  /*-- U+1148 .. U+114F --*/
   ""      , ""      , "ck"    , "ch"    , ""      , ""      , "pb"    , "pN"    ,  /*-- U+1150 .. U+1157 --*/
   "hh"    , "Q"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1158 .. U+115F --*/
   ""      , "a"     , "ae"    , "ya"    , "yae"   , "eo"    , "e"     , "yeo"   ,  /*-- U+1160 .. U+1167 --*/
   "ye"    , "o"     , "wa"    , "wae"   , "oe"    , "yo"    , "u"     , "weo"   ,  /*-- U+1168 .. U+116F --*/
   "we"    , "wi"    , "yu"    , "eu"    , "yi"    , "i"     , "a-o"   , "a-u"   ,  /*-- U+1170 .. U+1177 --*/
   "ya-o"  , "ya-yo" , "eo-o"  , "eo-u"  , "eo-eu" , "yeo-o" , "yeo-u" , "o-eo"  ,  /*-- U+1178 .. U+117F --*/
   "o-e"   , "o-ye"  , "o-o"   , "o-u"   , "yo-ya" , "yo-yae", "yo-yeo", "yo-o"  ,  /*-- U+1180 .. U+1187 --*/
   "yo-i"  , "u-a"   , "u-ae"  , "u-eo-eu", "u-ye"  , "u-u"   , "yu-a"  , "yu-eo" ,  /*-- U+1188 .. U+118F --*/
   "yu-e"  , "yu-yeo", "yu-ye" , "yu-u"  , "yu-i"  , "eu-u"  , "eu-eu" , "yi-u"  ,  /*-- U+1190 .. U+1197 --*/
   "i-a"   , "i-ya"  , "i-o"   , "i-u"   , "i-eu"  , "i-U"   , "U"     , "U-eo"  ,  /*-- U+1198 .. U+119F --*/
   "U-u"   , "U-i"   , "UU"    , ""      , ""      , ""      , ""      , ""      ,  /*-- U+11A0 .. U+11A7 --*/
   "g"     , "gg"    , "gs"    , "n"     , "nj"    , "nh"    , "d"     , "l"     ,  /*-- U+11A8 .. U+11AF --*/
   "lg"    , "lm"    , "lb"    , "ls"    , "lt"    , "lp"    , "lh"    , "m"     ,  /*-- U+11B0 .. U+11B7 --*/
   "b"     , "bs"    , "s"     , "ss"    , "ng"    , "j"     , "c"     , "k"     ,  /*-- U+11B8 .. U+11BF --*/
   "t"     , "p"     , "h"     , "gl"    , "gsg"   , "ng"    , "nd"    , "ns"    ,  /*-- U+11C0 .. U+11C7 --*/
   "nZ"    , "nt"    , "dg"    , "tl"    , "lgs"   , "ln"    , "ld"    , "lth"   ,  /*-- U+11C8 .. U+11CF --*/
   "ll"    , "lmg"   , "lms"   , "lbs"   , "lbh"   , "rNp"   , "lss"   , "lZ"    ,  /*-- U+11D0 .. U+11D7 --*/
   "lk"    , "lQ"    , "mg"    , "ml"    , "mb"    , "ms"    , "mss"   , "mZ"    ,  /*-- U+11D8 .. U+11DF --*/
   "mc"    , "mh"    , "mN"    , "bl"    , "bp"    , "ph"    , "pN"    , "sg"    ,  /*-- U+11E0 .. U+11E7 --*/
   "sd"    , "sl"    , "sb"    , "Z"     , "g"     , "ss"    , ""      , "kh"    ,  /*-- U+11E8 .. U+11EF --*/
   "N"     , "Ns"    , "NZ"    , "pb"    , "pN"    , "hn"    , "hl"    , "hm"    ,  /*-- U+11F0 .. U+11F7 --*/
   "hb"    , "Q"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+11F8 .. U+11FF --*/
   "ha"    , "hu"    , "hi"    , "haa"   , "hee"   , "he"    , "ho"    , ""      ,  /*-- U+1200 .. U+1207 --*/
   "la"    , "lu"    , "li"    , "laa"   , "lee"   , "le"    , "lo"    , "lwa"   ,  /*-- U+1208 .. U+120F --*/
   "hha"   , "hhu"   , "hhi"   , "hhaa"  , "hhee"  , "hhe"   , "hho"   , "hhwa"  ,  /*-- U+1210 .. U+1217 --*/
   "ma"    , "mu"    , "mi"    , "maa"   , "mee"   , "me"    , "mo"    , "mwa"   ,  /*-- U+1218 .. U+121F --*/
   "sza"   , "szu"   , "szi"   , "szaa"  , "szee"  , "sze"   , "szo"   , "szwa"  ,  /*-- U+1220 .. U+1227 --*/
   "ra"    , "ru"    , "ri"    , "raa"   , "ree"   , "re"    , "ro"    , "rwa"   ,  /*-- U+1228 .. U+122F --*/
   "sa"    , "su"    , "si"    , "saa"   , "see"   , "se"    , "so"    , "swa"   ,  /*-- U+1230 .. U+1237 --*/
   "sha"   , "shu"   , "shi"   , "shaa"  , "shee"  , "she"   , "sho"   , "shwa"  ,  /*-- U+1238 .. U+123F --*/
   "qa"    , "qu"    , "qi"    , "qaa"   , "qee"   , "qe"    , "qo"    , ""      ,  /*-- U+1240 .. U+1247 --*/
   "qwa"   , ""      , "qwi"   , "qwaa"  , "qwee"  , "qwe"   , ""      , ""      ,  /*-- U+1248 .. U+124F --*/
   "qha"   , "qhu"   , "qhi"   , "qhaa"  , "qhee"  , "qhe"   , "qho"   , ""      ,  /*-- U+1250 .. U+1257 --*/
   "qhwa"  , ""      , "qhwi"  , "qhwaa" , "qhwee" , "qhwe"  , ""      , ""      ,  /*-- U+1258 .. U+125F --*/
   "ba"    , "bu"    , "bi"    , "baa"   , "bee"   , "be"    , "bo"    , "bwa"   ,  /*-- U+1260 .. U+1267 --*/
   "va"    , "vu"    , "vi"    , "vaa"   , "vee"   , "ve"    , "vo"    , "vwa"   ,  /*-- U+1268 .. U+126F --*/
   "ta"    , "tu"    , "ti"    , "taa"   , "tee"   , "te"    , "to"    , "twa"   ,  /*-- U+1270 .. U+1277 --*/
   "ca"    , "cu"    , "ci"    , "caa"   , "cee"   , "ce"    , "co"    , "cwa"   ,  /*-- U+1278 .. U+127F --*/
   "xa"    , "xu"    , "xi"    , "xaa"   , "xee"   , "xe"    , "xo"    , ""      ,  /*-- U+1280 .. U+1287 --*/
   "xwa"   , ""      , "xwi"   , "xwaa"  , "xwee"  , "xwe"   , ""      , ""      ,  /*-- U+1288 .. U+128F --*/
   "na"    , "nu"    , "ni"    , "naa"   , "nee"   , "ne"    , "no"    , "nwa"   ,  /*-- U+1290 .. U+1297 --*/
   "nya"   , "nyu"   , "nyi"   , "nyaa"  , "nyee"  , "nye"   , "nyo"   , "nywa"  ,  /*-- U+1298 .. U+129F --*/
   "'a"    , "'u"    , ""      , "'aa"   , "'ee"   , "'e"    , "'o"    , "'wa"   ,  /*-- U+12A0 .. U+12A7 --*/
   "ka"    , "ku"    , "ki"    , "kaa"   , "kee"   , "ke"    , "ko"    , ""      ,  /*-- U+12A8 .. U+12AF --*/
   "kwa"   , ""      , "kwi"   , "kwaa"  , "kwee"  , "kwe"   , ""      , ""      ,  /*-- U+12B0 .. U+12B7 --*/
   "kxa"   , "kxu"   , "kxi"   , "kxaa"  , "kxee"  , "kxe"   , "kxo"   , ""      ,  /*-- U+12B8 .. U+12BF --*/
   "kxwa"  , ""      , "kxwi"  , "kxwaa" , "kxwee" , "kxwe"  , ""      , ""      ,  /*-- U+12C0 .. U+12C7 --*/
   "wa"    , "wu"    , "wi"    , "waa"   , "wee"   , "we"    , "wo"    , ""      ,  /*-- U+12C8 .. U+12CF --*/
   "`a"    , "`u"    , "`i"    , "`aa"   , "`ee"   , "`e"    , "`o"    , ""      ,  /*-- U+12D0 .. U+12D7 --*/
   "za"    , "zu"    , "zi"    , "zaa"   , "zee"   , "ze"    , "zo"    , "zwa"   ,  /*-- U+12D8 .. U+12DF --*/
   "zha"   , "zhu"   , "zhi"   , "zhaa"  , "zhee"  , "zhe"   , "zho"   , "zhwa"  ,  /*-- U+12E0 .. U+12E7 --*/
   "ya"    , "yu"    , "yi"    , "yaa"   , "yee"   , "ye"    , "yo"    , ""      ,  /*-- U+12E8 .. U+12EF --*/
   "da"    , "du"    , "di"    , "daa"   , "dee"   , "de"    , "do"    , "dwa"   ,  /*-- U+12F0 .. U+12F7 --*/
   "dda"   , "ddu"   , "ddi"   , "ddaa"  , "ddee"  , "dde"   , "ddo"   , "ddwa"  ,  /*-- U+12F8 .. U+12FF --*/
   "ja"    , "ju"    , "ji"    , "jaa"   , "jee"   , "je"    , "jo"    , "jwa"   ,  /*-- U+1300 .. U+1307 --*/
   "ga"    , "gu"    , "gi"    , "gaa"   , "gee"   , "ge"    , "go"    , ""      ,  /*-- U+1308 .. U+130F --*/
   "gwa"   , ""      , "gwi"   , "gwaa"  , "gwee"  , "gwe"   , ""      , ""      ,  /*-- U+1310 .. U+1317 --*/
   "gga"   , "ggu"   , "ggi"   , "ggaa"  , "ggee"  , "gge"   , "ggo"   , ""      ,  /*-- U+1318 .. U+131F --*/
   "tha"   , "thu"   , "thi"   , "thaa"  , "thee"  , "the"   , "tho"   , "thwa"  ,  /*-- U+1320 .. U+1327 --*/
   "cha"   , "chu"   , "chi"   , "chaa"  , "chee"  , "che"   , "cho"   , "chwa"  ,  /*-- U+1328 .. U+132F --*/
   "pha"   , "phu"   , "phi"   , "phaa"  , "phee"  , "phe"   , "pho"   , "phwa"  ,  /*-- U+1330 .. U+1337 --*/
   "tsa"   , "tsu"   , "tsi"   , "tsaa"  , "tsee"  , "tse"   , "tso"   , "tswa"  ,  /*-- U+1338 .. U+133F --*/
   "tza"   , "tzu"   , "tzi"   , "tzaa"  , "tzee"  , "tze"   , "tzo"   , ""      ,  /*-- U+1340 .. U+1347 --*/
   "fa"    , "fu"    , "fi"    , "faa"   , "fee"   , "fe"    , "fo"    , "fwa"   ,  /*-- U+1348 .. U+134F --*/
   "pa"    , "pu"    , "pi"    , "paa"   , "pee"   , "pe"    , "po"    , "pwa"   ,  /*-- U+1350 .. U+1357 --*/
   "rya"   , "mya"   , "fya"   , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1358 .. U+135F --*/
   ""      , " "     , "."     , ","     , ";"     , ":"     , ":: "   , "?"     ,  /*-- U+1360 .. U+1367 --*/
   "//"    , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+1368 .. U+136F --*/
   "8"     , "9"     , "10+"   , "20+"   , "30+"   , "40+"   , "50+"   , "60+"   ,  /*-- U+1370 .. U+1377 --*/
   "70+"   , "80+"   , "90+"   , "100+"  , "10,000+", ""      , ""      , ""      ,  /*-- U+1378 .. U+137F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1380 .. U+1387 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1388 .. U+138F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1390 .. U+1397 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1398 .. U+139F --*/
   "a"     , "e"     , "i"     , "o"     , "u"     , "v"     , "ga"    , "ka"    ,  /*-- U+13A0 .. U+13A7 --*/
   "ge"    , "gi"    , "go"    , "gu"    , "gv"    , "ha"    , "he"    , "hi"    ,  /*-- U+13A8 .. U+13AF --*/
   "ho"    , "hu"    , "hv"    , "la"    , "le"    , "li"    , "lo"    , "lu"    ,  /*-- U+13B0 .. U+13B7 --*/
   "lv"    , "ma"    , "me"    , "mi"    , "mo"    , "mu"    , "na"    , "hna"   ,  /*-- U+13B8 .. U+13BF --*/
   "nah"   , "ne"    , "ni"    , "no"    , "nu"    , "nv"    , "qua"   , "que"   ,  /*-- U+13C0 .. U+13C7 --*/
   "qui"   , "quo"   , "quu"   , "quv"   , "sa"    , "s"     , "se"    , "si"    ,  /*-- U+13C8 .. U+13CF --*/
   "so"    , "su"    , "sv"    , "da"    , "ta"    , "de"    , "te"    , "di"    ,  /*-- U+13D0 .. U+13D7 --*/
   "ti"    , "do"    , "du"    , "dv"    , "dla"   , "tla"   , "tle"   , "tli"   ,  /*-- U+13D8 .. U+13DF --*/
   "tlo"   , "tlu"   , "tlv"   , "tsa"   , "tse"   , "tsi"   , "tso"   , "tsu"   ,  /*-- U+13E0 .. U+13E7 --*/
   "tsv"   , "wa"    , "we"    , "wi"    , "wo"    , "wu"    , "wv"    , "ya"    ,  /*-- U+13E8 .. U+13EF --*/
   "ye"    , "yi"    , "yo"    , "yu"    , "yv"    , ""      , ""      , ""      ,  /*-- U+13F0 .. U+13F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+13F8 .. U+13FF --*/
   ""      , "e"     , "aai"   , "i"     , "ii"    , "o"     , "oo"    , "oo"    ,  /*-- U+1400 .. U+1407 --*/
   "ee"    , "i"     , "a"     , "aa"    , "we"    , "we"    , "wi"    , "wi"    ,  /*-- U+1408 .. U+140F --*/
   "wii"   , "wii"   , "wo"    , "wo"    , "woo"   , "woo"   , "woo"   , "wa"    ,  /*-- U+1410 .. U+1417 --*/
   "wa"    , "waa"   , "waa"   , "waa"   , "ai"    , "w"     , "'"     , "t"     ,  /*-- U+1418 .. U+141F --*/
   "k"     , "sh"    , "s"     , "n"     , "w"     , "n"     , ""      , "w"     ,  /*-- U+1420 .. U+1427 --*/
   "c"     , "?"     , "l"     , "en"    , "in"    , "on"    , "an"    , "pe"    ,  /*-- U+1428 .. U+142F --*/
   "paai"  , "pi"    , "pii"   , "po"    , "poo"   , "poo"   , "hee"   , "hi"    ,  /*-- U+1430 .. U+1437 --*/
   "pa"    , "paa"   , "pwe"   , "pwe"   , "pwi"   , "pwi"   , "pwii"  , "pwii"  ,  /*-- U+1438 .. U+143F --*/
   "pwo"   , "pwo"   , "pwoo"  , "pwoo"  , "pwa"   , "pwa"   , "pwaa"  , "pwaa"  ,  /*-- U+1440 .. U+1447 --*/
   "pwaa"  , "p"     , "p"     , "h"     , "te"    , "taai"  , "ti"    , "tii"   ,  /*-- U+1448 .. U+144F --*/
   "to"    , "too"   , "too"   , "dee"   , "di"    , "ta"    , "taa"   , "twe"   ,  /*-- U+1450 .. U+1457 --*/
   "twe"   , "twi"   , "twi"   , "twii"  , "twii"  , "two"   , "two"   , "twoo"  ,  /*-- U+1458 .. U+145F --*/
   "twoo"  , "twa"   , "twa"   , "twaa"  , "twaa"  , "twaa"  , "t"     , "tte"   ,  /*-- U+1460 .. U+1467 --*/
   "tti"   , "tto"   , "tta"   , "ke"    , "kaai"  , "ki"    , "kii"   , "ko"    ,  /*-- U+1468 .. U+146F --*/
   "koo"   , "koo"   , "ka"    , "kaa"   , "kwe"   , "kwe"   , "kwi"   , "kwi"   ,  /*-- U+1470 .. U+1477 --*/
   "kwii"  , "kwii"  , "kwo"   , "kwo"   , "kwoo"  , "kwoo"  , "kwa"   , "kwa"   ,  /*-- U+1478 .. U+147F --*/
   "kwaa"  , "kwaa"  , "kwaa"  , "k"     , "kw"    , "keh"   , "kih"   , "koh"   ,  /*-- U+1480 .. U+1487 --*/
   "kah"   , "ce"    , "caai"  , "ci"    , "cii"   , "co"    , "coo"   , "coo"   ,  /*-- U+1488 .. U+148F --*/
   "ca"    , "caa"   , "cwe"   , "cwe"   , "cwi"   , "cwi"   , "cwii"  , "cwii"  ,  /*-- U+1490 .. U+1497 --*/
   "cwo"   , "cwo"   , "cwoo"  , "cwoo"  , "cwa"   , "cwa"   , "cwaa"  , "cwaa"  ,  /*-- U+1498 .. U+149F --*/
   "cwaa"  , "c"     , "th"    , "me"    , "maai"  , "mi"    , "mii"   , "mo"    ,  /*-- U+14A0 .. U+14A7 --*/
   "moo"   , "moo"   , "ma"    , "maa"   , "mwe"   , "mwe"   , "mwi"   , "mwi"   ,  /*-- U+14A8 .. U+14AF --*/
   "mwii"  , "mwii"  , "mwo"   , "mwo"   , "mwoo"  , "mwoo"  , "mwa"   , "mwa"   ,  /*-- U+14B0 .. U+14B7 --*/
   "mwaa"  , "mwaa"  , "mwaa"  , "m"     , "m"     , "mh"    , "m"     , "m"     ,  /*-- U+14B8 .. U+14BF --*/
   "ne"    , "naai"  , "ni"    , "nii"   , "no"    , "noo"   , "noo"   , "na"    ,  /*-- U+14C0 .. U+14C7 --*/
   "naa"   , "nwe"   , "nwe"   , "nwa"   , "nwa"   , "nwaa"  , "nwaa"  , "nwaa"  ,  /*-- U+14C8 .. U+14CF --*/
   "n"     , "ng"    , "nh"    , "le"    , "laai"  , "li"    , "lii"   , "lo"    ,  /*-- U+14D0 .. U+14D7 --*/
   "loo"   , "loo"   , "la"    , "laa"   , "lwe"   , "lwe"   , "lwi"   , "lwi"   ,  /*-- U+14D8 .. U+14DF --*/
   "lwii"  , "lwii"  , "lwo"   , "lwo"   , "lwoo"  , "lwoo"  , "lwa"   , "lwa"   ,  /*-- U+14E0 .. U+14E7 --*/
   "lwaa"  , "lwaa"  , "l"     , "l"     , "l"     , "se"    , "saai"  , "si"    ,  /*-- U+14E8 .. U+14EF --*/
   "sii"   , "so"    , "soo"   , "soo"   , "sa"    , "saa"   , "swe"   , "swe"   ,  /*-- U+14F0 .. U+14F7 --*/
   "swi"   , "swi"   , "swii"  , "swii"  , "swo"   , "swo"   , "swoo"  , "swoo"  ,  /*-- U+14F8 .. U+14FF --*/
   "swa"   , "swa"   , "swaa"  , "swaa"  , "swaa"  , "s"     , "s"     , "sw"    ,  /*-- U+1500 .. U+1507 --*/
   "s"     , "sk"    , "skw"   , "sW"    , "spwa"  , "stwa"  , "skwa"  , "scwa"  ,  /*-- U+1508 .. U+150F --*/
   "she"   , "shi"   , "shii"  , "sho"   , "shoo"  , "sha"   , "shaa"  , "shwe"  ,  /*-- U+1510 .. U+1517 --*/
   "shwe"  , "shwi"  , "shwi"  , "shwii" , "shwii" , "shwo"  , "shwo"  , "shwoo" ,  /*-- U+1518 .. U+151F --*/
   "shwoo" , "shwa"  , "shwa"  , "shwaa" , "shwaa" , "sh"    , "ye"    , "yaai"  ,  /*-- U+1520 .. U+1527 --*/
   "yi"    , "yii"   , "yo"    , "yoo"   , "yoo"   , "ya"    , "yaa"   , "ywe"   ,  /*-- U+1528 .. U+152F --*/
   "ywe"   , "ywi"   , "ywi"   , "ywii"  , "ywii"  , "ywo"   , "ywo"   , "ywoo"  ,  /*-- U+1530 .. U+1537 --*/
   "ywoo"  , "ywa"   , "ywa"   , "ywaa"  , "ywaa"  , "ywaa"  , "y"     , "y"     ,  /*-- U+1538 .. U+153F --*/
   "y"     , "yi"    , "re"    , "re"    , "le"    , "raai"  , "ri"    , "rii"   ,  /*-- U+1540 .. U+1547 --*/
   "ro"    , "roo"   , "lo"    , "ra"    , "raa"   , "la"    , "rwaa"  , "rwaa"  ,  /*-- U+1548 .. U+154F --*/
   "r"     , "r"     , "r"     , "fe"    , "faai"  , "fi"    , "fii"   , "fo"    ,  /*-- U+1550 .. U+1557 --*/
   "foo"   , "fa"    , "faa"   , "fwaa"  , "fwaa"  , "f"     , "the"   , "the"   ,  /*-- U+1558 .. U+155F --*/
   "thi"   , "thi"   , "thii"  , "thii"  , "tho"   , "thoo"  , "tha"   , "thaa"  ,  /*-- U+1560 .. U+1567 --*/
   "thwaa" , "thwaa" , "th"    , "tthe"  , "tthi"  , "ttho"  , "ttha"  , "tth"   ,  /*-- U+1568 .. U+156F --*/
   "tye"   , "tyi"   , "tyo"   , "tya"   , "he"    , "hi"    , "hii"   , "ho"    ,  /*-- U+1570 .. U+1577 --*/
   "hoo"   , "ha"    , "haa"   , "h"     , "h"     , "hk"    , "qaai"  , "qi"    ,  /*-- U+1578 .. U+157F --*/
   "qii"   , "qo"    , "qoo"   , "qa"    , "qaa"   , "q"     , "tlhe"  , "tlhi"  ,  /*-- U+1580 .. U+1587 --*/
   "tlho"  , "tlha"  , "re"    , "ri"    , "ro"    , "ra"    , "ngaai" , "ngi"   ,  /*-- U+1588 .. U+158F --*/
   "ngii"  , "ngo"   , "ngoo"  , "nga"   , "ngaa"  , "ng"    , "nng"   , "she"   ,  /*-- U+1590 .. U+1597 --*/
   "shi"   , "sho"   , "sha"   , "the"   , "thi"   , "tho"   , "tha"   , "th"    ,  /*-- U+1598 .. U+159F --*/
   "lhi"   , "lhii"  , "lho"   , "lhoo"  , "lha"   , "lhaa"  , "lh"    , "the"   ,  /*-- U+15A0 .. U+15A7 --*/
   "thi"   , "thii"  , "tho"   , "thoo"  , "tha"   , "thaa"  , "th"    , "b"     ,  /*-- U+15A8 .. U+15AF --*/
   "e"     , "i"     , "o"     , "a"     , "we"    , "wi"    , "wo"    , "wa"    ,  /*-- U+15B0 .. U+15B7 --*/
   "ne"    , "ni"    , "no"    , "na"    , "ke"    , "ki"    , "ko"    , "ka"    ,  /*-- U+15B8 .. U+15BF --*/
   "he"    , "hi"    , "ho"    , "ha"    , "ghu"   , "gho"   , "ghe"   , "ghee"  ,  /*-- U+15C0 .. U+15C7 --*/
   "ghi"   , "gha"   , "ru"    , "ro"    , "re"    , "ree"   , "ri"    , "ra"    ,  /*-- U+15C8 .. U+15CF --*/
   "wu"    , "wo"    , "we"    , "wee"   , "wi"    , "wa"    , "hwu"   , "hwo"   ,  /*-- U+15D0 .. U+15D7 --*/
   "hwe"   , "hwee"  , "hwi"   , "hwa"   , "thu"   , "tho"   , "the"   , "thee"  ,  /*-- U+15D8 .. U+15DF --*/
   "thi"   , "tha"   , "ttu"   , "tto"   , "tte"   , "ttee"  , "tti"   , "tta"   ,  /*-- U+15E0 .. U+15E7 --*/
   "pu"    , "po"    , "pe"    , "pee"   , "pi"    , "pa"    , "p"     , "gu"    ,  /*-- U+15E8 .. U+15EF --*/
   "go"    , "ge"    , "gee"   , "gi"    , "ga"    , "khu"   , "kho"   , "khe"   ,  /*-- U+15F0 .. U+15F7 --*/
   "khee"  , "khi"   , "kha"   , "kku"   , "kko"   , "kke"   , "kkee"  , "kki"   ,  /*-- U+15F8 .. U+15FF --*/
   "kka"   , "kk"    , "nu"    , "no"    , "ne"    , "nee"   , "ni"    , "na"    ,  /*-- U+1600 .. U+1607 --*/
   "mu"    , "mo"    , "me"    , "mee"   , "mi"    , "ma"    , "yu"    , "yo"    ,  /*-- U+1608 .. U+160F --*/
   "ye"    , "yee"   , "yi"    , "ya"    , "ju"    , "ju"    , "jo"    , "je"    ,  /*-- U+1610 .. U+1617 --*/
   "jee"   , "ji"    , "ji"    , "ja"    , "jju"   , "jjo"   , "jje"   , "jjee"  ,  /*-- U+1618 .. U+161F --*/
   "jji"   , "jja"   , "lu"    , "lo"    , "le"    , "lee"   , "li"    , "la"    ,  /*-- U+1620 .. U+1627 --*/
   "dlu"   , "dlo"   , "dle"   , "dlee"  , "dli"   , "dla"   , "lhu"   , "lho"   ,  /*-- U+1628 .. U+162F --*/
   "lhe"   , "lhee"  , "lhi"   , "lha"   , "tlhu"  , "tlho"  , "tlhe"  , "tlhee" ,  /*-- U+1630 .. U+1637 --*/
   "tlhi"  , "tlha"  , "tlu"   , "tlo"   , "tle"   , "tlee"  , "tli"   , "tla"   ,  /*-- U+1638 .. U+163F --*/
   "zu"    , "zo"    , "ze"    , "zee"   , "zi"    , "za"    , "z"     , "z"     ,  /*-- U+1640 .. U+1647 --*/
   "dzu"   , "dzo"   , "dze"   , "dzee"  , "dzi"   , "dza"   , "su"    , "so"    ,  /*-- U+1648 .. U+164F --*/
   "se"    , "see"   , "si"    , "sa"    , "shu"   , "sho"   , "she"   , "shee"  ,  /*-- U+1650 .. U+1657 --*/
   "shi"   , "sha"   , "sh"    , "tsu"   , "tso"   , "tse"   , "tsee"  , "tsi"   ,  /*-- U+1658 .. U+165F --*/
   "tsa"   , "chu"   , "cho"   , "che"   , "chee"  , "chi"   , "cha"   , "ttsu"  ,  /*-- U+1660 .. U+1667 --*/
   "ttso"  , "ttse"  , "ttsee" , "ttsi"  , "ttsa"  , "X"     , "."     , "qai"   ,  /*-- U+1668 .. U+166F --*/
   "ngai"  , "nngi"  , "nngii" , "nngo"  , "nngoo" , "nnga"  , "nngaa" , ""      ,  /*-- U+1670 .. U+1677 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1678 .. U+167F --*/
   " "     , "b"     , "l"     , "f"     , "s"     , "n"     , "h"     , "d"     ,  /*-- U+1680 .. U+1687 --*/
   "t"     , "c"     , "q"     , "m"     , "g"     , "ng"    , "z"     , "r"     ,  /*-- U+1688 .. U+168F --*/
   "a"     , "o"     , "u"     , "e"     , "i"     , "ch"    , "th"    , "ph"    ,  /*-- U+1690 .. U+1697 --*/
   "p"     , "x"     , "p"     , "<"     , ">"     , ""      , ""      , ""      ,  /*-- U+1698 .. U+169F --*/
   "f"     , "v"     , "u"     , "yr"    , "y"     , "w"     , "th"    , "th"    ,  /*-- U+16A0 .. U+16A7 --*/
   "a"     , "o"     , "ac"    , "ae"    , "o"     , "o"     , "o"     , "oe"    ,  /*-- U+16A8 .. U+16AF --*/
   "on"    , "r"     , "k"     , "c"     , "k"     , "g"     , "ng"    , "g"     ,  /*-- U+16B0 .. U+16B7 --*/
   "g"     , "w"     , "h"     , "h"     , "h"     , "h"     , "n"     , "n"     ,  /*-- U+16B8 .. U+16BF --*/
   "n"     , "i"     , "e"     , "j"     , "g"     , "ae"    , "a"     , "eo"    ,  /*-- U+16C0 .. U+16C7 --*/
   "p"     , "z"     , "s"     , "s"     , "s"     , "c"     , "z"     , "t"     ,  /*-- U+16C8 .. U+16CF --*/
   "t"     , "d"     , "b"     , "b"     , "p"     , "p"     , "e"     , "m"     ,  /*-- U+16D0 .. U+16D7 --*/
   "m"     , "m"     , "l"     , "l"     , "ng"    , "ng"    , "d"     , "o"     ,  /*-- U+16D8 .. U+16DF --*/
   "ear"   , "ior"   , "qu"    , "qu"    , "qu"    , "s"     , "yr"    , "yr"    ,  /*-- U+16E0 .. U+16E7 --*/
   "yr"    , "q"     , "x"     , "."     , ":"     , "+"     , "17"    , "18"    ,  /*-- U+16E8 .. U+16EF --*/
   "19"    , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+16F0 .. U+16F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+16F8 .. U+16FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1700 .. U+1707 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1708 .. U+170F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1710 .. U+1717 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1718 .. U+171F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1720 .. U+1727 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1728 .. U+172F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1730 .. U+1737 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1738 .. U+173F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1740 .. U+1747 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1748 .. U+174F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1750 .. U+1757 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1758 .. U+175F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1760 .. U+1767 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1768 .. U+176F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1770 .. U+1777 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1778 .. U+177F --*/
   "k"     , "kh"    , "g"     , "gh"    , "ng"    , "c"     , "ch"    , "j"     ,  /*-- U+1780 .. U+1787 --*/
   "jh"    , "ny"    , "t"     , "tth"   , "d"     , "ddh"   , "nn"    , "t"     ,  /*-- U+1788 .. U+178F --*/
   "th"    , "d"     , "dh"    , "n"     , "p"     , "ph"    , "b"     , "bh"    ,  /*-- U+1790 .. U+1797 --*/
   "m"     , "y"     , "r"     , "l"     , "v"     , "sh"    , "ss"    , "s"     ,  /*-- U+1798 .. U+179F --*/
   "h"     , "l"     , "q"     , "a"     , "aa"    , "i"     , "ii"    , "u"     ,  /*-- U+17A0 .. U+17A7 --*/
   "uk"    , "uu"    , "uuv"   , "ry"    , "ryy"   , "ly"    , "lyy"   , "e"     ,  /*-- U+17A8 .. U+17AF --*/
   "ai"    , "oo"    , "oo"    , "au"    , "a"     , "aa"    , "aa"    , "i"     ,  /*-- U+17B0 .. U+17B7 --*/
   "ii"    , "y"     , "yy"    , "u"     , "uu"    , "ua"    , "oe"    , "ya"    ,  /*-- U+17B8 .. U+17BF --*/
   "ie"    , "e"     , "ae"    , "ai"    , "oo"    , "au"    , "M"     , "H"     ,  /*-- U+17C0 .. U+17C7 --*/
   "a`"    , ""      , ""      , ""      , "r"     , ""      , "!"     , ""      ,  /*-- U+17C8 .. U+17CF --*/
   ""      , ""      , ""      , ""      , "."     , " // "  , ":"     , "+"     ,  /*-- U+17D0 .. U+17D7 --*/
   "++"    , " * "   , " /// " , "KR"    , "'"     , ""      , ""      , ""      ,  /*-- U+17D8 .. U+17DF --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+17E0 .. U+17E7 --*/
   "8"     , "9"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+17E8 .. U+17EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+17F0 .. U+17F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+17F8 .. U+17FF --*/
   " @ "   , " ... " , ", "    , ". "    , ": "    , " // "  , ""      , "-"     ,  /*-- U+1800 .. U+1807 --*/
   ", "    , ". "    , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1808 .. U+180F --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+1810 .. U+1817 --*/
   "8"     , "9"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1818 .. U+181F --*/
   "a"     , "e"     , "i"     , "o"     , "u"     , "O"     , "U"     , "ee"    ,  /*-- U+1820 .. U+1827 --*/
   "n"     , "ng"    , "b"     , "p"     , "q"     , "g"     , "m"     , "l"     ,  /*-- U+1828 .. U+182F --*/
   "s"     , "sh"    , "t"     , "d"     , "ch"    , "j"     , "y"     , "r"     ,  /*-- U+1830 .. U+1837 --*/
   "w"     , "f"     , "k"     , "kha"   , "ts"    , "z"     , "h"     , "zr"    ,  /*-- U+1838 .. U+183F --*/
   "lh"    , "zh"    , "ch"    , "-"     , "e"     , "i"     , "o"     , "u"     ,  /*-- U+1840 .. U+1847 --*/
   "O"     , "U"     , "ng"    , "b"     , "p"     , "q"     , "g"     , "m"     ,  /*-- U+1848 .. U+184F --*/
   "t"     , "d"     , "ch"    , "j"     , "ts"    , "y"     , "w"     , "k"     ,  /*-- U+1850 .. U+1857 --*/
   "g"     , "h"     , "jy"    , "ny"    , "dz"    , "e"     , "i"     , "iy"    ,  /*-- U+1858 .. U+185F --*/
   "U"     , "u"     , "ng"    , "k"     , "g"     , "h"     , "p"     , "sh"    ,  /*-- U+1860 .. U+1867 --*/
   "t"     , "d"     , "j"     , "f"     , "g"     , "h"     , "ts"    , "z"     ,  /*-- U+1868 .. U+186F --*/
   "r"     , "ch"    , "zh"    , "i"     , "k"     , "r"     , "f"     , "zh"    ,  /*-- U+1870 .. U+1877 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1878 .. U+187F --*/
   ""      , "H"     , "X"     , "W"     , "M"     , " 3 "   , " 333 " , "a"     ,  /*-- U+1880 .. U+1887 --*/
   "i"     , "k"     , "ng"    , "c"     , "tt"    , "tth"   , "dd"    , "nn"    ,  /*-- U+1888 .. U+188F --*/
   "t"     , "d"     , "p"     , "ph"    , "ss"    , "zh"    , "z"     , "a"     ,  /*-- U+1890 .. U+1897 --*/
   "t"     , "zh"    , "gh"    , "ng"    , "c"     , "jh"    , "tta"   , "ddh"   ,  /*-- U+1898 .. U+189F --*/
   "t"     , "dh"    , "ss"    , "cy"    , "zh"    , "z"     , "u"     , "y"     ,  /*-- U+18A0 .. U+18A7 --*/
   "bh"    , "'"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18A8 .. U+18AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18B0 .. U+18B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18B8 .. U+18BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18C0 .. U+18C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18C8 .. U+18CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18D0 .. U+18D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18D8 .. U+18DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18E0 .. U+18E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18E8 .. U+18EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18F0 .. U+18F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+18F8 .. U+18FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1900 .. U+1907 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1908 .. U+190F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1910 .. U+1917 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1918 .. U+191F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1920 .. U+1927 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1928 .. U+192F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1930 .. U+1937 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1938 .. U+193F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1940 .. U+1947 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1948 .. U+194F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1950 .. U+1957 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1958 .. U+195F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1960 .. U+1967 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1968 .. U+196F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1970 .. U+1977 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1978 .. U+197F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1980 .. U+1987 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1988 .. U+198F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1990 .. U+1997 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1998 .. U+199F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19A0 .. U+19A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19A8 .. U+19AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19B0 .. U+19B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19B8 .. U+19BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19C0 .. U+19C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19C8 .. U+19CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19D0 .. U+19D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19D8 .. U+19DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19E0 .. U+19E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19E8 .. U+19EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19F0 .. U+19F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+19F8 .. U+19FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A00 .. U+1A07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A08 .. U+1A0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A10 .. U+1A17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A18 .. U+1A1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A20 .. U+1A27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A28 .. U+1A2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A30 .. U+1A37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A38 .. U+1A3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A40 .. U+1A47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A48 .. U+1A4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A50 .. U+1A57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A58 .. U+1A5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A60 .. U+1A67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A68 .. U+1A6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A70 .. U+1A77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A78 .. U+1A7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A80 .. U+1A87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A88 .. U+1A8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A90 .. U+1A97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1A98 .. U+1A9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AA0 .. U+1AA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AA8 .. U+1AAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AB0 .. U+1AB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AB8 .. U+1ABF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AC0 .. U+1AC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AC8 .. U+1ACF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AD0 .. U+1AD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AD8 .. U+1ADF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AE0 .. U+1AE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AE8 .. U+1AEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AF0 .. U+1AF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1AF8 .. U+1AFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B00 .. U+1B07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B08 .. U+1B0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B10 .. U+1B17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B18 .. U+1B1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B20 .. U+1B27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B28 .. U+1B2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B30 .. U+1B37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B38 .. U+1B3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B40 .. U+1B47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B48 .. U+1B4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B50 .. U+1B57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B58 .. U+1B5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B60 .. U+1B67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B68 .. U+1B6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B70 .. U+1B77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B78 .. U+1B7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B80 .. U+1B87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B88 .. U+1B8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B90 .. U+1B97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1B98 .. U+1B9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BA0 .. U+1BA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BA8 .. U+1BAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BB0 .. U+1BB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BB8 .. U+1BBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BC0 .. U+1BC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BC8 .. U+1BCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BD0 .. U+1BD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BD8 .. U+1BDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BE0 .. U+1BE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BE8 .. U+1BEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BF0 .. U+1BF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1BF8 .. U+1BFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C00 .. U+1C07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C08 .. U+1C0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C10 .. U+1C17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C18 .. U+1C1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C20 .. U+1C27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C28 .. U+1C2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C30 .. U+1C37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C38 .. U+1C3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C40 .. U+1C47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C48 .. U+1C4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C50 .. U+1C57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C58 .. U+1C5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C60 .. U+1C67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C68 .. U+1C6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C70 .. U+1C77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C78 .. U+1C7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C80 .. U+1C87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C88 .. U+1C8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C90 .. U+1C97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1C98 .. U+1C9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CA0 .. U+1CA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CA8 .. U+1CAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CB0 .. U+1CB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CB8 .. U+1CBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CC0 .. U+1CC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CC8 .. U+1CCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CD0 .. U+1CD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CD8 .. U+1CDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CE0 .. U+1CE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CE8 .. U+1CEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CF0 .. U+1CF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1CF8 .. U+1CFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D00 .. U+1D07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D08 .. U+1D0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D10 .. U+1D17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D18 .. U+1D1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D20 .. U+1D27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D28 .. U+1D2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D30 .. U+1D37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D38 .. U+1D3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D40 .. U+1D47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D48 .. U+1D4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D50 .. U+1D57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D58 .. U+1D5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D60 .. U+1D67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D68 .. U+1D6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D70 .. U+1D77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D78 .. U+1D7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D80 .. U+1D87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D88 .. U+1D8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D90 .. U+1D97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1D98 .. U+1D9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DA0 .. U+1DA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DA8 .. U+1DAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DB0 .. U+1DB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DB8 .. U+1DBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DC0 .. U+1DC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DC8 .. U+1DCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DD0 .. U+1DD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DD8 .. U+1DDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DE0 .. U+1DE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DE8 .. U+1DEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DF0 .. U+1DF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1DF8 .. U+1DFF --*/
   "A"     , "a"     , "B"     , "b"     , "B"     , "b"     , "B"     , "b"     ,  /*-- U+1E00 .. U+1E07 --*/
   "C"     , "c"     , "D"     , "d"     , "D"     , "d"     , "D"     , "d"     ,  /*-- U+1E08 .. U+1E0F --*/
   "D"     , "d"     , "D"     , "d"     , "E"     , "e"     , "E"     , "e"     ,  /*-- U+1E10 .. U+1E17 --*/
   "E"     , "e"     , "E"     , "e"     , "E"     , "e"     , "F"     , "f"     ,  /*-- U+1E18 .. U+1E1F --*/
   "G"     , "g"     , "H"     , "h"     , "H"     , "h"     , "H"     , "h"     ,  /*-- U+1E20 .. U+1E27 --*/
   "H"     , "h"     , "H"     , "h"     , "I"     , "i"     , "I"     , "i"     ,  /*-- U+1E28 .. U+1E2F --*/
   "K"     , "k"     , "K"     , "k"     , "K"     , "k"     , "L"     , "l"     ,  /*-- U+1E30 .. U+1E37 --*/
   "L"     , "l"     , "L"     , "l"     , "L"     , "l"     , "M"     , "m"     ,  /*-- U+1E38 .. U+1E3F --*/
   "M"     , "m"     , "M"     , "m"     , "N"     , "n"     , "N"     , "n"     ,  /*-- U+1E40 .. U+1E47 --*/
   "N"     , "n"     , "N"     , "n"     , "O"     , "o"     , "O"     , "o"     ,  /*-- U+1E48 .. U+1E4F --*/
   "O"     , "o"     , "O"     , "o"     , "P"     , "p"     , "P"     , "p"     ,  /*-- U+1E50 .. U+1E57 --*/
   "R"     , "r"     , "R"     , "r"     , "R"     , "r"     , "R"     , "r"     ,  /*-- U+1E58 .. U+1E5F --*/
   "S"     , "s"     , "S"     , "s"     , "S"     , "s"     , "S"     , "s"     ,  /*-- U+1E60 .. U+1E67 --*/
   "S"     , "s"     , "T"     , "t"     , "T"     , "t"     , "T"     , "t"     ,  /*-- U+1E68 .. U+1E6F --*/
   "T"     , "t"     , "U"     , "u"     , "U"     , "u"     , "U"     , "u"     ,  /*-- U+1E70 .. U+1E77 --*/
   "U"     , "u"     , "U"     , "u"     , "V"     , "v"     , "V"     , "v"     ,  /*-- U+1E78 .. U+1E7F --*/
   "W"     , "w"     , "W"     , "w"     , "W"     , "w"     , "W"     , "w"     ,  /*-- U+1E80 .. U+1E87 --*/
   "W"     , "w"     , "X"     , "x"     , "X"     , "x"     , "Y"     , "y"     ,  /*-- U+1E88 .. U+1E8F --*/
   "Z"     , "z"     , "Z"     , "z"     , "Z"     , "z"     , "h"     , "t"     ,  /*-- U+1E90 .. U+1E97 --*/
   "w"     , "y"     , "a"     , "S"     , ""      , ""      , ""      , ""      ,  /*-- U+1E98 .. U+1E9F --*/
   "A"     , "a"     , "A"     , "a"     , "A"     , "a"     , "A"     , "a"     ,  /*-- U+1EA0 .. U+1EA7 --*/
   "A"     , "a"     , "A"     , "a"     , "A"     , "a"     , "A"     , "a"     ,  /*-- U+1EA8 .. U+1EAF --*/
   "A"     , "a"     , "A"     , "a"     , "A"     , "a"     , "A"     , "a"     ,  /*-- U+1EB0 .. U+1EB7 --*/
   "E"     , "e"     , "E"     , "e"     , "E"     , "e"     , "E"     , "e"     ,  /*-- U+1EB8 .. U+1EBF --*/
   "E"     , "e"     , "E"     , "e"     , "E"     , "e"     , "E"     , "e"     ,  /*-- U+1EC0 .. U+1EC7 --*/
   "I"     , "i"     , "I"     , "i"     , "O"     , "o"     , "O"     , "o"     ,  /*-- U+1EC8 .. U+1ECF --*/
   "O"     , "o"     , "O"     , "o"     , "O"     , "o"     , "O"     , "o"     ,  /*-- U+1ED0 .. U+1ED7 --*/
   "O"     , "o"     , "O"     , "o"     , "O"     , "o"     , "O"     , "o"     ,  /*-- U+1ED8 .. U+1EDF --*/
   "O"     , "o"     , "O"     , "o"     , "U"     , "u"     , "U"     , "u"     ,  /*-- U+1EE0 .. U+1EE7 --*/
   "U"     , "u"     , "U"     , "u"     , "U"     , "u"     , "U"     , "u"     ,  /*-- U+1EE8 .. U+1EEF --*/
   "U"     , "u"     , "Y"     , "y"     , "Y"     , "y"     , "Y"     , "y"     ,  /*-- U+1EF0 .. U+1EF7 --*/
   "Y"     , "y"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+1EF8 .. U+1EFF --*/
   "a"     , "a"     , "a"     , "a"     , "a"     , "a"     , "a"     , "a"     ,  /*-- U+1F00 .. U+1F07 --*/
   "A"     , "A"     , "A"     , "A"     , "A"     , "A"     , "A"     , "A"     ,  /*-- U+1F08 .. U+1F0F --*/
   "e"     , "e"     , "e"     , "e"     , "e"     , "e"     , ""      , ""      ,  /*-- U+1F10 .. U+1F17 --*/
   "E"     , "E"     , "E"     , "E"     , "E"     , "E"     , ""      , ""      ,  /*-- U+1F18 .. U+1F1F --*/
   "e"     , "e"     , "e"     , "e"     , "e"     , "e"     , "e"     , "e"     ,  /*-- U+1F20 .. U+1F27 --*/
   "E"     , "E"     , "E"     , "E"     , "E"     , "E"     , "E"     , "E"     ,  /*-- U+1F28 .. U+1F2F --*/
   "i"     , "i"     , "i"     , "i"     , "i"     , "i"     , "i"     , "i"     ,  /*-- U+1F30 .. U+1F37 --*/
   "I"     , "I"     , "I"     , "I"     , "I"     , "I"     , "I"     , "I"     ,  /*-- U+1F38 .. U+1F3F --*/
   "o"     , "o"     , "o"     , "o"     , "o"     , "o"     , ""      , ""      ,  /*-- U+1F40 .. U+1F47 --*/
   "O"     , "O"     , "O"     , "O"     , "O"     , "O"     , ""      , ""      ,  /*-- U+1F48 .. U+1F4F --*/
   "u"     , "u"     , "u"     , "u"     , "u"     , "u"     , "u"     , "u"     ,  /*-- U+1F50 .. U+1F57 --*/
   ""      , "U"     , ""      , "U"     , ""      , "U"     , ""      , "U"     ,  /*-- U+1F58 .. U+1F5F --*/
   "o"     , "o"     , "o"     , "o"     , "o"     , "o"     , "o"     , "o"     ,  /*-- U+1F60 .. U+1F67 --*/
   "O"     , "O"     , "O"     , "O"     , "O"     , "O"     , "O"     , "O"     ,  /*-- U+1F68 .. U+1F6F --*/
   "a"     , "a"     , "e"     , "e"     , "e"     , "e"     , "i"     , "i"     ,  /*-- U+1F70 .. U+1F77 --*/
   "o"     , "o"     , "u"     , "u"     , "o"     , "o"     , ""      , ""      ,  /*-- U+1F78 .. U+1F7F --*/
   "a"     , "a"     , "a"     , "a"     , "a"     , "a"     , "a"     , "a"     ,  /*-- U+1F80 .. U+1F87 --*/
   "A"     , "A"     , "A"     , "A"     , "A"     , "A"     , "A"     , "A"     ,  /*-- U+1F88 .. U+1F8F --*/
   "e"     , "e"     , "e"     , "e"     , "e"     , "e"     , "e"     , "e"     ,  /*-- U+1F90 .. U+1F97 --*/
   "E"     , "E"     , "E"     , "E"     , "E"     , "E"     , "E"     , "E"     ,  /*-- U+1F98 .. U+1F9F --*/
   "o"     , "o"     , "o"     , "o"     , "o"     , "o"     , "o"     , "o"     ,  /*-- U+1FA0 .. U+1FA7 --*/
   "O"     , "O"     , "O"     , "O"     , "O"     , "O"     , "O"     , "O"     ,  /*-- U+1FA8 .. U+1FAF --*/
   "a"     , "a"     , "a"     , "a"     , "a"     , ""      , "a"     , "a"     ,  /*-- U+1FB0 .. U+1FB7 --*/
   "A"     , "A"     , "A"     , "A"     , "A"     , "'"     , "i"     , "'"     ,  /*-- U+1FB8 .. U+1FBF --*/
   "~"     , "\"~"   , "e"     , "e"     , "e"     , ""      , "e"     , "e"     ,  /*-- U+1FC0 .. U+1FC7 --*/
   "E"     , "E"     , "E"     , "E"     , "E"     , "'`"    , "\""    , "'~"    ,  /*-- U+1FC8 .. U+1FCF --*/
   "i"     , "i"     , "i"     , "i"     , ""      , ""      , "i"     , "i"     ,  /*-- U+1FD0 .. U+1FD7 --*/
   "I"     , "I"     , "I"     , "I"     , ""      , "`'"    , "`'"    , "`~"    ,  /*-- U+1FD8 .. U+1FDF --*/
   "u"     , "u"     , "u"     , "u"     , "R"     , "R"     , "u"     , "u"     ,  /*-- U+1FE0 .. U+1FE7 --*/
   "U"     , "U"     , "U"     , "U"     , "R"     , "\"`"   , "\"'"   , "`"     ,  /*-- U+1FE8 .. U+1FEF --*/
   ""      , ""      , "o"     , "o"     , "o"     , ""      , "o"     , "o"     ,  /*-- U+1FF0 .. U+1FF7 --*/
   "O"     , "O"     , "O"     , "O"     , "O"     , "'"     , "`"     , ""      ,  /*-- U+1FF8 .. U+1FFF --*/
   " "     , " "     , " "     , " "     , " "     , " "     , " "     , " "     ,  /*-- U+2000 .. U+2007 --*/
   " "     , " "     , " "     , " "     , ""      , ""      , ""      , ""      ,  /*-- U+2008 .. U+200F --*/
   "-"     , "-"     , "-"     , "-"     , "--"    , "--"    , "||"    , "_"     ,  /*-- U+2010 .. U+2017 --*/
   "'"     , "'"     , ","     , "'"     , "\""    , "\""    , "\""    , "\""    ,  /*-- U+2018 .. U+201F --*/
   "+"     , "++"    , "*"     , "*>"    , "."     , ".."    , "..."   , "."     ,  /*-- U+2020 .. U+2027 --*/
   "\n"    , "\n\n"  , ""      , ""      , ""      , ""      , ""      , " "     ,  /*-- U+2028 .. U+202F --*/
   "%0"    , "%00"   , "'"     , "\""    , "'''"   , "`"     , "\""    , "```"   ,  /*-- U+2030 .. U+2037 --*/
   "^"     , "<"     , ">"     , "*"     , "!!"    , "!?"    , "-"     , "_"     ,  /*-- U+2038 .. U+203F --*/
   "-"     , "^"     , "***"   , "--"    , "/"     , "-["    , "]-"    , ""      ,  /*-- U+2040 .. U+2047 --*/
   "?!"    , "!?"    , "r"     , "PP"    , "(]"    , "[)"    , ""      , ""      ,  /*-- U+2048 .. U+204F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2050 .. U+2057 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2058 .. U+205F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2060 .. U+2067 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2068 .. U+206F --*/
   "0"     , ""      , ""      , ""      , "4"     , "5"     , "6"     , "7"     ,  /*-- U+2070 .. U+2077 --*/
   "8"     , "9"     , "+"     , "-"     , "="     , "("     , ")"     , "n"     ,  /*-- U+2078 .. U+207F --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+2080 .. U+2087 --*/
   "8"     , "9"     , "+"     , "-"     , "="     , "("     , ")"     , ""      ,  /*-- U+2088 .. U+208F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2090 .. U+2097 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2098 .. U+209F --*/
   "ECU"   , "CL"    , "Cr"    , "FF"    , "L"     , "mil"   , "N"     , "Pts"   ,  /*-- U+20A0 .. U+20A7 --*/
   "Rs"    , "W"     , "NS"    , "D"     , "EUR"   , "K"     , "T"     , "Dr"    ,  /*-- U+20A8 .. U+20AF --*/
   "Pf"    , "P"     , "G"     , "A"     , "H"     , "C"     , "lt"    , "S"     ,  /*-- U+20B0 .. U+20B7 --*/
   "T"     , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20B8 .. U+20BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20C0 .. U+20C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20C8 .. U+20CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20D0 .. U+20D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20D8 .. U+20DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20E0 .. U+20E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20E8 .. U+20EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20F0 .. U+20F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+20F8 .. U+20FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2100 .. U+2107 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2108 .. U+210F --*/
   ""      , ""      , ""      , ""      , "Lb"    , ""      , ""      , ""      ,  /*-- U+2110 .. U+2117 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2118 .. U+211F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2120 .. U+2127 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2128 .. U+212F --*/
   ""      , ""      , ""      , "M"     , ""      , ""      , ""      , ""      ,  /*-- U+2130 .. U+2137 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2138 .. U+213F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2140 .. U+2147 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2148 .. U+214F --*/
   ""      , ""      , ""      , " 1/3 " , " 2/3 " , " 1/5 " , " 2/5 " , " 3/5 " ,  /*-- U+2150 .. U+2157 --*/
   " 4/5 " , " 1/6 " , " 5/6 " , " 1/8 " , " 3/8 " , " 5/8 " , " 7/8 " , " 1/"   ,  /*-- U+2158 .. U+215F --*/
   "I"     , "II"    , "III"   , "IV"    , "V"     , "VI"    , "VII"   , "VIII"  ,  /*-- U+2160 .. U+2167 --*/
   "IX"    , "X"     , "XI"    , "XII"   , "L"     , "C"     , "D"     , "M"     ,  /*-- U+2168 .. U+216F --*/
   "i"     , "ii"    , "iii"   , "iv"    , "v"     , "vi"    , "vii"   , "viii"  ,  /*-- U+2170 .. U+2177 --*/
   "ix"    , "x"     , "xi"    , "xii"   , "l"     , "c"     , "d"     , "m"     ,  /*-- U+2178 .. U+217F --*/
   "(D"    , "D)"    , "((|))" , ")"     , ""      , ""      , ""      , ""      ,  /*-- U+2180 .. U+2187 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2188 .. U+218F --*/
   "-"     , "|"     , "-"     , "|"     , "-"     , "|"     , "\\"    , "/"     ,  /*-- U+2190 .. U+2197 --*/
   "\\"    , "/"     , "-"     , "-"     , "~"     , "~"     , "-"     , "|"     ,  /*-- U+2198 .. U+219F --*/
   "-"     , "|"     , "-"     , "-"     , "-"     , "|"     , "-"     , "|"     ,  /*-- U+21A0 .. U+21A7 --*/
   "|"     , "-"     , "-"     , "-"     , "-"     , "-"     , "-"     , "|"     ,  /*-- U+21A8 .. U+21AF --*/
   "|"     , "|"     , "|"     , "|"     , "|"     , "|"     , "^"     , "V"     ,  /*-- U+21B0 .. U+21B7 --*/
   "\\"    , "="     , "V"     , "^"     , "-"     , "-"     , "|"     , "|"     ,  /*-- U+21B8 .. U+21BF --*/
   "-"     , "-"     , "|"     , "|"     , "="     , "|"     , "="     , "="     ,  /*-- U+21C0 .. U+21C7 --*/
   "|"     , "="     , "|"     , "="     , "="     , "="     , "="     , "="     ,  /*-- U+21C8 .. U+21CF --*/
   "="     , "|"     , "="     , "|"     , "="     , "|"     , "\\"    , "/"     ,  /*-- U+21D0 .. U+21D7 --*/
   "\\"    , "/"     , "="     , "="     , "~"     , "~"     , "|"     , "|"     ,  /*-- U+21D8 .. U+21DF --*/
   "-"     , "|"     , "-"     , "|"     , "-"     , "-"     , "-"     , "|"     ,  /*-- U+21E0 .. U+21E7 --*/
   "-"     , "|"     , "|"     , "|"     , "|"     , "|"     , "|"     , "|"     ,  /*-- U+21E8 .. U+21EF --*/
   "-"     , "\\"    , "\\"    , "|"     , ""      , ""      , ""      , ""      ,  /*-- U+21F0 .. U+21F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+21F8 .. U+21FF --*/
   ""      , ""      , "partial", ""      , ""      , ""      , ""      , ""      ,  /*-- U+2200 .. U+2207 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2208 .. U+220F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2210 .. U+2217 --*/
   ""      , "Bullet", "sqrt"  , ""      , ""      , ""      , "infinity", ""      ,  /*-- U+2218 .. U+221F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2220 .. U+2227 --*/
   ""      , ""      , ""      , "integral", ""      , ""      , ""      , ""      ,  /*-- U+2228 .. U+222F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2230 .. U+2237 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2238 .. U+223F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2240 .. U+2247 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2248 .. U+224F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2250 .. U+2257 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2258 .. U+225F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2260 .. U+2267 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2268 .. U+226F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2270 .. U+2277 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2278 .. U+227F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2280 .. U+2287 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2288 .. U+228F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2290 .. U+2297 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2298 .. U+229F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22A0 .. U+22A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22A8 .. U+22AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22B0 .. U+22B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22B8 .. U+22BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22C0 .. U+22C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22C8 .. U+22CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22D0 .. U+22D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22D8 .. U+22DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22E0 .. U+22E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22E8 .. U+22EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22F0 .. U+22F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+22F8 .. U+22FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2300 .. U+2307 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2308 .. U+230F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2310 .. U+2317 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2318 .. U+231F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2320 .. U+2327 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2328 .. U+232F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2330 .. U+2337 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2338 .. U+233F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2340 .. U+2347 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2348 .. U+234F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2350 .. U+2357 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2358 .. U+235F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2360 .. U+2367 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2368 .. U+236F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2370 .. U+2377 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2378 .. U+237F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2380 .. U+2387 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2388 .. U+238F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2390 .. U+2397 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2398 .. U+239F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23A0 .. U+23A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23A8 .. U+23AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23B0 .. U+23B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23B8 .. U+23BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23C0 .. U+23C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23C8 .. U+23CF --*/
   ""      , "Breve" , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23D0 .. U+23D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23D8 .. U+23DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23E0 .. U+23E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23E8 .. U+23EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23F0 .. U+23F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+23F8 .. U+23FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2400 .. U+2407 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2408 .. U+240F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2410 .. U+2417 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2418 .. U+241F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2420 .. U+2427 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2428 .. U+242F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2430 .. U+2437 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2438 .. U+243F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2440 .. U+2447 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2448 .. U+244F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2450 .. U+2457 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2458 .. U+245F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2460 .. U+2467 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2468 .. U+246F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2470 .. U+2477 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2478 .. U+247F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2480 .. U+2487 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2488 .. U+248F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2490 .. U+2497 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2498 .. U+249F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24A0 .. U+24A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24A8 .. U+24AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24B0 .. U+24B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24B8 .. U+24BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24C0 .. U+24C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24C8 .. U+24CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24D0 .. U+24D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24D8 .. U+24DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24E0 .. U+24E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24E8 .. U+24EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24F0 .. U+24F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+24F8 .. U+24FF --*/
   "-"     , "-"     , "|"     , "|"     , "-"     , "-"     , "|"     , "|"     ,  /*-- U+2500 .. U+2507 --*/
   "-"     , "-"     , "|"     , "|"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2508 .. U+250F --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2510 .. U+2517 --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2518 .. U+251F --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2520 .. U+2527 --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2528 .. U+252F --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2530 .. U+2537 --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2538 .. U+253F --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2540 .. U+2547 --*/
   "+"     , "+"     , "+"     , "+"     , "-"     , "-"     , "|"     , "|"     ,  /*-- U+2548 .. U+254F --*/
   "-"     , "|"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2550 .. U+2557 --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2558 .. U+255F --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2560 .. U+2567 --*/
   "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     , "+"     ,  /*-- U+2568 .. U+256F --*/
   "+"     , "/"     , "\\"    , "X"     , "-"     , "|"     , "-"     , "|"     ,  /*-- U+2570 .. U+2577 --*/
   "-"     , "|"     , "-"     , "|"     , "-"     , "|"     , "-"     , "|"     ,  /*-- U+2578 .. U+257F --*/
   "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     ,  /*-- U+2580 .. U+2587 --*/
   "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     ,  /*-- U+2588 .. U+258F --*/
   "#"     , "#"     , "#"     , "#"     , "-"     , "|"     , ""      , ""      ,  /*-- U+2590 .. U+2597 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2598 .. U+259F --*/
   "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     ,  /*-- U+25A0 .. U+25A7 --*/
   "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     ,  /*-- U+25A8 .. U+25AF --*/
   "#"     , "#"     , "^"     , "^"     , "^"     , "^"     , ">"     , ">"     ,  /*-- U+25B0 .. U+25B7 --*/
   ">"     , ">"     , ">"     , ">"     , "V"     , "V"     , "V"     , "V"     ,  /*-- U+25B8 .. U+25BF --*/
   "<"     , "<"     , "<"     , "<"     , "<"     , "<"     , "*"     , "*"     ,  /*-- U+25C0 .. U+25C7 --*/
   "*"     , "*"     , "*"     , "*"     , "*"     , "*"     , "*"     , "*"     ,  /*-- U+25C8 .. U+25CF --*/
   "*"     , "*"     , "*"     , "*"     , "*"     , "*"     , "*"     , "*"     ,  /*-- U+25D0 .. U+25D7 --*/
   "*"     , "*"     , "*"     , "*"     , "*"     , "*"     , "*"     , "*"     ,  /*-- U+25D8 .. U+25DF --*/
   "*"     , "*"     , "*"     , "*"     , "*"     , "*"     , "*"     , "#"     ,  /*-- U+25E0 .. U+25E7 --*/
   "#"     , "#"     , "#"     , "#"     , "^"     , "^"     , "^"     , "O"     ,  /*-- U+25E8 .. U+25EF --*/
   "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     , "#"     ,  /*-- U+25F0 .. U+25F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+25F8 .. U+25FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2600 .. U+2607 --*/
   ""      , "Sun"   , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2608 .. U+260F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2610 .. U+2617 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2618 .. U+261F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2620 .. U+2627 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2628 .. U+262F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2630 .. U+2637 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2638 .. U+263F --*/
   ""      , ""      , ""      , "Jupiter", ""      , ""      , ""      , ""      ,  /*-- U+2640 .. U+2647 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2648 .. U+264F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2650 .. U+2657 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2658 .. U+265F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2660 .. U+2667 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2668 .. U+266F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2670 .. U+2677 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2678 .. U+267F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2680 .. U+2687 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2688 .. U+268F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2690 .. U+2697 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2698 .. U+269F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26A0 .. U+26A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26A8 .. U+26AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26B0 .. U+26B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26B8 .. U+26BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26C0 .. U+26C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26C8 .. U+26CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26D0 .. U+26D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26D8 .. U+26DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26E0 .. U+26E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26E8 .. U+26EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26F0 .. U+26F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+26F8 .. U+26FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2700 .. U+2707 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2708 .. U+270F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2710 .. U+2717 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2718 .. U+271F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2720 .. U+2727 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2728 .. U+272F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2730 .. U+2737 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2738 .. U+273F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2740 .. U+2747 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2748 .. U+274F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2750 .. U+2757 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2758 .. U+275F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2760 .. U+2767 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2768 .. U+276F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2770 .. U+2777 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2778 .. U+277F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2780 .. U+2787 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2788 .. U+278F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2790 .. U+2797 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2798 .. U+279F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27A0 .. U+27A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27A8 .. U+27AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27B0 .. U+27B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27B8 .. U+27BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27C0 .. U+27C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27C8 .. U+27CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27D0 .. U+27D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27D8 .. U+27DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27E0 .. U+27E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27E8 .. U+27EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27F0 .. U+27F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+27F8 .. U+27FF --*/
   " "     , "a"     , "1"     , "b"     , "'"     , "k"     , "2"     , "l"     ,  /*-- U+2800 .. U+2807 --*/
   "@"     , "c"     , "i"     , "f"     , "/"     , "m"     , "s"     , "p"     ,  /*-- U+2808 .. U+280F --*/
   "\""    , "e"     , "3"     , "h"     , "9"     , "o"     , "6"     , "r"     ,  /*-- U+2810 .. U+2817 --*/
   "^"     , "d"     , "j"     , "g"     , ">"     , "n"     , "t"     , "q"     ,  /*-- U+2818 .. U+281F --*/
   ","     , "*"     , "5"     , "<"     , "-"     , "u"     , "8"     , "v"     ,  /*-- U+2820 .. U+2827 --*/
   "."     , "%"     , "["     , "$"     , "+"     , "x"     , "!"     , "&"     ,  /*-- U+2828 .. U+282F --*/
   ";"     , ":"     , "4"     , "\\"    , "0"     , "z"     , "7"     , "("     ,  /*-- U+2830 .. U+2837 --*/
   "_"     , "?"     , "w"     , "]"     , "#"     , "y"     , ")"     , "="     ,  /*-- U+2838 .. U+283F --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2840 .. U+2847 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2848 .. U+284F --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2850 .. U+2857 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2858 .. U+285F --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2860 .. U+2867 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2868 .. U+286F --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2870 .. U+2877 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2878 .. U+287F --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2880 .. U+2887 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2888 .. U+288F --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2890 .. U+2897 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+2898 .. U+289F --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28A0 .. U+28A7 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28A8 .. U+28AF --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28B0 .. U+28B7 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28B8 .. U+28BF --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28C0 .. U+28C7 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28C8 .. U+28CF --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28D0 .. U+28D7 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28D8 .. U+28DF --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28E0 .. U+28E7 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28E8 .. U+28EF --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28F0 .. U+28F7 --*/
   "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     , "_"     ,  /*-- U+28F8 .. U+28FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2900 .. U+2907 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2908 .. U+290F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2910 .. U+2917 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2918 .. U+291F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2920 .. U+2927 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2928 .. U+292F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2930 .. U+2937 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2938 .. U+293F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2940 .. U+2947 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2948 .. U+294F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2950 .. U+2957 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2958 .. U+295F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2960 .. U+2967 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2968 .. U+296F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2970 .. U+2977 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2978 .. U+297F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2980 .. U+2987 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2988 .. U+298F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2990 .. U+2997 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2998 .. U+299F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29A0 .. U+29A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29A8 .. U+29AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29B0 .. U+29B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29B8 .. U+29BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29C0 .. U+29C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29C8 .. U+29CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29D0 .. U+29D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29D8 .. U+29DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29E0 .. U+29E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29E8 .. U+29EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29F0 .. U+29F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+29F8 .. U+29FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A00 .. U+2A07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A08 .. U+2A0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A10 .. U+2A17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A18 .. U+2A1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A20 .. U+2A27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A28 .. U+2A2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A30 .. U+2A37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A38 .. U+2A3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A40 .. U+2A47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A48 .. U+2A4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A50 .. U+2A57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A58 .. U+2A5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A60 .. U+2A67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A68 .. U+2A6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A70 .. U+2A77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A78 .. U+2A7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A80 .. U+2A87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A88 .. U+2A8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A90 .. U+2A97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2A98 .. U+2A9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AA0 .. U+2AA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AA8 .. U+2AAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AB0 .. U+2AB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AB8 .. U+2ABF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AC0 .. U+2AC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AC8 .. U+2ACF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AD0 .. U+2AD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AD8 .. U+2ADF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AE0 .. U+2AE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AE8 .. U+2AEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AF0 .. U+2AF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2AF8 .. U+2AFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B00 .. U+2B07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B08 .. U+2B0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B10 .. U+2B17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B18 .. U+2B1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B20 .. U+2B27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B28 .. U+2B2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B30 .. U+2B37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B38 .. U+2B3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B40 .. U+2B47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B48 .. U+2B4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B50 .. U+2B57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B58 .. U+2B5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B60 .. U+2B67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B68 .. U+2B6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B70 .. U+2B77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B78 .. U+2B7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B80 .. U+2B87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B88 .. U+2B8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B90 .. U+2B97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2B98 .. U+2B9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BA0 .. U+2BA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BA8 .. U+2BAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BB0 .. U+2BB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BB8 .. U+2BBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BC0 .. U+2BC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BC8 .. U+2BCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BD0 .. U+2BD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BD8 .. U+2BDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BE0 .. U+2BE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BE8 .. U+2BEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BF0 .. U+2BF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2BF8 .. U+2BFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C00 .. U+2C07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C08 .. U+2C0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C10 .. U+2C17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C18 .. U+2C1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C20 .. U+2C27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C28 .. U+2C2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C30 .. U+2C37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C38 .. U+2C3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C40 .. U+2C47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C48 .. U+2C4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C50 .. U+2C57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C58 .. U+2C5F --*/
   "L"     , ""      , "L"     , "P"     , "R"     , "a"     , "t"     , "H"     ,  /*-- U+2C60 .. U+2C67 --*/
   "h"     , "K"     , "k"     , "Z"     , "z"     , "A"     , "M"     , "A"     ,  /*-- U+2C68 .. U+2C6F --*/
   "A"     , "v"     , "W"     , "w"     , "v"     , "H"     , "h"     , "ph"    ,  /*-- U+2C70 .. U+2C77 --*/
   "e"     , "r"     , "o"     , "E"     , "j"     , "V"     , "S"     , "Z"     ,  /*-- U+2C78 .. U+2C7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C80 .. U+2C87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C88 .. U+2C8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C90 .. U+2C97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2C98 .. U+2C9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CA0 .. U+2CA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CA8 .. U+2CAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CB0 .. U+2CB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CB8 .. U+2CBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CC0 .. U+2CC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CC8 .. U+2CCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CD0 .. U+2CD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CD8 .. U+2CDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CE0 .. U+2CE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CE8 .. U+2CEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CF0 .. U+2CF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2CF8 .. U+2CFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D00 .. U+2D07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D08 .. U+2D0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D10 .. U+2D17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D18 .. U+2D1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D20 .. U+2D27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D28 .. U+2D2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D30 .. U+2D37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D38 .. U+2D3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D40 .. U+2D47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D48 .. U+2D4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D50 .. U+2D57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D58 .. U+2D5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D60 .. U+2D67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D68 .. U+2D6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D70 .. U+2D77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D78 .. U+2D7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D80 .. U+2D87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D88 .. U+2D8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D90 .. U+2D97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2D98 .. U+2D9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DA0 .. U+2DA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DA8 .. U+2DAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DB0 .. U+2DB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DB8 .. U+2DBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DC0 .. U+2DC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DC8 .. U+2DCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DD0 .. U+2DD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DD8 .. U+2DDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DE0 .. U+2DE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DE8 .. U+2DEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DF0 .. U+2DF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2DF8 .. U+2DFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E00 .. U+2E07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E08 .. U+2E0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , "-"     ,  /*-- U+2E10 .. U+2E17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E18 .. U+2E1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E20 .. U+2E27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E28 .. U+2E2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E30 .. U+2E37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E38 .. U+2E3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E40 .. U+2E47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E48 .. U+2E4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E50 .. U+2E57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E58 .. U+2E5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E60 .. U+2E67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E68 .. U+2E6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E70 .. U+2E77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E78 .. U+2E7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E80 .. U+2E87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E88 .. U+2E8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E90 .. U+2E97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2E98 .. U+2E9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EA0 .. U+2EA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EA8 .. U+2EAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EB0 .. U+2EB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EB8 .. U+2EBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EC0 .. U+2EC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EC8 .. U+2ECF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2ED0 .. U+2ED7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2ED8 .. U+2EDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EE0 .. U+2EE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EE8 .. U+2EEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EF0 .. U+2EF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2EF8 .. U+2EFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F00 .. U+2F07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F08 .. U+2F0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F10 .. U+2F17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F18 .. U+2F1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F20 .. U+2F27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F28 .. U+2F2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F30 .. U+2F37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F38 .. U+2F3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F40 .. U+2F47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F48 .. U+2F4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F50 .. U+2F57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F58 .. U+2F5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F60 .. U+2F67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F68 .. U+2F6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F70 .. U+2F77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F78 .. U+2F7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F80 .. U+2F87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F88 .. U+2F8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F90 .. U+2F97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2F98 .. U+2F9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FA0 .. U+2FA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FA8 .. U+2FAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FB0 .. U+2FB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FB8 .. U+2FBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FC0 .. U+2FC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FC8 .. U+2FCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FD0 .. U+2FD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FD8 .. U+2FDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FE0 .. U+2FE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FE8 .. U+2FEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FF0 .. U+2FF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+2FF8 .. U+2FFF --*/
   " "     , ", "    , ". "    , "\""    , "(JIS)" , "\""    , "/"     , "0"     ,  /*-- U+3000 .. U+3007 --*/
   "<"     , "> "    , "<<"    , ">> "   , "["     , "] "    , "{"     , "} "    ,  /*-- U+3008 .. U+300F --*/
   "[("    , ")] "   , "@"     , "X "    , "["     , "] "    , "[["    , "]] "   ,  /*-- U+3010 .. U+3017 --*/
   "(("    , ")) "   , "[["    , "]] "   , "~ "    , "\""    , "\""    , "\""    ,  /*-- U+3018 .. U+301F --*/
   "@"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+3020 .. U+3027 --*/
   "8"     , "9"     , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3028 .. U+302F --*/
   "~"     , "+"     , "+"     , "+"     , "+"     , ""      , "@"     , " // "  ,  /*-- U+3030 .. U+3037 --*/
   "+10+"  , "+20+"  , "+30+"  , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3038 .. U+303F --*/
   ""      , "a"     , "a"     , "i"     , "i"     , "u"     , "u"     , "e"     ,  /*-- U+3040 .. U+3047 --*/
   "e"     , "o"     , "o"     , "ka"    , "ga"    , "ki"    , "gi"    , "ku"    ,  /*-- U+3048 .. U+304F --*/
   "gu"    , "ke"    , "ge"    , "ko"    , "go"    , "sa"    , "za"    , "si"    ,  /*-- U+3050 .. U+3057 --*/
   "zi"    , "su"    , "zu"    , "se"    , "ze"    , "so"    , "zo"    , "ta"    ,  /*-- U+3058 .. U+305F --*/
   "da"    , "ti"    , "di"    , "tu"    , "tu"    , "du"    , "te"    , "de"    ,  /*-- U+3060 .. U+3067 --*/
   "to"    , "do"    , "na"    , "ni"    , "nu"    , "ne"    , "no"    , "ha"    ,  /*-- U+3068 .. U+306F --*/
   "ba"    , "pa"    , "hi"    , "bi"    , "pi"    , "hu"    , "bu"    , "pu"    ,  /*-- U+3070 .. U+3077 --*/
   "he"    , "be"    , "pe"    , "ho"    , "bo"    , "po"    , "ma"    , "mi"    ,  /*-- U+3078 .. U+307F --*/
   "mu"    , "me"    , "mo"    , "ya"    , "ya"    , "yu"    , "yu"    , "yo"    ,  /*-- U+3080 .. U+3087 --*/
   "yo"    , "ra"    , "ri"    , "ru"    , "re"    , "ro"    , "wa"    , "wa"    ,  /*-- U+3088 .. U+308F --*/
   "wi"    , "we"    , "wo"    , "n"     , "vu"    , ""      , ""      , ""      ,  /*-- U+3090 .. U+3097 --*/
   ""      , ""      , ""      , ""      , ""      , "\""    , "\""    , ""      ,  /*-- U+3098 .. U+309F --*/
   ""      , "a"     , "a"     , "i"     , "i"     , "u"     , "u"     , "e"     ,  /*-- U+30A0 .. U+30A7 --*/
   "e"     , "o"     , "o"     , "ka"    , "ga"    , "ki"    , "gi"    , "ku"    ,  /*-- U+30A8 .. U+30AF --*/
   "gu"    , "ke"    , "ge"    , "ko"    , "go"    , "sa"    , "za"    , "si"    ,  /*-- U+30B0 .. U+30B7 --*/
   "zi"    , "su"    , "zu"    , "se"    , "ze"    , "so"    , "zo"    , "ta"    ,  /*-- U+30B8 .. U+30BF --*/
   "da"    , "ti"    , "di"    , "tu"    , "tu"    , "du"    , "te"    , "de"    ,  /*-- U+30C0 .. U+30C7 --*/
   "to"    , "do"    , "na"    , "ni"    , "nu"    , "ne"    , "no"    , "ha"    ,  /*-- U+30C8 .. U+30CF --*/
   "ba"    , "pa"    , "hi"    , "bi"    , "pi"    , "hu"    , "bu"    , "pu"    ,  /*-- U+30D0 .. U+30D7 --*/
   "he"    , "be"    , "pe"    , "ho"    , "bo"    , "po"    , "ma"    , "mi"    ,  /*-- U+30D8 .. U+30DF --*/
   "mu"    , "me"    , "mo"    , "ya"    , "ya"    , "yu"    , "yu"    , "yo"    ,  /*-- U+30E0 .. U+30E7 --*/
   "yo"    , "ra"    , "ri"    , "ru"    , "re"    , "ro"    , "wa"    , "wa"    ,  /*-- U+30E8 .. U+30EF --*/
   "wi"    , "we"    , "wo"    , "n"     , "vu"    , "ka"    , "ke"    , "va"    ,  /*-- U+30F0 .. U+30F7 --*/
   "vi"    , "ve"    , "vo"    , ""      , ""      , "\""    , "\""    , ""      ,  /*-- U+30F8 .. U+30FF --*/
   ""      , ""      , ""      , ""      , ""      , "B"     , "P"     , "M"     ,  /*-- U+3100 .. U+3107 --*/
   "F"     , "D"     , "T"     , "N"     , "L"     , "G"     , "K"     , "H"     ,  /*-- U+3108 .. U+310F --*/
   "J"     , "Q"     , "X"     , "ZH"    , "CH"    , "SH"    , "R"     , "Z"     ,  /*-- U+3110 .. U+3117 --*/
   "C"     , "S"     , "A"     , "O"     , "E"     , "EH"    , "AI"    , "EI"    ,  /*-- U+3118 .. U+311F --*/
   "AU"    , "OU"    , "AN"    , "EN"    , "ANG"   , "ENG"   , "ER"    , "I"     ,  /*-- U+3120 .. U+3127 --*/
   "U"     , "IU"    , "V"     , "NG"    , "GN"    , ""      , ""      , ""      ,  /*-- U+3128 .. U+312F --*/
   ""      , "g"     , "gg"    , "gs"    , "n"     , "nj"    , "nh"    , "d"     ,  /*-- U+3130 .. U+3137 --*/
   "dd"    , "r"     , "lg"    , "lm"    , "lb"    , "ls"    , "lt"    , "lp"    ,  /*-- U+3138 .. U+313F --*/
   "rh"    , "m"     , "b"     , "bb"    , "bs"    , "s"     , "ss"    , ""      ,  /*-- U+3140 .. U+3147 --*/
   "j"     , "jj"    , "c"     , "k"     , "t"     , "p"     , "h"     , "a"     ,  /*-- U+3148 .. U+314F --*/
   "ae"    , "ya"    , "yae"   , "eo"    , "e"     , "yeo"   , "ye"    , "o"     ,  /*-- U+3150 .. U+3157 --*/
   "wa"    , "wae"   , "oe"    , "yo"    , "u"     , "weo"   , "we"    , "wi"    ,  /*-- U+3158 .. U+315F --*/
   "yu"    , "eu"    , "yi"    , "i"     , ""      , "nn"    , "nd"    , "ns"    ,  /*-- U+3160 .. U+3167 --*/
   "nZ"    , "lgs"   , "ld"    , "lbs"   , "lZ"    , "lQ"    , "mb"    , "ms"    ,  /*-- U+3168 .. U+316F --*/
   "mZ"    , "mN"    , "bg"    , ""      , "bsg"   , "bst"   , "bj"    , "bt"    ,  /*-- U+3170 .. U+3177 --*/
   "bN"    , "bbN"   , "sg"    , "sn"    , "sd"    , "sb"    , "sj"    , "Z"     ,  /*-- U+3178 .. U+317F --*/
   ""      , "N"     , "Ns"    , "NZ"    , "pN"    , "hh"    , "Q"     , "yo-ya" ,  /*-- U+3180 .. U+3187 --*/
   "yo-yae", "yo-i"  , "yu-yeo", "yu-ye" , "yu-i"  , "U"     , "U-i"   , ""      ,  /*-- U+3188 .. U+318F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3190 .. U+3197 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3198 .. U+319F --*/
   "BU"    , "ZI"    , "JI"    , "GU"    , "EE"    , "ENN"   , "OO"    , "ONN"   ,  /*-- U+31A0 .. U+31A7 --*/
   "IR"    , "ANN"   , "INN"   , "UNN"   , "IM"    , "NGG"   , "AINN"  , "AUNN"  ,  /*-- U+31A8 .. U+31AF --*/
   "AM"    , "OM"    , "ONG"   , "INNN"  , "P"     , "T"     , "K"     , "H"     ,  /*-- U+31B0 .. U+31B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31B8 .. U+31BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31C0 .. U+31C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31C8 .. U+31CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31D0 .. U+31D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31D8 .. U+31DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31E0 .. U+31E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31E8 .. U+31EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31F0 .. U+31F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+31F8 .. U+31FF --*/
   "(g)"   , "(n)"   , "(d)"   , "(r)"   , "(m)"   , "(b)"   , "(s)"   , "()"    ,  /*-- U+3200 .. U+3207 --*/
   "(j)"   , "(c)"   , "(k)"   , "(t)"   , "(p)"   , "(h)"   , "(ga)"  , "(na)"  ,  /*-- U+3208 .. U+320F --*/
   "(da)"  , "(ra)"  , "(ma)"  , "(ba)"  , "(sa)"  , "(a)"   , "(ja)"  , "(ca)"  ,  /*-- U+3210 .. U+3217 --*/
   "(ka)"  , "(ta)"  , "(pa)"  , "(ha)"  , "(ju)"  , ""      , ""      , ""      ,  /*-- U+3218 .. U+321F --*/
   "(1) "  , "(2) "  , "(3) "  , "(4) "  , "(5) "  , "(6) "  , "(7) "  , "(8) "  ,  /*-- U+3220 .. U+3227 --*/
   "(9) "  , "(10) " , "(Yue) ", "(Huo) ", "(Shui) ", "(Mu) " , "(Jin) ", "(Tu) " ,  /*-- U+3228 .. U+322F --*/
   "(Ri) " , "(Zhu) ", "(You) ", "(She) ", "(Ming) ", "(Te) " , "(Cai) ", "(Zhu) ",  /*-- U+3230 .. U+3237 --*/
   "(Lao) ", "(Dai) ", "(Hu) " , "(Xue) ", "(Jian) ", "(Qi) " , "(Zi) " , "(Xie) ",  /*-- U+3238 .. U+323F --*/
   "(Ji) " , "(Xiu) ", "<<"    , ">>"    , ""      , ""      , ""      , ""      ,  /*-- U+3240 .. U+3247 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3248 .. U+324F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3250 .. U+3257 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3258 .. U+325F --*/
   "(g)"   , "(n)"   , "(d)"   , "(r)"   , "(m)"   , "(b)"   , "(s)"   , "()"    ,  /*-- U+3260 .. U+3267 --*/
   "(j)"   , "(c)"   , "(k)"   , "(t)"   , "(p)"   , "(h)"   , "(ga)"  , "(na)"  ,  /*-- U+3268 .. U+326F --*/
   "(da)"  , "(ra)"  , "(ma)"  , "(ba)"  , "(sa)"  , "(a)"   , "(ja)"  , "(ca)"  ,  /*-- U+3270 .. U+3277 --*/
   "(ka)"  , "(ta)"  , "(pa)"  , "(ha)"  , ""      , ""      , ""      , "KIS "  ,  /*-- U+3278 .. U+327F --*/
   "(1) "  , "(2) "  , "(3) "  , "(4) "  , "(5) "  , "(6) "  , "(7) "  , "(8) "  ,  /*-- U+3280 .. U+3287 --*/
   "(9) "  , "(10) " , "(Yue) ", "(Huo) ", "(Shui) ", "(Mu) " , "(Jin) ", "(Tu) " ,  /*-- U+3288 .. U+328F --*/
   "(Ri) " , "(Zhu) ", "(You) ", "(She) ", "(Ming) ", "(Te) " , "(Cai) ", "(Zhu) ",  /*-- U+3290 .. U+3297 --*/
   "(Lao) ", "(Mi) " , "(Nan) ", "(Nu) " , "(Shi) ", "(You) ", "(Yin) ", "(Zhu) ",  /*-- U+3298 .. U+329F --*/
   "(Xiang) ", "(Xiu) ", "(Xie) ", "(Zheng) ", "(Shang) ", "(Zhong) ", "(Xia) ", "(Zuo) ",  /*-- U+32A0 .. U+32A7 --*/
   "(You) ", "(Yi) " , "(Zong) ", "(Xue) ", "(Jian) ", "(Qi) " , "(Zi) " , "(Xie) ",  /*-- U+32A8 .. U+32AF --*/
   "(Ye) " , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+32B0 .. U+32B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+32B8 .. U+32BF --*/
   "1M"    , "2M"    , "3M"    , "4M"    , "5M"    , "6M"    , "7M"    , "8M"    ,  /*-- U+32C0 .. U+32C7 --*/
   "9M"    , "10M"   , "11M"   , "12M"   , ""      , ""      , ""      , ""      ,  /*-- U+32C8 .. U+32CF --*/
   "a"     , "i"     , "u"     , "u"     , "o"     , "ka"    , "ki"    , "ku"    ,  /*-- U+32D0 .. U+32D7 --*/
   "ke"    , "ko"    , "sa"    , "si"    , "su"    , "se"    , "so"    , "ta"    ,  /*-- U+32D8 .. U+32DF --*/
   "ti"    , "tu"    , "te"    , "to"    , "na"    , "ni"    , "nu"    , "ne"    ,  /*-- U+32E0 .. U+32E7 --*/
   "no"    , "ha"    , "hi"    , "hu"    , "he"    , "ho"    , "ma"    , "mi"    ,  /*-- U+32E8 .. U+32EF --*/
   "mu"    , "me"    , "mo"    , "ya"    , "yu"    , "yo"    , "ra"    , "ri"    ,  /*-- U+32F0 .. U+32F7 --*/
   "ru"    , "re"    , "ro"    , "wa"    , "wi"    , "we"    , "wo"    , ""      ,  /*-- U+32F8 .. U+32FF --*/
   "apartment", "alpha" , "ampere", "are"   , "inning", "inch"  , "won"   , "escudo",  /*-- U+3300 .. U+3307 --*/
   "acre"  , "ounce" , "ohm"   , "kai-ri", "carat" , "calorie", "gallon", "gamma" ,  /*-- U+3308 .. U+330F --*/
   "giga"  , "guinea", "curie" , "guilder", "kilo"  , "kilogram", "kilometer", "kilowatt",  /*-- U+3310 .. U+3317 --*/
   "gram"  , "gram ton", "cruzeiro", "krone" , "case"  , "koruna", "co-op" , "cycle" ,  /*-- U+3318 .. U+331F --*/
   "centime", "shilling", "centi" , "cent"  , "dozen" , "desi"  , "dollar", "ton"   ,  /*-- U+3320 .. U+3327 --*/
   "nano"  , "knot"  , "heights", "percent", "parts" , "barrel", "piaster", "picul" ,  /*-- U+3328 .. U+332F --*/
   "pico"  , "building", "farad" , "feet"  , "bushel", "franc" , "hectare", "peso"  ,  /*-- U+3330 .. U+3337 --*/
   "pfennig", "hertz" , "pence" , "page"  , "beta"  , "point" , "volt"  , "hon"   ,  /*-- U+3338 .. U+333F --*/
   "pound" , "hall"  , "horn"  , "micro" , "mile"  , "mach"  , "mark"  , "mansion",  /*-- U+3340 .. U+3347 --*/
   "micron", "milli" , "millibar", "mega"  , "megaton", "meter" , "yard"  , "yard"  ,  /*-- U+3348 .. U+334F --*/
   "yuan"  , "liter" , "lira"  , "rupee" , "ruble" , "rem"   , "roentgen", "watt"  ,  /*-- U+3350 .. U+3357 --*/
   "0h"    , "1h"    , "2h"    , "3h"    , "4h"    , "5h"    , "6h"    , "7h"    ,  /*-- U+3358 .. U+335F --*/
   "8h"    , "9h"    , "10h"   , "11h"   , "12h"   , "13h"   , "14h"   , "15h"   ,  /*-- U+3360 .. U+3367 --*/
   "16h"   , "17h"   , "18h"   , "19h"   , "20h"   , "21h"   , "22h"   , "23h"   ,  /*-- U+3368 .. U+336F --*/
   "24h"   , "HPA"   , "da"    , "AU"    , "bar"   , "oV"    , "pc"    , ""      ,  /*-- U+3370 .. U+3377 --*/
   ""      , ""      , ""      , "Heisei", "Syouwa", "Taisyou", "Meiji" , "Inc."  ,  /*-- U+3378 .. U+337F --*/
   "pA"    , "nA"    , "microamp", "mA"    , "kA"    , "kB"    , "MB"    , "GB"    ,  /*-- U+3380 .. U+3387 --*/
   "cal"   , "kcal"  , "pF"    , "nF"    , "microFarad", "microgram", "mg"    , "kg"    ,  /*-- U+3388 .. U+338F --*/
   "Hz"    , "kHz"   , "MHz"   , "GHz"   , "THz"   , "microliter", "ml"    , "dl"    ,  /*-- U+3390 .. U+3397 --*/
   "kl"    , "fm"    , "nm"    , "micrometer", "mm"    , "cm"    , "km"    , "mm^2"  ,  /*-- U+3398 .. U+339F --*/
   "cm^2"  , "m^2"   , "km^2"  , "mm^4"  , "cm^3"  , "m^3"   , "km^3"  , "m/s"   ,  /*-- U+33A0 .. U+33A7 --*/
   "m/s^2" , "Pa"    , "kPa"   , "MPa"   , "GPa"   , "rad"   , "rad/s" , "rad/s^2",  /*-- U+33A8 .. U+33AF --*/
   "ps"    , "ns"    , "microsecond", "ms"    , "pV"    , "nV"    , "microvolt", "mV"    ,  /*-- U+33B0 .. U+33B7 --*/
   "kV"    , "MV"    , "pW"    , "nW"    , "microwatt", "mW"    , "kW"    , "MW"    ,  /*-- U+33B8 .. U+33BF --*/
   "kOhm"  , "MOhm"  , "a.m."  , "Bq"    , "cc"    , "cd"    , "C/kg"  , "Co."   ,  /*-- U+33C0 .. U+33C7 --*/
   "dB"    , "Gy"    , "ha"    , "HP"    , "in"    , "K.K."  , "KM"    , "kt"    ,  /*-- U+33C8 .. U+33CF --*/
   "lm"    , "ln"    , "log"   , "lx"    , "mb"    , "mil"   , "mol"   , "pH"    ,  /*-- U+33D0 .. U+33D7 --*/
   "p.m."  , "PPM"   , "PR"    , "sr"    , "Sv"    , "Wb"    , ""      , ""      ,  /*-- U+33D8 .. U+33DF --*/
   "1d"    , "2d"    , "3d"    , "4d"    , "5d"    , "6d"    , "7d"    , "8d"    ,  /*-- U+33E0 .. U+33E7 --*/
   "9d"    , "10d"   , "11d"   , "12d"   , "13d"   , "14d"   , "15d"   , "16d"   ,  /*-- U+33E8 .. U+33EF --*/
   "17d"   , "18d"   , "19d"   , "20d"   , "21d"   , "22d"   , "23d"   , "24d"   ,  /*-- U+33F0 .. U+33F7 --*/
   "25d"   , "26d"   , "27d"   , "28d"   , "29d"   , "30d"   , "31d"   , ""      ,  /*-- U+33F8 .. U+33FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3400 .. U+3407 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3408 .. U+340F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3410 .. U+3417 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3418 .. U+341F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3420 .. U+3427 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3428 .. U+342F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3430 .. U+3437 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3438 .. U+343F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3440 .. U+3447 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3448 .. U+344F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3450 .. U+3457 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3458 .. U+345F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3460 .. U+3467 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3468 .. U+346F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3470 .. U+3477 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3478 .. U+347F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3480 .. U+3487 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3488 .. U+348F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3490 .. U+3497 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3498 .. U+349F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34A0 .. U+34A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34A8 .. U+34AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34B0 .. U+34B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34B8 .. U+34BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34C0 .. U+34C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34C8 .. U+34CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34D0 .. U+34D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34D8 .. U+34DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34E0 .. U+34E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34E8 .. U+34EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34F0 .. U+34F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+34F8 .. U+34FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3500 .. U+3507 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3508 .. U+350F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3510 .. U+3517 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3518 .. U+351F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3520 .. U+3527 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3528 .. U+352F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3530 .. U+3537 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3538 .. U+353F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3540 .. U+3547 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3548 .. U+354F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3550 .. U+3557 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3558 .. U+355F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3560 .. U+3567 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3568 .. U+356F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3570 .. U+3577 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3578 .. U+357F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3580 .. U+3587 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3588 .. U+358F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3590 .. U+3597 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3598 .. U+359F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35A0 .. U+35A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35A8 .. U+35AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35B0 .. U+35B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35B8 .. U+35BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35C0 .. U+35C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35C8 .. U+35CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35D0 .. U+35D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35D8 .. U+35DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35E0 .. U+35E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35E8 .. U+35EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35F0 .. U+35F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+35F8 .. U+35FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3600 .. U+3607 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3608 .. U+360F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3610 .. U+3617 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3618 .. U+361F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3620 .. U+3627 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3628 .. U+362F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3630 .. U+3637 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3638 .. U+363F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3640 .. U+3647 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3648 .. U+364F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3650 .. U+3657 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3658 .. U+365F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3660 .. U+3667 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3668 .. U+366F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3670 .. U+3677 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3678 .. U+367F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3680 .. U+3687 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3688 .. U+368F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3690 .. U+3697 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3698 .. U+369F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36A0 .. U+36A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36A8 .. U+36AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36B0 .. U+36B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36B8 .. U+36BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36C0 .. U+36C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36C8 .. U+36CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36D0 .. U+36D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36D8 .. U+36DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36E0 .. U+36E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36E8 .. U+36EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36F0 .. U+36F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+36F8 .. U+36FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3700 .. U+3707 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3708 .. U+370F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3710 .. U+3717 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3718 .. U+371F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3720 .. U+3727 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3728 .. U+372F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3730 .. U+3737 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3738 .. U+373F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3740 .. U+3747 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3748 .. U+374F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3750 .. U+3757 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3758 .. U+375F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3760 .. U+3767 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3768 .. U+376F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3770 .. U+3777 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3778 .. U+377F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3780 .. U+3787 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3788 .. U+378F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3790 .. U+3797 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3798 .. U+379F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37A0 .. U+37A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37A8 .. U+37AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37B0 .. U+37B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37B8 .. U+37BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37C0 .. U+37C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37C8 .. U+37CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37D0 .. U+37D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37D8 .. U+37DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37E0 .. U+37E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37E8 .. U+37EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37F0 .. U+37F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+37F8 .. U+37FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3800 .. U+3807 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3808 .. U+380F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3810 .. U+3817 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3818 .. U+381F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3820 .. U+3827 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3828 .. U+382F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3830 .. U+3837 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3838 .. U+383F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3840 .. U+3847 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3848 .. U+384F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3850 .. U+3857 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3858 .. U+385F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3860 .. U+3867 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3868 .. U+386F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3870 .. U+3877 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3878 .. U+387F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3880 .. U+3887 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3888 .. U+388F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3890 .. U+3897 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3898 .. U+389F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38A0 .. U+38A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38A8 .. U+38AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38B0 .. U+38B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38B8 .. U+38BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38C0 .. U+38C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38C8 .. U+38CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38D0 .. U+38D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38D8 .. U+38DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38E0 .. U+38E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38E8 .. U+38EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38F0 .. U+38F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+38F8 .. U+38FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3900 .. U+3907 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3908 .. U+390F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3910 .. U+3917 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3918 .. U+391F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3920 .. U+3927 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3928 .. U+392F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3930 .. U+3937 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3938 .. U+393F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3940 .. U+3947 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3948 .. U+394F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3950 .. U+3957 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3958 .. U+395F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3960 .. U+3967 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3968 .. U+396F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3970 .. U+3977 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3978 .. U+397F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3980 .. U+3987 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3988 .. U+398F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3990 .. U+3997 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3998 .. U+399F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39A0 .. U+39A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39A8 .. U+39AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39B0 .. U+39B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39B8 .. U+39BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39C0 .. U+39C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39C8 .. U+39CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39D0 .. U+39D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39D8 .. U+39DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39E0 .. U+39E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39E8 .. U+39EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39F0 .. U+39F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+39F8 .. U+39FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A00 .. U+3A07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A08 .. U+3A0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A10 .. U+3A17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A18 .. U+3A1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A20 .. U+3A27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A28 .. U+3A2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A30 .. U+3A37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A38 .. U+3A3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A40 .. U+3A47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A48 .. U+3A4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A50 .. U+3A57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A58 .. U+3A5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A60 .. U+3A67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A68 .. U+3A6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A70 .. U+3A77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A78 .. U+3A7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A80 .. U+3A87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A88 .. U+3A8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A90 .. U+3A97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3A98 .. U+3A9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AA0 .. U+3AA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AA8 .. U+3AAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AB0 .. U+3AB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AB8 .. U+3ABF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AC0 .. U+3AC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AC8 .. U+3ACF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AD0 .. U+3AD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AD8 .. U+3ADF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AE0 .. U+3AE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AE8 .. U+3AEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AF0 .. U+3AF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3AF8 .. U+3AFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B00 .. U+3B07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B08 .. U+3B0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B10 .. U+3B17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B18 .. U+3B1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B20 .. U+3B27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B28 .. U+3B2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B30 .. U+3B37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B38 .. U+3B3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B40 .. U+3B47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B48 .. U+3B4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B50 .. U+3B57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B58 .. U+3B5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B60 .. U+3B67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B68 .. U+3B6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B70 .. U+3B77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B78 .. U+3B7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B80 .. U+3B87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B88 .. U+3B8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B90 .. U+3B97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3B98 .. U+3B9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BA0 .. U+3BA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BA8 .. U+3BAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BB0 .. U+3BB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BB8 .. U+3BBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BC0 .. U+3BC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BC8 .. U+3BCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BD0 .. U+3BD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BD8 .. U+3BDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BE0 .. U+3BE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BE8 .. U+3BEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BF0 .. U+3BF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3BF8 .. U+3BFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C00 .. U+3C07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C08 .. U+3C0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C10 .. U+3C17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C18 .. U+3C1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C20 .. U+3C27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C28 .. U+3C2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C30 .. U+3C37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C38 .. U+3C3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C40 .. U+3C47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C48 .. U+3C4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C50 .. U+3C57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C58 .. U+3C5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C60 .. U+3C67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C68 .. U+3C6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C70 .. U+3C77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C78 .. U+3C7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C80 .. U+3C87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C88 .. U+3C8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C90 .. U+3C97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3C98 .. U+3C9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CA0 .. U+3CA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CA8 .. U+3CAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CB0 .. U+3CB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CB8 .. U+3CBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CC0 .. U+3CC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CC8 .. U+3CCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CD0 .. U+3CD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CD8 .. U+3CDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CE0 .. U+3CE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CE8 .. U+3CEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CF0 .. U+3CF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3CF8 .. U+3CFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D00 .. U+3D07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D08 .. U+3D0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D10 .. U+3D17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D18 .. U+3D1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D20 .. U+3D27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D28 .. U+3D2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D30 .. U+3D37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D38 .. U+3D3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D40 .. U+3D47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D48 .. U+3D4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D50 .. U+3D57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D58 .. U+3D5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D60 .. U+3D67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D68 .. U+3D6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D70 .. U+3D77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D78 .. U+3D7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D80 .. U+3D87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D88 .. U+3D8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D90 .. U+3D97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3D98 .. U+3D9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DA0 .. U+3DA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DA8 .. U+3DAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DB0 .. U+3DB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DB8 .. U+3DBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DC0 .. U+3DC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DC8 .. U+3DCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DD0 .. U+3DD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DD8 .. U+3DDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DE0 .. U+3DE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DE8 .. U+3DEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DF0 .. U+3DF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3DF8 .. U+3DFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E00 .. U+3E07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E08 .. U+3E0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E10 .. U+3E17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E18 .. U+3E1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E20 .. U+3E27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E28 .. U+3E2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E30 .. U+3E37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E38 .. U+3E3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E40 .. U+3E47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E48 .. U+3E4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E50 .. U+3E57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E58 .. U+3E5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E60 .. U+3E67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E68 .. U+3E6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E70 .. U+3E77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E78 .. U+3E7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E80 .. U+3E87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E88 .. U+3E8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E90 .. U+3E97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3E98 .. U+3E9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EA0 .. U+3EA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EA8 .. U+3EAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EB0 .. U+3EB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EB8 .. U+3EBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EC0 .. U+3EC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EC8 .. U+3ECF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3ED0 .. U+3ED7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3ED8 .. U+3EDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EE0 .. U+3EE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EE8 .. U+3EEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EF0 .. U+3EF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3EF8 .. U+3EFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F00 .. U+3F07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F08 .. U+3F0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F10 .. U+3F17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F18 .. U+3F1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F20 .. U+3F27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F28 .. U+3F2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F30 .. U+3F37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F38 .. U+3F3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F40 .. U+3F47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F48 .. U+3F4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F50 .. U+3F57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F58 .. U+3F5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F60 .. U+3F67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F68 .. U+3F6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F70 .. U+3F77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F78 .. U+3F7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F80 .. U+3F87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F88 .. U+3F8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F90 .. U+3F97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3F98 .. U+3F9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FA0 .. U+3FA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FA8 .. U+3FAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FB0 .. U+3FB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FB8 .. U+3FBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FC0 .. U+3FC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FC8 .. U+3FCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FD0 .. U+3FD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FD8 .. U+3FDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FE0 .. U+3FE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FE8 .. U+3FEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FF0 .. U+3FF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+3FF8 .. U+3FFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4000 .. U+4007 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4008 .. U+400F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4010 .. U+4017 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4018 .. U+401F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4020 .. U+4027 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4028 .. U+402F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4030 .. U+4037 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4038 .. U+403F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4040 .. U+4047 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4048 .. U+404F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4050 .. U+4057 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4058 .. U+405F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4060 .. U+4067 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4068 .. U+406F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4070 .. U+4077 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4078 .. U+407F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4080 .. U+4087 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4088 .. U+408F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4090 .. U+4097 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4098 .. U+409F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40A0 .. U+40A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40A8 .. U+40AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40B0 .. U+40B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40B8 .. U+40BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40C0 .. U+40C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40C8 .. U+40CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40D0 .. U+40D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40D8 .. U+40DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40E0 .. U+40E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40E8 .. U+40EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40F0 .. U+40F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+40F8 .. U+40FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4100 .. U+4107 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4108 .. U+410F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4110 .. U+4117 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4118 .. U+411F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4120 .. U+4127 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4128 .. U+412F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4130 .. U+4137 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4138 .. U+413F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4140 .. U+4147 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4148 .. U+414F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4150 .. U+4157 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4158 .. U+415F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4160 .. U+4167 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4168 .. U+416F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4170 .. U+4177 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4178 .. U+417F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4180 .. U+4187 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4188 .. U+418F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4190 .. U+4197 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4198 .. U+419F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41A0 .. U+41A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41A8 .. U+41AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41B0 .. U+41B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41B8 .. U+41BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41C0 .. U+41C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41C8 .. U+41CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41D0 .. U+41D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41D8 .. U+41DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41E0 .. U+41E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41E8 .. U+41EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41F0 .. U+41F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+41F8 .. U+41FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4200 .. U+4207 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4208 .. U+420F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4210 .. U+4217 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4218 .. U+421F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4220 .. U+4227 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4228 .. U+422F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4230 .. U+4237 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4238 .. U+423F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4240 .. U+4247 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4248 .. U+424F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4250 .. U+4257 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4258 .. U+425F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4260 .. U+4267 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4268 .. U+426F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4270 .. U+4277 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4278 .. U+427F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4280 .. U+4287 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4288 .. U+428F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4290 .. U+4297 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4298 .. U+429F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42A0 .. U+42A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42A8 .. U+42AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42B0 .. U+42B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42B8 .. U+42BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42C0 .. U+42C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42C8 .. U+42CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42D0 .. U+42D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42D8 .. U+42DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42E0 .. U+42E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42E8 .. U+42EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42F0 .. U+42F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+42F8 .. U+42FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4300 .. U+4307 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4308 .. U+430F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4310 .. U+4317 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4318 .. U+431F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4320 .. U+4327 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4328 .. U+432F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4330 .. U+4337 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4338 .. U+433F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4340 .. U+4347 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4348 .. U+434F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4350 .. U+4357 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4358 .. U+435F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4360 .. U+4367 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4368 .. U+436F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4370 .. U+4377 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4378 .. U+437F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4380 .. U+4387 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4388 .. U+438F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4390 .. U+4397 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4398 .. U+439F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43A0 .. U+43A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43A8 .. U+43AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43B0 .. U+43B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43B8 .. U+43BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43C0 .. U+43C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43C8 .. U+43CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43D0 .. U+43D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43D8 .. U+43DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43E0 .. U+43E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43E8 .. U+43EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43F0 .. U+43F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+43F8 .. U+43FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4400 .. U+4407 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4408 .. U+440F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4410 .. U+4417 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4418 .. U+441F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4420 .. U+4427 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4428 .. U+442F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4430 .. U+4437 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4438 .. U+443F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4440 .. U+4447 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4448 .. U+444F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4450 .. U+4457 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4458 .. U+445F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4460 .. U+4467 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4468 .. U+446F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4470 .. U+4477 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4478 .. U+447F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4480 .. U+4487 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4488 .. U+448F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4490 .. U+4497 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4498 .. U+449F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44A0 .. U+44A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44A8 .. U+44AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44B0 .. U+44B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44B8 .. U+44BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44C0 .. U+44C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44C8 .. U+44CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44D0 .. U+44D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44D8 .. U+44DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44E0 .. U+44E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44E8 .. U+44EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44F0 .. U+44F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+44F8 .. U+44FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4500 .. U+4507 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4508 .. U+450F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4510 .. U+4517 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4518 .. U+451F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4520 .. U+4527 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4528 .. U+452F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4530 .. U+4537 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4538 .. U+453F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4540 .. U+4547 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4548 .. U+454F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4550 .. U+4557 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4558 .. U+455F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4560 .. U+4567 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4568 .. U+456F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4570 .. U+4577 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4578 .. U+457F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4580 .. U+4587 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4588 .. U+458F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4590 .. U+4597 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4598 .. U+459F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45A0 .. U+45A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45A8 .. U+45AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45B0 .. U+45B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45B8 .. U+45BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45C0 .. U+45C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45C8 .. U+45CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45D0 .. U+45D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45D8 .. U+45DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45E0 .. U+45E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45E8 .. U+45EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45F0 .. U+45F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+45F8 .. U+45FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4600 .. U+4607 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4608 .. U+460F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4610 .. U+4617 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4618 .. U+461F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4620 .. U+4627 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4628 .. U+462F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4630 .. U+4637 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4638 .. U+463F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4640 .. U+4647 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4648 .. U+464F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4650 .. U+4657 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4658 .. U+465F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4660 .. U+4667 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4668 .. U+466F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4670 .. U+4677 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4678 .. U+467F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4680 .. U+4687 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4688 .. U+468F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4690 .. U+4697 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4698 .. U+469F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46A0 .. U+46A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46A8 .. U+46AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46B0 .. U+46B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46B8 .. U+46BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46C0 .. U+46C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46C8 .. U+46CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46D0 .. U+46D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46D8 .. U+46DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46E0 .. U+46E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46E8 .. U+46EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46F0 .. U+46F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+46F8 .. U+46FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4700 .. U+4707 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4708 .. U+470F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4710 .. U+4717 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4718 .. U+471F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4720 .. U+4727 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4728 .. U+472F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4730 .. U+4737 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4738 .. U+473F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4740 .. U+4747 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4748 .. U+474F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4750 .. U+4757 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4758 .. U+475F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4760 .. U+4767 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4768 .. U+476F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4770 .. U+4777 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4778 .. U+477F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4780 .. U+4787 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4788 .. U+478F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4790 .. U+4797 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4798 .. U+479F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47A0 .. U+47A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47A8 .. U+47AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47B0 .. U+47B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47B8 .. U+47BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47C0 .. U+47C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47C8 .. U+47CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47D0 .. U+47D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47D8 .. U+47DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47E0 .. U+47E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47E8 .. U+47EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47F0 .. U+47F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+47F8 .. U+47FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4800 .. U+4807 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4808 .. U+480F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4810 .. U+4817 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4818 .. U+481F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4820 .. U+4827 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4828 .. U+482F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4830 .. U+4837 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4838 .. U+483F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4840 .. U+4847 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4848 .. U+484F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4850 .. U+4857 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4858 .. U+485F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4860 .. U+4867 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4868 .. U+486F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4870 .. U+4877 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4878 .. U+487F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4880 .. U+4887 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4888 .. U+488F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4890 .. U+4897 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4898 .. U+489F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48A0 .. U+48A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48A8 .. U+48AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48B0 .. U+48B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48B8 .. U+48BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48C0 .. U+48C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48C8 .. U+48CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48D0 .. U+48D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48D8 .. U+48DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48E0 .. U+48E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48E8 .. U+48EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48F0 .. U+48F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+48F8 .. U+48FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4900 .. U+4907 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4908 .. U+490F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4910 .. U+4917 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4918 .. U+491F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4920 .. U+4927 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4928 .. U+492F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4930 .. U+4937 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4938 .. U+493F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4940 .. U+4947 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4948 .. U+494F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4950 .. U+4957 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4958 .. U+495F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4960 .. U+4967 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4968 .. U+496F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4970 .. U+4977 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4978 .. U+497F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4980 .. U+4987 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4988 .. U+498F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4990 .. U+4997 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4998 .. U+499F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49A0 .. U+49A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49A8 .. U+49AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49B0 .. U+49B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49B8 .. U+49BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49C0 .. U+49C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49C8 .. U+49CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49D0 .. U+49D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49D8 .. U+49DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49E0 .. U+49E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49E8 .. U+49EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49F0 .. U+49F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+49F8 .. U+49FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A00 .. U+4A07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A08 .. U+4A0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A10 .. U+4A17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A18 .. U+4A1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A20 .. U+4A27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A28 .. U+4A2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A30 .. U+4A37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A38 .. U+4A3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A40 .. U+4A47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A48 .. U+4A4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A50 .. U+4A57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A58 .. U+4A5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A60 .. U+4A67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A68 .. U+4A6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A70 .. U+4A77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A78 .. U+4A7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A80 .. U+4A87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A88 .. U+4A8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A90 .. U+4A97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4A98 .. U+4A9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AA0 .. U+4AA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AA8 .. U+4AAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AB0 .. U+4AB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AB8 .. U+4ABF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AC0 .. U+4AC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AC8 .. U+4ACF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AD0 .. U+4AD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AD8 .. U+4ADF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AE0 .. U+4AE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AE8 .. U+4AEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AF0 .. U+4AF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4AF8 .. U+4AFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B00 .. U+4B07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B08 .. U+4B0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B10 .. U+4B17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B18 .. U+4B1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B20 .. U+4B27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B28 .. U+4B2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B30 .. U+4B37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B38 .. U+4B3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B40 .. U+4B47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B48 .. U+4B4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B50 .. U+4B57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B58 .. U+4B5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B60 .. U+4B67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B68 .. U+4B6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B70 .. U+4B77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B78 .. U+4B7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B80 .. U+4B87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B88 .. U+4B8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B90 .. U+4B97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4B98 .. U+4B9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BA0 .. U+4BA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BA8 .. U+4BAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BB0 .. U+4BB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BB8 .. U+4BBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BC0 .. U+4BC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BC8 .. U+4BCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BD0 .. U+4BD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BD8 .. U+4BDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BE0 .. U+4BE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BE8 .. U+4BEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BF0 .. U+4BF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4BF8 .. U+4BFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C00 .. U+4C07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C08 .. U+4C0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C10 .. U+4C17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C18 .. U+4C1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C20 .. U+4C27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C28 .. U+4C2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C30 .. U+4C37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C38 .. U+4C3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C40 .. U+4C47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C48 .. U+4C4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C50 .. U+4C57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C58 .. U+4C5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C60 .. U+4C67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C68 .. U+4C6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C70 .. U+4C77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C78 .. U+4C7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C80 .. U+4C87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C88 .. U+4C8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C90 .. U+4C97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4C98 .. U+4C9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CA0 .. U+4CA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CA8 .. U+4CAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CB0 .. U+4CB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CB8 .. U+4CBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CC0 .. U+4CC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CC8 .. U+4CCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CD0 .. U+4CD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CD8 .. U+4CDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CE0 .. U+4CE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CE8 .. U+4CEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CF0 .. U+4CF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4CF8 .. U+4CFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D00 .. U+4D07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D08 .. U+4D0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D10 .. U+4D17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D18 .. U+4D1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D20 .. U+4D27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D28 .. U+4D2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D30 .. U+4D37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D38 .. U+4D3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D40 .. U+4D47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D48 .. U+4D4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D50 .. U+4D57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D58 .. U+4D5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D60 .. U+4D67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D68 .. U+4D6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D70 .. U+4D77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D78 .. U+4D7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D80 .. U+4D87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D88 .. U+4D8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D90 .. U+4D97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4D98 .. U+4D9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DA0 .. U+4DA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DA8 .. U+4DAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DB0 .. U+4DB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DB8 .. U+4DBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DC0 .. U+4DC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DC8 .. U+4DCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DD0 .. U+4DD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DD8 .. U+4DDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DE0 .. U+4DE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DE8 .. U+4DEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DF0 .. U+4DF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+4DF8 .. U+4DFF --*/
   ""      , "Ding " , "Kao "  , "Qi "   , "Shang ", "Xia "  , ""      , "Mo "   ,  /*-- U+4E00 .. U+4E07 --*/
   "Zhang ", "San "  , "Shang ", "Xia "  , "Ji "   , "Bu "   , "Yu "   , "Mian " ,  /*-- U+4E08 .. U+4E0F --*/
   "Gai "  , "Chou " , "Chou " , "Zhuan ", "Qie "  , "Pi "   , "Shi "  , "Shi "  ,  /*-- U+4E10 .. U+4E17 --*/
   "Qiu "  , "Bing " , "Ye "   , "Cong " , "Dong " , "Si "   , "Cheng ", "Diu "  ,  /*-- U+4E18 .. U+4E1F --*/
   "Qiu "  , "Liang ", "Diu "  , "You "  , "Liang ", "Yan "  , "Bing " , "Sang " ,  /*-- U+4E20 .. U+4E27 --*/
   "Gun "  , "Jiu "  , "Ge "   , "Ya "   , "Qiang ", "Zhong ", "Ji "   , "Jie "  ,  /*-- U+4E28 .. U+4E2F --*/
   "Feng " , "Guan " , "Chuan ", "Chan " , "Lin "  , "Zhuo " , "Zhu "  , "Ha "   ,  /*-- U+4E30 .. U+4E37 --*/
   "Wan "  , "Dan "  , "Wei "  , "Zhu "  , "Jing " , "Li "   , "Ju "   , "Pie "  ,  /*-- U+4E38 .. U+4E3F --*/
   "Fu "   , "Yi "   , "Yi "   , "Nai "  , "Shime ", "Jiu "  , "Jiu "  , "Zhe "  ,  /*-- U+4E40 .. U+4E47 --*/
   "Yao "  , "Yi "   , ""      , "Zhi "  , "Wu "   , "Zha "  , "Hu "   , "Fa "   ,  /*-- U+4E48 .. U+4E4F --*/
   "Le "   , "Zhong ", "Ping " , "Pang " , "Qiao " , "Hu "   , "Guai " , "Cheng ",  /*-- U+4E50 .. U+4E57 --*/
   "Cheng ", "Yi "   , "Yin "  , ""      , "Mie "  , "Jiu "  , "Qi "   , "Ye "   ,  /*-- U+4E58 .. U+4E5F --*/
   "Xi "   , "Xiang ", "Gai "  , "Diu "  , "Hal "  , ""      , "Shu "  , "Twul " ,  /*-- U+4E60 .. U+4E67 --*/
   "Shi "  , "Ji "   , "Nang " , "Jia "  , "Kel "  , "Shi "  , ""      , "Ol "   ,  /*-- U+4E68 .. U+4E6F --*/
   "Mai "  , "Luan " , "Cal "  , "Ru "   , "Xue "  , "Yan "  , "Fu "   , "Sha "  ,  /*-- U+4E70 .. U+4E77 --*/
   "Na "   , "Gan "  , "Sol "  , "El "   , "Cwul " , ""      , "Gan "  , "Chi "  ,  /*-- U+4E78 .. U+4E7F --*/
   "Gui "  , "Gan "  , "Luan " , "Lin "  , "Yi "   , "Jue "  , "Liao " , "Ma "   ,  /*-- U+4E80 .. U+4E87 --*/
   "Yu "   , "Zheng ", "Shi "  , "Shi "  , "Er "   , "Chu "  , "Yu "   , "Yu "   ,  /*-- U+4E88 .. U+4E8F --*/
   "Yu "   , "Yun "  , "Hu "   , "Qi "   , "Wu "   , "Jing " , "Si "   , "Sui "  ,  /*-- U+4E90 .. U+4E97 --*/
   "Gen "  , "Gen "  , "Ya "   , "Xie "  , "Ya "   , "Qi "   , "Ya "   , "Ji "   ,  /*-- U+4E98 .. U+4E9F --*/
   "Tou "  , "Wang " , "Kang " , "Ta "   , "Jiao " , "Hai "  , "Yi "   , "Chan " ,  /*-- U+4EA0 .. U+4EA7 --*/
   "Heng " , "Mu "   , ""      , "Xiang ", "Jing " , "Ting " , "Liang ", "Xiang ",  /*-- U+4EA8 .. U+4EAF --*/
   "Jing " , "Ye "   , "Qin "  , "Bo "   , "You "  , "Xie "  , "Dan "  , "Lian " ,  /*-- U+4EB0 .. U+4EB7 --*/
   "Duo "  , "Wei "  , "Ren "  , "Ren "  , "Ji "   , "La "   , "Wang " , "Yi "   ,  /*-- U+4EB8 .. U+4EBF --*/
   "Shi "  , "Ren "  , "Le "   , "Ding " , "Ze "   , "Jin "  , "Pu "   , "Chou " ,  /*-- U+4EC0 .. U+4EC7 --*/
   "Ba "   , "Zhang ", "Jin "  , "Jie "  , "Bing " , "Reng " , "Cong " , "Fo "   ,  /*-- U+4EC8 .. U+4ECF --*/
   "San "  , "Lun "  , "Sya "  , "Cang " , "Zi "   , "Shi "  , "Ta "   , "Zhang ",  /*-- U+4ED0 .. U+4ED7 --*/
   "Fu "   , "Xian " , "Xian " , "Tuo "  , "Hong " , "Tong " , "Ren "  , "Qian " ,  /*-- U+4ED8 .. U+4EDF --*/
   "Gan "  , "Yi "   , "Di "   , "Dai "  , "Ling " , "Yi "   , "Chao " , "Chang ",  /*-- U+4EE0 .. U+4EE7 --*/
   "Sa "   , ""      , "Yi "   , "Mu "   , "Men "  , "Ren "  , "Jia "  , "Chao " ,  /*-- U+4EE8 .. U+4EEF --*/
   "Yang " , "Qian " , "Zhong ", "Pi "   , "Wan "  , "Wu "   , "Jian " , "Jie "  ,  /*-- U+4EF0 .. U+4EF7 --*/
   "Yao "  , "Feng " , "Cang " , "Ren "  , "Wang " , "Fen "  , "Di "   , "Fang " ,  /*-- U+4EF8 .. U+4EFF --*/
   "Zhong ", "Qi "   , "Pei "  , "Yu "   , "Diao " , "Dun "  , "Wen "  , "Yi "   ,  /*-- U+4F00 .. U+4F07 --*/
   "Xin "  , "Kang " , "Yi "   , "Ji "   , "Ai "   , "Wu "   , "Ji "   , "Fu "   ,  /*-- U+4F08 .. U+4F0F --*/
   "Fa "   , "Xiu "  , "Jin "  , "Bei "  , "Dan "  , "Fu "   , "Tang " , "Zhong ",  /*-- U+4F10 .. U+4F17 --*/
   "You "  , "Huo "  , "Hui "  , "Yu "   , "Cui "  , "Chuan ", "San "  , "Wei "  ,  /*-- U+4F18 .. U+4F1F --*/
   "Chuan ", "Che "  , "Ya "   , "Xian " , "Shang ", "Chang ", "Lun "  , "Cang " ,  /*-- U+4F20 .. U+4F27 --*/
   "Xun "  , "Xin "  , "Wei "  , "Zhu "  , ""      , "Xuan " , "Nu "   , "Bo "   ,  /*-- U+4F28 .. U+4F2F --*/
   "Gu "   , "Ni "   , "Ni "   , "Xie "  , "Ban "  , "Xu "   , "Ling " , "Zhou " ,  /*-- U+4F30 .. U+4F37 --*/
   "Shen " , "Qu "   , "Si "   , "Beng " , "Si "   , "Jia "  , "Pi "   , "Yi "   ,  /*-- U+4F38 .. U+4F3F --*/
   "Si "   , "Ai "   , "Zheng ", "Dian " , "Han "  , "Mai "  , "Dan "  , "Zhu "  ,  /*-- U+4F40 .. U+4F47 --*/
   "Bu "   , "Qu "   , "Bi "   , "Shao " , "Ci "   , "Wei "  , "Di "   , "Zhu "  ,  /*-- U+4F48 .. U+4F4F --*/
   "Zuo "  , "You "  , "Yang " , "Ti "   , "Zhan " , "He "   , "Bi "   , "Tuo "  ,  /*-- U+4F50 .. U+4F57 --*/
   "She "  , "Yu "   , "Yi "   , "Fo "   , "Zuo "  , "Kou "  , "Ning " , "Tong " ,  /*-- U+4F58 .. U+4F5F --*/
   "Ni "   , "Xuan " , "Qu "   , "Yong " , "Wa "   , "Qian " , ""      , "Ka "   ,  /*-- U+4F60 .. U+4F67 --*/
   ""      , "Pei "  , "Huai " , "He "   , "Lao "  , "Xiang ", "Ge "   , "Yang " ,  /*-- U+4F68 .. U+4F6F --*/
   "Bai "  , "Fa "   , "Ming " , "Jia "  , "Er "   , "Bing " , "Ji "   , "Hen "  ,  /*-- U+4F70 .. U+4F77 --*/
   "Huo "  , "Gui "  , "Quan " , "Tiao " , "Jiao " , "Ci "   , "Yi "   , "Shi "  ,  /*-- U+4F78 .. U+4F7F --*/
   "Xing " , "Shen " , "Tuo "  , "Kan "  , "Zhi "  , "Gai "  , "Lai "  , "Yi "   ,  /*-- U+4F80 .. U+4F87 --*/
   "Chi "  , "Kua "  , "Guang ", "Li "   , "Yin "  , "Shi "  , "Mi "   , "Zhu "  ,  /*-- U+4F88 .. U+4F8F --*/
   "Xu "   , "You "  , "An "   , "Lu "   , "Mou "  , "Er "   , "Lun "  , "Tong " ,  /*-- U+4F90 .. U+4F97 --*/
   "Cha "  , "Chi "  , "Xun "  , "Gong " , "Zhou " , "Yi "   , "Ru "   , "Jian " ,  /*-- U+4F98 .. U+4F9F --*/
   "Xia "  , "Jia "  , "Zai "  , "Lu "   , "Ko "   , "Jiao " , "Zhen " , "Ce "   ,  /*-- U+4FA0 .. U+4FA7 --*/
   "Qiao " , "Kuai " , "Chai " , "Ning " , "Nong " , "Jin "  , "Wu "   , "Hou "  ,  /*-- U+4FA8 .. U+4FAF --*/
   "Jiong ", "Cheng ", "Zhen " , "Zuo "  , "Chou " , "Qin "  , "Lu "   , "Ju "   ,  /*-- U+4FB0 .. U+4FB7 --*/
   "Shu "  , "Ting " , "Shen " , "Tuo "  , "Bo "   , "Nan "  , "Hao "  , "Bian " ,  /*-- U+4FB8 .. U+4FBF --*/
   "Tui "  , "Yu "   , "Xi "   , "Cu "   , "E "    , "Qiu "  , "Xu "   , "Kuang ",  /*-- U+4FC0 .. U+4FC7 --*/
   "Ku "   , "Wu "   , "Jun "  , "Yi "   , "Fu "   , "Lang " , "Zu "   , "Qiao " ,  /*-- U+4FC8 .. U+4FCF --*/
   "Li "   , "Yong " , "Hun "  , "Jing " , "Xian " , "San "  , "Pai "  , "Su "   ,  /*-- U+4FD0 .. U+4FD7 --*/
   "Fu "   , "Xi "   , "Li "   , "Fu "   , "Ping " , "Bao "  , "Yu "   , "Si "   ,  /*-- U+4FD8 .. U+4FDF --*/
   "Xia "  , "Xin "  , "Xiu "  , "Yu "   , "Ti "   , "Che "  , "Chou " , ""      ,  /*-- U+4FE0 .. U+4FE7 --*/
   "Yan "  , "Lia "  , "Li "   , "Lai "  , ""      , "Jian " , "Xiu "  , "Fu "   ,  /*-- U+4FE8 .. U+4FEF --*/
   "He "   , "Ju "   , "Xiao " , "Pai "  , "Jian " , "Biao " , "Chu "  , "Fei "  ,  /*-- U+4FF0 .. U+4FF7 --*/
   "Feng " , "Ya "   , "An "   , "Bei "  , "Yu "   , "Xin "  , "Bi "   , "Jian " ,  /*-- U+4FF8 .. U+4FFF --*/
   "Chang ", "Chi "  , "Bing " , "Zan "  , "Yao "  , "Cui "  , "Lia "  , "Wan "  ,  /*-- U+5000 .. U+5007 --*/
   "Lai "  , "Cang " , "Zong " , "Ge "   , "Guan " , "Bei "  , "Tian " , "Shu "  ,  /*-- U+5008 .. U+500F --*/
   "Shu "  , "Men "  , "Dao "  , "Tan "  , "Jue "  , "Chui " , "Xing " , "Peng " ,  /*-- U+5010 .. U+5017 --*/
   "Tang " , "Hou "  , "Yi "   , "Qi "   , "Ti "   , "Gan "  , "Jing " , "Jie "  ,  /*-- U+5018 .. U+501F --*/
   "Sui "  , "Chang ", "Jie "  , "Fang " , "Zhi "  , "Kong " , "Juan " , "Zong " ,  /*-- U+5020 .. U+5027 --*/
   "Ju "   , "Qian " , "Ni "   , "Lun "  , "Zhuo " , "Wei "  , "Luo "  , "Song " ,  /*-- U+5028 .. U+502F --*/
   "Leng " , "Hun "  , "Dong " , "Zi "   , "Ben "  , "Wu "   , "Ju "   , "Nai "  ,  /*-- U+5030 .. U+5037 --*/
   "Cai "  , "Jian " , "Zhai " , "Ye "   , "Zhi "  , "Sha "  , "Qing " , ""      ,  /*-- U+5038 .. U+503F --*/
   "Ying " , "Cheng ", "Jian " , "Yan "  , "Nuan " , "Zhong ", "Chun " , "Jia "  ,  /*-- U+5040 .. U+5047 --*/
   "Jie "  , "Wei "  , "Yu "   , "Bing " , "Ruo "  , "Ti "   , "Wei "  , "Pian " ,  /*-- U+5048 .. U+504F --*/
   "Yan "  , "Feng " , "Tang " , "Wo "   , "E "    , "Xie "  , "Che "  , "Sheng ",  /*-- U+5050 .. U+5057 --*/
   "Kan "  , "Di "   , "Zuo "  , "Cha "  , "Ting " , "Bei "  , "Ye "   , "Huang ",  /*-- U+5058 .. U+505F --*/
   "Yao "  , "Zhan " , "Chou " , "Yan "  , "You "  , "Jian " , "Xu "   , "Zha "  ,  /*-- U+5060 .. U+5067 --*/
   "Ci "   , "Fu "   , "Bi "   , "Zhi "  , "Zong " , "Mian " , "Ji "   , "Yi "   ,  /*-- U+5068 .. U+506F --*/
   "Xie "  , "Xun "  , "Si "   , "Duan " , "Ce "   , "Zhen " , "Ou "   , "Tou "  ,  /*-- U+5070 .. U+5077 --*/
   "Tou "  , "Bei "  , "Za "   , "Lu "   , "Jie "  , "Wei "  , "Fen "  , "Chang ",  /*-- U+5078 .. U+507F --*/
   "Gui "  , "Sou "  , "Zhi "  , "Su "   , "Xia "  , "Fu "   , "Yuan " , "Rong " ,  /*-- U+5080 .. U+5087 --*/
   "Li "   , "Ru "   , "Yun "  , "Gou "  , "Ma "   , "Bang " , "Dian " , "Tang " ,  /*-- U+5088 .. U+508F --*/
   "Hao "  , "Jie "  , "Xi "   , "Shan " , "Qian " , "Jue "  , "Cang " , "Chu "  ,  /*-- U+5090 .. U+5097 --*/
   "San "  , "Bei "  , "Xiao " , "Yong " , "Yao "  , "Tan "  , "Suo "  , "Yang " ,  /*-- U+5098 .. U+509F --*/
   "Fa "   , "Bing " , "Jia "  , "Dai "  , "Zai "  , "Tang " , ""      , "Bin "  ,  /*-- U+50A0 .. U+50A7 --*/
   "Chu "  , "Nuo "  , "Can "  , "Lei "  , "Cui "  , "Yong " , "Zao "  , "Zong " ,  /*-- U+50A8 .. U+50AF --*/
   "Peng " , "Song " , "Ao "   , "Chuan ", "Yu "   , "Zhai " , "Cou "  , "Shang ",  /*-- U+50B0 .. U+50B7 --*/
   "Qiang ", "Jing " , "Chi "  , "Sha "  , "Han "  , "Zhang ", "Qing " , "Yan "  ,  /*-- U+50B8 .. U+50BF --*/
   "Di "   , "Xi "   , "Lu "   , "Bei "  , "Piao " , "Jin "  , "Lian " , "Lu "   ,  /*-- U+50C0 .. U+50C7 --*/
   "Man "  , "Qian " , "Xian " , "Tan "  , "Ying " , "Dong " , "Zhuan ", "Xiang ",  /*-- U+50C8 .. U+50CF --*/
   "Shan " , "Qiao " , "Jiong ", "Tui "  , "Zun "  , "Pu "   , "Xi "   , "Lao "  ,  /*-- U+50D0 .. U+50D7 --*/
   "Chang ", "Guang ", "Liao " , "Qi "   , "Deng " , "Chan " , "Wei "  , "Ji "   ,  /*-- U+50D8 .. U+50DF --*/
   "Fan "  , "Hui "  , "Chuan ", "Jian " , "Dan "  , "Jiao " , "Jiu "  , "Seng " ,  /*-- U+50E0 .. U+50E7 --*/
   "Fen "  , "Xian " , "Jue "  , "E "    , "Jiao " , "Jian " , "Tong " , "Lin "  ,  /*-- U+50E8 .. U+50EF --*/
   "Bo "   , "Gu "   , ""      , "Su "   , "Xian " , "Jiang ", "Min "  , "Ye "   ,  /*-- U+50F0 .. U+50F7 --*/
   "Jin "  , "Jia "  , "Qiao " , "Pi "   , "Feng " , "Zhou " , "Ai "   , "Sai "  ,  /*-- U+50F8 .. U+50FF --*/
   "Yi "   , "Jun "  , "Nong " , "Chan " , "Yi "   , "Dang " , "Jing " , "Xuan " ,  /*-- U+5100 .. U+5107 --*/
   "Kuai " , "Jian " , "Chu "  , "Dan "  , "Jiao " , "Sha "  , "Zai "  , ""      ,  /*-- U+5108 .. U+510F --*/
   "Bin "  , "An "   , "Ru "   , "Tai "  , "Chou " , "Chai " , "Lan "  , "Ni "   ,  /*-- U+5110 .. U+5117 --*/
   "Jin "  , "Qian " , "Meng " , "Wu "   , "Ning " , "Qiong ", "Ni "   , "Chang ",  /*-- U+5118 .. U+511F --*/
   "Lie "  , "Lei "  , "Lu "   , "Kuang ", "Bao "  , "Du "   , "Biao " , "Zan "  ,  /*-- U+5120 .. U+5127 --*/
   "Zhi "  , "Si "   , "You "  , "Hao "  , "Chen " , "Chen " , "Li "   , "Teng " ,  /*-- U+5128 .. U+512F --*/
   "Wei "  , "Long " , "Chu "  , "Chan " , "Rang " , "Shu "  , "Hui "  , "Li "   ,  /*-- U+5130 .. U+5137 --*/
   "Luo "  , "Zan "  , "Nuo "  , "Tang " , "Yan "  , "Lei "  , "Nang " , "Er "   ,  /*-- U+5138 .. U+513F --*/
   "Wu "   , "Yun "  , "Zan "  , "Yuan " , "Xiong ", "Chong ", "Zhao " , "Xiong ",  /*-- U+5140 .. U+5147 --*/
   "Xian " , "Guang ", "Dui "  , "Ke "   , "Dui "  , "Mian " , "Tu "   , "Chang ",  /*-- U+5148 .. U+514F --*/
   "Er "   , "Dui "  , "Er "   , "Xin "  , "Tu "   , "Si "   , "Yan "  , "Yan "  ,  /*-- U+5150 .. U+5157 --*/
   "Shi "  , "Shi "  , "Dang " , "Qian " , "Dou "  , "Fen "  , "Mao "  , "Shen " ,  /*-- U+5158 .. U+515F --*/
   "Dou "  , "Bai "  , "Jing " , "Li "   , "Huang ", "Ru "   , "Wang " , "Nei "  ,  /*-- U+5160 .. U+5167 --*/
   "Quan " , "Liang ", "Yu "   , "Ba "   , "Gong " , "Liu "  , "Xi "   , ""      ,  /*-- U+5168 .. U+516F --*/
   "Lan "  , "Gong " , "Tian " , "Guan " , "Xing " , "Bing " , "Qi "   , "Ju "   ,  /*-- U+5170 .. U+5177 --*/
   "Dian " , "Zi "   , "Ppwun ", "Yang " , "Jian " , "Shou " , "Ji "   , "Yi "   ,  /*-- U+5178 .. U+517F --*/
   "Ji "   , "Chan " , "Jiong ", "Mao "  , "Ran "  , "Nei "  , "Yuan " , "Mao "  ,  /*-- U+5180 .. U+5187 --*/
   "Gang " , "Ran "  , "Ce "   , "Jiong ", "Ce "   , "Zai "  , "Gua "  , "Jiong ",  /*-- U+5188 .. U+518F --*/
   "Mao "  , "Zhou " , "Mou "  , "Gou "  , "Xu "   , "Mian " , "Mi "   , "Rong " ,  /*-- U+5190 .. U+5197 --*/
   "Yin "  , "Xie "  , "Kan "  , "Jun "  , "Nong " , "Yi "   , "Mi "   , "Shi "  ,  /*-- U+5198 .. U+519F --*/
   "Guan " , "Meng " , "Zhong ", "Ju "   , "Yuan " , "Ming " , "Kou "  , "Lam "  ,  /*-- U+51A0 .. U+51A7 --*/
   "Fu "   , "Xie "  , "Mi "   , "Bing " , "Dong " , "Tai "  , "Gang " , "Feng " ,  /*-- U+51A8 .. U+51AF --*/
   "Bing " , "Hu "   , "Chong ", "Jue "  , "Hu "   , "Kuang ", "Ye "   , "Leng " ,  /*-- U+51B0 .. U+51B7 --*/
   "Pan "  , "Fu "   , "Min "  , "Dong " , "Xian " , "Lie "  , "Xia "  , "Jian " ,  /*-- U+51B8 .. U+51BF --*/
   "Jing " , "Shu "  , "Mei "  , "Tu "   , "Qi "   , "Gu "   , "Zhun " , "Song " ,  /*-- U+51C0 .. U+51C7 --*/
   "Jing " , "Liang ", "Qing " , "Diao " , "Ling " , "Dong " , "Gan "  , "Jian " ,  /*-- U+51C8 .. U+51CF --*/
   "Yin "  , "Cou "  , "Yi "   , "Li "   , "Cang " , "Ming " , "Zhuen ", "Cui "  ,  /*-- U+51D0 .. U+51D7 --*/
   "Si "   , "Duo "  , "Jin "  , "Lin "  , "Lin "  , "Ning " , "Xi "   , "Du "   ,  /*-- U+51D8 .. U+51DF --*/
   "Ji "   , "Fan "  , "Fan "  , "Fan "  , "Feng " , "Ju "   , "Chu "  , "Tako " ,  /*-- U+51E0 .. U+51E7 --*/
   "Feng " , "Mok "  , "Ci "   , "Fu "   , "Feng " , "Ping " , "Feng " , "Kai "  ,  /*-- U+51E8 .. U+51EF --*/
   "Huang ", "Kai "  , "Gan "  , "Deng " , "Ping " , "Qu "   , "Xiong ", "Kuai " ,  /*-- U+51F0 .. U+51F7 --*/
   "Tu "   , "Ao "   , "Chu "  , "Ji "   , "Dang " , "Han "  , "Han "  , "Zao "  ,  /*-- U+51F8 .. U+51FF --*/
   "Dao "  , "Diao " , "Dao "  , "Ren "  , "Ren "  , "Chuang ", "Fen "  , "Qie "  ,  /*-- U+5200 .. U+5207 --*/
   "Yi "   , "Ji "   , "Kan "  , "Qian " , "Cun "  , "Chu "  , "Wen "  , "Ji "   ,  /*-- U+5208 .. U+520F --*/
   "Dan "  , "Xing " , "Hua "  , "Wan "  , "Jue "  , "Li "   , "Yue "  , "Lie "  ,  /*-- U+5210 .. U+5217 --*/
   "Liu "  , "Ze "   , "Gang " , "Chuang ", "Fu "   , "Chu "  , "Qu "   , "Ju "   ,  /*-- U+5218 .. U+521F --*/
   "Shan " , "Min "  , "Ling " , "Zhong ", "Pan "  , "Bie "  , "Jie "  , "Jie "  ,  /*-- U+5220 .. U+5227 --*/
   "Bao "  , "Li "   , "Shan " , "Bie "  , "Chan " , "Jing " , "Gua "  , "Gen "  ,  /*-- U+5228 .. U+522F --*/
   "Dao "  , "Chuang ", "Kui "  , "Ku "   , "Duo "  , "Er "   , "Zhi "  , "Shua " ,  /*-- U+5230 .. U+5237 --*/
   "Quan " , "Cha "  , "Ci "   , "Ke "   , "Jie "  , "Gui "  , "Ci "   , "Gui "  ,  /*-- U+5238 .. U+523F --*/
   "Kai "  , "Duo "  , "Ji "   , "Ti "   , "Jing " , "Lou "  , "Gen "  , "Ze "   ,  /*-- U+5240 .. U+5247 --*/
   "Yuan " , "Cuo "  , "Xue "  , "Ke "   , "La "   , "Qian " , "Cha "  , "Chuang ",  /*-- U+5248 .. U+524F --*/
   "Gua "  , "Jian " , "Cuo "  , "Li "   , "Ti "   , "Fei "  , "Pou "  , "Chan " ,  /*-- U+5250 .. U+5257 --*/
   "Qi "   , "Chuang ", "Zi "   , "Gang " , "Wan "  , "Bo "   , "Ji "   , "Duo "  ,  /*-- U+5258 .. U+525F --*/
   "Qing " , "Yan "  , "Zhuo " , "Jian " , "Ji "   , "Bo "   , "Yan "  , "Ju "   ,  /*-- U+5260 .. U+5267 --*/
   "Huo "  , "Sheng ", "Jian " , "Duo "  , "Duan " , "Wu "   , "Gua "  , "Fu "   ,  /*-- U+5268 .. U+526F --*/
   "Sheng ", "Jian " , "Ge "   , "Zha "  , "Kai "  , "Chuang ", "Juan " , "Chan " ,  /*-- U+5270 .. U+5277 --*/
   "Tuan " , "Lu "   , "Li "   , "Fou "  , "Shan " , "Piao " , "Kou "  , "Jiao " ,  /*-- U+5278 .. U+527F --*/
   "Gua "  , "Qiao " , "Jue "  , "Hua "  , "Zha "  , "Zhuo " , "Lian " , "Ju "   ,  /*-- U+5280 .. U+5287 --*/
   "Pi "   , "Liu "  , "Gui "  , "Jiao " , "Gui "  , "Jian " , "Jian " , "Tang " ,  /*-- U+5288 .. U+528F --*/
   "Huo "  , "Ji "   , "Jian " , "Yi "   , "Jian " , "Zhi "  , "Chan " , "Cuan " ,  /*-- U+5290 .. U+5297 --*/
   "Mo "   , "Li "   , "Zhu "  , "Li "   , "Ya "   , "Quan " , "Ban "  , "Gong " ,  /*-- U+5298 .. U+529F --*/
   "Jia "  , "Wu "   , "Mai "  , "Lie "  , "Jin "  , "Keng " , "Xie "  , "Zhi "  ,  /*-- U+52A0 .. U+52A7 --*/
   "Dong " , "Zhu "  , "Nu "   , "Jie "  , "Qu "   , "Shao " , "Yi "   , "Zhu "  ,  /*-- U+52A8 .. U+52AF --*/
   "Miao " , "Li "   , "Jing " , "Lao "  , "Lao "  , "Juan " , "Kou "  , "Yang " ,  /*-- U+52B0 .. U+52B7 --*/
   "Wa "   , "Xiao " , "Mou "  , "Kuang ", "Jie "  , "Lie "  , "He "   , "Shi "  ,  /*-- U+52B8 .. U+52BF --*/
   "Ke "   , "Jing " , "Hao "  , "Bo "   , "Min "  , "Chi "  , "Lang " , "Yong " ,  /*-- U+52C0 .. U+52C7 --*/
   "Yong " , "Mian " , "Ke "   , "Xun "  , "Juan " , "Qing " , "Lu "   , "Pou "  ,  /*-- U+52C8 .. U+52CF --*/
   "Meng " , "Lai "  , "Le "   , "Kai "  , "Mian " , "Dong " , "Xu "   , "Xu "   ,  /*-- U+52D0 .. U+52D7 --*/
   "Kan "  , "Wu "   , "Yi "   , "Xun "  , "Weng " , "Sheng ", "Lao "  , "Mu "   ,  /*-- U+52D8 .. U+52DF --*/
   "Lu "   , "Piao " , "Shi "  , "Ji "   , "Qin "  , "Qiang ", "Jiao " , "Quan " ,  /*-- U+52E0 .. U+52E7 --*/
   "Yang " , "Yi "   , "Jue "  , "Fan "  , "Juan " , "Tong " , "Ju "   , "Dan "  ,  /*-- U+52E8 .. U+52EF --*/
   "Xie "  , "Mai "  , "Xun "  , "Xun "  , "Lu "   , "Li "   , "Che "  , "Rang " ,  /*-- U+52F0 .. U+52F7 --*/
   "Quan " , "Bao "  , "Shao " , "Yun "  , "Jiu "  , "Bao "  , "Gou "  , "Wu "   ,  /*-- U+52F8 .. U+52FF --*/
   "Yun "  , "Mwun " , "Nay "  , "Gai "  , "Gai "  , "Bao "  , "Cong " , ""      ,  /*-- U+5300 .. U+5307 --*/
   "Xiong ", "Peng " , "Ju "   , "Tao "  , "Ge "   , "Pu "   , "An "   , "Pao "  ,  /*-- U+5308 .. U+530F --*/
   "Fu "   , "Gong " , "Da "   , "Jiu "  , "Qiong ", "Bi "   , "Hua "  , "Bei "  ,  /*-- U+5310 .. U+5317 --*/
   "Nao "  , "Chi "  , "Fang " , "Jiu "  , "Yi "   , "Za "   , "Jiang ", "Kang " ,  /*-- U+5318 .. U+531F --*/
   "Jiang ", "Kuang ", "Hu "   , "Xia "  , "Qu "   , "Bian " , "Gui "  , "Qie "  ,  /*-- U+5320 .. U+5327 --*/
   "Zang " , "Kuang ", "Fei "  , "Hu "   , "Tou "  , "Gui "  , "Gui "  , "Hui "  ,  /*-- U+5328 .. U+532F --*/
   "Dan "  , "Gui "  , "Lian " , "Lian " , "Suan " , "Du "   , "Jiu "  , "Qu "   ,  /*-- U+5330 .. U+5337 --*/
   "Xi "   , "Pi "   , "Qu "   , "Yi "   , "Qia "  , "Yan "  , "Bian " , "Ni "   ,  /*-- U+5338 .. U+533F --*/
   "Qu "   , "Shi "  , "Xin "  , "Qian " , "Nian " , "Sa "   , "Zu "   , "Sheng ",  /*-- U+5340 .. U+5347 --*/
   "Wu "   , "Hui "  , "Ban "  , "Shi "  , "Xi "   , "Wan "  , "Hua "  , "Xie "  ,  /*-- U+5348 .. U+534F --*/
   "Wan "  , "Bei "  , "Zu "   , "Zhuo " , "Xie "  , "Dan "  , "Mai "  , "Nan "  ,  /*-- U+5350 .. U+5357 --*/
   "Dan "  , "Ji "   , "Bo "   , "Shuai ", "Bu "   , "Kuang ", "Bian " , "Bu "   ,  /*-- U+5358 .. U+535F --*/
   "Zhan " , "Qia "  , "Lu "   , "You "  , "Lu "   , "Xi "   , "Gua "  , "Wo "   ,  /*-- U+5360 .. U+5367 --*/
   "Xie "  , "Jie "  , "Jie "  , "Wei "  , "Ang "  , "Qiong ", "Zhi "  , "Mao "  ,  /*-- U+5368 .. U+536F --*/
   "Yin "  , "Wei "  , "Shao " , "Ji "   , "Que "  , "Luan " , "Shi "  , "Juan " ,  /*-- U+5370 .. U+5377 --*/
   "Xie "  , "Xu "   , "Jin "  , "Que "  , "Wu "   , "Ji "   , "E "    , "Qing " ,  /*-- U+5378 .. U+537F --*/
   "Xi "   , ""      , "Han "  , "Zhan " , "E "    , "Ting " , "Li "   , "Zhe "  ,  /*-- U+5380 .. U+5387 --*/
   "Han "  , "Li "   , "Ya "   , "Ya "   , "Yan "  , "She "  , "Zhi "  , "Zha "  ,  /*-- U+5388 .. U+538F --*/
   "Pang " , ""      , "He "   , "Ya "   , "Zhi "  , "Ce "   , "Pang " , "Ti "   ,  /*-- U+5390 .. U+5397 --*/
   "Li "   , "She "  , "Hou "  , "Ting " , "Zui "  , "Cuo "  , "Fei "  , "Yuan " ,  /*-- U+5398 .. U+539F --*/
   "Ce "   , "Yuan " , "Xiang ", "Yan "  , "Li "   , "Jue "  , "Sha "  , "Dian " ,  /*-- U+53A0 .. U+53A7 --*/
   "Chu "  , "Jiu "  , "Qin "  , "Ao "   , "Gui "  , "Yan "  , "Si "   , "Li "   ,  /*-- U+53A8 .. U+53AF --*/
   "Chang ", "Lan "  , "Li "   , "Yan "  , "Yan "  , "Yuan " , "Si "   , "Gong " ,  /*-- U+53B0 .. U+53B7 --*/
   "Lin "  , "Qiu "  , "Qu "   , "Qu "   , "Uk "   , "Lei "  , "Du "   , "Xian " ,  /*-- U+53B8 .. U+53BF --*/
   "Zhuan ", "San "  , "Can "  , "Can "  , "Can "  , "Can "  , "Ai "   , "Dai "  ,  /*-- U+53C0 .. U+53C7 --*/
   "You "  , "Cha "  , "Ji "   , "You "  , "Shuang ", "Fan "  , "Shou " , "Guai " ,  /*-- U+53C8 .. U+53CF --*/
   "Ba "   , "Fa "   , "Ruo "  , "Shi "  , "Shu "  , "Zhuo " , "Qu "   , "Shou " ,  /*-- U+53D0 .. U+53D7 --*/
   "Bian " , "Xu "   , "Jia "  , "Pan "  , "Sou "  , "Gao "  , "Wei "  , "Sou "  ,  /*-- U+53D8 .. U+53DF --*/
   "Die "  , "Rui "  , "Cong " , "Kou "  , "Gu "   , "Ju "   , "Ling " , "Gua "  ,  /*-- U+53E0 .. U+53E7 --*/
   "Tao "  , "Kou "  , "Zhi "  , "Jiao " , "Zhao " , "Ba "   , "Ding " , "Ke "   ,  /*-- U+53E8 .. U+53EF --*/
   "Tai "  , "Chi "  , "Shi "  , "You "  , "Qiu "  , "Po "   , "Xie "  , "Hao "  ,  /*-- U+53F0 .. U+53F7 --*/
   "Si "   , "Tan "  , "Chi "  , "Le "   , "Diao " , "Ji "   , ""      , "Hong " ,  /*-- U+53F8 .. U+53FF --*/
   "Mie "  , "Xu "   , "Mang " , "Chi "  , "Ge "   , "Xuan " , "Yao "  , "Zi "   ,  /*-- U+5400 .. U+5407 --*/
   "He "   , "Ji "   , "Diao " , "Cun "  , "Tong " , "Ming " , "Hou "  , "Li "   ,  /*-- U+5408 .. U+540F --*/
   "Tu "   , "Xiang ", "Zha "  , "Xia "  , "Ye "   , "Lu "   , "A "    , "Ma "   ,  /*-- U+5410 .. U+5417 --*/
   "Ou "   , "Xue "  , "Yi "   , "Jun "  , "Chou " , "Lin "  , "Tun "  , "Yin "  ,  /*-- U+5418 .. U+541F --*/
   "Fei "  , "Bi "   , "Qin "  , "Qin "  , "Jie "  , "Bu "   , "Fou "  , "Ba "   ,  /*-- U+5420 .. U+5427 --*/
   "Dun "  , "Fen "  , "E "    , "Han "  , "Ting " , "Hang " , "Shun " , "Qi "   ,  /*-- U+5428 .. U+542F --*/
   "Hong " , "Zhi "  , "Shen " , "Wu "   , "Wu "   , "Chao " , "Ne "   , "Xue "  ,  /*-- U+5430 .. U+5437 --*/
   "Xi "   , "Chui " , "Dou "  , "Wen "  , "Hou "  , "Ou "   , "Wu "   , "Gao "  ,  /*-- U+5438 .. U+543F --*/
   "Ya "   , "Jun "  , "Lu "   , "E "    , "Ge "   , "Mei "  , "Ai "   , "Qi "   ,  /*-- U+5440 .. U+5447 --*/
   "Cheng ", "Wu "   , "Gao "  , "Fu "   , "Jiao " , "Hong " , "Chi "  , "Sheng ",  /*-- U+5448 .. U+544F --*/
   "Ne "   , "Tun "  , "Fu "   , "Yi "   , "Dai "  , "Ou "   , "Li "   , "Bai "  ,  /*-- U+5450 .. U+5457 --*/
   "Yuan " , "Kuai " , ""      , "Qiang ", "Wu "   , "E "    , "Shi "  , "Quan " ,  /*-- U+5458 .. U+545F --*/
   "Pen "  , "Wen "  , "Ni "   , "M "    , "Ling " , "Ran "  , "You "  , "Di "   ,  /*-- U+5460 .. U+5467 --*/
   "Zhou " , "Shi "  , "Zhou " , "Tie "  , "Xi "   , "Yi "   , "Qi "   , "Ping " ,  /*-- U+5468 .. U+546F --*/
   "Zi "   , "Gu "   , "Zi "   , "Wei "  , "Xu "   , "He "   , "Nao "  , "Xia "  ,  /*-- U+5470 .. U+5477 --*/
   "Pei "  , "Yi "   , "Xiao " , "Shen " , "Hu "   , "Ming " , "Da "   , "Qu "   ,  /*-- U+5478 .. U+547F --*/
   "Ju "   , "Gem "  , "Za "   , "Tuo "  , "Duo "  , "Pou "  , "Pao "  , "Bi "   ,  /*-- U+5480 .. U+5487 --*/
   "Fu "   , "Yang " , "He "   , "Zha "  , "He "   , "Hai "  , "Jiu "  , "Yong " ,  /*-- U+5488 .. U+548F --*/
   "Fu "   , "Que "  , "Zhou " , "Wa "   , "Ka "   , "Gu "   , "Ka "   , "Zuo "  ,  /*-- U+5490 .. U+5497 --*/
   "Bu "   , "Long " , "Dong " , "Ning " , "Tha "  , "Si "   , "Xian " , "Huo "  ,  /*-- U+5498 .. U+549F --*/
   "Qi "   , "Er "   , "E "    , "Guang ", "Zha "  , "Xi "   , "Yi "   , "Lie "  ,  /*-- U+54A0 .. U+54A7 --*/
   "Zi "   , "Mie "  , "Mi "   , "Zhi "  , "Yao "  , "Ji "   , "Zhou " , "Ge "   ,  /*-- U+54A8 .. U+54AF --*/
   "Shuai ", "Zan "  , "Xiao " , "Ke "   , "Hui "  , "Kua "  , "Huai " , "Tao "  ,  /*-- U+54B0 .. U+54B7 --*/
   "Xian " , "E "    , "Xuan " , "Xiu "  , "Wai "  , "Yan "  , "Lao "  , "Yi "   ,  /*-- U+54B8 .. U+54BF --*/
   "Ai "   , "Pin "  , "Shen " , "Tong " , "Hong " , "Xiong ", "Chi "  , "Wa "   ,  /*-- U+54C0 .. U+54C7 --*/
   "Ha "   , "Zai "  , "Yu "   , "Di "   , "Pai "  , "Xiang ", "Ai "   , "Hen "  ,  /*-- U+54C8 .. U+54CF --*/
   "Kuang ", "Ya "   , "Da "   , "Xiao " , "Bi "   , "Yue "  , ""      , "Hua "  ,  /*-- U+54D0 .. U+54D7 --*/
   "Sasou ", "Kuai " , "Duo "  , ""      , "Ji "   , "Nong " , "Mou "  , "Yo "   ,  /*-- U+54D8 .. U+54DF --*/
   "Hao "  , "Yuan " , "Long " , "Pou "  , "Mang " , "Ge "   , "E "    , "Chi "  ,  /*-- U+54E0 .. U+54E7 --*/
   "Shao " , "Li "   , "Na "   , "Zu "   , "He "   , "Ku "   , "Xiao " , "Xian " ,  /*-- U+54E8 .. U+54EF --*/
   "Lao "  , "Bo "   , "Zhe "  , "Zha "  , "Liang ", "Ba "   , "Mie "  , "Le "   ,  /*-- U+54F0 .. U+54F7 --*/
   "Sui "  , "Fou "  , "Bu "   , "Han "  , "Heng " , "Geng " , "Shuo " , "Ge "   ,  /*-- U+54F8 .. U+54FF --*/
   "You "  , "Yan "  , "Gu "   , "Gu "   , "Bai "  , "Han "  , "Suo "  , "Chun " ,  /*-- U+5500 .. U+5507 --*/
   "Yi "   , "Ai "   , "Jia "  , "Tu "   , "Xian " , "Huan " , "Li "   , "Xi "   ,  /*-- U+5508 .. U+550F --*/
   "Tang " , "Zuo "  , "Qiu "  , "Che "  , "Wu "   , "Zao "  , "Ya "   , "Dou "  ,  /*-- U+5510 .. U+5517 --*/
   "Qi "   , "Di "   , "Qin "  , "Ma "   , "Mal "  , "Hong " , "Dou "  , "Kes "  ,  /*-- U+5518 .. U+551F --*/
   "Lao "  , "Liang ", "Suo "  , "Zao "  , "Huan " , "Lang " , "Sha "  , "Ji "   ,  /*-- U+5520 .. U+5527 --*/
   "Zuo "  , "Wo "   , "Feng " , "Yin "  , "Hu "   , "Qi "   , "Shou " , "Wei "  ,  /*-- U+5528 .. U+552F --*/
   "Shua " , "Chang ", "Er "   , "Li "   , "Qiang ", "An "   , "Jie "  , "Yo "   ,  /*-- U+5530 .. U+5537 --*/
   "Nian " , "Yu "   , "Tian " , "Lai "  , "Sha "  , "Xi "   , "Tuo "  , "Hu "   ,  /*-- U+5538 .. U+553F --*/
   "Ai "   , "Zhou " , "Nou "  , "Ken "  , "Zhuo " , "Zhuo " , "Shang ", "Di "   ,  /*-- U+5540 .. U+5547 --*/
   "Heng " , "Lan "  , "A "    , "Xiao " , "Xiang ", "Tun "  , "Wu "   , "Wen "  ,  /*-- U+5548 .. U+554F --*/
   "Cui "  , "Sha "  , "Hu "   , "Qi "   , "Qi "   , "Tao "  , "Dan "  , "Dan "  ,  /*-- U+5550 .. U+5557 --*/
   "Ye "   , "Zi "   , "Bi "   , "Cui "  , "Chuo " , "He "   , "Ya "   , "Qi "   ,  /*-- U+5558 .. U+555F --*/
   "Zhe "  , "Pei "  , "Liang ", "Xian " , "Pi "   , "Sha "  , "La "   , "Ze "   ,  /*-- U+5560 .. U+5567 --*/
   "Qing " , "Gua "  , "Pa "   , "Zhe "  , "Se "   , "Zhuan ", "Nie "  , "Guo "  ,  /*-- U+5568 .. U+556F --*/
   "Luo "  , "Yan "  , "Di "   , "Quan " , "Tan "  , "Bo "   , "Ding " , "Lang " ,  /*-- U+5570 .. U+5577 --*/
   "Xiao " , ""      , "Tang " , "Chi "  , "Ti "   , "An "   , "Jiu "  , "Dan "  ,  /*-- U+5578 .. U+557F --*/
   "Ke "   , "Yong " , "Wei "  , "Nan "  , "Shan " , "Yu "   , "Zhe "  , "La "   ,  /*-- U+5580 .. U+5587 --*/
   "Jie "  , "Hou "  , "Han "  , "Die "  , "Zhou " , "Chai " , "Wai "  , "Re "   ,  /*-- U+5588 .. U+558F --*/
   "Yu "   , "Yin "  , "Zan "  , "Yao "  , "Wo "   , "Mian " , "Hu "   , "Yun "  ,  /*-- U+5590 .. U+5597 --*/
   "Chuan ", "Hui "  , "Huan " , "Huan " , "Xi "   , "He "   , "Ji "   , "Kui "  ,  /*-- U+5598 .. U+559F --*/
   "Zhong ", "Wei "  , "Sha "  , "Xu "   , "Huang ", "Du "   , "Nie "  , "Xuan " ,  /*-- U+55A0 .. U+55A7 --*/
   "Liang ", "Yu "   , "Sang " , "Chi "  , "Qiao " , "Yan "  , "Dan "  , "Pen "  ,  /*-- U+55A8 .. U+55AF --*/
   "Can "  , "Li "   , "Yo "   , "Zha "  , "Wei "  , "Miao " , "Ying " , "Pen "  ,  /*-- U+55B0 .. U+55B7 --*/
   "Phos " , "Kui "  , "Xi "   , "Yu "   , "Jie "  , "Lou "  , "Ku "   , "Sao "  ,  /*-- U+55B8 .. U+55BF --*/
   "Huo "  , "Ti "   , "Yao "  , "He "   , "A "    , "Xiu "  , "Qiang ", "Se "   ,  /*-- U+55C0 .. U+55C7 --*/
   "Yong " , "Su "   , "Hong " , "Xie "  , "Yi "   , "Suo "  , "Ma "   , "Cha "  ,  /*-- U+55C8 .. U+55CF --*/
   "Hai "  , "Ke "   , "Ta "   , "Sang " , "Tian " , "Ru "   , "Sou "  , "Wa "   ,  /*-- U+55D0 .. U+55D7 --*/
   "Ji "   , "Pang " , "Wu "   , "Xian " , "Shi "  , "Ge "   , "Zi "   , "Jie "  ,  /*-- U+55D8 .. U+55DF --*/
   "Luo "  , "Weng " , "Wa "   , "Si "   , "Chi "  , "Hao "  , "Suo "  , "Jia "  ,  /*-- U+55E0 .. U+55E7 --*/
   "Hai "  , "Suo "  , "Qin "  , "Nie "  , "He "   , "Cis "  , "Sai "  , "Ng "   ,  /*-- U+55E8 .. U+55EF --*/
   "Ge "   , "Na "   , "Dia "  , "Ai "   , ""      , "Tong " , "Bi "   , "Ao "   ,  /*-- U+55F0 .. U+55F7 --*/
   "Ao "   , "Lian " , "Cui "  , "Zhe "  , "Mo "   , "Sou "  , "Sou "  , "Tan "  ,  /*-- U+55F8 .. U+55FF --*/
   "Di "   , "Qi "   , "Jiao " , "Chong ", "Jiao " , "Kai "  , "Tan "  , "San "  ,  /*-- U+5600 .. U+5607 --*/
   "Cao "  , "Jia "  , "Ai "   , "Xiao " , "Piao " , "Lou "  , "Ga "   , "Gu "   ,  /*-- U+5608 .. U+560F --*/
   "Xiao " , "Hu "   , "Hui "  , "Guo "  , "Ou "   , "Xian " , "Ze "   , "Chang ",  /*-- U+5610 .. U+5617 --*/
   "Xu "   , "Po "   , "De "   , "Ma "   , "Ma "   , "Hu "   , "Lei "  , "Du "   ,  /*-- U+5618 .. U+561F --*/
   "Ga "   , "Tang " , "Ye "   , "Beng " , "Ying " , "Saai " , "Jiao " , "Mi "   ,  /*-- U+5620 .. U+5627 --*/
   "Xiao " , "Hua "  , "Mai "  , "Ran "  , "Zuo "  , "Peng " , "Lao "  , "Xiao " ,  /*-- U+5628 .. U+562F --*/
   "Ji "   , "Zhu "  , "Chao " , "Kui "  , "Zui "  , "Xiao " , "Si "   , "Hao "  ,  /*-- U+5630 .. U+5637 --*/
   "Fu "   , "Liao " , "Qiao " , "Xi "   , "Xiu "  , "Tan "  , "Tan "  , "Mo "   ,  /*-- U+5638 .. U+563F --*/
   "Xun "  , "E "    , "Zun "  , "Fan "  , "Chi "  , "Hui "  , "Zan "  , "Chuang ",  /*-- U+5640 .. U+5647 --*/
   "Cu "   , "Dan "  , "Yu "   , "Tun "  , "Cheng ", "Jiao " , "Ye "   , "Xi "   ,  /*-- U+5648 .. U+564F --*/
   "Qi "   , "Hao "  , "Lian " , "Xu "   , "Deng " , "Hui "  , "Yin "  , "Pu "   ,  /*-- U+5650 .. U+5657 --*/
   "Jue "  , "Qin "  , "Xun "  , "Nie "  , "Lu "   , "Si "   , "Yan "  , "Ying " ,  /*-- U+5658 .. U+565F --*/
   "Da "   , "Dan "  , "Yu "   , "Zhou " , "Jin "  , "Nong " , "Yue "  , "Hui "  ,  /*-- U+5660 .. U+5667 --*/
   "Qi "   , "E "    , "Zao "  , "Yi "   , "Shi "  , "Jiao " , "Yuan " , "Ai "   ,  /*-- U+5668 .. U+566F --*/
   "Yong " , "Jue "  , "Kuai " , "Yu "   , "Pen "  , "Dao "  , "Ge "   , "Xin "  ,  /*-- U+5670 .. U+5677 --*/
   "Dun "  , "Dang " , "Sin "  , "Sai "  , "Pi "   , "Pi "   , "Yin "  , "Zui "  ,  /*-- U+5678 .. U+567F --*/
   "Ning " , "Di "   , "Lan "  , "Ta "   , "Huo "  , "Ru "   , "Hao "  , "Xia "  ,  /*-- U+5680 .. U+5687 --*/
   "Ya "   , "Duo "  , "Xi "   , "Chou " , "Ji "   , "Jin "  , "Hao "  , "Ti "   ,  /*-- U+5688 .. U+568F --*/
   "Chang ", ""      , ""      , "Ca "   , "Ti "   , "Lu "   , "Hui "  , "Bo "   ,  /*-- U+5690 .. U+5697 --*/
   "You "  , "Nie "  , "Yin "  , "Hu "   , "Mo "   , "Huang ", "Zhe "  , "Li "   ,  /*-- U+5698 .. U+569F --*/
   "Liu "  , "Haai " , "Nang " , "Xiao " , "Mo "   , "Yan "  , "Li "   , "Lu "   ,  /*-- U+56A0 .. U+56A7 --*/
   "Long " , "Fu "   , "Dan "  , "Chen " , "Pin "  , "Pi "   , "Xiang ", "Huo "  ,  /*-- U+56A8 .. U+56AF --*/
   "Mo "   , "Xi "   , "Duo "  , "Ku "   , "Yan "  , "Chan " , "Ying " , "Rang " ,  /*-- U+56B0 .. U+56B7 --*/
   "Dian " , "La "   , "Ta "   , "Xiao " , "Jiao " , "Chuo " , "Huan " , "Huo "  ,  /*-- U+56B8 .. U+56BF --*/
   "Zhuan ", "Nie "  , "Xiao " , "Ca "   , "Li "   , "Chan " , "Chai " , "Li "   ,  /*-- U+56C0 .. U+56C7 --*/
   "Yi "   , "Luo "  , "Nang " , "Zan "  , "Su "   , "Xi "   , "So "   , "Jian " ,  /*-- U+56C8 .. U+56CF --*/
   "Za "   , "Zhu "  , "Lan "  , "Nie "  , "Nang " , ""      , ""      , "Wei "  ,  /*-- U+56D0 .. U+56D7 --*/
   "Hui "  , "Yin "  , "Qiu "  , "Si "   , "Nin "  , "Jian " , "Hui "  , "Xin "  ,  /*-- U+56D8 .. U+56DF --*/
   "Yin "  , "Nan "  , "Tuan " , "Tuan " , "Dun "  , "Kang " , "Yuan " , "Jiong ",  /*-- U+56E0 .. U+56E7 --*/
   "Pian " , "Yun "  , "Cong " , "Hu "   , "Hui "  , "Yuan " , "You "  , "Guo "  ,  /*-- U+56E8 .. U+56EF --*/
   "Kun "  , "Cong " , "Wei "  , "Tu "   , "Wei "  , "Lun "  , "Guo "  , "Qun "  ,  /*-- U+56F0 .. U+56F7 --*/
   "Ri "   , "Ling " , "Gu "   , "Guo "  , "Tai "  , "Guo "  , "Tu "   , "You "  ,  /*-- U+56F8 .. U+56FF --*/
   "Guo "  , "Yin "  , "Hun "  , "Pu "   , "Yu "   , "Han "  , "Yuan " , "Lun "  ,  /*-- U+5700 .. U+5707 --*/
   "Quan " , "Yu "   , "Qing " , "Guo "  , "Chuan ", "Wei "  , "Yuan " , "Quan " ,  /*-- U+5708 .. U+570F --*/
   "Ku "   , "Fu "   , "Yuan " , "Yuan " , "E "    , "Tu "   , "Tu "   , "Tu "   ,  /*-- U+5710 .. U+5717 --*/
   "Tuan " , "Lue "  , "Hui "  , "Yi "   , "Yuan " , "Luan " , "Luan " , "Tu "   ,  /*-- U+5718 .. U+571F --*/
   "Ya "   , "Tu "   , "Ting " , "Sheng ", "Pu "   , "Lu "   , "Iri "  , "Ya "   ,  /*-- U+5720 .. U+5727 --*/
   "Zai "  , "Wei "  , "Ge "   , "Yu "   , "Wu "   , "Gui "  , "Pi "   , "Yi "   ,  /*-- U+5728 .. U+572F --*/
   "Di "   , "Qian " , "Qian " , "Zhen " , "Zhuo " , "Dang " , "Qia "  , "Akutsu ",  /*-- U+5730 .. U+5737 --*/
   "Yama " , "Kuang ", "Chang ", "Qi "   , "Nie "  , "Mo "   , "Ji "   , "Jia "  ,  /*-- U+5738 .. U+573F --*/
   "Zhi "  , "Zhi "  , "Ban "  , "Xun "  , "Tou "  , "Qin "  , "Fen "  , "Jun "  ,  /*-- U+5740 .. U+5747 --*/
   "Keng " , "Tun "  , "Fang " , "Fen "  , "Ben "  , "Tan "  , "Kan "  , "Pi "   ,  /*-- U+5748 .. U+574F --*/
   "Zuo "  , "Keng " , "Bi "   , "Xing " , "Di "   , "Jing " , "Ji "   , "Kuai " ,  /*-- U+5750 .. U+5757 --*/
   "Di "   , "Jing " , "Jian " , "Tan "  , "Li "   , "Ba "   , "Wu "   , "Fen "  ,  /*-- U+5758 .. U+575F --*/
   "Zhui " , "Po "   , "Pan "  , "Tang " , "Kun "  , "Qu "   , "Tan "  , "Zhi "  ,  /*-- U+5760 .. U+5767 --*/
   "Tuo "  , "Gan "  , "Ping " , "Dian " , "Gua "  , "Ni "   , "Tai "  , "Pi "   ,  /*-- U+5768 .. U+576F --*/
   "Jiong ", "Yang " , "Fo "   , "Ao "   , "Liu "  , "Qiu "  , "Mu "   , "Ke "   ,  /*-- U+5770 .. U+5777 --*/
   "Gou "  , "Xue "  , "Ba "   , "Chi "  , "Che "  , "Ling " , "Zhu "  , "Fu "   ,  /*-- U+5778 .. U+577F --*/
   "Hu "   , "Zhi "  , "Chui " , "La "   , "Long " , "Long " , "Lu "   , "Ao "   ,  /*-- U+5780 .. U+5787 --*/
   "Tay "  , "Pao "  , ""      , "Xing " , "Dong " , "Ji "   , "Ke "   , "Lu "   ,  /*-- U+5788 .. U+578F --*/
   "Ci "   , "Chi "  , "Lei "  , "Gai "  , "Yin "  , "Hou "  , "Dui "  , "Zhao " ,  /*-- U+5790 .. U+5797 --*/
   "Fu "   , "Guang ", "Yao "  , "Duo "  , "Duo "  , "Gui "  , "Cha "  , "Yang " ,  /*-- U+5798 .. U+579F --*/
   "Yin "  , "Fa "   , "Gou "  , "Yuan " , "Die "  , "Xie "  , "Ken "  , "Jiong ",  /*-- U+57A0 .. U+57A7 --*/
   "Shou " , "E "    , "Ha "   , "Dian " , "Hong " , "Wu "   , "Kua "  , ""      ,  /*-- U+57A8 .. U+57AF --*/
   "Tao "  , "Dang " , "Kai "  , "Gake " , "Nao "  , "An "   , "Xing " , "Xian " ,  /*-- U+57B0 .. U+57B7 --*/
   "Huan " , "Bang " , "Pei "  , "Ba "   , "Yi "   , "Yin "  , "Han "  , "Xu "   ,  /*-- U+57B8 .. U+57BF --*/
   "Chui " , "Cen "  , "Geng " , "Ai "   , "Peng " , "Fang " , "Que "  , "Yong " ,  /*-- U+57C0 .. U+57C7 --*/
   "Xun "  , "Jia "  , "Di "   , "Mai "  , "Lang " , "Xuan " , "Cheng ", "Yan "  ,  /*-- U+57C8 .. U+57CF --*/
   "Jin "  , "Zhe "  , "Lei "  , "Lie "  , "Bu "   , "Cheng ", "Gomi " , "Bu "   ,  /*-- U+57D0 .. U+57D7 --*/
   "Shi "  , "Xun "  , "Guo "  , "Jiong ", "Ye "   , "Nian " , "Di "   , "Yu "   ,  /*-- U+57D8 .. U+57DF --*/
   "Bu "   , "Ya "   , "Juan " , "Sui "  , "Pi "   , "Cheng ", "Wan "  , "Ju "   ,  /*-- U+57E0 .. U+57E7 --*/
   "Lun "  , "Zheng ", "Kong " , "Chong ", "Dong " , "Dai "  , "Tan "  , "An "   ,  /*-- U+57E8 .. U+57EF --*/
   "Cai "  , "Shu "  , "Beng " , "Kan "  , "Zhi "  , "Duo "  , "Yi "   , "Zhi "  ,  /*-- U+57F0 .. U+57F7 --*/
   "Yi "   , "Pei "  , "Ji "   , "Zhun " , "Qi "   , "Sao "  , "Ju "   , "Ni "   ,  /*-- U+57F8 .. U+57FF --*/
   "Ku "   , "Ke "   , "Tang " , "Kun "  , "Ni "   , "Jian " , "Dui "  , "Jin "  ,  /*-- U+5800 .. U+5807 --*/
   "Gang " , "Yu "   , "E "    , "Peng " , "Gu "   , "Tu "   , "Leng " , ""      ,  /*-- U+5808 .. U+580F --*/
   "Ya "   , "Qian " , ""      , "An "   , ""      , "Duo "  , "Nao "  , "Tu "   ,  /*-- U+5810 .. U+5817 --*/
   "Cheng ", "Yin "  , "Hun "  , "Bi "   , "Lian " , "Guo "  , "Die "  , "Zhuan ",  /*-- U+5818 .. U+581F --*/
   "Hou "  , "Bao "  , "Bao "  , "Yu "   , "Di "   , "Mao "  , "Jie "  , "Ruan " ,  /*-- U+5820 .. U+5827 --*/
   "E "    , "Geng " , "Kan "  , "Zong " , "Yu "   , "Huang ", "E "    , "Yao "  ,  /*-- U+5828 .. U+582F --*/
   "Yan "  , "Bao "  , "Ji "   , "Mei "  , "Chang ", "Du "   , "Tuo "  , "Yin "  ,  /*-- U+5830 .. U+5837 --*/
   "Feng " , "Zhong ", "Jie "  , "Zhen " , "Feng " , "Gang " , "Chuan ", "Jian " ,  /*-- U+5838 .. U+583F --*/
   "Pyeng ", "Toride ", "Xiang ", "Huang ", "Leng " , "Duan " , ""      , "Xuan " ,  /*-- U+5840 .. U+5847 --*/
   "Ji "   , "Ji "   , "Kuai " , "Ying " , "Ta "   , "Cheng ", "Yong " , "Kai "  ,  /*-- U+5848 .. U+584F --*/
   "Su "   , "Su "   , "Shi "  , "Mi "   , "Ta "   , "Weng " , "Cheng ", "Tu "   ,  /*-- U+5850 .. U+5857 --*/
   "Tang " , "Que "  , "Zhong ", "Li "   , "Peng " , "Bang " , "Sai "  , "Zang " ,  /*-- U+5858 .. U+585F --*/
   "Dui "  , "Tian " , "Wu "   , "Cheng ", "Xun "  , "Ge "   , "Zhen " , "Ai "   ,  /*-- U+5860 .. U+5867 --*/
   "Gong " , "Yan "  , "Kan "  , "Tian " , "Yuan " , "Wen "  , "Xie "  , "Liu "  ,  /*-- U+5868 .. U+586F --*/
   "Ama "  , "Lang " , "Chang ", "Peng " , "Beng " , "Chen " , "Cu "   , "Lu "   ,  /*-- U+5870 .. U+5877 --*/
   "Ou "   , "Qian " , "Mei "  , "Mo "   , "Zhuan ", "Shuang ", "Shu "  , "Lou "  ,  /*-- U+5878 .. U+587F --*/
   "Chi "  , "Man "  , "Biao " , "Jing " , "Qi "   , "Shu "  , "Di "   , "Zhang ",  /*-- U+5880 .. U+5887 --*/
   "Kan "  , "Yong " , "Dian " , "Chen " , "Zhi "  , "Xi "   , "Guo "  , "Qiang ",  /*-- U+5888 .. U+588F --*/
   "Jin "  , "Di "   , "Shang ", "Mu "   , "Cui "  , "Yan "  , "Ta "   , "Zeng " ,  /*-- U+5890 .. U+5897 --*/
   "Qi "   , "Qiang ", "Liang ", ""      , "Zhui " , "Qiao " , "Zeng " , "Xu "   ,  /*-- U+5898 .. U+589F --*/
   "Shan " , "Shan " , "Ba "   , "Pu "   , "Kuai " , "Dong " , "Fan "  , "Que "  ,  /*-- U+58A0 .. U+58A7 --*/
   "Mo "   , "Dun "  , "Dun "  , "Dun "  , "Di "   , "Sheng ", "Duo "  , "Duo "  ,  /*-- U+58A8 .. U+58AF --*/
   "Tan "  , "Deng " , "Wu "   , "Fen "  , "Huang ", "Tan "  , "Da "   , "Ye "   ,  /*-- U+58B0 .. U+58B7 --*/
   "Sho "  , "Mama " , "Yu "   , "Qiang ", "Ji "   , "Qiao " , "Ken "  , "Yi "   ,  /*-- U+58B8 .. U+58BF --*/
   "Pi "   , "Bi "   , "Dian " , "Jiang ", "Ye "   , "Yong " , "Bo "   , "Tan "  ,  /*-- U+58C0 .. U+58C7 --*/
   "Lan "  , "Ju "   , "Huai " , "Dang " , "Rang " , "Qian " , "Xun "  , "Lan "  ,  /*-- U+58C8 .. U+58CF --*/
   "Xi "   , "He "   , "Ai "   , "Ya "   , "Dao "  , "Hao "  , "Ruan " , "Mama " ,  /*-- U+58D0 .. U+58D7 --*/
   "Lei "  , "Kuang ", "Lu "   , "Yan "  , "Tan "  , "Wei "  , "Huai " , "Long " ,  /*-- U+58D8 .. U+58DF --*/
   "Long " , "Rui "  , "Li "   , "Lin "  , "Rang " , "Ten "  , "Xun "  , "Yan "  ,  /*-- U+58E0 .. U+58E7 --*/
   "Lei "  , "Ba "   , ""      , "Shi "  , "Ren "  , ""      , "Zhuang ", "Zhuang ",  /*-- U+58E8 .. U+58EF --*/
   "Sheng ", "Yi "   , "Mai "  , "Ke "   , "Zhu "  , "Zhuang ", "Hu "   , "Hu "   ,  /*-- U+58F0 .. U+58F7 --*/
   "Kun "  , "Yi "   , "Hu "   , "Xu "   , "Kun "  , "Shou " , "Mang " , "Zun "  ,  /*-- U+58F8 .. U+58FF --*/
   "Shou " , "Yi "   , "Zhi "  , "Gu "   , "Chu "  , "Jiang ", "Feng " , "Bei "  ,  /*-- U+5900 .. U+5907 --*/
   "Cay "  , "Bian " , "Sui "  , "Qun "  , "Ling " , "Fu "   , "Zuo "  , "Xia "  ,  /*-- U+5908 .. U+590F --*/
   "Xiong ", ""      , "Nao "  , "Xia "  , "Kui "  , "Xi "   , "Wai "  , "Yuan " ,  /*-- U+5910 .. U+5917 --*/
   "Mao "  , "Su "   , "Duo "  , "Duo "  , "Ye "   , "Qing " , "Uys "  , "Gou "  ,  /*-- U+5918 .. U+591F --*/
   "Gou "  , "Qi "   , "Meng " , "Meng " , "Yin "  , "Huo "  , "Chen " , "Da "   ,  /*-- U+5920 .. U+5927 --*/
   "Ze "   , "Tian " , "Tai "  , "Fu "   , "Guai " , "Yao "  , "Yang " , "Hang " ,  /*-- U+5928 .. U+592F --*/
   "Gao "  , "Shi "  , "Ben "  , "Tai "  , "Tou "  , "Yan "  , "Bi "   , "Yi "   ,  /*-- U+5930 .. U+5937 --*/
   "Kua "  , "Jia "  , "Duo "  , "Kwu "  , "Kuang ", "Yun "  , "Jia "  , "Pa "   ,  /*-- U+5938 .. U+593F --*/
   "En "   , "Lian " , "Huan " , "Di "   , "Yan "  , "Pao "  , "Quan " , "Qi "   ,  /*-- U+5940 .. U+5947 --*/
   "Nai "  , "Feng " , "Xie "  , "Fen "  , "Dian " , ""      , "Kui "  , "Zou "  ,  /*-- U+5948 .. U+594F --*/
   "Huan " , "Qi "   , "Kai "  , "Zha "  , "Ben "  , "Yi "   , "Jiang ", "Tao "  ,  /*-- U+5950 .. U+5957 --*/
   "Zang " , "Ben "  , "Xi "   , "Xiang ", "Fei "  , "Diao " , "Xun "  , "Keng " ,  /*-- U+5958 .. U+595F --*/
   "Dian " , "Ao "   , "She "  , "Weng " , "Pan "  , "Ao "   , "Wu "   , "Ao "   ,  /*-- U+5960 .. U+5967 --*/
   "Jiang ", "Lian " , "Duo "  , "Yun "  , "Jiang ", "Shi "  , "Fen "  , "Huo "  ,  /*-- U+5968 .. U+596F --*/
   "Bi "   , "Lian " , "Duo "  , "Nu "   , "Nu "   , "Ding " , "Nai "  , "Qian " ,  /*-- U+5970 .. U+5977 --*/
   "Jian " , "Ta "   , "Jiu "  , "Nan "  , "Cha "  , "Hao "  , "Xian " , "Fan "  ,  /*-- U+5978 .. U+597F --*/
   "Ji "   , "Shuo " , "Ru "   , "Fei "  , "Wang " , "Hong " , "Zhuang ", "Fu "   ,  /*-- U+5980 .. U+5987 --*/
   "Ma "   , "Dan "  , "Ren "  , "Fu "   , "Jing " , "Yan "  , "Xie "  , "Wen "  ,  /*-- U+5988 .. U+598F --*/
   "Zhong ", "Pa "   , "Du "   , "Ji "   , "Keng " , "Zhong ", "Yao "  , "Jin "  ,  /*-- U+5990 .. U+5997 --*/
   "Yun "  , "Miao " , "Pei "  , "Shi "  , "Yue "  , "Zhuang ", "Niu "  , "Yan "  ,  /*-- U+5998 .. U+599F --*/
   "Na "   , "Xin "  , "Fen "  , "Bi "   , "Yu "   , "Tuo "  , "Feng " , "Yuan " ,  /*-- U+59A0 .. U+59A7 --*/
   "Fang " , "Wu "   , "Yu "   , "Gui "  , "Du "   , "Ba "   , "Ni "   , "Zhou " ,  /*-- U+59A8 .. U+59AF --*/
   "Zhuo " , "Zhao " , "Da "   , "Nai "  , "Yuan " , "Tou "  , "Xuan " , "Zhi "  ,  /*-- U+59B0 .. U+59B7 --*/
   "E "    , "Mei "  , "Mo "   , "Qi "   , "Bi "   , "Shen " , "Qie "  , "E "    ,  /*-- U+59B8 .. U+59BF --*/
   "He "   , "Xu "   , "Fa "   , "Zheng ", "Min "  , "Ban "  , "Mu "   , "Fu "   ,  /*-- U+59C0 .. U+59C7 --*/
   "Ling " , "Zi "   , "Zi "   , "Shi "  , "Ran "  , "Shan " , "Yang " , "Man "  ,  /*-- U+59C8 .. U+59CF --*/
   "Jie "  , "Gu "   , "Si "   , "Xing " , "Wei "  , "Zi "   , "Ju "   , "Shan " ,  /*-- U+59D0 .. U+59D7 --*/
   "Pin "  , "Ren "  , "Yao "  , "Tong " , "Jiang ", "Shu "  , "Ji "   , "Gai "  ,  /*-- U+59D8 .. U+59DF --*/
   "Shang ", "Kuo "  , "Juan " , "Jiao " , "Gou "  , "Mu "   , "Jian " , "Jian " ,  /*-- U+59E0 .. U+59E7 --*/
   "Yi "   , "Nian " , "Zhi "  , "Ji "   , "Ji "   , "Xian " , "Heng " , "Guang ",  /*-- U+59E8 .. U+59EF --*/
   "Jun "  , "Kua "  , "Yan "  , "Ming " , "Lie "  , "Pei "  , "Yan "  , "You "  ,  /*-- U+59F0 .. U+59F7 --*/
   "Yan "  , "Cha "  , "Shen " , "Yin "  , "Chi "  , "Gui "  , "Quan " , "Zi "   ,  /*-- U+59F8 .. U+59FF --*/
   "Song " , "Wei "  , "Hong " , "Wa "   , "Lou "  , "Ya "   , "Rao "  , "Jiao " ,  /*-- U+5A00 .. U+5A07 --*/
   "Luan " , "Ping " , "Xian " , "Shao " , "Li "   , "Cheng ", "Xiao " , "Mang " ,  /*-- U+5A08 .. U+5A0F --*/
   "Fu "   , "Suo "  , "Wu "   , "Wei "  , "Ke "   , "Lai "  , "Chuo " , "Ding " ,  /*-- U+5A10 .. U+5A17 --*/
   "Niang ", "Xing " , "Nan "  , "Yu "   , "Nuo "  , "Pei "  , "Nei "  , "Juan " ,  /*-- U+5A18 .. U+5A1F --*/
   "Shen " , "Zhi "  , "Han "  , "Di "   , "Zhuang ", "E "    , "Pin "  , "Tui "  ,  /*-- U+5A20 .. U+5A27 --*/
   "Han "  , "Mian " , "Wu "   , "Yan "  , "Wu "   , "Xi "   , "Yan "  , "Yu "   ,  /*-- U+5A28 .. U+5A2F --*/
   "Si "   , "Yu "   , "Wa "   , ""      , "Xian " , "Ju "   , "Qu "   , "Shui " ,  /*-- U+5A30 .. U+5A37 --*/
   "Qi "   , "Xian " , "Zhui " , "Dong " , "Chang ", "Lu "   , "Ai "   , "E "    ,  /*-- U+5A38 .. U+5A3F --*/
   "E "    , "Lou "  , "Mian " , "Cong " , "Pou "  , "Ju "   , "Po "   , "Cai "  ,  /*-- U+5A40 .. U+5A47 --*/
   "Ding " , "Wan "  , "Biao " , "Xiao " , "Shu "  , "Qi "   , "Hui "  , "Fu "   ,  /*-- U+5A48 .. U+5A4F --*/
   "E "    , "Wo "   , "Tan "  , "Fei "  , "Wei "  , "Jie "  , "Tian " , "Ni "   ,  /*-- U+5A50 .. U+5A57 --*/
   "Quan " , "Jing " , "Hun "  , "Jing " , "Qian " , "Dian " , "Xing " , "Hu "   ,  /*-- U+5A58 .. U+5A5F --*/
   "Wa "   , "Lai "  , "Bi "   , "Yin "  , "Chou " , "Chuo " , "Fu "   , "Jing " ,  /*-- U+5A60 .. U+5A67 --*/
   "Lun "  , "Yan "  , "Lan "  , "Kun "  , "Yin "  , "Ya "   , "Ju "   , "Li "   ,  /*-- U+5A68 .. U+5A6F --*/
   "Dian " , "Xian " , "Hwa "  , "Hua "  , "Ying " , "Chan " , "Shen " , "Ting " ,  /*-- U+5A70 .. U+5A77 --*/
   "Dang " , "Yao "  , "Wu "   , "Nan "  , "Ruo "  , "Jia "  , "Tou "  , "Xu "   ,  /*-- U+5A78 .. U+5A7F --*/
   "Yu "   , "Wei "  , "Ti "   , "Rou "  , "Mei "  , "Dan "  , "Ruan " , "Qin "  ,  /*-- U+5A80 .. U+5A87 --*/
   "Hui "  , "Wu "   , "Qian " , "Chun " , "Mao "  , "Fu "   , "Jie "  , "Duan " ,  /*-- U+5A88 .. U+5A8F --*/
   "Xi "   , "Zhong ", "Mei "  , "Huang ", "Mian " , "An "   , "Ying " , "Xuan " ,  /*-- U+5A90 .. U+5A97 --*/
   "Jie "  , "Wei "  , "Mei "  , "Yuan " , "Zhen " , "Qiu "  , "Ti "   , "Xie "  ,  /*-- U+5A98 .. U+5A9F --*/
   "Tuo "  , "Lian " , "Mao "  , "Ran "  , "Si "   , "Pian " , "Wei "  , "Wa "   ,  /*-- U+5AA0 .. U+5AA7 --*/
   "Jiu "  , "Hu "   , "Ao "   , ""      , "Bou "  , "Xu "   , "Tou "  , "Gui "  ,  /*-- U+5AA8 .. U+5AAF --*/
   "Zou "  , "Yao "  , "Pi "   , "Xi "   , "Yuan " , "Ying " , "Rong " , "Ru "   ,  /*-- U+5AB0 .. U+5AB7 --*/
   "Chi "  , "Liu "  , "Mei "  , "Pan "  , "Ao "   , "Ma "   , "Gou "  , "Kui "  ,  /*-- U+5AB8 .. U+5ABF --*/
   "Qin "  , "Jia "  , "Sao "  , "Zhen " , "Yuan " , "Cha "  , "Yong " , "Ming " ,  /*-- U+5AC0 .. U+5AC7 --*/
   "Ying " , "Ji "   , "Su "   , "Niao " , "Xian " , "Tao "  , "Pang " , "Lang " ,  /*-- U+5AC8 .. U+5ACF --*/
   "Nao "  , "Bao "  , "Ai "   , "Pi "   , "Pin "  , "Yi "   , "Piao " , "Yu "   ,  /*-- U+5AD0 .. U+5AD7 --*/
   "Lei "  , "Xuan " , "Man "  , "Yi "   , "Zhang ", "Kang " , "Yong " , "Ni "   ,  /*-- U+5AD8 .. U+5ADF --*/
   "Li "   , "Di "   , "Gui "  , "Yan "  , "Jin "  , "Zhuan ", "Chang ", "Ce "   ,  /*-- U+5AE0 .. U+5AE7 --*/
   "Han "  , "Nen "  , "Lao "  , "Mo "   , "Zhe "  , "Hu "   , "Hu "   , "Ao "   ,  /*-- U+5AE8 .. U+5AEF --*/
   "Nen "  , "Qiang ", "Ma "   , "Pie "  , "Gu "   , "Wu "   , "Jiao " , "Tuo "  ,  /*-- U+5AF0 .. U+5AF7 --*/
   "Zhan " , "Mao "  , "Xian " , "Xian " , "Mo "   , "Liao " , "Lian " , "Hua "  ,  /*-- U+5AF8 .. U+5AFF --*/
   "Gui "  , "Deng " , "Zhi "  , "Xu "   , "Yi "   , "Hua "  , "Xi "   , "Hui "  ,  /*-- U+5B00 .. U+5B07 --*/
   "Rao "  , "Xi "   , "Yan "  , "Chan " , "Jiao " , "Mei "  , "Fan "  , "Fan "  ,  /*-- U+5B08 .. U+5B0F --*/
   "Xian " , "Yi "   , "Wei "  , "Jiao " , "Fu "   , "Shi "  , "Bi "   , "Shan " ,  /*-- U+5B10 .. U+5B17 --*/
   "Sui "  , "Qiang ", "Lian " , "Huan " , "Xin "  , "Niao " , "Dong " , "Yi "   ,  /*-- U+5B18 .. U+5B1F --*/
   "Can "  , "Ai "   , "Niang ", "Neng " , "Ma "   , "Tiao " , "Chou " , "Jin "  ,  /*-- U+5B20 .. U+5B27 --*/
   "Ci "   , "Yu "   , "Pin "  , "Yong " , "Xu "   , "Nai "  , "Yan "  , "Tai "  ,  /*-- U+5B28 .. U+5B2F --*/
   "Ying " , "Can "  , "Niao " , "Wo "   , "Ying " , "Mian " , "Kaka " , "Ma "   ,  /*-- U+5B30 .. U+5B37 --*/
   "Shen " , "Xing " , "Ni "   , "Du "   , "Liu "  , "Yuan " , "Lan "  , "Yan "  ,  /*-- U+5B38 .. U+5B3F --*/
   "Shuang ", "Ling " , "Jiao " , "Niang ", "Lan "  , "Xian " , "Ying " , "Shuang ",  /*-- U+5B40 .. U+5B47 --*/
   "Shuai ", "Quan " , "Mi "   , "Li "   , "Luan " , "Yan "  , "Zhu "  , "Lan "  ,  /*-- U+5B48 .. U+5B4F --*/
   "Zi "   , "Jie "  , "Jue "  , "Jue "  , "Kong " , "Yun "  , "Zi "   , "Zi "   ,  /*-- U+5B50 .. U+5B57 --*/
   "Cun "  , "Sun "  , "Fu "   , "Bei "  , "Zi "   , "Xiao " , "Xin "  , "Meng " ,  /*-- U+5B58 .. U+5B5F --*/
   "Si "   , "Tai "  , "Bao "  , "Ji "   , "Gu "   , "Nu "   , "Xue "  , ""      ,  /*-- U+5B60 .. U+5B67 --*/
   "Zhuan ", "Hai "  , "Luan " , "Sun "  , "Huai " , "Mie "  , "Cong " , "Qian " ,  /*-- U+5B68 .. U+5B6F --*/
   "Shu "  , "Chan " , "Ya "   , "Zi "   , "Ni "   , "Fu "   , "Zi "   , "Li "   ,  /*-- U+5B70 .. U+5B77 --*/
   "Xue "  , "Bo "   , "Ru "   , "Lai "  , "Nie "  , "Nie "  , "Ying " , "Luan " ,  /*-- U+5B78 .. U+5B7F --*/
   "Mian " , "Zhu "  , "Rong " , "Ta "   , "Gui "  , "Zhai " , "Qiong ", "Yu "   ,  /*-- U+5B80 .. U+5B87 --*/
   "Shou " , "An "   , "Tu "   , "Song " , "Wan "  , "Rou "  , "Yao "  , "Hong " ,  /*-- U+5B88 .. U+5B8F --*/
   "Yi "   , "Jing " , "Zhun " , "Mi "   , "Zhu "  , "Dang " , "Hong " , "Zong " ,  /*-- U+5B90 .. U+5B97 --*/
   "Guan " , "Zhou " , "Ding " , "Wan "  , "Yi "   , "Bao "  , "Shi "  , "Shi "  ,  /*-- U+5B98 .. U+5B9F --*/
   "Chong ", "Shen " , "Ke "   , "Xuan " , "Shi "  , "You "  , "Huan " , "Yi "   ,  /*-- U+5BA0 .. U+5BA7 --*/
   "Tiao " , "Shi "  , "Xian " , "Gong " , "Cheng ", "Qun "  , "Gong " , "Xiao " ,  /*-- U+5BA8 .. U+5BAF --*/
   "Zai "  , "Zha "  , "Bao "  , "Hai "  , "Yan "  , "Xiao " , "Jia "  , "Shen " ,  /*-- U+5BB0 .. U+5BB7 --*/
   "Chen " , "Rong " , "Huang ", "Mi "   , "Kou "  , "Kuan " , "Bin "  , "Su "   ,  /*-- U+5BB8 .. U+5BBF --*/
   "Cai "  , "Zan "  , "Ji "   , "Yuan " , "Ji "   , "Yin "  , "Mi "   , "Kou "  ,  /*-- U+5BC0 .. U+5BC7 --*/
   "Qing " , "Que "  , "Zhen " , "Jian " , "Fu "   , "Ning " , "Bing " , "Huan " ,  /*-- U+5BC8 .. U+5BCF --*/
   "Mei "  , "Qin "  , "Han "  , "Yu "   , "Shi "  , "Ning " , "Qin "  , "Ning " ,  /*-- U+5BD0 .. U+5BD7 --*/
   "Zhi "  , "Yu "   , "Bao "  , "Kuan " , "Ning " , "Qin "  , "Mo "   , "Cha "  ,  /*-- U+5BD8 .. U+5BDF --*/
   "Ju "   , "Gua "  , "Qin "  , "Hu "   , "Wu "   , "Liao " , "Shi "  , "Zhu "  ,  /*-- U+5BE0 .. U+5BE7 --*/
   "Zhai " , "Shen " , "Wei "  , "Xie "  , "Kuan " , "Hui "  , "Liao " , "Jun "  ,  /*-- U+5BE8 .. U+5BEF --*/
   "Huan " , "Yi "   , "Yi "   , "Bao "  , "Qin "  , "Chong ", "Bao "  , "Feng " ,  /*-- U+5BF0 .. U+5BF7 --*/
   "Cun "  , "Dui "  , "Si "   , "Xun "  , "Dao "  , "Lu "   , "Dui "  , "Shou " ,  /*-- U+5BF8 .. U+5BFF --*/
   "Po "   , "Feng " , "Zhuan ", "Fu "   , "She "  , "Ke "   , "Jiang ", "Jiang ",  /*-- U+5C00 .. U+5C07 --*/
   "Zhuan ", "Wei "  , "Zun "  , "Xun "  , "Shu "  , "Dui "  , "Dao "  , "Xiao " ,  /*-- U+5C08 .. U+5C0F --*/
   "Ji "   , "Shao " , "Er "   , "Er "   , "Er "   , "Ga "   , "Jian " , "Shu "  ,  /*-- U+5C10 .. U+5C17 --*/
   "Chen " , "Shang ", "Shang ", "Mo "   , "Ga "   , "Chang ", "Liao " , "Xian " ,  /*-- U+5C18 .. U+5C1F --*/
   "Xian " , ""      , "Wang " , "Wang " , "You "  , "Liao " , "Liao " , "Yao "  ,  /*-- U+5C20 .. U+5C27 --*/
   "Mang " , "Wang " , "Wang " , "Wang " , "Ga "   , "Yao "  , "Duo "  , "Kui "  ,  /*-- U+5C28 .. U+5C2F --*/
   "Zhong ", "Jiu "  , "Gan "  , "Gu "   , "Gan "  , "Tui "  , "Gan "  , "Gan "  ,  /*-- U+5C30 .. U+5C37 --*/
   "Shi "  , "Yin "  , "Chi "  , "Kao "  , "Ni "   , "Jin "  , "Wei "  , "Niao " ,  /*-- U+5C38 .. U+5C3F --*/
   "Ju "   , "Pi "   , "Ceng " , "Xi "   , "Bi "   , "Ju "   , "Jie "  , "Tian " ,  /*-- U+5C40 .. U+5C47 --*/
   "Qu "   , "Ti "   , "Jie "  , "Wu "   , "Diao " , "Shi "  , "Shi "  , "Ping " ,  /*-- U+5C48 .. U+5C4F --*/
   "Ji "   , "Xie "  , "Chen " , "Xi "   , "Ni "   , "Zhan " , "Xi "   , ""      ,  /*-- U+5C50 .. U+5C57 --*/
   "Man "  , "E "    , "Lou "  , "Ping " , "Ti "   , "Fei "  , "Shu "  , "Xie "  ,  /*-- U+5C58 .. U+5C5F --*/
   "Tu "   , "Lu "   , "Lu "   , "Xi "   , "Ceng " , "Lu "   , "Ju "   , "Xie "  ,  /*-- U+5C60 .. U+5C67 --*/
   "Ju "   , "Jue "  , "Liao " , "Jue "  , "Shu "  , "Xi "   , "Che "  , "Tun "  ,  /*-- U+5C68 .. U+5C6F --*/
   "Ni "   , "Shan " , ""      , "Xian " , "Li "   , "Xue "  , "Nata " , ""      ,  /*-- U+5C70 .. U+5C77 --*/
   "Long " , "Yi "   , "Qi "   , "Ren "  , "Wu "   , "Han "  , "Shen " , "Yu "   ,  /*-- U+5C78 .. U+5C7F --*/
   "Chu "  , "Sui "  , "Qi "   , ""      , "Yue "  , "Ban "  , "Yao "  , "Ang "  ,  /*-- U+5C80 .. U+5C87 --*/
   "Ya "   , "Wu "   , "Jie "  , "E "    , "Ji "   , "Qian " , "Fen "  , "Yuan " ,  /*-- U+5C88 .. U+5C8F --*/
   "Qi "   , "Cen "  , "Qian " , "Qi "   , "Cha "  , "Jie "  , "Qu "   , "Gang " ,  /*-- U+5C90 .. U+5C97 --*/
   "Xian " , "Ao "   , "Lan "  , "Dao "  , "Ba "   , "Zuo "  , "Zuo "  , "Yang " ,  /*-- U+5C98 .. U+5C9F --*/
   "Ju "   , "Gang " , "Ke "   , "Gou "  , "Xue "  , "Bei "  , "Li "   , "Tiao " ,  /*-- U+5CA0 .. U+5CA7 --*/
   "Ju "   , "Yan "  , "Fu "   , "Xiu "  , "Jia "  , "Ling " , "Tuo "  , "Pei "  ,  /*-- U+5CA8 .. U+5CAF --*/
   "You "  , "Dai "  , "Kuang ", "Yue "  , "Qu "   , "Hu "   , "Po "   , "Min "  ,  /*-- U+5CB0 .. U+5CB7 --*/
   "An "   , "Tiao " , "Ling " , "Chi "  , "Yuri " , "Dong " , "Cem "  , "Kui "  ,  /*-- U+5CB8 .. U+5CBF --*/
   "Xiu "  , "Mao "  , "Tong " , "Xue "  , "Yi "   , "Kura " , "He "   , "Ke "   ,  /*-- U+5CC0 .. U+5CC7 --*/
   "Luo "  , "E "    , "Fu "   , "Xun "  , "Die "  , "Lu "   , "An "   , "Er "   ,  /*-- U+5CC8 .. U+5CCF --*/
   "Gai "  , "Quan " , "Tong " , "Yi "   , "Mu "   , "Shi "  , "An "   , "Wei "  ,  /*-- U+5CD0 .. U+5CD7 --*/
   "Hu "   , "Zhi "  , "Mi "   , "Li "   , "Ji "   , "Tong " , "Wei "  , "You "  ,  /*-- U+5CD8 .. U+5CDF --*/
   "Sang " , "Xia "  , "Li "   , "Yao "  , "Jiao " , "Zheng ", "Luan " , "Jiao " ,  /*-- U+5CE0 .. U+5CE7 --*/
   "E "    , "E "    , "Yu "   , "Ye "   , "Bu "   , "Qiao " , "Qun "  , "Feng " ,  /*-- U+5CE8 .. U+5CEF --*/
   "Feng " , "Nao "  , "Li "   , "You "  , "Xian " , "Hong " , "Dao "  , "Shen " ,  /*-- U+5CF0 .. U+5CF7 --*/
   "Cheng ", "Tu "   , "Geng " , "Jun "  , "Hao "  , "Xia "  , "Yin "  , "Yu "   ,  /*-- U+5CF8 .. U+5CFF --*/
   "Lang " , "Kan "  , "Lao "  , "Lai "  , "Xian " , "Que "  , "Kong " , "Chong ",  /*-- U+5D00 .. U+5D07 --*/
   "Chong ", "Ta "   , "Lin "  , "Hua "  , "Ju "   , "Lai "  , "Qi "   , "Min "  ,  /*-- U+5D08 .. U+5D0F --*/
   "Kun "  , "Kun "  , "Zu "   , "Gu "   , "Cui "  , "Ya "   , "Ya "   , "Gang " ,  /*-- U+5D10 .. U+5D17 --*/
   "Lun "  , "Lun "  , "Leng " , "Jue "  , "Duo "  , "Zheng ", "Guo "  , "Yin "  ,  /*-- U+5D18 .. U+5D1F --*/
   "Dong " , "Han "  , "Zheng ", "Wei "  , "Yao "  , "Pi "   , "Yan "  , "Song " ,  /*-- U+5D20 .. U+5D27 --*/
   "Jie "  , "Beng " , "Zu "   , "Jue "  , "Dong " , "Zhan " , "Gu "   , "Yin "  ,  /*-- U+5D28 .. U+5D2F --*/
   ""      , "Ze "   , "Huang ", "Yu "   , "Wei "  , "Yang " , "Feng " , "Qiu "  ,  /*-- U+5D30 .. U+5D37 --*/
   "Dun "  , "Ti "   , "Yi "   , "Zhi "  , "Shi "  , "Zai "  , "Yao "  , "E "    ,  /*-- U+5D38 .. U+5D3F --*/
   "Zhu "  , "Kan "  , "Lu "   , "Yan "  , "Mei "  , "Gan "  , "Ji "   , "Ji "   ,  /*-- U+5D40 .. U+5D47 --*/
   "Huan " , "Ting " , "Sheng ", "Mei "  , "Qian " , "Wu "   , "Yu "   , "Zong " ,  /*-- U+5D48 .. U+5D4F --*/
   "Lan "  , "Jue "  , "Yan "  , "Yan "  , "Wei "  , "Zong " , "Cha "  , "Sui "  ,  /*-- U+5D50 .. U+5D57 --*/
   "Rong " , "Yamashina ", "Qin "  , "Yu "   , "Kewashii ", "Lou "  , "Tu "   , "Dui "  ,  /*-- U+5D58 .. U+5D5F --*/
   "Xi "   , "Weng " , "Cang " , "Dang " , "Hong " , "Jie "  , "Ai "   , "Liu "  ,  /*-- U+5D60 .. U+5D67 --*/
   "Wu "   , "Song " , "Qiao " , "Zi "   , "Wei "  , "Beng " , "Dian " , "Cuo "  ,  /*-- U+5D68 .. U+5D6F --*/
   "Qian " , "Yong " , "Nie "  , "Cuo "  , "Ji "   , ""      , "Tao "  , "Song " ,  /*-- U+5D70 .. U+5D77 --*/
   "Zong " , "Jiang ", "Liao " , "Kang " , "Chan " , "Die "  , "Cen "  , "Ding " ,  /*-- U+5D78 .. U+5D7F --*/
   "Tu "   , "Lou "  , "Zhang ", "Zhan " , "Zhan " , "Ao "   , "Cao "  , "Qu "   ,  /*-- U+5D80 .. U+5D87 --*/
   "Qiang ", "Zui "  , "Zui "  , "Dao "  , "Dao "  , "Xi "   , "Yu "   , "Bo "   ,  /*-- U+5D88 .. U+5D8F --*/
   "Long " , "Xiang ", "Ceng " , "Bo "   , "Qin "  , "Jiao " , "Yan "  , "Lao "  ,  /*-- U+5D90 .. U+5D97 --*/
   "Zhan " , "Lin "  , "Liao " , "Liao " , "Jin "  , "Deng " , "Duo "  , "Zun "  ,  /*-- U+5D98 .. U+5D9F --*/
   "Jiao " , "Gui "  , "Yao "  , "Qiao " , "Yao "  , "Jue "  , "Zhan " , "Yi "   ,  /*-- U+5DA0 .. U+5DA7 --*/
   "Xue "  , "Nao "  , "Ye "   , "Ye "   , "Yi "   , "E "    , "Xian " , "Ji "   ,  /*-- U+5DA8 .. U+5DAF --*/
   "Xie "  , "Ke "   , "Xi "   , "Di "   , "Ao "   , "Zui "  , ""      , "Ni "   ,  /*-- U+5DB0 .. U+5DB7 --*/
   "Rong " , "Dao "  , "Ling " , "Za "   , "Yu "   , "Yue "  , "Yin "  , ""      ,  /*-- U+5DB8 .. U+5DBF --*/
   "Jie "  , "Li "   , "Sui "  , "Long " , "Long " , "Dian " , "Ying " , "Xi "   ,  /*-- U+5DC0 .. U+5DC7 --*/
   "Ju "   , "Chan " , "Ying " , "Kui "  , "Yan "  , "Wei "  , "Nao "  , "Quan " ,  /*-- U+5DC8 .. U+5DCF --*/
   "Chao " , "Cuan " , "Luan " , "Dian " , "Dian " , ""      , "Yan "  , "Yan "  ,  /*-- U+5DD0 .. U+5DD7 --*/
   "Yan "  , "Nao "  , "Yan "  , "Chuan ", "Gui "  , "Chuan ", "Zhou " , "Huang ",  /*-- U+5DD8 .. U+5DDF --*/
   "Jing " , "Xun "  , "Chao " , "Chao " , "Lie "  , "Gong " , "Zuo "  , "Qiao " ,  /*-- U+5DE0 .. U+5DE7 --*/
   "Ju "   , "Gong " , "Kek "  , "Wu "   , "Pwu "  , "Pwu "  , "Chai " , "Qiu "  ,  /*-- U+5DE8 .. U+5DEF --*/
   "Qiu "  , "Ji "   , "Yi "   , "Si "   , "Ba "   , "Zhi "  , "Zhao " , "Xiang ",  /*-- U+5DF0 .. U+5DF7 --*/
   "Yi "   , "Jin "  , "Xun "  , "Juan " , "Phas " , "Xun "  , "Jin "  , "Fu "   ,  /*-- U+5DF8 .. U+5DFF --*/
   "Za "   , "Bi "   , "Shi "  , "Bu "   , "Ding " , "Shuai ", "Fan "  , "Nie "  ,  /*-- U+5E00 .. U+5E07 --*/
   "Shi "  , "Fen "  , "Pa "   , "Zhi "  , "Xi "   , "Hu "   , "Dan "  , "Wei "  ,  /*-- U+5E08 .. U+5E0F --*/
   "Zhang ", "Tang " , "Dai "  , "Ma "   , "Pei "  , "Pa "   , "Tie "  , "Fu "   ,  /*-- U+5E10 .. U+5E17 --*/
   "Lian " , "Zhi "  , "Zhou " , "Bo "   , "Zhi "  , "Di "   , "Mo "   , "Yi "   ,  /*-- U+5E18 .. U+5E1F --*/
   "Yi "   , "Ping " , "Qia "  , "Juan " , "Ru "   , "Shuai ", "Dai "  , "Zheng ",  /*-- U+5E20 .. U+5E27 --*/
   "Shui " , "Qiao " , "Zhen " , "Shi "  , "Qun "  , "Xi "   , "Bang " , "Dai "  ,  /*-- U+5E28 .. U+5E2F --*/
   "Gui "  , "Chou " , "Ping " , "Zhang ", "Sha "  , "Wan "  , "Dai "  , "Wei "  ,  /*-- U+5E30 .. U+5E37 --*/
   "Chang ", "Sha "  , "Qi "   , "Ze "   , "Guo "  , "Mao "  , "Du "   , "Hou "  ,  /*-- U+5E38 .. U+5E3F --*/
   "Zheng ", "Xu "   , "Mi "   , "Wei "  , "Wo "   , "Fu "   , "Yi "   , "Bang " ,  /*-- U+5E40 .. U+5E47 --*/
   "Ping " , "Tazuna ", "Gong " , "Pan "  , "Huang ", "Dao "  , "Mi "   , "Jia "  ,  /*-- U+5E48 .. U+5E4F --*/
   "Teng " , "Hui "  , "Zhong ", "Shan " , "Man "  , "Mu "   , "Biao " , "Guo "  ,  /*-- U+5E50 .. U+5E57 --*/
   "Ze "   , "Mu "   , "Bang " , "Zhang ", "Jiong ", "Chan " , "Fu "   , "Zhi "  ,  /*-- U+5E58 .. U+5E5F --*/
   "Hu "   , "Fan "  , "Chuang ", "Bi "   , "Hei "  , ""      , "Mi "   , "Qiao " ,  /*-- U+5E60 .. U+5E67 --*/
   "Chan " , "Fen "  , "Meng " , "Bang " , "Chou " , "Mie "  , "Chu "  , "Jie "  ,  /*-- U+5E68 .. U+5E6F --*/
   "Xian " , "Lan "  , "Gan "  , "Ping " , "Nian " , "Qian " , "Bing " , "Bing " ,  /*-- U+5E70 .. U+5E77 --*/
   "Xing " , "Gan "  , "Yao "  , "Huan " , "You "  , "You "  , "Ji "   , "Yan "  ,  /*-- U+5E78 .. U+5E7F --*/
   "Pi "   , "Ting " , "Ze "   , "Guang ", "Zhuang ", "Mo "   , "Qing " , "Bi "   ,  /*-- U+5E80 .. U+5E87 --*/
   "Qin "  , "Dun "  , "Chuang ", "Gui "  , "Ya "   , "Bai "  , "Jie "  , "Xu "   ,  /*-- U+5E88 .. U+5E8F --*/
   "Lu "   , "Wu "   , ""      , "Ku "   , "Ying " , "Di "   , "Pao "  , "Dian " ,  /*-- U+5E90 .. U+5E97 --*/
   "Ya "   , "Miao " , "Geng " , "Ci "   , "Fu "   , "Tong " , "Pang " , "Fei "  ,  /*-- U+5E98 .. U+5E9F --*/
   "Xiang ", "Yi "   , "Zhi "  , "Tiao " , "Zhi "  , "Xiu "  , "Du "   , "Zuo "  ,  /*-- U+5EA0 .. U+5EA7 --*/
   "Xiao " , "Tu "   , "Gui "  , "Ku "   , "Pang " , "Ting " , "You "  , "Bu "   ,  /*-- U+5EA8 .. U+5EAF --*/
   "Ding " , "Cheng ", "Lai "  , "Bei "  , "Ji "   , "An "   , "Shu "  , "Kang " ,  /*-- U+5EB0 .. U+5EB7 --*/
   "Yong " , "Tuo "  , "Song " , "Shu "  , "Qing " , "Yu "   , "Yu "   , "Miao " ,  /*-- U+5EB8 .. U+5EBF --*/
   "Sou "  , "Ce "   , "Xiang ", "Fei "  , "Jiu "  , "He "   , "Hui "  , "Liu "  ,  /*-- U+5EC0 .. U+5EC7 --*/
   "Sha "  , "Lian " , "Lang " , "Sou "  , "Jian " , "Pou "  , "Qing " , "Jiu "  ,  /*-- U+5EC8 .. U+5ECF --*/
   "Jiu "  , "Qin "  , "Ao "   , "Kuo "  , "Lou "  , "Yin "  , "Liao " , "Dai "  ,  /*-- U+5ED0 .. U+5ED7 --*/
   "Lu "   , "Yi "   , "Chu "  , "Chan " , "Tu "   , "Si "   , "Xin "  , "Miao " ,  /*-- U+5ED8 .. U+5EDF --*/
   "Chang ", "Wu "   , "Fei "  , "Guang ", "Koc "  , "Kuai " , "Bi "   , "Qiang ",  /*-- U+5EE0 .. U+5EE7 --*/
   "Xie "  , "Lin "  , "Lin "  , "Liao " , "Lu "   , ""      , "Ying " , "Xian " ,  /*-- U+5EE8 .. U+5EEF --*/
   "Ting " , "Yong " , "Li "   , "Ting " , "Yin "  , "Xun "  , "Yan "  , "Ting " ,  /*-- U+5EF0 .. U+5EF7 --*/
   "Di "   , "Po "   , "Jian " , "Hui "  , "Nai "  , "Hui "  , "Gong " , "Nian " ,  /*-- U+5EF8 .. U+5EFF --*/
   "Kai "  , "Bian " , "Yi "   , "Qi "   , "Nong " , "Fen "  , "Ju "   , "Yan "  ,  /*-- U+5F00 .. U+5F07 --*/
   "Yi "   , "Zang " , "Bi "   , "Yi "   , "Yi "   , "Er "   , "San "  , "Shi "  ,  /*-- U+5F08 .. U+5F0F --*/
   "Er "   , "Shi "  , "Shi "  , "Gong " , "Diao " , "Yin "  , "Hu "   , "Fu "   ,  /*-- U+5F10 .. U+5F17 --*/
   "Hong " , "Wu "   , "Tui "  , "Chi "  , "Jiang ", "Ba "   , "Shen " , "Di "   ,  /*-- U+5F18 .. U+5F1F --*/
   "Zhang ", "Jue "  , "Tao "  , "Fu "   , "Di "   , "Mi "   , "Xian " , "Hu "   ,  /*-- U+5F20 .. U+5F27 --*/
   "Chao " , "Nu "   , "Jing " , "Zhen " , "Yi "   , "Mi "   , "Quan " , "Wan "  ,  /*-- U+5F28 .. U+5F2F --*/
   "Shao " , "Ruo "  , "Xuan " , "Jing " , "Dun "  , "Zhang ", "Jiang ", "Qiang ",  /*-- U+5F30 .. U+5F37 --*/
   "Peng " , "Dan "  , "Qiang ", "Bi "   , "Bi "   , "She "  , "Dan "  , "Jian " ,  /*-- U+5F38 .. U+5F3F --*/
   "Gou "  , "Sei "  , "Fa "   , "Bi "   , "Kou "  , "Nagi " , "Bie "  , "Xiao " ,  /*-- U+5F40 .. U+5F47 --*/
   "Dan "  , "Kuo "  , "Qiang ", "Hong " , "Mi "   , "Kuo "  , "Wan "  , "Jue "  ,  /*-- U+5F48 .. U+5F4F --*/
   "Ji "   , "Ji "   , "Gui "  , "Dang " , "Lu "   , "Lu "   , "Tuan " , "Hui "  ,  /*-- U+5F50 .. U+5F57 --*/
   "Zhi "  , "Hui "  , "Hui "  , "Yi "   , "Yi "   , "Yi "   , "Yi "   , "Huo "  ,  /*-- U+5F58 .. U+5F5F --*/
   "Huo "  , "Shan " , "Xing " , "Wen "  , "Tong " , "Yan "  , "Yan "  , "Yu "   ,  /*-- U+5F60 .. U+5F67 --*/
   "Chi "  , "Cai "  , "Biao " , "Diao " , "Bin "  , "Peng " , "Yong " , "Piao " ,  /*-- U+5F68 .. U+5F6F --*/
   "Zhang ", "Ying " , "Chi "  , "Chi "  , "Zhuo " , "Tuo "  , "Ji "   , "Pang " ,  /*-- U+5F70 .. U+5F77 --*/
   "Zhong ", "Yi "   , "Wang " , "Che "  , "Bi "   , "Chi "  , "Ling " , "Fu "   ,  /*-- U+5F78 .. U+5F7F --*/
   "Wang " , "Zheng ", "Cu "   , "Wang " , "Jing " , "Dai "  , "Xi "   , "Xun "  ,  /*-- U+5F80 .. U+5F87 --*/
   "Hen "  , "Yang " , "Huai " , "Lu "   , "Hou "  , "Wa "   , "Cheng ", "Zhi "  ,  /*-- U+5F88 .. U+5F8F --*/
   "Xu "   , "Jing " , "Tu "   , "Cong " , ""      , "Lai "  , "Cong " , "De "   ,  /*-- U+5F90 .. U+5F97 --*/
   "Pai "  , "Xi "   , ""      , "Qi "   , "Chang ", "Zhi "  , "Cong " , "Zhou " ,  /*-- U+5F98 .. U+5F9F --*/
   "Lai "  , "Yu "   , "Xie "  , "Jie "  , "Jian " , "Chi "  , "Jia "  , "Bian " ,  /*-- U+5FA0 .. U+5FA7 --*/
   "Huang ", "Fu "   , "Xun "  , "Wei "  , "Pang " , "Yao "  , "Wei "  , "Xi "   ,  /*-- U+5FA8 .. U+5FAF --*/
   "Zheng ", "Piao " , "Chi "  , "De "   , "Zheng ", "Zheng ", "Bie "  , "De "   ,  /*-- U+5FB0 .. U+5FB7 --*/
   "Chong ", "Che "  , "Jiao " , "Wei "  , "Jiao " , "Hui "  , "Mei "  , "Long " ,  /*-- U+5FB8 .. U+5FBF --*/
   "Xiang ", "Bao "  , "Qu "   , "Xin "  , "Shu "  , "Bi "   , "Yi "   , "Le "   ,  /*-- U+5FC0 .. U+5FC7 --*/
   "Ren "  , "Dao "  , "Ding " , "Gai "  , "Ji "   , "Ren "  , "Ren "  , "Chan " ,  /*-- U+5FC8 .. U+5FCF --*/
   "Tan "  , "Te "   , "Te "   , "Gan "  , "Qi "   , "Shi "  , "Cun "  , "Zhi "  ,  /*-- U+5FD0 .. U+5FD7 --*/
   "Wang " , "Mang " , "Xi "   , "Fan "  , "Ying " , "Tian " , "Min "  , "Min "  ,  /*-- U+5FD8 .. U+5FDF --*/
   "Zhong ", "Chong ", "Wu "   , "Ji "   , "Wu "   , "Xi "   , "Ye "   , "You "  ,  /*-- U+5FE0 .. U+5FE7 --*/
   "Wan "  , "Cong " , "Zhong ", "Kuai " , "Yu "   , "Bian " , "Zhi "  , "Qi "   ,  /*-- U+5FE8 .. U+5FEF --*/
   "Cui "  , "Chen " , "Tai "  , "Tun "  , "Qian " , "Nian " , "Hun "  , "Xiong ",  /*-- U+5FF0 .. U+5FF7 --*/
   "Niu "  , "Wang " , "Xian " , "Xin "  , "Kang " , "Hu "   , "Kai "  , "Fen "  ,  /*-- U+5FF8 .. U+5FFF --*/
   "Huai " , "Tai "  , "Song " , "Wu "   , "Ou "   , "Chang ", "Chuang ", "Ju "   ,  /*-- U+6000 .. U+6007 --*/
   "Yi "   , "Bao "  , "Chao " , "Min "  , "Pei "  , "Zuo "  , "Zen "  , "Yang " ,  /*-- U+6008 .. U+600F --*/
   "Kou "  , "Ban "  , "Nu "   , "Nao "  , "Zheng ", "Pa "   , "Bu "   , "Tie "  ,  /*-- U+6010 .. U+6017 --*/
   "Gu "   , "Hu "   , "Ju "   , "Da "   , "Lian " , "Si "   , "Chou " , "Di "   ,  /*-- U+6018 .. U+601F --*/
   "Dai "  , "Yi "   , "Tu "   , "You "  , "Fu "   , "Ji "   , "Peng " , "Xing " ,  /*-- U+6020 .. U+6027 --*/
   "Yuan " , "Ni "   , "Guai " , "Fu "   , "Xi "   , "Bi "   , "You "  , "Qie "  ,  /*-- U+6028 .. U+602F --*/
   "Xuan " , "Cong " , "Bing " , "Huang ", "Xu "   , "Chu "  , "Pi "   , "Xi "   ,  /*-- U+6030 .. U+6037 --*/
   "Xi "   , "Tan "  , "Koraeru ", "Zong " , "Dui "  , ""      , "Ki "   , "Yi "   ,  /*-- U+6038 .. U+603F --*/
   "Chi "  , "Ren "  , "Xun "  , "Shi "  , "Xi "   , "Lao "  , "Heng " , "Kuang ",  /*-- U+6040 .. U+6047 --*/
   "Mu "   , "Zhi "  , "Xie "  , "Lian " , "Tiao " , "Huang ", "Die "  , "Hao "  ,  /*-- U+6048 .. U+604F --*/
   "Kong " , "Gui "  , "Heng " , "Xi "   , "Xiao " , "Shu "  , "S "    , "Kua "  ,  /*-- U+6050 .. U+6057 --*/
   "Qiu "  , "Yang " , "Hui "  , "Hui "  , "Chi "  , "Jia "  , "Yi "   , "Xiong ",  /*-- U+6058 .. U+605F --*/
   "Guai " , "Lin "  , "Hui "  , "Zi "   , "Xu "   , "Chi "  , "Xiang ", "Nu "   ,  /*-- U+6060 .. U+6067 --*/
   "Hen "  , "En "   , "Ke "   , "Tong " , "Tian " , "Gong " , "Quan " , "Xi "   ,  /*-- U+6068 .. U+606F --*/
   "Qia "  , "Yue "  , "Peng " , "Ken "  , "De "   , "Hui "  , "E "    , "Kyuu " ,  /*-- U+6070 .. U+6077 --*/
   "Tong " , "Yan "  , "Kai "  , "Ce "   , "Nao "  , "Yun "  , "Mang " , "Yong " ,  /*-- U+6078 .. U+607F --*/
   "Yong " , "Yuan " , "Pi "   , "Kun "  , "Qiao " , "Yue "  , "Yu "   , "Yu "   ,  /*-- U+6080 .. U+6087 --*/
   "Jie "  , "Xi "   , "Zhe "  , "Lin "  , "Ti "   , "Han "  , "Hao "  , "Qie "  ,  /*-- U+6088 .. U+608F --*/
   "Ti "   , "Bu "   , "Yi "   , "Qian " , "Hui "  , "Xi "   , "Bei "  , "Man "  ,  /*-- U+6090 .. U+6097 --*/
   "Yi "   , "Heng " , "Song " , "Quan " , "Cheng ", "Hui "  , "Wu "   , "Wu "   ,  /*-- U+6098 .. U+609F --*/
   "You "  , "Li "   , "Liang ", "Huan " , "Cong " , "Yi "   , "Yue "  , "Li "   ,  /*-- U+60A0 .. U+60A7 --*/
   "Nin "  , "Nao "  , "E "    , "Que "  , "Xuan " , "Qian " , "Wu "   , "Min "  ,  /*-- U+60A8 .. U+60AF --*/
   "Cong " , "Fei "  , "Bei "  , "Duo "  , "Cui "  , "Chang ", "Men "  , "Li "   ,  /*-- U+60B0 .. U+60B7 --*/
   "Ji "   , "Guan " , "Guan " , "Xing " , "Dao "  , "Qi "   , "Kong " , "Tian " ,  /*-- U+60B8 .. U+60BF --*/
   "Lun "  , "Xi "   , "Kan "  , "Kun "  , "Ni "   , "Qing " , "Chou " , "Dun "  ,  /*-- U+60C0 .. U+60C7 --*/
   "Guo "  , "Chan " , "Liang ", "Wan "  , "Yuan " , "Jin "  , "Ji "   , "Lin "  ,  /*-- U+60C8 .. U+60CF --*/
   "Yu "   , "Huo "  , "He "   , "Quan " , "Tan "  , "Ti "   , "Ti "   , "Nie "  ,  /*-- U+60D0 .. U+60D7 --*/
   "Wang " , "Chuo " , "Bu "   , "Hun "  , "Xi "   , "Tang " , "Xin "  , "Wei "  ,  /*-- U+60D8 .. U+60DF --*/
   "Hui "  , "E "    , "Rui "  , "Zong " , "Jian " , "Yong " , "Dian " , "Ju "   ,  /*-- U+60E0 .. U+60E7 --*/
   "Can "  , "Cheng ", "De "   , "Bei "  , "Qie "  , "Can "  , "Dan "  , "Guan " ,  /*-- U+60E8 .. U+60EF --*/
   "Duo "  , "Nao "  , "Yun "  , "Xiang ", "Zhui " , "Die "  , "Huang ", "Chun " ,  /*-- U+60F0 .. U+60F7 --*/
   "Qiong ", "Re "   , "Xing " , "Ce "   , "Bian " , "Hun "  , "Zong " , "Ti "   ,  /*-- U+60F8 .. U+60FF --*/
   "Qiao " , "Chou " , "Bei "  , "Xuan " , "Wei "  , "Ge "   , "Qian " , "Wei "  ,  /*-- U+6100 .. U+6107 --*/
   "Yu "   , "Yu "   , "Bi "   , "Xuan " , "Huan " , "Min "  , "Bi "   , "Yi "   ,  /*-- U+6108 .. U+610F --*/
   "Mian " , "Yong " , "Kai "  , "Dang " , "Yin "  , "E "    , "Chen " , "Mou "  ,  /*-- U+6110 .. U+6117 --*/
   "Ke "   , "Ke "   , "Yu "   , "Ai "   , "Qie "  , "Yan "  , "Nuo "  , "Gan "  ,  /*-- U+6118 .. U+611F --*/
   "Yun "  , "Zong " , "Sai "  , "Leng " , "Fen "  , ""      , "Kui "  , "Kui "  ,  /*-- U+6120 .. U+6127 --*/
   "Que "  , "Gong " , "Yun "  , "Su "   , "Su "   , "Qi "   , "Yao "  , "Song " ,  /*-- U+6128 .. U+612F --*/
   "Huang ", "Ji "   , "Gu "   , "Ju "   , "Chuang ", "Ni "   , "Xie "  , "Kai "  ,  /*-- U+6130 .. U+6137 --*/
   "Zheng ", "Yong " , "Cao "  , "Sun "  , "Shen " , "Bo "   , "Kai "  , "Yuan " ,  /*-- U+6138 .. U+613F --*/
   "Xie "  , "Hun "  , "Yong " , "Yang " , "Li "   , "Sao "  , "Tao "  , "Yin "  ,  /*-- U+6140 .. U+6147 --*/
   "Ci "   , "Xu "   , "Qian " , "Tai "  , "Huang ", "Yun "  , "Shen " , "Ming " ,  /*-- U+6148 .. U+614F --*/
   ""      , "She "  , "Cong " , "Piao " , "Mo "   , "Mu "   , "Guo "  , "Chi "  ,  /*-- U+6150 .. U+6157 --*/
   "Can "  , "Can "  , "Can "  , "Cui "  , "Min "  , "Te "   , "Zhang ", "Tong " ,  /*-- U+6158 .. U+615F --*/
   "Ao "   , "Shuang ", "Man "  , "Guan " , "Que "  , "Zao "  , "Jiu "  , "Hui "  ,  /*-- U+6160 .. U+6167 --*/
   "Kai "  , "Lian " , "Ou "   , "Song " , "Jin "  , "Yin "  , "Lu "   , "Shang ",  /*-- U+6168 .. U+616F --*/
   "Wei "  , "Tuan " , "Man "  , "Qian " , "She "  , "Yong " , "Qing " , "Kang " ,  /*-- U+6170 .. U+6177 --*/
   "Di "   , "Zhi "  , "Lou "  , "Juan " , "Qi "   , "Qi "   , "Yu "   , "Ping " ,  /*-- U+6178 .. U+617F --*/
   "Liao " , "Cong " , "You "  , "Chong ", "Zhi "  , "Tong " , "Cheng ", "Qi "   ,  /*-- U+6180 .. U+6187 --*/
   "Qu "   , "Peng " , "Bei "  , "Bie "  , "Chun " , "Jiao " , "Zeng " , "Chi "  ,  /*-- U+6188 .. U+618F --*/
   "Lian " , "Ping " , "Kui "  , "Hui "  , "Qiao " , "Cheng ", "Yin "  , "Yin "  ,  /*-- U+6190 .. U+6197 --*/
   "Xi "   , "Xi "   , "Dan "  , "Tan "  , "Duo "  , "Dui "  , "Dui "  , "Su "   ,  /*-- U+6198 .. U+619F --*/
   "Jue "  , "Ce "   , "Xiao " , "Fan "  , "Fen "  , "Lao "  , "Lao "  , "Chong ",  /*-- U+61A0 .. U+61A7 --*/
   "Han "  , "Qi "   , "Xian " , "Min "  , "Jing " , "Liao " , "Wu "   , "Can "  ,  /*-- U+61A8 .. U+61AF --*/
   "Jue "  , "Cu "   , "Xian " , "Tan "  , "Sheng ", "Pi "   , "Yi "   , "Chu "  ,  /*-- U+61B0 .. U+61B7 --*/
   "Xian " , "Nao "  , "Dan "  , "Tan "  , "Jing " , "Song " , "Han "  , "Jiao " ,  /*-- U+61B8 .. U+61BF --*/
   "Wai "  , "Huan " , "Dong " , "Qin "  , "Qin "  , "Qu "   , "Cao "  , "Ken "  ,  /*-- U+61C0 .. U+61C7 --*/
   "Xie "  , "Ying " , "Ao "   , "Mao "  , "Yi "   , "Lin "  , "Se "   , "Jun "  ,  /*-- U+61C8 .. U+61CF --*/
   "Huai " , "Men "  , "Lan "  , "Ai "   , "Lin "  , "Yan "  , "Gua "  , "Xia "  ,  /*-- U+61D0 .. U+61D7 --*/
   "Chi "  , "Yu "   , "Yin "  , "Dai "  , "Meng " , "Ai "   , "Meng " , "Dui "  ,  /*-- U+61D8 .. U+61DF --*/
   "Qi "   , "Mo "   , "Lan "  , "Men "  , "Chou " , "Zhi "  , "Nuo "  , "Nuo "  ,  /*-- U+61E0 .. U+61E7 --*/
   "Yan "  , "Yang " , "Bo "   , "Zhi "  , "Kuang ", "Kuang ", "You "  , "Fu "   ,  /*-- U+61E8 .. U+61EF --*/
   "Liu "  , "Mie "  , "Cheng ", ""      , "Chan " , "Meng " , "Lan "  , "Huai " ,  /*-- U+61F0 .. U+61F7 --*/
   "Xuan " , "Rang " , "Chan " , "Ji "   , "Ju "   , "Huan " , "She "  , "Yi "   ,  /*-- U+61F8 .. U+61FF --*/
   "Lian " , "Nan "  , "Mi "   , "Tang " , "Jue "  , "Gang " , "Gang " , "Gang " ,  /*-- U+6200 .. U+6207 --*/
   "Ge "   , "Yue "  , "Wu "   , "Jian " , "Xu "   , "Shu "  , "Rong " , "Xi "   ,  /*-- U+6208 .. U+620F --*/
   "Cheng ", "Wo "   , "Jie "  , "Ge "   , "Jian " , "Qiang ", "Huo "  , "Qiang ",  /*-- U+6210 .. U+6217 --*/
   "Zhan " , "Dong " , "Qi "   , "Jia "  , "Die "  , "Zei "  , "Jia "  , "Ji "   ,  /*-- U+6218 .. U+621F --*/
   "Shi "  , "Kan "  , "Ji "   , "Kui "  , "Gai "  , "Deng " , "Zhan " , "Chuang ",  /*-- U+6220 .. U+6227 --*/
   "Ge "   , "Jian " , "Jie "  , "Yu "   , "Jian " , "Yan "  , "Lu "   , "Xi "   ,  /*-- U+6228 .. U+622F --*/
   "Zhan " , "Xi "   , "Xi "   , "Chuo " , "Dai "  , "Qu "   , "Hu "   , "Hu "   ,  /*-- U+6230 .. U+6237 --*/
   "Hu "   , "E "    , "Shi "  , "Li "   , "Mao "  , "Hu "   , "Li "   , "Fang " ,  /*-- U+6238 .. U+623F --*/
   "Suo "  , "Bian " , "Dian " , "Jiong ", "Shang ", "Yi "   , "Yi "   , "Shan " ,  /*-- U+6240 .. U+6247 --*/
   "Hu "   , "Fei "  , "Yan "  , "Shou " , "T "    , "Cai "  , "Zha "  , "Qiu "  ,  /*-- U+6248 .. U+624F --*/
   "Le "   , "Bu "   , "Ba "   , "Da "   , "Reng " , "Fu "   , "Hameru ", "Zai "  ,  /*-- U+6250 .. U+6257 --*/
   "Tuo "  , "Zhang ", "Diao " , "Kang " , "Yu "   , "Ku "   , "Han "  , "Shen " ,  /*-- U+6258 .. U+625F --*/
   "Cha "  , "Yi "   , "Gu "   , "Kou "  , "Wu "   , "Tuo "  , "Qian " , "Zhi "  ,  /*-- U+6260 .. U+6267 --*/
   "Ren "  , "Kuo "  , "Men "  , "Sao "  , "Yang " , "Niu "  , "Ban "  , "Che "  ,  /*-- U+6268 .. U+626F --*/
   "Rao "  , "Xi "   , "Qian " , "Ban "  , "Jia "  , "Yu "   , "Fu "   , "Ao "   ,  /*-- U+6270 .. U+6277 --*/
   "Xi "   , "Pi "   , "Zhi "  , "Zi "   , "E "    , "Dun "  , "Zhao " , "Cheng ",  /*-- U+6278 .. U+627F --*/
   "Ji "   , "Yan "  , "Kuang ", "Bian " , "Chao " , "Ju "   , "Wen "  , "Hu "   ,  /*-- U+6280 .. U+6287 --*/
   "Yue "  , "Jue "  , "Ba "   , "Qin "  , "Zhen " , "Zheng ", "Yun "  , "Wan "  ,  /*-- U+6288 .. U+628F --*/
   "Nu "   , "Yi "   , "Shu "  , "Zhua " , "Pou "  , "Tou "  , "Dou "  , "Kang " ,  /*-- U+6290 .. U+6297 --*/
   "Zhe "  , "Pou "  , "Fu "   , "Pao "  , "Ba "   , "Ao "   , "Ze "   , "Tuan " ,  /*-- U+6298 .. U+629F --*/
   "Kou "  , "Lun "  , "Qiang ", ""      , "Hu "   , "Bao "  , "Bing " , "Zhi "  ,  /*-- U+62A0 .. U+62A7 --*/
   "Peng " , "Tan "  , "Pu "   , "Pi "   , "Tai "  , "Yao "  , "Zhen " , "Zha "  ,  /*-- U+62A8 .. U+62AF --*/
   "Yang " , "Bao "  , "He "   , "Ni "   , "Yi "   , "Di "   , "Chi "  , "Pi "   ,  /*-- U+62B0 .. U+62B7 --*/
   "Za "   , "Mo "   , "Mo "   , "Shen " , "Ya "   , "Chou " , "Qu "   , "Min "  ,  /*-- U+62B8 .. U+62BF --*/
   "Chu "  , "Jia "  , "Fu "   , "Zhan " , "Zhu "  , "Dan "  , "Chai " , "Mu "   ,  /*-- U+62C0 .. U+62C7 --*/
   "Nian " , "La "   , "Fu "   , "Pao "  , "Ban "  , "Pai "  , "Ling " , "Na "   ,  /*-- U+62C8 .. U+62CF --*/
   "Guai " , "Qian " , "Ju "   , "Tuo "  , "Ba "   , "Tuo "  , "Tuo "  , "Ao "   ,  /*-- U+62D0 .. U+62D7 --*/
   "Ju "   , "Zhuo " , "Pan "  , "Zhao " , "Bai "  , "Bai "  , "Di "   , "Ni "   ,  /*-- U+62D8 .. U+62DF --*/
   "Ju "   , "Kuo "  , "Long " , "Jian " , ""      , "Yong " , "Lan "  , "Ning " ,  /*-- U+62E0 .. U+62E7 --*/
   "Bo "   , "Ze "   , "Qian " , "Hen "  , "Gua "  , "Shi "  , "Jie "  , "Zheng ",  /*-- U+62E8 .. U+62EF --*/
   "Nin "  , "Gong " , "Gong " , "Quan " , "Shuan ", "Cun "  , "Zan "  , "Kao "  ,  /*-- U+62F0 .. U+62F7 --*/
   "Chi "  , "Xie "  , "Ce "   , "Hui "  , "Pin "  , "Zhuai ", "Shi "  , "Na "   ,  /*-- U+62F8 .. U+62FF --*/
   "Bo "   , "Chi "  , "Gua "  , "Zhi "  , "Kuo "  , "Duo "  , "Duo "  , "Zhi "  ,  /*-- U+6300 .. U+6307 --*/
   "Qie "  , "An "   , "Nong " , "Zhen " , "Ge "   , "Jiao " , "Ku "   , "Dong " ,  /*-- U+6308 .. U+630F --*/
   "Ru "   , "Tiao " , "Lie "  , "Zha "  , "Lu "   , "Die "  , "Wa "   , "Jue "  ,  /*-- U+6310 .. U+6317 --*/
   "Mushiru ", "Ju "   , "Zhi "  , "Luan " , "Ya "   , "Zhua " , "Ta "   , "Xie "  ,  /*-- U+6318 .. U+631F --*/
   "Nao "  , "Dang " , "Jiao " , "Zheng ", "Ji "   , "Hui "  , "Xun "  , "Ku "   ,  /*-- U+6320 .. U+6327 --*/
   "Ai "   , "Tuo "  , "Nuo "  , "Cuo "  , "Bo "   , "Geng " , "Ti "   , "Zhen " ,  /*-- U+6328 .. U+632F --*/
   "Cheng ", "Suo "  , "Suo "  , "Keng " , "Mei "  , "Long " , "Ju "   , "Peng " ,  /*-- U+6330 .. U+6337 --*/
   "Jian " , "Yi "   , "Ting " , "Shan " , "Nuo "  , "Wan "  , "Xie "  , "Cha "  ,  /*-- U+6338 .. U+633F --*/
   "Feng " , "Jiao " , "Wu "   , "Jun "  , "Jiu "  , "Tong " , "Kun "  , "Huo "  ,  /*-- U+6340 .. U+6347 --*/
   "Tu "   , "Zhuo " , "Pou "  , "Le "   , "Ba "   , "Han "  , "Shao " , "Nie "  ,  /*-- U+6348 .. U+634F --*/
   "Juan " , "Ze "   , "Song " , "Ye "   , "Jue "  , "Bu "   , "Huan " , "Bu "   ,  /*-- U+6350 .. U+6357 --*/
   "Zun "  , "Yi "   , "Zhai " , "Lu "   , "Sou "  , "Tuo "  , "Lao "  , "Sun "  ,  /*-- U+6358 .. U+635F --*/
   "Bang " , "Jian " , "Huan " , "Dao "  , ""      , "Wan "  , "Qin "  , "Peng " ,  /*-- U+6360 .. U+6367 --*/
   "She "  , "Lie "  , "Min "  , "Men "  , "Fu "   , "Bai "  , "Ju "   , "Dao "  ,  /*-- U+6368 .. U+636F --*/
   "Wo "   , "Ai "   , "Juan " , "Yue "  , "Zong " , "Chen " , "Chui " , "Jie "  ,  /*-- U+6370 .. U+6377 --*/
   "Tu "   , "Ben "  , "Na "   , "Nian " , "Nuo "  , "Zu "   , "Wo "   , "Xi "   ,  /*-- U+6378 .. U+637F --*/
   "Xian " , "Cheng ", "Dian " , "Sao "  , "Lun "  , "Qing " , "Gang " , "Duo "  ,  /*-- U+6380 .. U+6387 --*/
   "Shou " , "Diao " , "Pou "  , "Di "   , "Zhang ", "Gun "  , "Ji "   , "Tao "  ,  /*-- U+6388 .. U+638F --*/
   "Qia "  , "Qi "   , "Pai "  , "Shu "  , "Qian " , "Ling " , "Yi "   , "Ya "   ,  /*-- U+6390 .. U+6397 --*/
   "Jue "  , "Zheng ", "Liang ", "Gua "  , "Yi "   , "Huo "  , "Shan " , "Zheng ",  /*-- U+6398 .. U+639F --*/
   "Lue "  , "Cai "  , "Tan "  , "Che "  , "Bing " , "Jie "  , "Ti "   , "Kong " ,  /*-- U+63A0 .. U+63A7 --*/
   "Tui "  , "Yan "  , "Cuo "  , "Zou "  , "Ju "   , "Tian " , "Qian " , "Ken "  ,  /*-- U+63A8 .. U+63AF --*/
   "Bai "  , "Shou " , "Jie "  , "Lu "   , "Guo "  , "Haba " , ""      , "Zhi "  ,  /*-- U+63B0 .. U+63B7 --*/
   "Dan "  , "Mang " , "Xian " , "Sao "  , "Guan " , "Peng " , "Yuan " , "Nuo "  ,  /*-- U+63B8 .. U+63BF --*/
   "Jian " , "Zhen " , "Jiu "  , "Jian " , "Yu "   , "Yan "  , "Kui "  , "Nan "  ,  /*-- U+63C0 .. U+63C7 --*/
   "Hong " , "Rou "  , "Pi "   , "Wei "  , "Sai "  , "Zou "  , "Xuan " , "Miao " ,  /*-- U+63C8 .. U+63CF --*/
   "Ti "   , "Nie "  , "Cha "  , "Shi "  , "Zong " , "Zhen " , "Yi "   , "Shun " ,  /*-- U+63D0 .. U+63D7 --*/
   "Heng " , "Bian " , "Yang " , "Huan " , "Yan "  , "Zuan " , "An "   , "Xu "   ,  /*-- U+63D8 .. U+63DF --*/
   "Ya "   , "Wo "   , "Ke "   , "Chuai ", "Ji "   , "Ti "   , "La "   , "La "   ,  /*-- U+63E0 .. U+63E7 --*/
   "Cheng ", "Kai "  , "Jiu "  , "Jiu "  , "Tu "   , "Jie "  , "Hui "  , "Geng " ,  /*-- U+63E8 .. U+63EF --*/
   "Chong ", "Shuo " , "She "  , "Xie "  , "Yuan " , "Qian " , "Ye "   , "Cha "  ,  /*-- U+63F0 .. U+63F7 --*/
   "Zha "  , "Bei "  , "Yao "  , ""      , ""      , "Lan "  , "Wen "  , "Qin "  ,  /*-- U+63F8 .. U+63FF --*/
   "Chan " , "Ge "   , "Lou "  , "Zong " , "Geng " , "Jiao " , "Gou "  , "Qin "  ,  /*-- U+6400 .. U+6407 --*/
   "Yong " , "Que "  , "Chou " , "Chi "  , "Zhan " , "Sun "  , "Sun "  , "Bo "   ,  /*-- U+6408 .. U+640F --*/
   "Chu "  , "Rong " , "Beng " , "Cuo "  , "Sao "  , "Ke "   , "Yao "  , "Dao "  ,  /*-- U+6410 .. U+6417 --*/
   "Zhi "  , "Nu "   , "Xie "  , "Jian " , "Sou "  , "Qiu "  , "Gao "  , "Xian " ,  /*-- U+6418 .. U+641F --*/
   "Shuo " , "Sang " , "Jin "  , "Mie "  , "E "    , "Chui " , "Nuo "  , "Shan " ,  /*-- U+6420 .. U+6427 --*/
   "Ta "   , "Jie "  , "Tang " , "Pan "  , "Ban "  , "Da "   , "Li "   , "Tao "  ,  /*-- U+6428 .. U+642F --*/
   "Hu "   , "Zhi "  , "Wa "   , "Xia "  , "Qian " , "Wen "  , "Qiang ", "Tian " ,  /*-- U+6430 .. U+6437 --*/
   "Zhen " , "E "    , "Xi "   , "Nuo "  , "Quan " , "Cha "  , "Zha "  , "Ge "   ,  /*-- U+6438 .. U+643F --*/
   "Wu "   , "En "   , "She "  , "Kang " , "She "  , "Shu "  , "Bai "  , "Yao "  ,  /*-- U+6440 .. U+6447 --*/
   "Bin "  , "Sou "  , "Tan "  , "Sa "   , "Chan " , "Suo "  , "Liao " , "Chong ",  /*-- U+6448 .. U+644F --*/
   "Chuang ", "Guo "  , "Bing " , "Feng " , "Shuai ", "Di "   , "Qi "   , "Sou "  ,  /*-- U+6450 .. U+6457 --*/
   "Zhai " , "Lian " , "Tang " , "Chi "  , "Guan " , "Lu "   , "Luo "  , "Lou "  ,  /*-- U+6458 .. U+645F --*/
   "Zong " , "Gai "  , "Hu "   , "Zha "  , "Chuang ", "Tang " , "Hua "  , "Cui "  ,  /*-- U+6460 .. U+6467 --*/
   "Nai "  , "Mo "   , "Jiang ", "Gui "  , "Ying " , "Zhi "  , "Ao "   , "Zhi "  ,  /*-- U+6468 .. U+646F --*/
   "Nie "  , "Man "  , "Shan " , "Kou "  , "Shu "  , "Suo "  , "Tuan " , "Jiao " ,  /*-- U+6470 .. U+6477 --*/
   "Mo "   , "Mo "   , "Zhe "  , "Xian " , "Keng " , "Piao " , "Jiang ", "Yin "  ,  /*-- U+6478 .. U+647F --*/
   "Gou "  , "Qian " , "Lue "  , "Ji "   , "Ying " , "Jue "  , "Pie "  , "Pie "  ,  /*-- U+6480 .. U+6487 --*/
   "Lao "  , "Dun "  , "Xian " , "Ruan " , "Kui "  , "Zan "  , "Yi "   , "Xun "  ,  /*-- U+6488 .. U+648F --*/
   "Cheng ", "Cheng ", "Sa "   , "Nao "  , "Heng " , "Si "   , "Qian " , "Huang ",  /*-- U+6490 .. U+6497 --*/
   "Da "   , "Zun "  , "Nian " , "Lin "  , "Zheng ", "Hui "  , "Zhuang ", "Jiao " ,  /*-- U+6498 .. U+649F --*/
   "Ji "   , "Cao "  , "Dan "  , "Dan "  , "Che "  , "Bo "   , "Che "  , "Jue "  ,  /*-- U+64A0 .. U+64A7 --*/
   "Xiao " , "Liao " , "Ben "  , "Fu "   , "Qiao " , "Bo "   , "Cuo "  , "Zhuo " ,  /*-- U+64A8 .. U+64AF --*/
   "Zhuan ", "Tuo "  , "Pu "   , "Qin "  , "Dun "  , "Nian " , ""      , "Xie "  ,  /*-- U+64B0 .. U+64B7 --*/
   "Lu "   , "Jiao " , "Cuan " , "Ta "   , "Han "  , "Qiao " , "Zhua " , "Jian " ,  /*-- U+64B8 .. U+64BF --*/
   "Gan "  , "Yong " , "Lei "  , "Kuo "  , "Lu "   , "Shan " , "Zhuo " , "Ze "   ,  /*-- U+64C0 .. U+64C7 --*/
   "Pu "   , "Chuo " , "Ji "   , "Dang " , "Suo "  , "Cao "  , "Qing " , "Jing " ,  /*-- U+64C8 .. U+64CF --*/
   "Huan " , "Jie "  , "Qin "  , "Kuai " , "Dan "  , "Xi "   , "Ge "   , "Pi "   ,  /*-- U+64D0 .. U+64D7 --*/
   "Bo "   , "Ao "   , "Ju "   , "Ye "   , ""      , "Mang " , "Sou "  , "Mi "   ,  /*-- U+64D8 .. U+64DF --*/
   "Ji "   , "Tai "  , "Zhuo " , "Dao "  , "Xing " , "Lan "  , "Ca "   , "Ju "   ,  /*-- U+64E0 .. U+64E7 --*/
   "Ye "   , "Ru "   , "Ye "   , "Ye "   , "Ni "   , "Hu "   , "Ji "   , "Bin "  ,  /*-- U+64E8 .. U+64EF --*/
   "Ning " , "Ge "   , "Zhi "  , "Jie "  , "Kuo "  , "Mo "   , "Jian " , "Xie "  ,  /*-- U+64F0 .. U+64F7 --*/
   "Lie "  , "Tan "  , "Bai "  , "Sou "  , "Lu "   , "Lue "  , "Rao "  , "Zhi "  ,  /*-- U+64F8 .. U+64FF --*/
   "Pan "  , "Yang " , "Lei "  , "Sa "   , "Shu "  , "Zan "  , "Nian " , "Xian " ,  /*-- U+6500 .. U+6507 --*/
   "Jun "  , "Huo "  , "Li "   , "La "   , "Han "  , "Ying " , "Lu "   , "Long " ,  /*-- U+6508 .. U+650F --*/
   "Qian " , "Qian " , "Zan "  , "Qian " , "Lan "  , "San "  , "Ying " , "Mei "  ,  /*-- U+6510 .. U+6517 --*/
   "Rang " , "Chan " , ""      , "Cuan " , "Xi "   , "She "  , "Luo "  , "Jun "  ,  /*-- U+6518 .. U+651F --*/
   "Mi "   , "Li "   , "Zan "  , "Luan " , "Tan "  , "Zuan " , "Li "   , "Dian " ,  /*-- U+6520 .. U+6527 --*/
   "Wa "   , "Dang " , "Jiao " , "Jue "  , "Lan "  , "Li "   , "Nang " , "Zhi "  ,  /*-- U+6528 .. U+652F --*/
   "Gui "  , "Gui "  , "Qi "   , "Xin "  , "Pu "   , "Sui "  , "Shou " , "Kao "  ,  /*-- U+6530 .. U+6537 --*/
   "You "  , "Gai "  , "Yi "   , "Gong " , "Gan "  , "Ban "  , "Fang " , "Zheng ",  /*-- U+6538 .. U+653F --*/
   "Bo "   , "Dian " , "Kou "  , "Min "  , "Wu "   , "Gu "   , "He "   , "Ce "   ,  /*-- U+6540 .. U+6547 --*/
   "Xiao " , "Mi "   , "Chu "  , "Ge "   , "Di "   , "Xu "   , "Jiao " , "Min "  ,  /*-- U+6548 .. U+654F --*/
   "Chen " , "Jiu "  , "Zhen " , "Duo "  , "Yu "   , "Chi "  , "Ao "   , "Bai "  ,  /*-- U+6550 .. U+6557 --*/
   "Xu "   , "Jiao " , "Duo "  , "Lian " , "Nie "  , "Bi "   , "Chang ", "Dian " ,  /*-- U+6558 .. U+655F --*/
   "Duo "  , "Yi "   , "Gan "  , "San "  , "Ke "   , "Yan "  , "Dun "  , "Qi "   ,  /*-- U+6560 .. U+6567 --*/
   "Dou "  , "Xiao " , "Duo "  , "Jiao " , "Jing " , "Yang " , "Xia "  , "Min "  ,  /*-- U+6568 .. U+656F --*/
   "Shu "  , "Ai "   , "Qiao " , "Ai "   , "Zheng ", "Di "   , "Zhen " , "Fu "   ,  /*-- U+6570 .. U+6577 --*/
   "Shu "  , "Liao " , "Qu "   , "Xiong ", "Xi "   , "Jiao " , "Sen "  , "Jiao " ,  /*-- U+6578 .. U+657F --*/
   "Zhuo " , "Yi "   , "Lian " , "Bi "   , "Li "   , "Xiao " , "Xiao " , "Wen "  ,  /*-- U+6580 .. U+6587 --*/
   "Xue "  , "Qi "   , "Qi "   , "Zhai " , "Bin "  , "Jue "  , "Zhai " , ""      ,  /*-- U+6588 .. U+658F --*/
   "Fei "  , "Ban "  , "Ban "  , "Lan "  , "Yu "   , "Lan "  , "Wei "  , "Dou "  ,  /*-- U+6590 .. U+6597 --*/
   "Sheng ", "Liao " , "Jia "  , "Hu "   , "Xie "  , "Jia "  , "Yu "   , "Zhen " ,  /*-- U+6598 .. U+659F --*/
   "Jiao " , "Wo "   , "Tou "  , "Chu "  , "Jin "  , "Chi "  , "Yin "  , "Fu "   ,  /*-- U+65A0 .. U+65A7 --*/
   "Qiang ", "Zhan " , "Qu "   , "Zhuo " , "Zhan " , "Duan " , "Zhuo " , "Si "   ,  /*-- U+65A8 .. U+65AF --*/
   "Xin "  , "Zhuo " , "Zhuo " , "Qin "  , "Lin "  , "Zhuo " , "Chu "  , "Duan " ,  /*-- U+65B0 .. U+65B7 --*/
   "Zhu "  , "Fang " , "Xie "  , "Hang " , "Yu "   , "Shi "  , "Pei "  , "You "  ,  /*-- U+65B8 .. U+65BF --*/
   "Mye "  , "Pang " , "Qi "   , "Zhan " , "Mao "  , "Lu "   , "Pei "  , "Pi "   ,  /*-- U+65C0 .. U+65C7 --*/
   "Liu "  , "Fu "   , "Fang " , "Xuan " , "Jing " , "Jing " , "Ni "   , "Zu "   ,  /*-- U+65C8 .. U+65CF --*/
   "Zhao " , "Yi "   , "Liu "  , "Shao " , "Jian " , "Es "   , "Yi "   , "Qi "   ,  /*-- U+65D0 .. U+65D7 --*/
   "Zhi "  , "Fan "  , "Piao " , "Fan "  , "Zhan " , "Guai " , "Sui "  , "Yu "   ,  /*-- U+65D8 .. U+65DF --*/
   "Wu "   , "Ji "   , "Ji "   , "Ji "   , "Huo "  , "Ri "   , "Dan "  , "Jiu "  ,  /*-- U+65E0 .. U+65E7 --*/
   "Zhi "  , "Zao "  , "Xie "  , "Tiao " , "Xun "  , "Xu "   , "Xu "   , "Xu "   ,  /*-- U+65E8 .. U+65EF --*/
   "Gan "  , "Han "  , "Tai "  , "Di "   , "Xu "   , "Chan " , "Shi "  , "Kuang ",  /*-- U+65F0 .. U+65F7 --*/
   "Yang " , "Shi "  , "Wang " , "Min "  , "Min "  , "Tun "  , "Chun " , "Wu "   ,  /*-- U+65F8 .. U+65FF --*/
   "Yun "  , "Bei "  , "Ang "  , "Ze "   , "Ban "  , "Jie "  , "Kun "  , "Sheng ",  /*-- U+6600 .. U+6607 --*/
   "Hu "   , "Fang " , "Hao "  , "Gui "  , "Chang ", "Xuan " , "Ming " , "Hun "  ,  /*-- U+6608 .. U+660F --*/
   "Fen "  , "Qin "  , "Hu "   , "Yi "   , "Xi "   , "Xin "  , "Yan "  , "Ze "   ,  /*-- U+6610 .. U+6617 --*/
   "Fang " , "Tan "  , "Shen " , "Ju "   , "Yang " , "Zan "  , "Bing " , "Xing " ,  /*-- U+6618 .. U+661F --*/
   "Ying " , "Xuan " , "Pei "  , "Zhen " , "Ling " , "Chun " , "Hao "  , "Mei "  ,  /*-- U+6620 .. U+6627 --*/
   "Zuo "  , "Mo "   , "Bian " , "Xu "   , "Hun "  , "Zhao " , "Zong " , "Shi "  ,  /*-- U+6628 .. U+662F --*/
   "Shi "  , "Yu "   , "Fei "  , "Die "  , "Mao "  , "Ni "   , "Chang ", "Wen "  ,  /*-- U+6630 .. U+6637 --*/
   "Dong " , "Ai "   , "Bing " , "Ang "  , "Zhou " , "Long " , "Xian " , "Kuang ",  /*-- U+6638 .. U+663F --*/
   "Tiao " , "Chao " , "Shi "  , "Huang ", "Huang ", "Xuan " , "Kui "  , "Xu "   ,  /*-- U+6640 .. U+6647 --*/
   "Jiao " , "Jin "  , "Zhi "  , "Jin "  , "Shang ", "Tong " , "Hong " , "Yan "  ,  /*-- U+6648 .. U+664F --*/
   "Gai "  , "Xiang ", "Shai " , "Xiao " , "Ye "   , "Yun "  , "Hui "  , "Han "  ,  /*-- U+6650 .. U+6657 --*/
   "Han "  , "Jun "  , "Wan "  , "Xian " , "Kun "  , "Zhou " , "Xi "   , "Cheng ",  /*-- U+6658 .. U+665F --*/
   "Sheng ", "Bu "   , "Zhe "  , "Zhe "  , "Wu "   , "Han "  , "Hui "  , "Hao "  ,  /*-- U+6660 .. U+6667 --*/
   "Chen " , "Wan "  , "Tian " , "Zhuo " , "Zui "  , "Zhou " , "Pu "   , "Jing " ,  /*-- U+6668 .. U+666F --*/
   "Xi "   , "Shan " , "Yi "   , "Xi "   , "Qing " , "Qi "   , "Jing " , "Gui "  ,  /*-- U+6670 .. U+6677 --*/
   "Zhen " , "Yi "   , "Zhi "  , "An "   , "Wan "  , "Lin "  , "Liang ", "Chang ",  /*-- U+6678 .. U+667F --*/
   "Wang " , "Xiao " , "Zan "  , "Hi "   , "Xuan " , "Xuan " , "Yi "   , "Xia "  ,  /*-- U+6680 .. U+6687 --*/
   "Yun "  , "Hui "  , "Fu "   , "Min "  , "Kui "  , "He "   , "Ying " , "Du "   ,  /*-- U+6688 .. U+668F --*/
   "Wei "  , "Shu "  , "Qing " , "Mao "  , "Nan "  , "Jian " , "Nuan " , "An "   ,  /*-- U+6690 .. U+6697 --*/
   "Yang " , "Chun " , "Yao "  , "Suo "  , "Jin "  , "Ming " , "Jiao " , "Kai "  ,  /*-- U+6698 .. U+669F --*/
   "Gao "  , "Weng " , "Chang ", "Qi "   , "Hao "  , "Yan "  , "Li "   , "Ai "   ,  /*-- U+66A0 .. U+66A7 --*/
   "Ji "   , "Gui "  , "Men "  , "Zan "  , "Xie "  , "Hao "  , "Mu "   , "Mo "   ,  /*-- U+66A8 .. U+66AF --*/
   "Cong " , "Ni "   , "Zhang ", "Hui "  , "Bao "  , "Han "  , "Xuan " , "Chuan ",  /*-- U+66B0 .. U+66B7 --*/
   "Liao " , "Xian " , "Dan "  , "Jing " , "Pie "  , "Lin "  , "Tun "  , "Xi "   ,  /*-- U+66B8 .. U+66BF --*/
   "Yi "   , "Ji "   , "Huang ", "Tai "  , "Ye "   , "Ye "   , "Li "   , "Tan "  ,  /*-- U+66C0 .. U+66C7 --*/
   "Tong " , "Xiao " , "Fei "  , "Qin "  , "Zhao " , "Hao "  , "Yi "   , "Xiang ",  /*-- U+66C8 .. U+66CF --*/
   "Xing " , "Sen "  , "Jiao " , "Bao "  , "Jing " , "Yian " , "Ai "   , "Ye "   ,  /*-- U+66D0 .. U+66D7 --*/
   "Ru "   , "Shu "  , "Meng " , "Xun "  , "Yao "  , "Pu "   , "Li "   , "Chen " ,  /*-- U+66D8 .. U+66DF --*/
   "Kuang ", "Die "  , ""      , "Yan "  , "Huo "  , "Lu "   , "Xi "   , "Rong " ,  /*-- U+66E0 .. U+66E7 --*/
   "Long " , "Nang " , "Luo "  , "Luan " , "Shai " , "Tang " , "Yan "  , "Chu "  ,  /*-- U+66E8 .. U+66EF --*/
   "Yue "  , "Yue "  , "Qu "   , "Yi "   , "Geng " , "Ye "   , "Hu "   , "He "   ,  /*-- U+66F0 .. U+66F7 --*/
   "Shu "  , "Cao "  , "Cao "  , "Noboru ", "Man "  , "Ceng " , "Ceng " , "Ti "   ,  /*-- U+66F8 .. U+66FF --*/
   "Zui "  , "Can "  , "Xu "   , "Hui "  , "Yin "  , "Qie "  , "Fen "  , "Pi "   ,  /*-- U+6700 .. U+6707 --*/
   "Yue "  , "You "  , "Ruan " , "Peng " , "Ban "  , "Fu "   , "Ling " , "Fei "  ,  /*-- U+6708 .. U+670F --*/
   "Qu "   , ""      , "Nu "   , "Tiao " , "Shuo " , "Zhen " , "Lang " , "Lang " ,  /*-- U+6710 .. U+6717 --*/
   "Juan " , "Ming " , "Huang ", "Wang " , "Tun "  , "Zhao " , "Ji "   , "Qi "   ,  /*-- U+6718 .. U+671F --*/
   "Ying " , "Zong " , "Wang " , "Tong " , "Lang " , ""      , "Meng " , "Long " ,  /*-- U+6720 .. U+6727 --*/
   "Mu "   , "Deng " , "Wei "  , "Mo "   , "Ben "  , "Zha "  , "Zhu "  , "Zhu "  ,  /*-- U+6728 .. U+672F --*/
   ""      , "Zhu "  , "Ren "  , "Ba "   , "Po "   , "Duo "  , "Duo "  , "Dao "  ,  /*-- U+6730 .. U+6737 --*/
   "Li "   , "Qiu "  , "Ji "   , "Jiu "  , "Bi "   , "Xiu "  , "Ting " , "Ci "   ,  /*-- U+6738 .. U+673F --*/
   "Sha "  , "Eburi ", "Za "   , "Quan " , "Qian " , "Yu "   , "Gan "  , "Wu "   ,  /*-- U+6740 .. U+6747 --*/
   "Cha "  , "Shan " , "Xun "  , "Fan "  , "Wu "   , "Zi "   , "Li "   , "Xing " ,  /*-- U+6748 .. U+674F --*/
   "Cai "  , "Cun "  , "Ren "  , "Shao " , "Tuo "  , "Di "   , "Zhang ", "Mang " ,  /*-- U+6750 .. U+6757 --*/
   "Chi "  , "Yi "   , "Gu "   , "Gong " , "Du "   , "Yi "   , "Qi "   , "Shu "  ,  /*-- U+6758 .. U+675F --*/
   "Gang " , "Tiao " , "Moku " , "Soma " , "Tochi ", "Lai "  , "Sugi " , "Mang " ,  /*-- U+6760 .. U+6767 --*/
   "Yang " , "Ma "   , "Miao " , "Si "   , "Yuan " , "Hang " , "Fei "  , "Bei "  ,  /*-- U+6768 .. U+676F --*/
   "Jie "  , "Dong " , "Gao "  , "Yao "  , "Xian " , "Chu "  , "Qun "  , "Pa "   ,  /*-- U+6770 .. U+6777 --*/
   "Shu "  , "Hua "  , "Xin "  , "Chou " , "Zhu "  , "Chou " , "Song " , "Ban "  ,  /*-- U+6778 .. U+677F --*/
   "Song " , "Ji "   , "Yue "  , "Jin "  , "Gou "  , "Ji "   , "Mao "  , "Pi "   ,  /*-- U+6780 .. U+6787 --*/
   "Bi "   , "Wang " , "Ang "  , "Fang " , "Fen "  , "Yi "   , "Fu "   , "Nan "  ,  /*-- U+6788 .. U+678F --*/
   "Xi "   , "Hu "   , "Ya "   , "Dou "  , "Xun "  , "Zhen " , "Yao "  , "Lin "  ,  /*-- U+6790 .. U+6797 --*/
   "Rui "  , "E "    , "Mei "  , "Zhao " , "Guo "  , "Zhi "  , "Cong " , "Yun "  ,  /*-- U+6798 .. U+679F --*/
   "Waku " , "Dou "  , "Shu "  , "Zao "  , ""      , "Li "   , "Haze " , "Jian " ,  /*-- U+67A0 .. U+67A7 --*/
   "Cheng ", "Matsu ", "Qiang ", "Feng " , "Nan "  , "Xiao " , "Xian " , "Ku "   ,  /*-- U+67A8 .. U+67AF --*/
   "Ping " , "Yi "   , "Xi "   , "Zhi "  , "Guai " , "Xiao " , "Jia "  , "Jia "  ,  /*-- U+67B0 .. U+67B7 --*/
   "Gou "  , "Fu "   , "Mo "   , "Yi "   , "Ye "   , "Ye "   , "Shi "  , "Nie "  ,  /*-- U+67B8 .. U+67BF --*/
   "Bi "   , "Duo "  , "Yi "   , "Ling " , "Bing " , "Ni "   , "La "   , "He "   ,  /*-- U+67C0 .. U+67C7 --*/
   "Pan "  , "Fan "  , "Zhong ", "Dai "  , "Ci "   , "Yang " , "Fu "   , "Bo "   ,  /*-- U+67C8 .. U+67CF --*/
   "Mou "  , "Gan "  , "Qi "   , "Ran "  , "Rou "  , "Mao "  , "Zhao " , "Song " ,  /*-- U+67D0 .. U+67D7 --*/
   "Zhe "  , "Xia "  , "You "  , "Shen " , "Ju "   , "Tuo "  , "Zuo "  , "Nan "  ,  /*-- U+67D8 .. U+67DF --*/
   "Ning " , "Yong " , "Di "   , "Zhi "  , "Zha "  , "Cha "  , "Dan "  , "Gu "   ,  /*-- U+67E0 .. U+67E7 --*/
   "Pu "   , "Jiu "  , "Ao "   , "Fu "   , "Jian " , "Bo "   , "Duo "  , "Ke "   ,  /*-- U+67E8 .. U+67EF --*/
   "Nai "  , "Zhu "  , "Bi "   , "Liu "  , "Chai " , "Zha "  , "Si "   , "Zhu "  ,  /*-- U+67F0 .. U+67F7 --*/
   "Pei "  , "Shi "  , "Guai " , "Cha "  , "Yao "  , "Jue "  , "Jiu "  , "Shi "  ,  /*-- U+67F8 .. U+67FF --*/
   "Zhi "  , "Liu "  , "Mei "  , "Hoy "  , "Rong " , "Zha "  , ""      , "Biao " ,  /*-- U+6800 .. U+6807 --*/
   "Zhan " , "Jie "  , "Long " , "Dong " , "Lu "   , "Sayng ", "Li "   , "Lan "  ,  /*-- U+6808 .. U+680F --*/
   "Yong " , "Shu "  , "Xun "  , "Shuan ", "Qi "   , "Zhen " , "Qi "   , "Li "   ,  /*-- U+6810 .. U+6817 --*/
   "Yi "   , "Xiang ", "Zhen " , "Li "   , "Su "   , "Gua "  , "Kan "  , "Bing " ,  /*-- U+6818 .. U+681F --*/
   "Ren "  , "Xiao " , "Bo "   , "Ren "  , "Bing " , "Zi "   , "Chou " , "Yi "   ,  /*-- U+6820 .. U+6827 --*/
   "Jie "  , "Xu "   , "Zhu "  , "Jian " , "Zui "  , "Er "   , "Er "   , "You "  ,  /*-- U+6828 .. U+682F --*/
   "Fa "   , "Gong " , "Kao "  , "Lao "  , "Zhan " , "Li "   , "Yin "  , "Yang " ,  /*-- U+6830 .. U+6837 --*/
   "He "   , "Gen "  , "Zhi "  , "Chi "  , "Ge "   , "Zai "  , "Luan " , "Fu "   ,  /*-- U+6838 .. U+683F --*/
   "Jie "  , "Hang " , "Gui "  , "Tao "  , "Guang ", "Wei "  , "Kuang ", "Ru "   ,  /*-- U+6840 .. U+6847 --*/
   "An "   , "An "   , "Juan " , "Yi "   , "Zhuo " , "Ku "   , "Zhi "  , "Qiong ",  /*-- U+6848 .. U+684F --*/
   "Tong " , "Sang " , "Sang " , "Huan " , "Jie "  , "Jiu "  , "Xue "  , "Duo "  ,  /*-- U+6850 .. U+6857 --*/
   "Zhui " , "Yu "   , "Zan "  , "Kasei ", "Ying " , "Masu " , ""      , "Zhan " ,  /*-- U+6858 .. U+685F --*/
   "Ya "   , "Nao "  , "Zhen " , "Dang " , "Qi "   , "Qiao " , "Hua "  , "Kuai " ,  /*-- U+6860 .. U+6867 --*/
   "Jiang ", "Zhuang ", "Xun "  , "Suo "  , "Sha "  , "Zhen " , "Bei "  , "Ting " ,  /*-- U+6868 .. U+686F --*/
   "Gua "  , "Jing " , "Bo "   , "Ben "  , "Fu "   , "Rui "  , "Tong " , "Jue "  ,  /*-- U+6870 .. U+6877 --*/
   "Xi "   , "Lang " , "Liu "  , "Feng " , "Qi "   , "Wen "  , "Jun "  , "Gan "  ,  /*-- U+6878 .. U+687F --*/
   "Cu "   , "Liang ", "Qiu "  , "Ting " , "You "  , "Mei "  , "Bang " , "Long " ,  /*-- U+6880 .. U+6887 --*/
   "Peng " , "Zhuang ", "Di "   , "Xuan " , "Tu "   , "Zao "  , "Ao "   , "Gu "   ,  /*-- U+6888 .. U+688F --*/
   "Bi "   , "Di "   , "Han "  , "Zi "   , "Zhi "  , "Ren "  , "Bei "  , "Geng " ,  /*-- U+6890 .. U+6897 --*/
   "Jian " , "Huan " , "Wan "  , "Nuo "  , "Jia "  , "Tiao " , "Ji "   , "Xiao " ,  /*-- U+6898 .. U+689F --*/
   "Lu "   , "Huan " , "Shao " , "Cen "  , "Fen "  , "Song " , "Meng " , "Wu "   ,  /*-- U+68A0 .. U+68A7 --*/
   "Li "   , "Li "   , "Dou "  , "Cen "  , "Ying " , "Suo "  , "Ju "   , "Ti "   ,  /*-- U+68A8 .. U+68AF --*/
   "Jie "  , "Kun "  , "Zhuo " , "Shu "  , "Chan " , "Fan "  , "Wei "  , "Jing " ,  /*-- U+68B0 .. U+68B7 --*/
   "Li "   , "Bing " , "Fumoto ", "Shikimi ", "Tao "  , "Zhi "  , "Lai "  , "Lian " ,  /*-- U+68B8 .. U+68BF --*/
   "Jian " , "Zhuo " , "Ling " , "Li "   , "Qi "   , "Bing " , "Zhun " , "Cong " ,  /*-- U+68C0 .. U+68C7 --*/
   "Qian " , "Mian " , "Qi "   , "Qi "   , "Cai "  , "Gun "  , "Chan " , "Te "   ,  /*-- U+68C8 .. U+68CF --*/
   "Fei "  , "Pai "  , "Bang " , "Pou "  , "Hun "  , "Zong " , "Cheng ", "Zao "  ,  /*-- U+68D0 .. U+68D7 --*/
   "Ji "   , "Li "   , "Peng " , "Yu "   , "Yu "   , "Gu "   , "Hun "  , "Dong " ,  /*-- U+68D8 .. U+68DF --*/
   "Tang " , "Gang " , "Wang " , "Di "   , "Xi "   , "Fan "  , "Cheng ", "Zhan " ,  /*-- U+68E0 .. U+68E7 --*/
   "Qi "   , "Yuan " , "Yan "  , "Yu "   , "Quan " , "Yi "   , "Sen "  , "Ren "  ,  /*-- U+68E8 .. U+68EF --*/
   "Chui " , "Leng " , "Qi "   , "Zhuo " , "Fu "   , "Ke "   , "Lai "  , "Zou "  ,  /*-- U+68F0 .. U+68F7 --*/
   "Zou "  , "Zhuo " , "Guan " , "Fen "  , "Fen "  , "Chen " , "Qiong ", "Nie "  ,  /*-- U+68F8 .. U+68FF --*/
   "Wan "  , "Guo "  , "Lu "   , "Hao "  , "Jie "  , "Yi "   , "Chou " , "Ju "   ,  /*-- U+6900 .. U+6907 --*/
   "Ju "   , "Cheng ", "Zuo "  , "Liang ", "Qiang ", "Zhi "  , "Zhui " , "Ya "   ,  /*-- U+6908 .. U+690F --*/
   "Ju "   , "Bei "  , "Jiao " , "Zhuo " , "Zi "   , "Bin "  , "Peng " , "Ding " ,  /*-- U+6910 .. U+6917 --*/
   "Chu "  , "Chang ", "Kunugi ", "Momiji ", "Jian " , "Gui "  , "Xi "   , "Du "   ,  /*-- U+6918 .. U+691F --*/
   "Qian " , "Kunugi ", "Soko " , "Shide ", "Luo "  , "Zhi "  , "Ken "  , "Myeng ",  /*-- U+6920 .. U+6927 --*/
   "Tafu " , ""      , "Peng " , "Zhan " , ""      , "Tuo "  , "Sen "  , "Duo "  ,  /*-- U+6928 .. U+692F --*/
   "Ye "   , "Fou "  , "Wei "  , "Wei "  , "Duan " , "Jia "  , "Zong " , "Jian " ,  /*-- U+6930 .. U+6937 --*/
   "Yi "   , "Shen " , "Xi "   , "Yan "  , "Yan "  , "Chuan ", "Zhan " , "Chun " ,  /*-- U+6938 .. U+693F --*/
   "Yu "   , "He "   , "Zha "  , "Wo "   , "Pian " , "Bi "   , "Yao "  , "Huo "  ,  /*-- U+6940 .. U+6947 --*/
   "Xu "   , "Ruo "  , "Yang " , "La "   , "Yan "  , "Ben "  , "Hun "  , "Kui "  ,  /*-- U+6948 .. U+694F --*/
   "Jie "  , "Kui "  , "Si "   , "Feng " , "Xie "  , "Tuo "  , "Zhi "  , "Jian " ,  /*-- U+6950 .. U+6957 --*/
   "Mu "   , "Mao "  , "Chu "  , "Hu "   , "Hu "   , "Lian " , "Leng " , "Ting " ,  /*-- U+6958 .. U+695F --*/
   "Nan "  , "Yu "   , "You "  , "Mei "  , "Song " , "Xuan " , "Xuan " , "Ying " ,  /*-- U+6960 .. U+6967 --*/
   "Zhen " , "Pian " , "Ye "   , "Ji "   , "Jie "  , "Ye "   , "Chu "  , "Shun " ,  /*-- U+6968 .. U+696F --*/
   "Yu "   , "Cou "  , "Wei "  , "Mei "  , "Di "   , "Ji "   , "Jie "  , "Kai "  ,  /*-- U+6970 .. U+6977 --*/
   "Qiu "  , "Ying " , "Rou "  , "Heng " , "Lou "  , "Le "   , "Hazou ", "Katsura ",  /*-- U+6978 .. U+697F --*/
   "Pin "  , "Muro " , "Gai "  , "Tan "  , "Lan "  , "Yun "  , "Yu "   , "Chen " ,  /*-- U+6980 .. U+6987 --*/
   "Lu "   , "Ju "   , "Sakaki ", ""      , "Pi "   , "Xie "  , "Jia "  , "Yi "   ,  /*-- U+6988 .. U+698F --*/
   "Zhan " , "Fu "   , "Nai "  , "Mi "   , "Lang " , "Rong " , "Gu "   , "Jian " ,  /*-- U+6990 .. U+6997 --*/
   "Ju "   , "Ta "   , "Yao "  , "Zhen " , "Bang " , "Sha "  , "Yuan " , "Zi "   ,  /*-- U+6998 .. U+699F --*/
   "Ming " , "Su "   , "Jia "  , "Yao "  , "Jie "  , "Huang ", "Gan "  , "Fei "  ,  /*-- U+69A0 .. U+69A7 --*/
   "Zha "  , "Qian " , "Ma "   , "Sun "  , "Yuan " , "Xie "  , "Rong " , "Shi "  ,  /*-- U+69A8 .. U+69AF --*/
   "Zhi "  , "Cui "  , "Yun "  , "Ting " , "Liu "  , "Rong " , "Tang " , "Que "  ,  /*-- U+69B0 .. U+69B7 --*/
   "Zhai " , "Si "   , "Sheng ", "Ta "   , "Ke "   , "Xi "   , "Gu "   , "Qi "   ,  /*-- U+69B8 .. U+69BF --*/
   "Kao "  , "Gao "  , "Sun "  , "Pan "  , "Tao "  , "Ge "   , "Xun "  , "Dian " ,  /*-- U+69C0 .. U+69C7 --*/
   "Nou "  , "Ji "   , "Shuo " , "Gou "  , "Chui " , "Qiang ", "Cha "  , "Qian " ,  /*-- U+69C8 .. U+69CF --*/
   "Huai " , "Mei "  , "Xu "   , "Gang " , "Gao "  , "Zhuo " , "Tuo "  , "Hashi ",  /*-- U+69D0 .. U+69D7 --*/
   "Yang " , "Dian " , "Jia "  , "Jian " , "Zui "  , "Kashi ", "Ori "  , "Bin "  ,  /*-- U+69D8 .. U+69DF --*/
   "Zhu "  , ""      , "Xi "   , "Qi "   , "Lian " , "Hui "  , "Yong " , "Qian " ,  /*-- U+69E0 .. U+69E7 --*/
   "Guo "  , "Gai "  , "Gai "  , "Tuan " , "Hua "  , "Cu "   , "Sen "  , "Cui "  ,  /*-- U+69E8 .. U+69EF --*/
   "Beng " , "You "  , "Hu "   , "Jiang ", "Hu "   , "Huan " , "Kui "  , "Yi "   ,  /*-- U+69F0 .. U+69F7 --*/
   "Nie "  , "Gao "  , "Kang " , "Gui "  , "Gui "  , "Cao "  , "Man "  , "Jin "  ,  /*-- U+69F8 .. U+69FF --*/
   "Di "   , "Zhuang ", "Le "   , "Lang " , "Chen " , "Cong " , "Li "   , "Xiu "  ,  /*-- U+6A00 .. U+6A07 --*/
   "Qing " , "Shuang ", "Fan "  , "Tong " , "Guan " , "Ji "   , "Suo "  , "Lei "  ,  /*-- U+6A08 .. U+6A0F --*/
   "Lu "   , "Liang ", "Mi "   , "Lou "  , "Chao " , "Su "   , "Ke "   , "Shu "  ,  /*-- U+6A10 .. U+6A17 --*/
   "Tang " , "Biao " , "Lu "   , "Jiu "  , "Shu "  , "Zha "  , "Shu "  , "Zhang ",  /*-- U+6A18 .. U+6A1F --*/
   "Men "  , "Mo "   , "Niao " , "Yang " , "Tiao " , "Peng " , "Zhu "  , "Sha "  ,  /*-- U+6A20 .. U+6A27 --*/
   "Xi "   , "Quan " , "Heng " , "Jian " , "Cong " , ""      , "Hokuso ", "Qiang ",  /*-- U+6A28 .. U+6A2F --*/
   "Tara " , "Ying " , "Er "   , "Xin "  , "Zhi "  , "Qiao " , "Zui "  , "Cong " ,  /*-- U+6A30 .. U+6A37 --*/
   "Pu "   , "Shu "  , "Hua "  , "Kui "  , "Zhen " , "Zun "  , "Yue "  , "Zhan " ,  /*-- U+6A38 .. U+6A3F --*/
   "Xi "   , "Xun "  , "Dian " , "Fa "   , "Gan "  , "Mo "   , "Wu "   , "Qiao " ,  /*-- U+6A40 .. U+6A47 --*/
   "Nao "  , "Lin "  , "Liu "  , "Qiao " , "Xian " , "Run "  , "Fan "  , "Zhan " ,  /*-- U+6A48 .. U+6A4F --*/
   "Tuo "  , "Lao "  , "Yun "  , "Shun " , "Tui "  , "Cheng ", "Tang " , "Meng " ,  /*-- U+6A50 .. U+6A57 --*/
   "Ju "   , "Cheng ", "Su "   , "Jue "  , "Jue "  , "Tan "  , "Hui "  , "Ji "   ,  /*-- U+6A58 .. U+6A5F --*/
   "Nuo "  , "Xiang ", "Tuo "  , "Ning " , "Rui "  , "Zhu "  , "Chuang ", "Zeng " ,  /*-- U+6A60 .. U+6A67 --*/
   "Fen "  , "Qiong ", "Ran "  , "Heng " , "Cen "  , "Gu "   , "Liu "  , "Lao "  ,  /*-- U+6A68 .. U+6A6F --*/
   "Gao "  , "Chu "  , "Zusa " , "Nude " , "Ca "   , "San "  , "Ji "   , "Dou "  ,  /*-- U+6A70 .. U+6A77 --*/
   "Shou " , "Lu "   , ""      , ""      , "Yuan " , "Ta "   , "Shu "  , "Jiang ",  /*-- U+6A78 .. U+6A7F --*/
   "Tan "  , "Lin "  , "Nong " , "Yin "  , "Xi "   , "Sui "  , "Shan " , "Zui "  ,  /*-- U+6A80 .. U+6A87 --*/
   "Xuan " , "Cheng ", "Gan "  , "Ju "   , "Zui "  , "Yi "   , "Qin "  , "Pu "   ,  /*-- U+6A88 .. U+6A8F --*/
   "Yan "  , "Lei "  , "Feng " , "Hui "  , "Dang " , "Ji "   , "Sui "  , "Bo "   ,  /*-- U+6A90 .. U+6A97 --*/
   "Bi "   , "Ding " , "Chu "  , "Zhua " , "Kuai " , "Ji "   , "Jie "  , "Jia "  ,  /*-- U+6A98 .. U+6A9F --*/
   "Qing " , "Zhe "  , "Jian " , "Qiang ", "Dao "  , "Yi "   , "Biao " , "Song " ,  /*-- U+6AA0 .. U+6AA7 --*/
   "She "  , "Lin "  , "Kunugi ", "Cha "  , "Meng " , "Yin "  , "Tao "  , "Tai "  ,  /*-- U+6AA8 .. U+6AAF --*/
   "Mian " , "Qi "   , "Toan " , "Bin "  , "Huo "  , "Ji "   , "Qian " , "Mi "   ,  /*-- U+6AB0 .. U+6AB7 --*/
   "Ning " , "Yi "   , "Gao "  , "Jian " , "Yin "  , "Er "   , "Qing " , "Yan "  ,  /*-- U+6AB8 .. U+6ABF --*/
   "Qi "   , "Mi "   , "Zhao " , "Gui "  , "Chun " , "Ji "   , "Kui "  , "Po "   ,  /*-- U+6AC0 .. U+6AC7 --*/
   "Deng " , "Chu "  , ""      , "Mian " , "You "  , "Zhi "  , "Guang ", "Qian " ,  /*-- U+6AC8 .. U+6ACF --*/
   "Lei "  , "Lei "  , "Sa "   , "Lu "   , "Li "   , "Cuan " , "Lu "   , "Mie "  ,  /*-- U+6AD0 .. U+6AD7 --*/
   "Hui "  , "Ou "   , "Lu "   , "Jie "  , "Gao "  , "Du "   , "Yuan " , "Li "   ,  /*-- U+6AD8 .. U+6ADF --*/
   "Fei "  , "Zhuo " , "Sou "  , "Lian " , "Tamo " , "Chu "  , ""      , "Zhu "  ,  /*-- U+6AE0 .. U+6AE7 --*/
   "Lu "   , "Yan "  , "Li "   , "Zhu "  , "Chen " , "Jie "  , "E "    , "Su "   ,  /*-- U+6AE8 .. U+6AEF --*/
   "Huai " , "Nie "  , "Yu "   , "Long " , "Lai "  , ""      , "Xian " , "Kwi "  ,  /*-- U+6AF0 .. U+6AF7 --*/
   "Ju "   , "Xiao " , "Ling " , "Ying " , "Jian " , "Yin "  , "You "  , "Ying " ,  /*-- U+6AF8 .. U+6AFF --*/
   "Xiang ", "Nong " , "Bo "   , "Chan " , "Lan "  , "Ju "   , "Shuang ", "She "  ,  /*-- U+6B00 .. U+6B07 --*/
   "Wei "  , "Cong " , "Quan " , "Qu "   , "Cang " , ""      , "Yu "   , "Luo "  ,  /*-- U+6B08 .. U+6B0F --*/
   "Li "   , "Zan "  , "Luan " , "Dang " , "Jue "  , "Em "   , "Lan "  , "Lan "  ,  /*-- U+6B10 .. U+6B17 --*/
   "Zhu "  , "Lei "  , "Li "   , "Ba "   , "Nang " , "Yu "   , "Ling " , "Tsuki ",  /*-- U+6B18 .. U+6B1F --*/
   "Qian " , "Ci "   , "Huan " , "Xin "  , "Yu "   , "Yu "   , "Qian " , "Ou "   ,  /*-- U+6B20 .. U+6B27 --*/
   "Xu "   , "Chao " , "Chu "  , "Chi "  , "Kai "  , "Yi "   , "Jue "  , "Xi "   ,  /*-- U+6B28 .. U+6B2F --*/
   "Xu "   , "Xia "  , "Yu "   , "Kuai " , "Lang " , "Kuan " , "Shuo " , "Xi "   ,  /*-- U+6B30 .. U+6B37 --*/
   "Ai "   , "Yi "   , "Qi "   , "Hu "   , "Chi "  , "Qin "  , "Kuan " , "Kan "  ,  /*-- U+6B38 .. U+6B3F --*/
   "Kuan " , "Kan "  , "Chuan ", "Sha "  , "Gua "  , "Yin "  , "Xin "  , "Xie "  ,  /*-- U+6B40 .. U+6B47 --*/
   "Yu "   , "Qian " , "Xiao " , "Yi "   , "Ge "   , "Wu "   , "Tan "  , "Jin "  ,  /*-- U+6B48 .. U+6B4F --*/
   "Ou "   , "Hu "   , "Ti "   , "Huan " , "Xu "   , "Pen "  , "Xi "   , "Xiao " ,  /*-- U+6B50 .. U+6B57 --*/
   "Xu "   , "Xi "   , "Sen "  , "Lian " , "Chu "  , "Yi "   , "Kan "  , "Yu "   ,  /*-- U+6B58 .. U+6B5F --*/
   "Chuo " , "Huan " , "Zhi "  , "Zheng ", "Ci "   , "Bu "   , "Wu "   , "Qi "   ,  /*-- U+6B60 .. U+6B67 --*/
   "Bu "   , "Bu "   , "Wai "  , "Ju "   , "Qian " , "Chi "  , "Se "   , "Chi "  ,  /*-- U+6B68 .. U+6B6F --*/
   "Se "   , "Zhong ", "Sui "  , "Sui "  , "Li "   , "Cuo "  , "Yu "   , "Li "   ,  /*-- U+6B70 .. U+6B77 --*/
   "Gui "  , "Dai "  , "Dai "  , "Si "   , "Jian " , "Zhe "  , "Mo "   , "Mo "   ,  /*-- U+6B78 .. U+6B7F --*/
   "Yao "  , "Mo "   , "Cu "   , "Yang " , "Tian " , "Sheng ", "Dai "  , "Shang ",  /*-- U+6B80 .. U+6B87 --*/
   "Xu "   , "Xun "  , "Shu "  , "Can "  , "Jue "  , "Piao " , "Qia "  , "Qiu "  ,  /*-- U+6B88 .. U+6B8F --*/
   "Su "   , "Qing " , "Yun "  , "Lian " , "Yi "   , "Fou "  , "Zhi "  , "Ye "   ,  /*-- U+6B90 .. U+6B97 --*/
   "Can "  , "Hun "  , "Dan "  , "Ji "   , "Ye "   , "Zhen " , "Yun "  , "Wen "  ,  /*-- U+6B98 .. U+6B9F --*/
   "Chou " , "Bin "  , "Ti "   , "Jin "  , "Shang ", "Yin "  , "Diao " , "Cu "   ,  /*-- U+6BA0 .. U+6BA7 --*/
   "Hui "  , "Cuan " , "Yi "   , "Dan "  , "Du "   , "Jiang ", "Lian " , "Bin "  ,  /*-- U+6BA8 .. U+6BAF --*/
   "Du "   , "Tsukusu ", "Jian " , "Shu "  , "Ou "   , "Duan " , "Zhu "  , "Yin "  ,  /*-- U+6BB0 .. U+6BB7 --*/
   "Qing " , "Yi "   , "Sha "  , "Que "  , "Ke "   , "Yao "  , "Jun "  , "Dian " ,  /*-- U+6BB8 .. U+6BBF --*/
   "Hui "  , "Hui "  , "Gu "   , "Que "  , "Ji "   , "Yi "   , "Ou "   , "Hui "  ,  /*-- U+6BC0 .. U+6BC7 --*/
   "Duan " , "Yi "   , "Xiao " , "Wu "   , "Guan " , "Mu "   , "Mei "  , "Mei "  ,  /*-- U+6BC8 .. U+6BCF --*/
   "Ai "   , "Zuo "  , "Du "   , "Yu "   , "Bi "   , "Bi "   , "Bi "   , "Pi "   ,  /*-- U+6BD0 .. U+6BD7 --*/
   "Pi "   , "Bi "   , "Chan " , "Mao "  , ""      , ""      , "Pu "   , "Mushiru ",  /*-- U+6BD8 .. U+6BDF --*/
   "Jia "  , "Zhan " , "Sai "  , "Mu "   , "Tuo "  , "Xun "  , "Er "   , "Rong " ,  /*-- U+6BE0 .. U+6BE7 --*/
   "Xian " , "Ju "   , "Mu "   , "Hao "  , "Qiu "  , "Dou "  , "Mushiru ", "Tan "  ,  /*-- U+6BE8 .. U+6BEF --*/
   "Pei "  , "Ju "   , "Duo "  , "Cui "  , "Bi "   , "San "  , ""      , "Mao "  ,  /*-- U+6BF0 .. U+6BF7 --*/
   "Sui "  , "Yu "   , "Yu "   , "Tuo "  , "He "   , "Jian " , "Ta "   , "San "  ,  /*-- U+6BF8 .. U+6BFF --*/
   "Lu "   , "Mu "   , "Li "   , "Tong " , "Rong " , "Chang ", "Pu "   , "Luo "  ,  /*-- U+6C00 .. U+6C07 --*/
   "Zhan " , "Sao "  , "Zhan " , "Meng " , "Luo "  , "Qu "   , "Die "  , "Shi "  ,  /*-- U+6C08 .. U+6C0F --*/
   "Di "   , "Min "  , "Jue "  , "Mang " , "Qi "   , "Pie "  , "Nai "  , "Qi "   ,  /*-- U+6C10 .. U+6C17 --*/
   "Dao "  , "Xian " , "Chuan ", "Fen "  , "Ri "   , "Nei "  , ""      , "Fu "   ,  /*-- U+6C18 .. U+6C1F --*/
   "Shen " , "Dong " , "Qing " , "Qi "   , "Yin "  , "Xi "   , "Hai "  , "Yang " ,  /*-- U+6C20 .. U+6C27 --*/
   "An "   , "Ya "   , "Ke "   , "Qing " , "Ya "   , "Dong " , "Dan "  , "Lu "   ,  /*-- U+6C28 .. U+6C2F --*/
   "Qing " , "Yang " , "Yun "  , "Yun "  , "Shui " , "San "  , "Zheng ", "Bing " ,  /*-- U+6C30 .. U+6C37 --*/
   "Yong " , "Dang " , "Shitamizu ", "Le "   , "Ni "   , "Tun "  , "Fan "  , "Gui "  ,  /*-- U+6C38 .. U+6C3F --*/
   "Ting " , "Zhi "  , "Qiu "  , "Bin "  , "Ze "   , "Mian " , "Cuan " , "Hui "  ,  /*-- U+6C40 .. U+6C47 --*/
   "Diao " , "Yi "   , "Cha "  , "Zhuo " , "Chuan ", "Wan "  , "Fan "  , "Dai "  ,  /*-- U+6C48 .. U+6C4F --*/
   "Xi "   , "Tuo "  , "Mang " , "Qiu "  , "Qi "   , "Shan " , "Pai "  , "Han "  ,  /*-- U+6C50 .. U+6C57 --*/
   "Qian " , "Wu "   , "Wu "   , "Xun "  , "Si "   , "Ru "   , "Gong " , "Jiang ",  /*-- U+6C58 .. U+6C5F --*/
   "Chi "  , "Wu "   , "Tsuchi ", ""      , "Tang " , "Zhi "  , "Chi "  , "Qian " ,  /*-- U+6C60 .. U+6C67 --*/
   "Mi "   , "Yu "   , "Wang " , "Qing " , "Jing " , "Rui "  , "Jun "  , "Hong " ,  /*-- U+6C68 .. U+6C6F --*/
   "Tai "  , "Quan " , "Ji "   , "Bian " , "Bian " , "Gan "  , "Wen "  , "Zhong ",  /*-- U+6C70 .. U+6C77 --*/
   "Fang " , "Xiong ", "Jue "  , "Hang " , "Niou " , "Qi "   , "Fen "  , "Xu "   ,  /*-- U+6C78 .. U+6C7F --*/
   "Xu "   , "Qin "  , "Yi "   , "Wo "   , "Yun "  , "Yuan " , "Hang " , "Yan "  ,  /*-- U+6C80 .. U+6C87 --*/
   "Chen " , "Chen " , "Dan "  , "You "  , "Dun "  , "Hu "   , "Huo "  , "Qie "  ,  /*-- U+6C88 .. U+6C8F --*/
   "Mu "   , "Rou "  , "Mei "  , "Ta "   , "Mian " , "Wu "   , "Chong ", "Tian " ,  /*-- U+6C90 .. U+6C97 --*/
   "Bi "   , "Sha "  , "Zhi "  , "Pei "  , "Pan "  , "Zhui " , "Za "   , "Gou "  ,  /*-- U+6C98 .. U+6C9F --*/
   "Liu "  , "Mei "  , "Ze "   , "Feng " , "Ou "   , "Li "   , "Lun "  , "Cang " ,  /*-- U+6CA0 .. U+6CA7 --*/
   "Feng " , "Wei "  , "Hu "   , "Mo "   , "Mei "  , "Shu "  , "Ju "   , "Zan "  ,  /*-- U+6CA8 .. U+6CAF --*/
   "Tuo "  , "Tuo "  , "Tuo "  , "He "   , "Li "   , "Mi "   , "Yi "   , "Fa "   ,  /*-- U+6CB0 .. U+6CB7 --*/
   "Fei "  , "You "  , "Tian " , "Zhi "  , "Zhao " , "Gu "   , "Zhan " , "Yan "  ,  /*-- U+6CB8 .. U+6CBF --*/
   "Si "   , "Kuang ", "Jiong ", "Ju "   , "Xie "  , "Qiu "  , "Yi "   , "Jia "  ,  /*-- U+6CC0 .. U+6CC7 --*/
   "Zhong ", "Quan " , "Bo "   , "Hui "  , "Mi "   , "Ben "  , "Zhuo " , "Chu "  ,  /*-- U+6CC8 .. U+6CCF --*/
   "Le "   , "You "  , "Gu "   , "Hong " , "Gan "  , "Fa "   , "Mao "  , "Si "   ,  /*-- U+6CD0 .. U+6CD7 --*/
   "Hu "   , "Ping " , "Ci "   , "Fan "  , "Chi "  , "Su "   , "Ning " , "Cheng ",  /*-- U+6CD8 .. U+6CDF --*/
   "Ling " , "Pao "  , "Bo "   , "Qi "   , "Si "   , "Ni "   , "Ju "   , "Yue "  ,  /*-- U+6CE0 .. U+6CE7 --*/
   "Zhu "  , "Sheng ", "Lei "  , "Xuan " , "Xue "  , "Fu "   , "Pan "  , "Min "  ,  /*-- U+6CE8 .. U+6CEF --*/
   "Tai "  , "Yang " , "Ji "   , "Yong " , "Guan " , "Beng " , "Xue "  , "Long " ,  /*-- U+6CF0 .. U+6CF7 --*/
   "Lu "   , ""      , "Bo "   , "Xie "  , "Po "   , "Ze "   , "Jing " , "Yin "  ,  /*-- U+6CF8 .. U+6CFF --*/
   "Zhou " , "Ji "   , "Yi "   , "Hui "  , "Hui "  , "Zui "  , "Cheng ", "Yin "  ,  /*-- U+6D00 .. U+6D07 --*/
   "Wei "  , "Hou "  , "Jian " , "Yang " , "Lie "  , "Si "   , "Ji "   , "Er "   ,  /*-- U+6D08 .. U+6D0F --*/
   "Xing " , "Fu "   , "Sa "   , "Suo "  , "Zhi "  , "Yin "  , "Wu "   , "Xi "   ,  /*-- U+6D10 .. U+6D17 --*/
   "Kao "  , "Zhu "  , "Jiang ", "Luo "  , ""      , "An "   , "Dong " , "Yi "   ,  /*-- U+6D18 .. U+6D1F --*/
   "Mou "  , "Lei "  , "Yi "   , "Mi "   , "Quan " , "Jin "  , "Mo "   , "Wei "  ,  /*-- U+6D20 .. U+6D27 --*/
   "Xiao " , "Xie "  , "Hong " , "Xu "   , "Shuo " , "Kuang ", "Tao "  , "Qie "  ,  /*-- U+6D28 .. U+6D2F --*/
   "Ju "   , "Er "   , "Zhou " , "Ru "   , "Ping " , "Xun "  , "Xiong ", "Zhi "  ,  /*-- U+6D30 .. U+6D37 --*/
   "Guang ", "Huan " , "Ming " , "Huo "  , "Wa "   , "Qia "  , "Pai "  , "Wu "   ,  /*-- U+6D38 .. U+6D3F --*/
   "Qu "   , "Liu "  , "Yi "   , "Jia "  , "Jing " , "Qian " , "Jiang ", "Jiao " ,  /*-- U+6D40 .. U+6D47 --*/
   "Cheng ", "Shi "  , "Zhuo " , "Ce "   , "Pal "  , "Kuai " , "Ji "   , "Liu "  ,  /*-- U+6D48 .. U+6D4F --*/
   "Chan " , "Hun "  , "Hu "   , "Nong " , "Xun "  , "Jin "  , "Lie "  , "Qiu "  ,  /*-- U+6D50 .. U+6D57 --*/
   "Wei "  , "Zhe "  , "Jun "  , "Han "  , "Bang " , "Mang " , "Zhuo " , "You "  ,  /*-- U+6D58 .. U+6D5F --*/
   "Xi "   , "Bo "   , "Dou "  , "Wan "  , "Hong " , "Yi "   , "Pu "   , "Ying " ,  /*-- U+6D60 .. U+6D67 --*/
   "Lan "  , "Hao "  , "Lang " , "Han "  , "Li "   , "Geng " , "Fu "   , "Wu "   ,  /*-- U+6D68 .. U+6D6F --*/
   "Lian " , "Chun " , "Feng " , "Yi "   , "Yu "   , "Tong " , "Lao "  , "Hai "  ,  /*-- U+6D70 .. U+6D77 --*/
   "Jin "  , "Jia "  , "Chong ", "Weng " , "Mei "  , "Sui "  , "Cheng ", "Pei "  ,  /*-- U+6D78 .. U+6D7F --*/
   "Xian " , "Shen " , "Tu "   , "Kun "  , "Pin "  , "Nie "  , "Han "  , "Jing " ,  /*-- U+6D80 .. U+6D87 --*/
   "Xiao " , "She "  , "Nian " , "Tu "   , "Yong " , "Xiao " , "Xian " , "Ting " ,  /*-- U+6D88 .. U+6D8F --*/
   "E "    , "Su "   , "Tun "  , "Juan " , "Cen "  , "Ti "   , "Li "   , "Shui " ,  /*-- U+6D90 .. U+6D97 --*/
   "Si "   , "Lei "  , "Shui " , "Tao "  , "Du "   , "Lao "  , "Lai "  , "Lian " ,  /*-- U+6D98 .. U+6D9F --*/
   "Wei "  , "Wo "   , "Yun "  , "Huan " , "Di "   , ""      , "Run "  , "Jian " ,  /*-- U+6DA0 .. U+6DA7 --*/
   "Zhang ", "Se "   , "Fu "   , "Guan " , "Xing " , "Shou " , "Shuan ", "Ya "   ,  /*-- U+6DA8 .. U+6DAF --*/
   "Chuo " , "Zhang ", "Ye "   , "Kong " , "Wo "   , "Han "  , "Tuo "  , "Dong " ,  /*-- U+6DB0 .. U+6DB7 --*/
   "He "   , "Wo "   , "Ju "   , "Gan "  , "Liang ", "Hun "  , "Ta "   , "Zhuo " ,  /*-- U+6DB8 .. U+6DBF --*/
   "Dian " , "Qie "  , "De "   , "Juan " , "Zi "   , "Xi "   , "Yao "  , "Qi "   ,  /*-- U+6DC0 .. U+6DC7 --*/
   "Gu "   , "Guo "  , "Han "  , "Lin "  , "Tang " , "Zhou " , "Peng " , "Hao "  ,  /*-- U+6DC8 .. U+6DCF --*/
   "Chang ", "Shu "  , "Qi "   , "Fang " , "Chi "  , "Lu "   , "Nao "  , "Ju "   ,  /*-- U+6DD0 .. U+6DD7 --*/
   "Tao "  , "Cong " , "Lei "  , "Zhi "  , "Peng " , "Fei "  , "Song " , "Tian " ,  /*-- U+6DD8 .. U+6DDF --*/
   "Pi "   , "Dan "  , "Yu "   , "Ni "   , "Yu "   , "Lu "   , "Gan "  , "Mi "   ,  /*-- U+6DE0 .. U+6DE7 --*/
   "Jing " , "Ling " , "Lun "  , "Yin "  , "Cui "  , "Qu "   , "Huai " , "Yu "   ,  /*-- U+6DE8 .. U+6DEF --*/
   "Nian " , "Shen " , "Piao " , "Chun " , "Wa "   , "Yuan " , "Lai "  , "Hun "  ,  /*-- U+6DF0 .. U+6DF7 --*/
   "Qing " , "Yan "  , "Qian " , "Tian " , "Miao " , "Zhi "  , "Yin "  , "Mi "   ,  /*-- U+6DF8 .. U+6DFF --*/
   "Ben "  , "Yuan " , "Wen "  , "Re "   , "Fei "  , "Qing " , "Yuan " , "Ke "   ,  /*-- U+6E00 .. U+6E07 --*/
   "Ji "   , "She "  , "Yuan " , "Shibui ", "Lu "   , "Zi "   , "Du "   , ""      ,  /*-- U+6E08 .. U+6E0F --*/
   "Jian " , "Min "  , "Pi "   , "Tani " , "Yu "   , "Yuan " , "Shen " , "Shen " ,  /*-- U+6E10 .. U+6E17 --*/
   "Rou "  , "Huan " , "Zhu "  , "Jian " , "Nuan " , "Yu "   , "Qiu "  , "Ting " ,  /*-- U+6E18 .. U+6E1F --*/
   "Qu "   , "Du "   , "Feng " , "Zha "  , "Bo "   , "Wo "   , "Wo "   , "Di "   ,  /*-- U+6E20 .. U+6E27 --*/
   "Wei "  , "Wen "  , "Ru "   , "Xie "  , "Ce "   , "Wei "  , "Ge "   , "Gang " ,  /*-- U+6E28 .. U+6E2F --*/
   "Yan "  , "Hong " , "Xuan " , "Mi "   , "Ke "   , "Mao "  , "Ying " , "Yan "  ,  /*-- U+6E30 .. U+6E37 --*/
   "You "  , "Hong " , "Miao " , "Xing " , "Mei "  , "Zai "  , "Hun "  , "Nai "  ,  /*-- U+6E38 .. U+6E3F --*/
   "Kui "  , "Shi "  , "E "    , "Pai "  , "Mei "  , "Lian " , "Qi "   , "Qi "   ,  /*-- U+6E40 .. U+6E47 --*/
   "Mei "  , "Tian " , "Cou "  , "Wei "  , "Can "  , "Tuan " , "Mian " , "Hui "  ,  /*-- U+6E48 .. U+6E4F --*/
   "Mo "   , "Xu "   , "Ji "   , "Pen "  , "Jian " , "Jian " , "Hu "   , "Feng " ,  /*-- U+6E50 .. U+6E57 --*/
   "Xiang ", "Yi "   , "Yin "  , "Zhan " , "Shi "  , "Jie "  , "Cheng ", "Huang ",  /*-- U+6E58 .. U+6E5F --*/
   "Tan "  , "Yu "   , "Bi "   , "Min "  , "Shi "  , "Tu "   , "Sheng ", "Yong " ,  /*-- U+6E60 .. U+6E67 --*/
   "Qu "   , "Zhong ", "Suei " , "Jiu "  , "Jiao " , "Qiou " , "Yin "  , "Tang " ,  /*-- U+6E68 .. U+6E6F --*/
   "Long " , "Huo "  , "Yuan " , "Nan "  , "Ban "  , "You "  , "Quan " , "Chui " ,  /*-- U+6E70 .. U+6E77 --*/
   "Liang ", "Chan " , "Yan "  , "Chun " , "Nie "  , "Zi "   , "Wan "  , "Shi "  ,  /*-- U+6E78 .. U+6E7F --*/
   "Man "  , "Ying " , "Ratsu ", "Kui "  , ""      , "Jian " , "Xu "   , "Lu "   ,  /*-- U+6E80 .. U+6E87 --*/
   "Gui "  , "Gai "  , ""      , ""      , "Po "   , "Jin "  , "Gui "  , "Tang " ,  /*-- U+6E88 .. U+6E8F --*/
   "Yuan " , "Suo "  , "Yuan " , "Lian " , "Yao "  , "Meng " , "Zhun " , "Sheng ",  /*-- U+6E90 .. U+6E97 --*/
   "Ke "   , "Tai "  , "Da "   , "Wa "   , "Liu "  , "Gou "  , "Sao "  , "Ming " ,  /*-- U+6E98 .. U+6E9F --*/
   "Zha "  , "Shi "  , "Yi "   , "Lun "  , "Ma "   , "Pu "   , "Wei "  , "Li "   ,  /*-- U+6EA0 .. U+6EA7 --*/
   "Cai "  , "Wu "   , "Xi "   , "Wen "  , "Qiang ", "Ze "   , "Shi "  , "Su "   ,  /*-- U+6EA8 .. U+6EAF --*/
   "Yi "   , "Zhen " , "Sou "  , "Yun "  , "Xiu "  , "Yin "  , "Rong " , "Hun "  ,  /*-- U+6EB0 .. U+6EB7 --*/
   "Su "   , "Su "   , "Ni "   , "Ta "   , "Shi "  , "Ru "   , "Wei "  , "Pan "  ,  /*-- U+6EB8 .. U+6EBF --*/
   "Chu "  , "Chu "  , "Pang " , "Weng " , "Cang " , "Mie "  , "He "   , "Dian " ,  /*-- U+6EC0 .. U+6EC7 --*/
   "Hao "  , "Huang ", "Xi "   , "Zi "   , "Di "   , "Zhi "  , "Ying " , "Fu "   ,  /*-- U+6EC8 .. U+6ECF --*/
   "Jie "  , "Hua "  , "Ge "   , "Zi "   , "Tao "  , "Teng " , "Sui "  , "Bi "   ,  /*-- U+6ED0 .. U+6ED7 --*/
   "Jiao " , "Hui "  , "Gun "  , "Yin "  , "Gao "  , "Long " , "Zhi "  , "Yan "  ,  /*-- U+6ED8 .. U+6EDF --*/
   "She "  , "Man "  , "Ying " , "Chun " , "Lu "   , "Lan "  , "Luan " , ""      ,  /*-- U+6EE0 .. U+6EE7 --*/
   "Bin "  , "Tan "  , "Yu "   , "Sou "  , "Hu "   , "Bi "   , "Biao " , "Zhi "  ,  /*-- U+6EE8 .. U+6EEF --*/
   "Jiang ", "Kou "  , "Shen " , "Shang ", "Di "   , "Mi "   , "Ao "   , "Lu "   ,  /*-- U+6EF0 .. U+6EF7 --*/
   "Hu "   , "Hu "   , "You "  , "Chan " , "Fan "  , "Yong " , "Gun "  , "Man "  ,  /*-- U+6EF8 .. U+6EFF --*/
   "Qing " , "Yu "   , "Piao " , "Ji "   , "Ya "   , "Jiao " , "Qi "   , "Xi "   ,  /*-- U+6F00 .. U+6F07 --*/
   "Ji "   , "Lu "   , "Lu "   , "Long " , "Jin "  , "Guo "  , "Cong " , "Lou "  ,  /*-- U+6F08 .. U+6F0F --*/
   "Zhi "  , "Gai "  , "Qiang ", "Li "   , "Yan "  , "Cao "  , "Jiao " , "Cong " ,  /*-- U+6F10 .. U+6F17 --*/
   "Qun "  , "Tuan " , "Ou "   , "Teng " , "Ye "   , "Xi "   , "Mi "   , "Tang " ,  /*-- U+6F18 .. U+6F1F --*/
   "Mo "   , "Shang ", "Han "  , "Lian " , "Lan "  , "Wa "   , "Li "   , "Qian " ,  /*-- U+6F20 .. U+6F27 --*/
   "Feng " , "Xuan " , "Yi "   , "Man "  , "Zi "   , "Mang " , "Kang " , "Lei "  ,  /*-- U+6F28 .. U+6F2F --*/
   "Peng " , "Shu "  , "Zhang ", "Zhang ", "Chong ", "Xu "   , "Huan " , "Kuo "  ,  /*-- U+6F30 .. U+6F37 --*/
   "Jian " , "Yan "  , "Chuang ", "Liao " , "Cui "  , "Ti "   , "Yang " , "Jiang ",  /*-- U+6F38 .. U+6F3F --*/
   "Cong " , "Ying " , "Hong " , "Xun "  , "Shu "  , "Guan " , "Ying " , "Xiao " ,  /*-- U+6F40 .. U+6F47 --*/
   ""      , ""      , "Xu "   , "Lian " , "Zhi "  , "Wei "  , "Pi "   , "Jue "  ,  /*-- U+6F48 .. U+6F4F --*/
   "Jiao " , "Po "   , "Dang " , "Hui "  , "Jie "  , "Wu "   , "Pa "   , "Ji "   ,  /*-- U+6F50 .. U+6F57 --*/
   "Pan "  , "Gui "  , "Xiao " , "Qian " , "Qian " , "Xi "   , "Lu "   , "Xi "   ,  /*-- U+6F58 .. U+6F5F --*/
   "Xuan " , "Dun "  , "Huang ", "Min "  , "Run "  , "Su "   , "Liao " , "Zhen " ,  /*-- U+6F60 .. U+6F67 --*/
   "Zhong ", "Yi "   , "Di "   , "Wan "  , "Dan "  , "Tan "  , "Chao " , "Xun "  ,  /*-- U+6F68 .. U+6F6F --*/
   "Kui "  , "Yie "  , "Shao " , "Tu "   , "Zhu "  , "San "  , "Hei "  , "Bi "   ,  /*-- U+6F70 .. U+6F77 --*/
   "Shan " , "Chan " , "Chan " , "Shu "  , "Tong " , "Pu "   , "Lin "  , "Wei "  ,  /*-- U+6F78 .. U+6F7F --*/
   "Se "   , "Se "   , "Cheng ", "Jiong ", "Cheng ", "Hua "  , "Jiao " , "Lao "  ,  /*-- U+6F80 .. U+6F87 --*/
   "Che "  , "Gan "  , "Cun "  , "Heng " , "Si "   , "Shu "  , "Peng " , "Han "  ,  /*-- U+6F88 .. U+6F8F --*/
   "Yun "  , "Liu "  , "Hong " , "Fu "   , "Hao "  , "He "   , "Xian " , "Jian " ,  /*-- U+6F90 .. U+6F97 --*/
   "Shan " , "Xi "   , "Oki "  , ""      , "Lan "  , ""      , "Yu "   , "Lin "  ,  /*-- U+6F98 .. U+6F9F --*/
   "Min "  , "Zao "  , "Dang " , "Wan "  , "Ze "   , "Xie "  , "Yu "   , "Li "   ,  /*-- U+6FA0 .. U+6FA7 --*/
   "Shi "  , "Xue "  , "Ling " , "Man "  , "Zi "   , "Yong " , "Kuai " , "Can "  ,  /*-- U+6FA8 .. U+6FAF --*/
   "Lian " , "Dian " , "Ye "   , "Ao "   , "Huan " , "Zhen " , "Chan " , "Man "  ,  /*-- U+6FB0 .. U+6FB7 --*/
   "Dan "  , "Dan "  , "Yi "   , "Sui "  , "Pi "   , "Ju "   , "Ta "   , "Qin "  ,  /*-- U+6FB8 .. U+6FBF --*/
   "Ji "   , "Zhuo " , "Lian " , "Nong " , "Guo "  , "Jin "  , "Fen "  , "Se "   ,  /*-- U+6FC0 .. U+6FC7 --*/
   "Ji "   , "Sui "  , "Hui "  , "Chu "  , "Ta "   , "Song " , "Ding " , ""      ,  /*-- U+6FC8 .. U+6FCF --*/
   "Zhu "  , "Lai "  , "Bin "  , "Lian " , "Mi "   , "Shi "  , "Shu "  , "Mi "   ,  /*-- U+6FD0 .. U+6FD7 --*/
   "Ning " , "Ying " , "Ying " , "Meng " , "Jin "  , "Qi "   , "Pi "   , "Ji "   ,  /*-- U+6FD8 .. U+6FDF --*/
   "Hao "  , "Ru "   , "Zui "  , "Wo "   , "Tao "  , "Yin "  , "Yin "  , "Dui "  ,  /*-- U+6FE0 .. U+6FE7 --*/
   "Ci "   , "Huo "  , "Jing " , "Lan "  , "Jun "  , "Ai "   , "Pu "   , "Zhuo " ,  /*-- U+6FE8 .. U+6FEF --*/
   "Wei "  , "Bin "  , "Gu "   , "Qian " , "Xing " , "Hama " , "Kuo "  , "Fei "  ,  /*-- U+6FF0 .. U+6FF7 --*/
   ""      , "Boku " , "Jian " , "Wei "  , "Luo "  , "Zan "  , "Lu "   , "Li "   ,  /*-- U+6FF8 .. U+6FFF --*/
   "You "  , "Yang " , "Lu "   , "Si "   , "Jie "  , "Ying " , "Du "   , "Wang " ,  /*-- U+7000 .. U+7007 --*/
   "Hui "  , "Xie "  , "Pan "  , "Shen " , "Biao " , "Chan " , "Mo "   , "Liu "  ,  /*-- U+7008 .. U+700F --*/
   "Jian " , "Pu "   , "Se "   , "Cheng ", "Gu "   , "Bin "  , "Huo "  , "Xian " ,  /*-- U+7010 .. U+7017 --*/
   "Lu "   , "Qin "  , "Han "  , "Ying " , "Yong " , "Li "   , "Jing " , "Xiao " ,  /*-- U+7018 .. U+701F --*/
   "Ying " , "Sui "  , "Wei "  , "Xie "  , "Huai " , "Hao "  , "Zhu "  , "Long " ,  /*-- U+7020 .. U+7027 --*/
   "Lai "  , "Dui "  , "Fan "  , "Hu "   , "Lai "  , ""      , ""      , "Ying " ,  /*-- U+7028 .. U+702F --*/
   "Mi "   , "Ji "   , "Lian " , "Jian " , "Ying " , "Fen "  , "Lin "  , "Yi "   ,  /*-- U+7030 .. U+7037 --*/
   "Jian " , "Yue "  , "Chan " , "Dai "  , "Rang " , "Jian " , "Lan "  , "Fan "  ,  /*-- U+7038 .. U+703F --*/
   "Shuang ", "Yuan " , "Zhuo " , "Feng " , "She "  , "Lei "  , "Lan "  , "Cong " ,  /*-- U+7040 .. U+7047 --*/
   "Qu "   , "Yong " , "Qian " , "Fa "   , "Guan " , "Que "  , "Yan "  , "Hao "  ,  /*-- U+7048 .. U+704F --*/
   "Hyeng ", "Sa "   , "Zan "  , "Luan " , "Yan "  , "Li "   , "Mi "   , "Shan " ,  /*-- U+7050 .. U+7057 --*/
   "Tan "  , "Dang " , "Jiao " , "Chan " , ""      , "Hao "  , "Ba "   , "Zhu "  ,  /*-- U+7058 .. U+705F --*/
   "Lan "  , "Lan "  , "Nang " , "Wan "  , "Luan " , "Xun "  , "Xian " , "Yan "  ,  /*-- U+7060 .. U+7067 --*/
   "Gan "  , "Yan "  , "Yu "   , "Huo "  , "Si "   , "Mie "  , "Guang ", "Deng " ,  /*-- U+7068 .. U+706F --*/
   "Hui "  , "Xiao " , "Xiao " , "Hu "   , "Hong " , "Ling " , "Zao "  , "Zhuan ",  /*-- U+7070 .. U+7077 --*/
   "Jiu "  , "Zha "  , "Xie "  , "Chi "  , "Zhuo " , "Zai "  , "Zai "  , "Can "  ,  /*-- U+7078 .. U+707F --*/
   "Yang " , "Qi "   , "Zhong ", "Fen "  , "Niu "  , "Jiong ", "Wen "  , "Po "   ,  /*-- U+7080 .. U+7087 --*/
   "Yi "   , "Lu "   , "Chui " , "Pi "   , "Kai "  , "Pan "  , "Yan "  , "Kai "  ,  /*-- U+7088 .. U+708F --*/
   "Pang " , "Mu "   , "Chao " , "Liao " , "Gui "  , "Kang " , "Tun "  , "Guang ",  /*-- U+7090 .. U+7097 --*/
   "Xin "  , "Zhi "  , "Guang ", "Guang ", "Wei "  , "Qiang ", ""      , "Da "   ,  /*-- U+7098 .. U+709F --*/
   "Xia "  , "Zheng ", "Zhu "  , "Ke "   , "Zhao " , "Fu "   , "Ba "   , "Duo "  ,  /*-- U+70A0 .. U+70A7 --*/
   "Duo "  , "Ling " , "Zhuo " , "Xuan " , "Ju "   , "Tan "  , "Pao "  , "Jiong ",  /*-- U+70A8 .. U+70AF --*/
   "Pao "  , "Tai "  , "Tai "  , "Bing " , "Yang " , "Tong " , "Han "  , "Zhu "  ,  /*-- U+70B0 .. U+70B7 --*/
   "Zha "  , "Dian " , "Wei "  , "Shi "  , "Lian " , "Chi "  , "Huang ", ""      ,  /*-- U+70B8 .. U+70BF --*/
   "Hu "   , "Shuo " , "Lan "  , "Jing " , "Jiao " , "Xu "   , "Xing " , "Quan " ,  /*-- U+70C0 .. U+70C7 --*/
   "Lie "  , "Huan " , "Yang " , "Xiao " , "Xiu "  , "Xian " , "Yin "  , "Wu "   ,  /*-- U+70C8 .. U+70CF --*/
   "Zhou " , "Yao "  , "Shi "  , "Wei "  , "Tong " , "Xue "  , "Zai "  , "Kai "  ,  /*-- U+70D0 .. U+70D7 --*/
   "Hong " , "Luo "  , "Xia "  , "Zhu "  , "Xuan " , "Zheng ", "Po "   , "Yan "  ,  /*-- U+70D8 .. U+70DF --*/
   "Hui "  , "Guang ", "Zhe "  , "Hui "  , "Kao "  , ""      , "Fan "  , "Shao " ,  /*-- U+70E0 .. U+70E7 --*/
   "Ye "   , "Hui "  , ""      , "Tang " , "Jin "  , "Re "   , ""      , "Xi "   ,  /*-- U+70E8 .. U+70EF --*/
   "Fu "   , "Jiong ", "Che "  , "Pu "   , "Jing " , "Zhuo " , "Ting " , "Wan "  ,  /*-- U+70F0 .. U+70F7 --*/
   "Hai "  , "Peng " , "Lang " , "Shan " , "Hu "   , "Feng " , "Chi "  , "Rong " ,  /*-- U+70F8 .. U+70FF --*/
   "Hu "   , "Xi "   , "Shu "  , "He "   , "Xun "  , "Ku "   , "Jue "  , "Xiao " ,  /*-- U+7100 .. U+7107 --*/
   "Xi "   , "Yan "  , "Han "  , "Zhuang ", "Jun "  , "Di "   , "Xie "  , "Ji "   ,  /*-- U+7108 .. U+710F --*/
   "Wu "   , ""      , ""      , "Han "  , "Yan "  , "Huan " , "Men "  , "Ju "   ,  /*-- U+7110 .. U+7117 --*/
   "Chou " , "Bei "  , "Fen "  , "Lin "  , "Kun "  , "Hun "  , "Tun "  , "Xi "   ,  /*-- U+7118 .. U+711F --*/
   "Cui "  , "Wu "   , "Hong " , "Ju "   , "Fu "   , "Wo "   , "Jiao " , "Cong " ,  /*-- U+7120 .. U+7127 --*/
   "Feng " , "Ping " , "Qiong ", "Ruo "  , "Xi "   , "Qiong ", "Xin "  , "Zhuo " ,  /*-- U+7128 .. U+712F --*/
   "Yan "  , "Yan "  , "Yi "   , "Jue "  , "Yu "   , "Gang " , "Ran "  , "Pi "   ,  /*-- U+7130 .. U+7137 --*/
   "Gu "   , ""      , "Sheng ", "Chang ", "Shao " , ""      , ""      , ""      ,  /*-- U+7138 .. U+713F --*/
   ""      , "Chen " , "He "   , "Kui "  , "Zhong ", "Duan " , "Xia "  , "Hui "  ,  /*-- U+7140 .. U+7147 --*/
   "Feng " , "Lian " , "Xuan " , "Xing " , "Huang ", "Jiao " , "Jian " , "Bi "   ,  /*-- U+7148 .. U+714F --*/
   "Ying " , "Zhu "  , "Wei "  , "Tuan " , "Tian " , "Xi "   , "Nuan " , "Nuan " ,  /*-- U+7150 .. U+7157 --*/
   "Chan " , "Yan "  , "Jiong ", "Jiong ", "Yu "   , "Mei "  , "Sha "  , "Wei "  ,  /*-- U+7158 .. U+715F --*/
   "Ye "   , "Xin "  , "Qiong ", "Rou "  , "Mei "  , "Huan " , "Xu "   , "Zhao " ,  /*-- U+7160 .. U+7167 --*/
   "Wei "  , "Fan "  , "Qiu "  , "Sui "  , "Yang " , "Lie "  , "Zhu "  , "Jie "  ,  /*-- U+7168 .. U+716F --*/
   "Gao "  , "Gua "  , "Bao "  , "Hu "   , "Yun "  , "Xia "  , ""      , ""      ,  /*-- U+7170 .. U+7177 --*/
   "Bian " , "Gou "  , "Tui "  , "Tang " , "Chao " , "Shan " , "N "    , "Bo "   ,  /*-- U+7178 .. U+717F --*/
   "Huang ", "Xie "  , "Xi "   , "Wu "   , "Xi "   , "Yun "  , "He "   , "He "   ,  /*-- U+7180 .. U+7187 --*/
   "Xi "   , "Yun "  , "Xiong ", "Nai "  , "Shan " , "Qiong ", "Yao "  , "Xun "  ,  /*-- U+7188 .. U+718F --*/
   "Mi "   , "Lian " , "Ying " , "Wen "  , "Rong " , "Oozutsu ", ""      , "Qiang ",  /*-- U+7190 .. U+7197 --*/
   "Liu "  , "Xi "   , "Bi "   , "Biao " , "Zong " , "Lu "   , "Jian " , "Shou " ,  /*-- U+7198 .. U+719F --*/
   "Yi "   , "Lou "  , "Feng " , "Sui "  , "Yi "   , "Tong " , "Jue "  , "Zong " ,  /*-- U+71A0 .. U+71A7 --*/
   "Yun "  , "Hu "   , "Yi "   , "Zhi "  , "Ao "   , "Wei "  , "Liao " , "Han "  ,  /*-- U+71A8 .. U+71AF --*/
   "Ou "   , "Re "   , "Jiong ", "Man "  , ""      , "Shang ", "Cuan " , "Zeng " ,  /*-- U+71B0 .. U+71B7 --*/
   "Jian " , "Xi "   , "Xi "   , "Xi "   , "Yi "   , "Xiao " , "Chi "  , "Huang ",  /*-- U+71B8 .. U+71BF --*/
   "Chan " , "Ye "   , "Qian " , "Ran "  , "Yan "  , "Xian " , "Qiao " , "Zun "  ,  /*-- U+71C0 .. U+71C7 --*/
   "Deng " , "Dun "  , "Shen " , "Jiao " , "Fen "  , "Si "   , "Liao " , "Yu "   ,  /*-- U+71C8 .. U+71CF --*/
   "Lin "  , "Tong " , "Shao " , "Fen "  , "Fan "  , "Yan "  , "Xun "  , "Lan "  ,  /*-- U+71D0 .. U+71D7 --*/
   "Mei "  , "Tang " , "Yi "   , "Jing " , "Men "  , ""      , ""      , "Ying " ,  /*-- U+71D8 .. U+71DF --*/
   "Yu "   , "Yi "   , "Xue "  , "Lan "  , "Tai "  , "Zao "  , "Can "  , "Sui "  ,  /*-- U+71E0 .. U+71E7 --*/
   "Xi "   , "Que "  , "Cong " , "Lian " , "Hui "  , "Zhu "  , "Xie "  , "Ling " ,  /*-- U+71E8 .. U+71EF --*/
   "Wei "  , "Yi "   , "Xie "  , "Zhao " , "Hui "  , "Tatsu ", "Nung " , "Lan "  ,  /*-- U+71F0 .. U+71F7 --*/
   "Ru "   , "Xian " , "Kao "  , "Xun "  , "Jin "  , "Chou " , "Chou " , "Yao "  ,  /*-- U+71F8 .. U+71FF --*/
   "He "   , "Lan "  , "Biao " , "Rong " , "Li "   , "Mo "   , "Bao "  , "Ruo "  ,  /*-- U+7200 .. U+7207 --*/
   "Lu "   , "La "   , "Ao "   , "Xun "  , "Kuang ", "Shuo " , ""      , "Li "   ,  /*-- U+7208 .. U+720F --*/
   "Lu "   , "Jue "  , "Liao " , "Yan "  , "Xi "   , "Xie "  , "Long " , "Ye "   ,  /*-- U+7210 .. U+7217 --*/
   ""      , "Rang " , "Yue "  , "Lan "  , "Cong " , "Jue "  , "Tong " , "Guan " ,  /*-- U+7218 .. U+721F --*/
   ""      , "Che "  , "Mi "   , "Tang " , "Lan "  , "Zhu "  , ""      , "Ling " ,  /*-- U+7220 .. U+7227 --*/
   "Cuan " , "Yu "   , "Zhua " , "Tsumekanmuri ", "Pa "   , "Zheng ", "Pao "  , "Cheng ",  /*-- U+7228 .. U+722F --*/
   "Yuan " , "Ai "   , "Wei "  , ""      , "Jue "  , "Jue "  , "Fu "   , "Ye "   ,  /*-- U+7230 .. U+7237 --*/
   "Ba "   , "Die "  , "Ye "   , "Yao "  , "Zu "   , "Shuang ", "Er "   , "Qiang ",  /*-- U+7238 .. U+723F --*/
   "Chuang ", "Ge "   , "Zang " , "Die "  , "Qiang ", "Yong " , "Qiang ", "Pian " ,  /*-- U+7240 .. U+7247 --*/
   "Ban "  , "Pan "  , "Shao " , "Jian " , "Pai "  , "Du "   , "Chuang ", "Tou "  ,  /*-- U+7248 .. U+724F --*/
   "Zha "  , "Bian " , "Die "  , "Bang " , "Bo "   , "Chuang ", "You "  , ""      ,  /*-- U+7250 .. U+7257 --*/
   "Du "   , "Ya "   , "Cheng ", "Niu "  , "Ushihen ", "Pin "  , "Jiu "  , "Mou "  ,  /*-- U+7258 .. U+725F --*/
   "Tuo "  , "Mu "   , "Lao "  , "Ren "  , "Mang " , "Fang " , "Mao "  , "Mu "   ,  /*-- U+7260 .. U+7267 --*/
   "Gang " , "Wu "   , "Yan "  , "Ge "   , "Bei "  , "Si "   , "Jian " , "Gu "   ,  /*-- U+7268 .. U+726F --*/
   "You "  , "Ge "   , "Sheng ", "Mu "   , "Di "   , "Qian " , "Quan " , "Quan " ,  /*-- U+7270 .. U+7277 --*/
   "Zi "   , "Te "   , "Xi "   , "Mang " , "Keng " , "Qian " , "Wu "   , "Gu "   ,  /*-- U+7278 .. U+727F --*/
   "Xi "   , "Li "   , "Li "   , "Pou "  , "Ji "   , "Gang " , "Zhi "  , "Ben "  ,  /*-- U+7280 .. U+7287 --*/
   "Quan " , "Run "  , "Du "   , "Ju "   , "Jia "  , "Jian " , "Feng " , "Pian " ,  /*-- U+7288 .. U+728F --*/
   "Ke "   , "Ju "   , "Kao "  , "Chu "  , "Xi "   , "Bei "  , "Luo "  , "Jie "  ,  /*-- U+7290 .. U+7297 --*/
   "Ma "   , "San "  , "Wei "  , "Li "   , "Dun "  , "Tong " , ""      , "Jiang ",  /*-- U+7298 .. U+729F --*/
   "Ikenie ", "Li "   , "Du "   , "Lie "  , "Pi "   , "Piao " , "Bao "  , "Xi "   ,  /*-- U+72A0 .. U+72A7 --*/
   "Chou " , "Wei "  , "Kui "  , "Chou " , "Quan " , "Fan "  , "Ba "   , "Fan "  ,  /*-- U+72A8 .. U+72AF --*/
   "Qiu "  , "Ji "   , "Cai "  , "Chuo " , "An "   , "Jie "  , "Zhuang ", "Guang ",  /*-- U+72B0 .. U+72B7 --*/
   "Ma "   , "You "  , "Kang " , "Bo "   , "Hou "  , "Ya "   , "Yin "  , "Huan " ,  /*-- U+72B8 .. U+72BF --*/
   "Zhuang ", "Yun "  , "Kuang ", "Niu "  , "Di "   , "Qing " , "Zhong ", "Mu "   ,  /*-- U+72C0 .. U+72C7 --*/
   "Bei "  , "Pi "   , "Ju "   , "Ni "   , "Sheng ", "Pao "  , "Xia "  , "Tuo "  ,  /*-- U+72C8 .. U+72CF --*/
   "Hu "   , "Ling " , "Fei "  , "Pi "   , "Ni "   , "Ao "   , "You "  , "Gou "  ,  /*-- U+72D0 .. U+72D7 --*/
   "Yue "  , "Ju "   , "Dan "  , "Po "   , "Gu "   , "Xian " , "Ning " , "Huan " ,  /*-- U+72D8 .. U+72DF --*/
   "Hen "  , "Jiao " , "He "   , "Zhao " , "Ji "   , "Xun "  , "Shan " , "Ta "   ,  /*-- U+72E0 .. U+72E7 --*/
   "Rong " , "Shou " , "Tong " , "Lao "  , "Du "   , "Xia "  , "Shi "  , "Hua "  ,  /*-- U+72E8 .. U+72EF --*/
   "Zheng ", "Yu "   , "Sun "  , "Yu "   , "Bi "   , "Mang " , "Xi "   , "Juan " ,  /*-- U+72F0 .. U+72F7 --*/
   "Li "   , "Xia "  , "Yin "  , "Suan " , "Lang " , "Bei "  , "Zhi "  , "Yan "  ,  /*-- U+72F8 .. U+72FF --*/
   "Sha "  , "Li "   , "Han "  , "Xian " , "Jing " , "Pai "  , "Fei "  , "Yao "  ,  /*-- U+7300 .. U+7307 --*/
   "Ba "   , "Qi "   , "Ni "   , "Biao " , "Yin "  , "Lai "  , "Xi "   , "Jian " ,  /*-- U+7308 .. U+730F --*/
   "Qiang ", "Kun "  , "Yan "  , "Guo "  , "Zong " , "Mi "   , "Chang ", "Yi "   ,  /*-- U+7310 .. U+7317 --*/
   "Zhi "  , "Zheng ", "Ya "   , "Meng " , "Cai "  , "Cu "   , "She "  , "Kari " ,  /*-- U+7318 .. U+731F --*/
   "Cen "  , "Luo "  , "Hu "   , "Zong " , "Ji "   , "Wei "  , "Feng " , "Wo "   ,  /*-- U+7320 .. U+7327 --*/
   "Yuan " , "Xing " , "Zhu "  , "Mao "  , "Wei "  , "Yuan " , "Xian " , "Tuan " ,  /*-- U+7328 .. U+732F --*/
   "Ya "   , "Nao "  , "Xie "  , "Jia "  , "Hou "  , "Bian " , "You "  , "You "  ,  /*-- U+7330 .. U+7337 --*/
   "Mei "  , "Zha "  , "Yao "  , "Sun "  , "Bo "   , "Ming " , "Hua "  , "Yuan " ,  /*-- U+7338 .. U+733F --*/
   "Sou "  , "Ma "   , "Yuan " , "Dai "  , "Yu "   , "Shi "  , "Hao "  , ""      ,  /*-- U+7340 .. U+7347 --*/
   "Yi "   , "Zhen " , "Chuang ", "Hao "  , "Man "  , "Jing " , "Jiang ", "Mu "   ,  /*-- U+7348 .. U+734F --*/
   "Zhang ", "Chan " , "Ao "   , "Ao "   , "Hao "  , "Cui "  , "Fen "  , "Jue "  ,  /*-- U+7350 .. U+7357 --*/
   "Bi "   , "Bi "   , "Huang ", "Pu "   , "Lin "  , "Yu "   , "Tong " , "Yao "  ,  /*-- U+7358 .. U+735F --*/
   "Liao " , "Shuo " , "Xiao " , "Swu "  , "Ton "  , "Xi "   , "Ge "   , "Juan " ,  /*-- U+7360 .. U+7367 --*/
   "Du "   , "Hui "  , "Kuai " , "Xian " , "Xie "  , "Ta "   , "Xian " , "Xun "  ,  /*-- U+7368 .. U+736F --*/
   "Ning " , "Pin "  , "Huo "  , "Nou "  , "Meng " , "Lie "  , "Nao "  , "Guang ",  /*-- U+7370 .. U+7377 --*/
   "Shou " , "Lu "   , "Ta "   , "Xian " , "Mi "   , "Rang " , "Huan " , "Nao "  ,  /*-- U+7378 .. U+737F --*/
   "Luo "  , "Xian " , "Qi "   , "Jue "  , "Xuan " , "Miao " , "Zi "   , "Lu "   ,  /*-- U+7380 .. U+7387 --*/
   "Lu "   , "Yu "   , "Su "   , "Wang " , "Qiu "  , "Ga "   , "Ding " , "Le "   ,  /*-- U+7388 .. U+738F --*/
   "Ba "   , "Ji "   , "Hong " , "Di "   , "Quan " , "Gan "  , "Jiu "  , "Yu "   ,  /*-- U+7390 .. U+7397 --*/
   "Ji "   , "Yu "   , "Yang " , "Ma "   , "Gong " , "Wu "   , "Fu "   , "Wen "  ,  /*-- U+7398 .. U+739F --*/
   "Jie "  , "Ya "   , "Fen "  , "Bian " , "Beng " , "Yue "  , "Jue "  , "Yun "  ,  /*-- U+73A0 .. U+73A7 --*/
   "Jue "  , "Wan "  , "Jian " , "Mei "  , "Dan "  , "Pi "   , "Wei "  , "Huan " ,  /*-- U+73A8 .. U+73AF --*/
   "Xian " , "Qiang ", "Ling " , "Dai "  , "Yi "   , "An "   , "Ping " , "Dian " ,  /*-- U+73B0 .. U+73B7 --*/
   "Fu "   , "Xuan " , "Xi "   , "Bo "   , "Ci "   , "Gou "  , "Jia "  , "Shao " ,  /*-- U+73B8 .. U+73BF --*/
   "Po "   , "Ci "   , "Ke "   , "Ran "  , "Sheng ", "Shen " , "Yi "   , "Zu "   ,  /*-- U+73C0 .. U+73C7 --*/
   "Jia "  , "Min "  , "Shan " , "Liu "  , "Bi "   , "Zhen " , "Zhen " , "Jue "  ,  /*-- U+73C8 .. U+73CF --*/
   "Fa "   , "Long " , "Jin "  , "Jiao " , "Jian " , "Li "   , "Guang ", "Xian " ,  /*-- U+73D0 .. U+73D7 --*/
   "Zhou " , "Gong " , "Yan "  , "Xiu "  , "Yang " , "Xu "   , "Luo "  , "Su "   ,  /*-- U+73D8 .. U+73DF --*/
   "Zhu "  , "Qin "  , "Ken "  , "Xun "  , "Bao "  , "Er "   , "Xiang ", "Yao "  ,  /*-- U+73E0 .. U+73E7 --*/
   "Xia "  , "Heng " , "Gui "  , "Chong ", "Xu "   , "Ban "  , "Pei "  , ""      ,  /*-- U+73E8 .. U+73EF --*/
   "Dang " , "Ei "   , "Hun "  , "Wen "  , "E "    , "Cheng ", "Ti "   , "Wu "   ,  /*-- U+73F0 .. U+73F7 --*/
   "Wu "   , "Cheng ", "Jun "  , "Mei "  , "Bei "  , "Ting " , "Xian " , "Chuo " ,  /*-- U+73F8 .. U+73FF --*/
   "Han "  , "Xuan " , "Yan "  , "Qiu "  , "Quan " , "Lang " , "Li "   , "Xiu "  ,  /*-- U+7400 .. U+7407 --*/
   "Fu "   , "Liu "  , "Ye "   , "Xi "   , "Ling " , "Li "   , "Jin "  , "Lian " ,  /*-- U+7408 .. U+740F --*/
   "Suo "  , "Chiisai ", ""      , "Wan "  , "Dian " , "Pin "  , "Zhan " , "Cui "  ,  /*-- U+7410 .. U+7417 --*/
   "Min "  , "Yu "   , "Ju "   , "Chen " , "Lai "  , "Wen "  , "Sheng ", "Wei "  ,  /*-- U+7418 .. U+741F --*/
   "Dian " , "Chu "  , "Zhuo " , "Pei "  , "Cheng ", "Hu "   , "Qi "   , "E "    ,  /*-- U+7420 .. U+7427 --*/
   "Kun "  , "Chang ", "Qi "   , "Beng " , "Wan "  , "Lu "   , "Cong " , "Guan " ,  /*-- U+7428 .. U+742F --*/
   "Yan "  , "Diao " , "Bei "  , "Lin "  , "Qin "  , "Pi "   , "Pa "   , "Que "  ,  /*-- U+7430 .. U+7437 --*/
   "Zhuo " , "Qin "  , "Fa "   , ""      , "Qiong ", "Du "   , "Jie "  , "Hun "  ,  /*-- U+7438 .. U+743F --*/
   "Yu "   , "Mao "  , "Mei "  , "Chun " , "Xuan " , "Ti "   , "Xing " , "Dai "  ,  /*-- U+7440 .. U+7447 --*/
   "Rou "  , "Min "  , "Zhen " , "Wei "  , "Ruan " , "Huan " , "Jie "  , "Chuan ",  /*-- U+7448 .. U+744F --*/
   "Jian " , "Zhuan ", "Yang " , "Lian " , "Quan " , "Xia "  , "Duan " , "Yuan " ,  /*-- U+7450 .. U+7457 --*/
   "Ye "   , "Nao "  , "Hu "   , "Ying " , "Yu "   , "Huang ", "Rui "  , "Se "   ,  /*-- U+7458 .. U+745F --*/
   "Liu "  , "Shi "  , "Rong " , "Suo "  , "Yao "  , "Wen "  , "Wu "   , "Jin "  ,  /*-- U+7460 .. U+7467 --*/
   "Jin "  , "Ying " , "Ma "   , "Tao "  , "Liu "  , "Tang " , "Li "   , "Lang " ,  /*-- U+7468 .. U+746F --*/
   "Gui "  , "Zhen " , "Qiang ", "Cuo "  , "Jue "  , "Zhao " , "Yao "  , "Ai "   ,  /*-- U+7470 .. U+7477 --*/
   "Bin "  , "Tu "   , "Chang ", "Kun "  , "Zhuan ", "Cong " , "Jin "  , "Yi "   ,  /*-- U+7478 .. U+747F --*/
   "Cui "  , "Cong " , "Qi "   , "Li "   , "Ying " , "Suo "  , "Qiu "  , "Xuan " ,  /*-- U+7480 .. U+7487 --*/
   "Ao "   , "Lian " , "Man "  , "Zhang ", "Yin "  , ""      , "Ying " , "Zhi "  ,  /*-- U+7488 .. U+748F --*/
   "Lu "   , "Wu "   , "Deng " , "Xiou " , "Zeng " , "Xun "  , "Qu "   , "Dang " ,  /*-- U+7490 .. U+7497 --*/
   "Lin "  , "Liao " , "Qiong ", "Su "   , "Huang ", "Gui "  , "Pu "   , "Jing " ,  /*-- U+7498 .. U+749F --*/
   "Fan "  , "Jin "  , "Liu "  , "Ji "   , ""      , "Jing " , "Ai "   , "Bi "   ,  /*-- U+74A0 .. U+74A7 --*/
   "Can "  , "Qu "   , "Zao "  , "Dang " , "Jiao " , "Gun "  , "Tan "  , "Hui "  ,  /*-- U+74A8 .. U+74AF --*/
   "Huan " , "Se "   , "Sui "  , "Tian " , ""      , "Yu "   , "Jin "  , "Lu "   ,  /*-- U+74B0 .. U+74B7 --*/
   "Bin "  , "Shou " , "Wen "  , "Zui "  , "Lan "  , "Xi "   , "Ji "   , "Xuan " ,  /*-- U+74B8 .. U+74BF --*/
   "Ruan " , "Huo "  , "Gai "  , "Lei "  , "Du "   , "Li "   , "Zhi "  , "Rou "  ,  /*-- U+74C0 .. U+74C7 --*/
   "Li "   , "Zan "  , "Qiong ", "Zhe "  , "Gui "  , "Sui "  , "La "   , "Long " ,  /*-- U+74C8 .. U+74CF --*/
   "Lu "   , "Li "   , "Zan "  , "Lan "  , "Ying " , "Mi "   , "Xiang ", "Xi "   ,  /*-- U+74D0 .. U+74D7 --*/
   "Guan " , "Dao "  , "Zan "  , "Huan " , "Gua "  , "Bo "   , "Die "  , "Bao "  ,  /*-- U+74D8 .. U+74DF --*/
   "Hu "   , "Zhi "  , "Piao " , "Ban "  , "Rang " , "Li "   , "Wa "   , "Dekaguramu ",  /*-- U+74E0 .. U+74E7 --*/
   "Jiang ", "Qian " , "Fan "  , "Pen "  , "Fang " , "Dan "  , "Weng " , "Ou "   ,  /*-- U+74E8 .. U+74EF --*/
   "Deshiguramu ", "Miriguramu ", "Thon " , "Hu "   , "Ling " , "Yi "   , "Ping " , "Ci "   ,  /*-- U+74F0 .. U+74F7 --*/
   "Hekutogura ", "Juan " , "Chang ", "Chi "  , "Sarake ", "Dang " , "Meng " , "Pou "  ,  /*-- U+74F8 .. U+74FF --*/
   "Zhui " , "Ping " , "Bian " , "Zhou " , "Zhen " , "Senchigura ", "Ci "   , "Ying " ,  /*-- U+7500 .. U+7507 --*/
   "Qi "   , "Xian " , "Lou "  , "Di "   , "Ou "   , "Meng " , "Zhuan ", "Peng " ,  /*-- U+7508 .. U+750F --*/
   "Lin "  , "Zeng " , "Wu "   , "Pi "   , "Dan "  , "Weng " , "Ying " , "Yan "  ,  /*-- U+7510 .. U+7517 --*/
   "Gan "  , "Dai "  , "Shen " , "Tian " , "Tian " , "Han "  , "Chang ", "Sheng ",  /*-- U+7518 .. U+751F --*/
   "Qing " , "Sheng ", "Chan " , "Chan " , "Rui "  , "Sheng ", "Su "   , "Sen "  ,  /*-- U+7520 .. U+7527 --*/
   "Yong " , "Shuai ", "Lu "   , "Fu "   , "Yong " , "Beng " , "Feng " , "Ning " ,  /*-- U+7528 .. U+752F --*/
   "Tian " , "You "  , "Jia "  , "Shen " , "Zha "  , "Dian " , "Fu "   , "Nan "  ,  /*-- U+7530 .. U+7537 --*/
   "Dian " , "Ping " , "Ting " , "Hua "  , "Ting " , "Quan " , "Zi "   , "Meng " ,  /*-- U+7538 .. U+753F --*/
   "Bi "   , "Qi "   , "Liu "  , "Xun "  , "Liu "  , "Chang ", "Mu "   , "Yun "  ,  /*-- U+7540 .. U+7547 --*/
   "Fan "  , "Fu "   , "Geng " , "Tian " , "Jie "  , "Jie "  , "Quan " , "Wei "  ,  /*-- U+7548 .. U+754F --*/
   "Fu "   , "Tian " , "Mu "   , "Tap "  , "Pan "  , "Jiang ", "Wa "   , "Da "   ,  /*-- U+7550 .. U+7557 --*/
   "Nan "  , "Liu "  , "Ben "  , "Zhen " , "Chu "  , "Mu "   , "Mu "   , "Ce "   ,  /*-- U+7558 .. U+755F --*/
   "Cen "  , "Gai "  , "Bi "   , "Da "   , "Zhi "  , "Lue "  , "Qi "   , "Lue "  ,  /*-- U+7560 .. U+7567 --*/
   "Pan "  , "Kesa " , "Fan "  , "Hua "  , "Yu "   , "Yu "   , "Mu "   , "Jun "  ,  /*-- U+7568 .. U+756F --*/
   "Yi "   , "Liu "  , "Yu "   , "Die "  , "Chou " , "Hua "  , "Dang " , "Chuo " ,  /*-- U+7570 .. U+7577 --*/
   "Ji "   , "Wan "  , "Jiang ", "Sheng ", "Chang ", "Tuan " , "Lei "  , "Ji "   ,  /*-- U+7578 .. U+757F --*/
   "Cha "  , "Liu "  , "Tatamu ", "Tuan " , "Lin "  , "Jiang ", "Jiang ", "Chou " ,  /*-- U+7580 .. U+7587 --*/
   "Bo "   , "Die "  , "Die "  , "Pi "   , "Nie "  , "Dan "  , "Shu "  , "Shu "  ,  /*-- U+7588 .. U+758F --*/
   "Zhi "  , "Yi "   , "Chuang ", "Nai "  , "Ding " , "Bi "   , "Jie "  , "Liao " ,  /*-- U+7590 .. U+7597 --*/
   "Gong " , "Ge "   , "Jiu "  , "Zhou " , "Xia "  , "Shan " , "Xu "   , "Nue "  ,  /*-- U+7598 .. U+759F --*/
   "Li "   , "Yang " , "Chen " , "You "  , "Ba "   , "Jie "  , "Jue "  , "Zhi "  ,  /*-- U+75A0 .. U+75A7 --*/
   "Xia "  , "Cui "  , "Bi "   , "Yi "   , "Li "   , "Zong " , "Chuang ", "Feng " ,  /*-- U+75A8 .. U+75AF --*/
   "Zhu "  , "Pao "  , "Pi "   , "Gan "  , "Ke "   , "Ci "   , "Xie "  , "Qi "   ,  /*-- U+75B0 .. U+75B7 --*/
   "Dan "  , "Zhen " , "Fa "   , "Zhi "  , "Teng " , "Ju "   , "Ji "   , "Fei "  ,  /*-- U+75B8 .. U+75BF --*/
   "Qu "   , "Dian " , "Jia "  , "Xian " , "Cha "  , "Bing " , "Ni "   , "Zheng ",  /*-- U+75C0 .. U+75C7 --*/
   "Yong " , "Jing " , "Quan " , "Chong ", "Tong " , "Yi "   , "Kai "  , "Wei "  ,  /*-- U+75C8 .. U+75CF --*/
   "Hui "  , "Duo "  , "Yang " , "Chi "  , "Zhi "  , "Hen "  , "Ya "   , "Mei "  ,  /*-- U+75D0 .. U+75D7 --*/
   "Dou "  , "Jing " , "Xiao " , "Tong " , "Tu "   , "Mang " , "Pi "   , "Xiao " ,  /*-- U+75D8 .. U+75DF --*/
   "Suan " , "Pu "   , "Li "   , "Zhi "  , "Cuo "  , "Duo "  , "Wu "   , "Sha "  ,  /*-- U+75E0 .. U+75E7 --*/
   "Lao "  , "Shou " , "Huan " , "Xian " , "Yi "   , "Peng " , "Zhang ", "Guan " ,  /*-- U+75E8 .. U+75EF --*/
   "Tan "  , "Fei "  , "Ma "   , "Lin "  , "Chi "  , "Ji "   , "Dian " , "An "   ,  /*-- U+75F0 .. U+75F7 --*/
   "Chi "  , "Bi "   , "Bei "  , "Min "  , "Gu "   , "Dui "  , "E "    , "Wei "  ,  /*-- U+75F8 .. U+75FF --*/
   "Yu "   , "Cui "  , "Ya "   , "Zhu "  , "Cu "   , "Dan "  , "Shen " , "Zhung ",  /*-- U+7600 .. U+7607 --*/
   "Ji "   , "Yu "   , "Hou "  , "Feng " , "La "   , "Yang " , "Shen " , "Tu "   ,  /*-- U+7608 .. U+760F --*/
   "Yu "   , "Gua "  , "Wen "  , "Huan " , "Ku "   , "Jia "  , "Yin "  , "Yi "   ,  /*-- U+7610 .. U+7617 --*/
   "Lu "   , "Sao "  , "Jue "  , "Chi "  , "Xi "   , "Guan " , "Yi "   , "Wen "  ,  /*-- U+7618 .. U+761F --*/
   "Ji "   , "Chuang ", "Ban "  , "Lei "  , "Liu "  , "Chai " , "Shou " , "Nue "  ,  /*-- U+7620 .. U+7627 --*/
   "Dian " , "Da "   , "Pie "  , "Tan "  , "Zhang ", "Biao " , "Shen " , "Cu "   ,  /*-- U+7628 .. U+762F --*/
   "Luo "  , "Yi "   , "Zong " , "Chou " , "Zhang ", "Zhai " , "Sou "  , "Suo "  ,  /*-- U+7630 .. U+7637 --*/
   "Que "  , "Diao " , "Lou "  , "Lu "   , "Mo "   , "Jin "  , "Yin "  , "Ying " ,  /*-- U+7638 .. U+763F --*/
   "Huang ", "Fu "   , "Liao " , "Long " , "Qiao " , "Liu "  , "Lao "  , "Xian " ,  /*-- U+7640 .. U+7647 --*/
   "Fei "  , "Dan "  , "Yin "  , "He "   , "Yan "  , "Ban "  , "Xian " , "Guan " ,  /*-- U+7648 .. U+764F --*/
   "Guai " , "Nong " , "Yu "   , "Wei "  , "Yi "   , "Yong " , "Pi "   , "Lei "  ,  /*-- U+7650 .. U+7657 --*/
   "Li "   , "Shu "  , "Dan "  , "Lin "  , "Dian " , "Lin "  , "Lai "  , "Pie "  ,  /*-- U+7658 .. U+765F --*/
   "Ji "   , "Chi "  , "Yang " , "Xian " , "Jie "  , "Zheng ", ""      , "Li "   ,  /*-- U+7660 .. U+7667 --*/
   "Huo "  , "Lai "  , "Shaku ", "Dian " , "Xian " , "Ying " , "Yin "  , "Qu "   ,  /*-- U+7668 .. U+766F --*/
   "Yong " , "Tan "  , "Dian " , "Luo "  , "Luan " , "Luan " , "Bo "   , ""      ,  /*-- U+7670 .. U+7677 --*/
   "Gui "  , "Po "   , "Fa "   , "Deng " , "Fa "   , "Bai "  , "Bai "  , "Qie "  ,  /*-- U+7678 .. U+767F --*/
   "Bi "   , "Zao "  , "Zao "  , "Mao "  , "De "   , "Pa "   , "Jie "  , "Huang ",  /*-- U+7680 .. U+7687 --*/
   "Gui "  , "Ci "   , "Ling " , "Gao "  , "Mo "   , "Ji "   , "Jiao " , "Peng " ,  /*-- U+7688 .. U+768F --*/
   "Gao "  , "Ai "   , "E "    , "Hao "  , "Han "  , "Bi "   , "Wan "  , "Chou " ,  /*-- U+7690 .. U+7697 --*/
   "Qian " , "Xi "   , "Ai "   , "Jiong ", "Hao "  , "Huang ", "Hao "  , "Ze "   ,  /*-- U+7698 .. U+769F --*/
   "Cui "  , "Hao "  , "Xiao " , "Ye "   , "Po "   , "Hao "  , "Jiao " , "Ai "   ,  /*-- U+76A0 .. U+76A7 --*/
   "Xing " , "Huang ", "Li "   , "Piao " , "He "   , "Jiao " , "Pi "   , "Gan "  ,  /*-- U+76A8 .. U+76AF --*/
   "Pao "  , "Zhou " , "Jun "  , "Qiu "  , "Cun "  , "Que "  , "Zha "  , "Gu "   ,  /*-- U+76B0 .. U+76B7 --*/
   "Jun "  , "Jun "  , "Zhou " , "Zha "  , "Gu "   , "Zhan " , "Du "   , "Min "  ,  /*-- U+76B8 .. U+76BF --*/
   "Qi "   , "Ying " , "Yu "   , "Bei "  , "Zhao " , "Zhong ", "Pen "  , "He "   ,  /*-- U+76C0 .. U+76C7 --*/
   "Ying " , "He "   , "Yi "   , "Bo "   , "Wan "  , "He "   , "Ang "  , "Zhan " ,  /*-- U+76C8 .. U+76CF --*/
   "Yan "  , "Jian " , "He "   , "Yu "   , "Kui "  , "Fan "  , "Gai "  , "Dao "  ,  /*-- U+76D0 .. U+76D7 --*/
   "Pan "  , "Fu "   , "Qiu "  , "Sheng ", "Dao "  , "Lu "   , "Zhan " , "Meng " ,  /*-- U+76D8 .. U+76DF --*/
   "Li "   , "Jin "  , "Xu "   , "Jian " , "Pan "  , "Guan " , "An "   , "Lu "   ,  /*-- U+76E0 .. U+76E7 --*/
   "Shu "  , "Zhou " , "Dang " , "An "   , "Gu "   , "Li "   , "Mu "   , "Cheng ",  /*-- U+76E8 .. U+76EF --*/
   "Gan "  , "Xu "   , "Mang " , "Mang " , "Zhi "  , "Qi "   , "Ruan " , "Tian " ,  /*-- U+76F0 .. U+76F7 --*/
   "Xiang ", "Dun "  , "Xin "  , "Xi "   , "Pan "  , "Feng " , "Dun "  , "Min "  ,  /*-- U+76F8 .. U+76FF --*/
   "Ming " , "Sheng ", "Shi "  , "Yun "  , "Mian " , "Pan "  , "Fang " , "Miao " ,  /*-- U+7700 .. U+7707 --*/
   "Dan "  , "Mei "  , "Mao "  , "Kan "  , "Xian " , "Ou "   , "Shi "  , "Yang " ,  /*-- U+7708 .. U+770F --*/
   "Zheng ", "Yao "  , "Shen " , "Huo "  , "Da "   , "Zhen " , "Kuang ", "Ju "   ,  /*-- U+7710 .. U+7717 --*/
   "Shen " , "Chi "  , "Sheng ", "Mei "  , "Mo "   , "Zhu "  , "Zhen " , "Zhen " ,  /*-- U+7718 .. U+771F --*/
   "Mian " , "Di "   , "Yuan " , "Die "  , "Yi "   , "Zi "   , "Zi "   , "Chao " ,  /*-- U+7720 .. U+7727 --*/
   "Zha "  , "Xuan " , "Bing " , "Mi "   , "Long " , "Sui "  , "Dong " , "Mi "   ,  /*-- U+7728 .. U+772F --*/
   "Die "  , "Yi "   , "Er "   , "Ming " , "Xuan " , "Chi "  , "Kuang ", "Juan " ,  /*-- U+7730 .. U+7737 --*/
   "Mou "  , "Zhen " , "Tiao " , "Yang " , "Yan "  , "Mo "   , "Zhong ", "Mai "  ,  /*-- U+7738 .. U+773F --*/
   "Zhao " , "Zheng ", "Mei "  , "Jun "  , "Shao " , "Han "  , "Huan " , "Di "   ,  /*-- U+7740 .. U+7747 --*/
   "Cheng ", "Cuo "  , "Juan " , "E "    , "Wan "  , "Xian " , "Xi "   , "Kun "  ,  /*-- U+7748 .. U+774F --*/
   "Lai "  , "Jian " , "Shan " , "Tian " , "Hun "  , "Wan "  , "Ling " , "Shi "  ,  /*-- U+7750 .. U+7757 --*/
   "Qiong ", "Lie "  , "Yai "  , "Jing " , "Zheng ", "Li "   , "Lai "  , "Sui "  ,  /*-- U+7758 .. U+775F --*/
   "Juan " , "Shui " , "Sui "  , "Du "   , "Bi "   , "Bi "   , "Mu "   , "Hun "  ,  /*-- U+7760 .. U+7767 --*/
   "Ni "   , "Lu "   , "Yi "   , "Jie "  , "Cai "  , "Zhou " , "Yu "   , "Hun "  ,  /*-- U+7768 .. U+776F --*/
   "Ma "   , "Xia "  , "Xing " , "Xi "   , "Gun "  , "Cai "  , "Chun " , "Jian " ,  /*-- U+7770 .. U+7777 --*/
   "Mei "  , "Du "   , "Hou "  , "Xuan " , "Ti "   , "Kui "  , "Gao "  , "Rui "  ,  /*-- U+7778 .. U+777F --*/
   "Mou "  , "Xu "   , "Fa "   , "Wen "  , "Miao " , "Chou " , "Kui "  , "Mi "   ,  /*-- U+7780 .. U+7787 --*/
   "Weng " , "Kou "  , "Dang " , "Chen " , "Ke "   , "Sou "  , "Xia "  , "Qiong ",  /*-- U+7788 .. U+778F --*/
   "Mao "  , "Ming " , "Man "  , "Shui " , "Ze "   , "Zhang ", "Yi "   , "Diao " ,  /*-- U+7790 .. U+7797 --*/
   "Ou "   , "Mo "   , "Shun " , "Cong " , "Lou "  , "Chi "  , "Man "  , "Piao " ,  /*-- U+7798 .. U+779F --*/
   "Cheng ", "Ji "   , "Meng " , ""      , "Run "  , "Pie "  , "Xi "   , "Qiao " ,  /*-- U+77A0 .. U+77A7 --*/
   "Pu "   , "Zhu "  , "Deng " , "Shen " , "Shun " , "Liao " , "Che "  , "Xian " ,  /*-- U+77A8 .. U+77AF --*/
   "Kan "  , "Ye "   , "Xu "   , "Tong " , "Mou "  , "Lin "  , "Kui "  , "Xian " ,  /*-- U+77B0 .. U+77B7 --*/
   "Ye "   , "Ai "   , "Hui "  , "Zhan " , "Jian " , "Gu "   , "Zhao " , "Qu "   ,  /*-- U+77B8 .. U+77BF --*/
   "Wei "  , "Chou " , "Sao "  , "Ning " , "Xun "  , "Yao "  , "Huo "  , "Meng " ,  /*-- U+77C0 .. U+77C7 --*/
   "Mian " , "Bin "  , "Mian " , "Li "   , "Kuang ", "Jue "  , "Xuan " , "Mian " ,  /*-- U+77C8 .. U+77CF --*/
   "Huo "  , "Lu "   , "Meng " , "Long " , "Guan " , "Man "  , "Xi "   , "Chu "  ,  /*-- U+77D0 .. U+77D7 --*/
   "Tang " , "Kan "  , "Zhu "  , "Mao "  , "Jin "  , "Lin "  , "Yu "   , "Shuo " ,  /*-- U+77D8 .. U+77DF --*/
   "Ce "   , "Jue "  , "Shi "  , "Yi "   , "Shen " , "Zhi "  , "Hou "  , "Shen " ,  /*-- U+77E0 .. U+77E7 --*/
   "Ying " , "Ju "   , "Zhou " , "Jiao " , "Cuo "  , "Duan " , "Ai "   , "Jiao " ,  /*-- U+77E8 .. U+77EF --*/
   "Zeng " , "Huo "  , "Bai "  , "Shi "  , "Ding " , "Qi "   , "Ji "   , "Zi "   ,  /*-- U+77F0 .. U+77F7 --*/
   "Gan "  , "Wu "   , "Tuo "  , "Ku "   , "Qiang ", "Xi "   , "Fan "  , "Kuang ",  /*-- U+77F8 .. U+77FF --*/
   "Dang " , "Ma "   , "Sha "  , "Dan "  , "Jue "  , "Li "   , "Fu "   , "Min "  ,  /*-- U+7800 .. U+7807 --*/
   "Nuo "  , "Huo "  , "Kang " , "Zhi "  , "Qi "   , "Kan "  , "Jie "  , "Fen "  ,  /*-- U+7808 .. U+780F --*/
   "E "    , "Ya "   , "Pi "   , "Zhe "  , "Yan "  , "Sui "  , "Zhuan ", "Che "  ,  /*-- U+7810 .. U+7817 --*/
   "Dun "  , "Pan "  , "Yan "  , ""      , "Feng " , "Fa "   , "Mo "   , "Zha "  ,  /*-- U+7818 .. U+781F --*/
   "Qu "   , "Yu "   , "Luo "  , "Tuo "  , "Tuo "  , "Di "   , "Zhai " , "Zhen " ,  /*-- U+7820 .. U+7827 --*/
   "Ai "   , "Fei "  , "Mu "   , "Zhu "  , "Li "   , "Bian " , "Nu "   , "Ping " ,  /*-- U+7828 .. U+782F --*/
   "Peng " , "Ling " , "Pao "  , "Le "   , "Po "   , "Bo "   , "Po "   , "Shen " ,  /*-- U+7830 .. U+7837 --*/
   "Za "   , "Nuo "  , "Li "   , "Long " , "Tong " , ""      , "Li "   , "Aragane ",  /*-- U+7838 .. U+783F --*/
   "Chu "  , "Keng " , "Quan " , "Zhu "  , "Kuang ", "Huo "  , "E "    , "Nao "  ,  /*-- U+7840 .. U+7847 --*/
   "Jia "  , "Lu "   , "Wei "  , "Ai "   , "Luo "  , "Ken "  , "Xing " , "Yan "  ,  /*-- U+7848 .. U+784F --*/
   "Tong " , "Peng " , "Xi "   , ""      , "Hong " , "Shuo " , "Xia "  , "Qiao " ,  /*-- U+7850 .. U+7857 --*/
   ""      , "Wei "  , "Qiao " , ""      , "Keng " , "Xiao " , "Que "  , "Chan " ,  /*-- U+7858 .. U+785F --*/
   "Lang " , "Hong " , "Yu "   , "Xiao " , "Xia "  , "Mang " , "Long " , "Iong " ,  /*-- U+7860 .. U+7867 --*/
   "Che "  , "Che "  , "E "    , "Liu "  , "Ying " , "Mang " , "Que "  , "Yan "  ,  /*-- U+7868 .. U+786F --*/
   "Sha "  , "Kun "  , "Yu "   , ""      , "Kaki " , "Lu "   , "Chen " , "Jian " ,  /*-- U+7870 .. U+7877 --*/
   "Nue "  , "Song " , "Zhuo " , "Keng " , "Peng " , "Yan "  , "Zhui " , "Kong " ,  /*-- U+7878 .. U+787F --*/
   "Ceng " , "Qi "   , "Zong " , "Qing " , "Lin "  , "Jun "  , "Bo "   , "Ding " ,  /*-- U+7880 .. U+7887 --*/
   "Min "  , "Diao " , "Jian " , "He "   , "Lu "   , "Ai "   , "Sui "  , "Que "  ,  /*-- U+7888 .. U+788F --*/
   "Ling " , "Bei "  , "Yin "  , "Dui "  , "Wu "   , "Qi "   , "Lun "  , "Wan "  ,  /*-- U+7890 .. U+7897 --*/
   "Dian " , "Gang " , "Pei "  , "Qi "   , "Chen " , "Ruan " , "Yan "  , "Die "  ,  /*-- U+7898 .. U+789F --*/
   "Ding " , "Du "   , "Tuo "  , "Jie "  , "Ying " , "Bian " , "Ke "   , "Bi "   ,  /*-- U+78A0 .. U+78A7 --*/
   "Wei "  , "Shuo " , "Zhen " , "Duan " , "Xia "  , "Dang " , "Ti "   , "Nao "  ,  /*-- U+78A8 .. U+78AF --*/
   "Peng " , "Jian " , "Di "   , "Tan "  , "Cha "  , "Seki " , "Qi "   , ""      ,  /*-- U+78B0 .. U+78B7 --*/
   "Feng " , "Xuan " , "Que "  , "Que "  , "Ma "   , "Gong " , "Nian " , "Su "   ,  /*-- U+78B8 .. U+78BF --*/
   "E "    , "Ci "   , "Liu "  , "Si "   , "Tang " , "Bang " , "Hua "  , "Pi "   ,  /*-- U+78C0 .. U+78C7 --*/
   "Wei "  , "Sang " , "Lei "  , "Cuo "  , "Zhen " , "Xia "  , "Qi "   , "Lian " ,  /*-- U+78C8 .. U+78CF --*/
   "Pan "  , "Wei "  , "Yun "  , "Dui "  , "Zhe "  , "Ke "   , "La "   , ""      ,  /*-- U+78D0 .. U+78D7 --*/
   "Qing " , "Gun "  , "Zhuan ", "Chan " , "Qi "   , "Ao "   , "Peng " , "Lu "   ,  /*-- U+78D8 .. U+78DF --*/
   "Lu "   , "Kan "  , "Qiang ", "Chen " , "Yin "  , "Lei "  , "Biao " , "Qi "   ,  /*-- U+78E0 .. U+78E7 --*/
   "Mo "   , "Qi "   , "Cui "  , "Zong " , "Qing " , "Chuo " , ""      , "Ji "   ,  /*-- U+78E8 .. U+78EF --*/
   "Shan " , "Lao "  , "Qu "   , "Zeng " , "Deng " , "Jian " , "Xi "   , "Lin "  ,  /*-- U+78F0 .. U+78F7 --*/
   "Ding " , "Dian " , "Huang ", "Pan "  , "Za "   , "Qiao " , "Di "   , "Li "   ,  /*-- U+78F8 .. U+78FF --*/
   "Tani " , "Jiao " , ""      , "Zhang ", "Qiao " , "Dun "  , "Xian " , "Yu "   ,  /*-- U+7900 .. U+7907 --*/
   "Zhui " , "He "   , "Huo "  , "Zhai " , "Lei "  , "Ke "   , "Chu "  , "Ji "   ,  /*-- U+7908 .. U+790F --*/
   "Que "  , "Dang " , "Yi "   , "Jiang ", "Pi "   , "Pi "   , "Yu "   , "Pin "  ,  /*-- U+7910 .. U+7917 --*/
   "Qi "   , "Ai "   , "Kai "  , "Jian " , "Yu "   , "Ruan " , "Meng " , "Pao "  ,  /*-- U+7918 .. U+791F --*/
   "Ci "   , ""      , ""      , "Mie "  , "Ca "   , "Xian " , "Kuang ", "Lei "  ,  /*-- U+7920 .. U+7927 --*/
   "Lei "  , "Zhi "  , "Li "   , "Li "   , "Fan "  , "Que "  , "Pao "  , "Ying " ,  /*-- U+7928 .. U+792F --*/
   "Li "   , "Long " , "Long " , "Mo "   , "Bo "   , "Shuang ", "Guan " , "Lan "  ,  /*-- U+7930 .. U+7937 --*/
   "Zan "  , "Yan "  , "Shi "  , "Shi "  , "Li "   , "Reng " , "She "  , "Yue "  ,  /*-- U+7938 .. U+793F --*/
   "Si "   , "Qi "   , "Ta "   , "Ma "   , "Xie "  , "Xian " , "Xian " , "Zhi "  ,  /*-- U+7940 .. U+7947 --*/
   "Qi "   , "Zhi "  , "Beng " , "Dui "  , "Zhong ", ""      , "Yi "   , "Shi "  ,  /*-- U+7948 .. U+794F --*/
   "You "  , "Zhi "  , "Tiao " , "Fu "   , "Fu "   , "Mi "   , "Zu "   , "Zhi "  ,  /*-- U+7950 .. U+7957 --*/
   "Suan " , "Mei "  , "Zuo "  , "Qu "   , "Hu "   , "Zhu "  , "Shen " , "Sui "  ,  /*-- U+7958 .. U+795F --*/
   "Ci "   , "Chai " , "Mi "   , "Lu "   , "Yu "   , "Xiang ", "Wu "   , "Tiao " ,  /*-- U+7960 .. U+7967 --*/
   "Piao " , "Zhu "  , "Gui "  , "Xia "  , "Zhi "  , "Ji "   , "Gao "  , "Zhen " ,  /*-- U+7968 .. U+796F --*/
   "Gao "  , "Shui " , "Jin "  , "Chen " , "Gai "  , "Kun "  , "Di "   , "Dao "  ,  /*-- U+7970 .. U+7977 --*/
   "Huo "  , "Tao "  , "Qi "   , "Gu "   , "Guan " , "Zui "  , "Ling " , "Lu "   ,  /*-- U+7978 .. U+797F --*/
   "Bing " , "Jin "  , "Dao "  , "Zhi "  , "Lu "   , "Shan " , "Bei "  , "Zhe "  ,  /*-- U+7980 .. U+7987 --*/
   "Hui "  , "You "  , "Xi "   , "Yin "  , "Zi "   , "Huo "  , "Zhen " , "Fu "   ,  /*-- U+7988 .. U+798F --*/
   "Yuan " , "Wu "   , "Xian " , "Yang " , "Ti "   , "Yi "   , "Mei "  , "Si "   ,  /*-- U+7990 .. U+7997 --*/
   "Di "   , ""      , "Zhuo " , "Zhen " , "Yong " , "Ji "   , "Gao "  , "Tang " ,  /*-- U+7998 .. U+799F --*/
   "Si "   , "Ma "   , "Ta "   , ""      , "Xuan " , "Qi "   , "Yu "   , "Xi "   ,  /*-- U+79A0 .. U+79A7 --*/
   "Ji "   , "Si "   , "Chan " , "Tan "  , "Kuai " , "Sui "  , "Li "   , "Nong " ,  /*-- U+79A8 .. U+79AF --*/
   "Ni "   , "Dao "  , "Li "   , "Rang " , "Yue "  , "Ti "   , "Zan "  , "Lei "  ,  /*-- U+79B0 .. U+79B7 --*/
   "Rou "  , "Yu "   , "Yu "   , "Chi "  , "Xie "  , "Qin "  , "He "   , "Tu "   ,  /*-- U+79B8 .. U+79BF --*/
   "Xiu "  , "Si "   , "Ren "  , "Tu "   , "Zi "   , "Cha "  , "Gan "  , "Yi "   ,  /*-- U+79C0 .. U+79C7 --*/
   "Xian " , "Bing " , "Nian " , "Qiu "  , "Qiu "  , "Chong ", "Fen "  , "Hao "  ,  /*-- U+79C8 .. U+79CF --*/
   "Yun "  , "Ke "   , "Miao " , "Zhi "  , "Geng " , "Bi "   , "Zhi "  , "Yu "   ,  /*-- U+79D0 .. U+79D7 --*/
   "Mi "   , "Ku "   , "Ban "  , "Pi "   , "Ni "   , "Li "   , "You "  , "Zu "   ,  /*-- U+79D8 .. U+79DF --*/
   "Pi "   , "Ba "   , "Ling " , "Mo "   , "Cheng ", "Nian " , "Qin "  , "Yang " ,  /*-- U+79E0 .. U+79E7 --*/
   "Zuo "  , "Zhi "  , "Zhi "  , "Shu "  , "Ju "   , "Zi "   , "Huo "  , "Ji "   ,  /*-- U+79E8 .. U+79EF --*/
   "Cheng ", "Tong " , "Zhi "  , "Huo "  , "He "   , "Yin "  , "Zi "   , "Zhi "  ,  /*-- U+79F0 .. U+79F7 --*/
   "Jie "  , "Ren "  , "Du "   , "Yi "   , "Zhu "  , "Hui "  , "Nong " , "Fu "   ,  /*-- U+79F8 .. U+79FF --*/
   "Xi "   , "Kao "  , "Lang " , "Fu "   , "Ze "   , "Shui " , "Lu "   , "Kun "  ,  /*-- U+7A00 .. U+7A07 --*/
   "Gan "  , "Geng " , "Ti "   , "Cheng ", "Tu "   , "Shao " , "Shui " , "Ya "   ,  /*-- U+7A08 .. U+7A0F --*/
   "Lun "  , "Lu "   , "Gu "   , "Zuo "  , "Ren "  , "Zhun " , "Bang " , "Bai "  ,  /*-- U+7A10 .. U+7A17 --*/
   "Ji "   , "Zhi "  , "Zhi "  , "Kun "  , "Leng " , "Peng " , "Ke "   , "Bing " ,  /*-- U+7A18 .. U+7A1F --*/
   "Chou " , "Zu "   , "Yu "   , "Su "   , "Lue "  , ""      , "Yi "   , "Xi "   ,  /*-- U+7A20 .. U+7A27 --*/
   "Bian " , "Ji "   , "Fu "   , "Bi "   , "Nuo "  , "Jie "  , "Zhong ", "Zong " ,  /*-- U+7A28 .. U+7A2F --*/
   "Xu "   , "Cheng ", "Dao "  , "Wen "  , "Lian " , "Zi "   , "Yu "   , "Ji "   ,  /*-- U+7A30 .. U+7A37 --*/
   "Xu "   , "Zhen " , "Zhi "  , "Dao "  , "Jia "  , "Ji "   , "Gao "  , "Gao "  ,  /*-- U+7A38 .. U+7A3F --*/
   "Gu "   , "Rong " , "Sui "  , "You "  , "Ji "   , "Kang " , "Mu "   , "Shan " ,  /*-- U+7A40 .. U+7A47 --*/
   "Men "  , "Zhi "  , "Ji "   , "Lu "   , "Su "   , "Ji "   , "Ying " , "Wen "  ,  /*-- U+7A48 .. U+7A4F --*/
   "Qiu "  , "Se "   , ""      , "Yi "   , "Huang ", "Qie "  , "Ji "   , "Sui "  ,  /*-- U+7A50 .. U+7A57 --*/
   "Xiao " , "Pu "   , "Jiao " , "Zhuo " , "Tong " , "Sai "  , "Lu "   , "Sui "  ,  /*-- U+7A58 .. U+7A5F --*/
   "Nong " , "Se "   , "Hui "  , "Rang " , "Nuo "  , "Yu "   , "Bin "  , "Ji "   ,  /*-- U+7A60 .. U+7A67 --*/
   "Tui "  , "Wen "  , "Cheng ", "Huo "  , "Gong " , "Lu "   , "Biao " , ""      ,  /*-- U+7A68 .. U+7A6F --*/
   "Rang " , "Zhuo " , "Li "   , "Zan "  , "Xue "  , "Wa "   , "Jiu "  , "Qiong ",  /*-- U+7A70 .. U+7A77 --*/
   "Xi "   , "Qiong ", "Kong " , "Yu "   , "Sen "  , "Jing " , "Yao "  , "Chuan ",  /*-- U+7A78 .. U+7A7F --*/
   "Zhun " , "Tu "   , "Lao "  , "Qie "  , "Zhai " , "Yao "  , "Bian " , "Bao "  ,  /*-- U+7A80 .. U+7A87 --*/
   "Yao "  , "Bing " , "Wa "   , "Zhu "  , "Jiao " , "Qiao " , "Diao " , "Wu "   ,  /*-- U+7A88 .. U+7A8F --*/
   "Gui "  , "Yao "  , "Zhi "  , "Chuang ", "Yao "  , "Tiao " , "Jiao " , "Chuang ",  /*-- U+7A90 .. U+7A97 --*/
   "Jiong ", "Xiao " , "Cheng ", "Kou "  , "Cuan " , "Wo "   , "Dan "  , "Ku "   ,  /*-- U+7A98 .. U+7A9F --*/
   "Ke "   , "Zhui " , "Xu "   , "Su "   , "Guan " , "Kui "  , "Dou "  , ""      ,  /*-- U+7AA0 .. U+7AA7 --*/
   "Yin "  , "Wo "   , "Wa "   , "Ya "   , "Yu "   , "Ju "   , "Qiong ", "Yao "  ,  /*-- U+7AA8 .. U+7AAF --*/
   "Yao "  , "Tiao " , "Chao " , "Yu "   , "Tian " , "Diao " , "Ju "   , "Liao " ,  /*-- U+7AB0 .. U+7AB7 --*/
   "Xi "   , "Wu "   , "Kui "  , "Chuang ", "Zhao " , ""      , "Kuan " , "Long " ,  /*-- U+7AB8 .. U+7ABF --*/
   "Cheng ", "Cui "  , "Piao " , "Zao "  , "Cuan " , "Qiao " , "Qiong ", "Dou "  ,  /*-- U+7AC0 .. U+7AC7 --*/
   "Zao "  , "Long " , "Qie "  , "Li "   , "Chu "  , "Shi "  , "Fou "  , "Qian " ,  /*-- U+7AC8 .. U+7ACF --*/
   "Chu "  , "Hong " , "Qi "   , "Qian " , "Gong " , "Shi "  , "Shu "  , "Miao " ,  /*-- U+7AD0 .. U+7AD7 --*/
   "Ju "   , "Zhan " , "Zhu "  , "Ling " , "Long " , "Bing " , "Jing " , "Jing " ,  /*-- U+7AD8 .. U+7ADF --*/
   "Zhang ", "Yi "   , "Si "   , "Jun "  , "Hong " , "Tong " , "Song " , "Jing " ,  /*-- U+7AE0 .. U+7AE7 --*/
   "Diao " , "Yi "   , "Shu "  , "Jing " , "Qu "   , "Jie "  , "Ping " , "Duan " ,  /*-- U+7AE8 .. U+7AEF --*/
   "Shao " , "Zhuan ", "Ceng " , "Deng " , "Cui "  , "Huai " , "Jing " , "Kan "  ,  /*-- U+7AF0 .. U+7AF7 --*/
   "Jing " , "Zhu "  , "Zhu "  , "Le "   , "Peng " , "Yu "   , "Chi "  , "Gan "  ,  /*-- U+7AF8 .. U+7AFF --*/
   "Mang " , "Zhu "  , "Utsubo ", "Du "   , "Ji "   , "Xiao " , "Ba "   , "Suan " ,  /*-- U+7B00 .. U+7B07 --*/
   "Ji "   , "Zhen " , "Zhao " , "Sun "  , "Ya "   , "Zhui " , "Yuan " , "Hu "   ,  /*-- U+7B08 .. U+7B0F --*/
   "Gang " , "Xiao " , "Cen "  , "Pi "   , "Bi "   , "Jian " , "Yi "   , "Dong " ,  /*-- U+7B10 .. U+7B17 --*/
   "Shan " , "Sheng ", "Xia "  , "Di "   , "Zhu "  , "Na "   , "Chi "  , "Gu "   ,  /*-- U+7B18 .. U+7B1F --*/
   "Li "   , "Qie "  , "Min "  , "Bao "  , "Tiao " , "Si "   , "Fu "   , "Ce "   ,  /*-- U+7B20 .. U+7B27 --*/
   "Ben "  , "Pei "  , "Da "   , "Zi "   , "Di "   , "Ling " , "Ze "   , "Nu "   ,  /*-- U+7B28 .. U+7B2F --*/
   "Fu "   , "Gou "  , "Fan "  , "Jia "  , "Ge "   , "Fan "  , "Shi "  , "Mao "  ,  /*-- U+7B30 .. U+7B37 --*/
   "Po "   , "Sey "  , "Jian " , "Qiong ", "Long " , "Souke ", "Bian " , "Luo "  ,  /*-- U+7B38 .. U+7B3F --*/
   "Gui "  , "Qu "   , "Chi "  , "Yin "  , "Yao "  , "Xian " , "Bi "   , "Qiong ",  /*-- U+7B40 .. U+7B47 --*/
   "Gua "  , "Deng " , "Jiao " , "Jin "  , "Quan " , "Sun "  , "Ru "   , "Fa "   ,  /*-- U+7B48 .. U+7B4F --*/
   "Kuang ", "Zhu "  , "Tong " , "Ji "   , "Da "   , "Xing " , "Ce "   , "Zhong ",  /*-- U+7B50 .. U+7B57 --*/
   "Kou "  , "Lai "  , "Bi "   , "Shai " , "Dang " , "Zheng ", "Ce "   , "Fu "   ,  /*-- U+7B58 .. U+7B5F --*/
   "Yun "  , "Tu "   , "Pa "   , "Li "   , "Lang " , "Ju "   , "Guan " , "Jian " ,  /*-- U+7B60 .. U+7B67 --*/
   "Han "  , "Tong " , "Xia "  , "Zhi "  , "Cheng ", "Suan " , "Shi "  , "Zhu "  ,  /*-- U+7B68 .. U+7B6F --*/
   "Zuo "  , "Xiao " , "Shao " , "Ting " , "Ce "   , "Yan "  , "Gao "  , "Kuai " ,  /*-- U+7B70 .. U+7B77 --*/
   "Gan "  , "Chou " , "Kago " , "Gang " , "Yun "  , "O "    , "Qian " , "Xiao " ,  /*-- U+7B78 .. U+7B7F --*/
   "Jian " , "Pu "   , "Lai "  , "Zou "  , "Bi "   , "Bi "   , "Bi "   , "Ge "   ,  /*-- U+7B80 .. U+7B87 --*/
   "Chi "  , "Guai " , "Yu "   , "Jian " , "Zhao " , "Gu "   , "Chi "  , "Zheng ",  /*-- U+7B88 .. U+7B8F --*/
   "Jing " , "Sha "  , "Zhou " , "Lu "   , "Bo "   , "Ji "   , "Lin "  , "Suan " ,  /*-- U+7B90 .. U+7B97 --*/
   "Jun "  , "Fu "   , "Zha "  , "Gu "   , "Kong " , "Qian " , "Quan " , "Jun "  ,  /*-- U+7B98 .. U+7B9F --*/
   "Chui " , "Guan " , "Yuan " , "Ce "   , "Ju "   , "Bo "   , "Ze "   , "Qie "  ,  /*-- U+7BA0 .. U+7BA7 --*/
   "Tuo "  , "Luo "  , "Dan "  , "Xiao " , "Ruo "  , "Jian " , "Xuan " , "Bian " ,  /*-- U+7BA8 .. U+7BAF --*/
   "Sun "  , "Xiang ", "Xian " , "Ping " , "Zhen " , "Sheng ", "Hu "   , "Shi "  ,  /*-- U+7BB0 .. U+7BB7 --*/
   "Zhu "  , "Yue "  , "Chun " , "Lu "   , "Wu "   , "Dong " , "Xiao " , "Ji "   ,  /*-- U+7BB8 .. U+7BBF --*/
   "Jie "  , "Huang ", "Xing " , "Mei "  , "Fan "  , "Chui " , "Zhuan ", "Pian " ,  /*-- U+7BC0 .. U+7BC7 --*/
   "Feng " , "Zhu "  , "Hong " , "Qie "  , "Hou "  , "Qiu "  , "Miao " , "Qian " ,  /*-- U+7BC8 .. U+7BCF --*/
   ""      , "Kui "  , "Sik "  , "Lou "  , "Yun "  , "He "   , "Tang " , "Yue "  ,  /*-- U+7BD0 .. U+7BD7 --*/
   "Chou " , "Gao "  , "Fei "  , "Ruo "  , "Zheng ", "Gou "  , "Nie "  , "Qian " ,  /*-- U+7BD8 .. U+7BDF --*/
   "Xiao " , "Cuan " , "Gong " , "Pang " , "Du "   , "Li "   , "Bi "   , "Zhuo " ,  /*-- U+7BE0 .. U+7BE7 --*/
   "Chu "  , "Shai " , "Chi "  , "Zhu "  , "Qiang ", "Long " , "Lan "  , "Jian " ,  /*-- U+7BE8 .. U+7BEF --*/
   "Bu "   , "Li "   , "Hui "  , "Bi "   , "Di "   , "Cong " , "Yan "  , "Peng " ,  /*-- U+7BF0 .. U+7BF7 --*/
   "Sen "  , "Zhuan ", "Pai "  , "Piao " , "Dou "  , "Yu "   , "Mie "  , "Zhuan ",  /*-- U+7BF8 .. U+7BFF --*/
   "Ze "   , "Xi "   , "Guo "  , "Yi "   , "Hu "   , "Chan " , "Kou "  , "Cu "   ,  /*-- U+7C00 .. U+7C07 --*/
   "Ping " , "Chou " , "Ji "   , "Gui "  , "Su "   , "Lou "  , "Zha "  , "Lu "   ,  /*-- U+7C08 .. U+7C0F --*/
   "Nian " , "Suo "  , "Cuan " , "Sasara ", "Suo "  , "Le "   , "Duan " , "Yana " ,  /*-- U+7C10 .. U+7C17 --*/
   "Xiao " , "Bo "   , "Mi "   , "Si "   , "Dang " , "Liao " , "Dan "  , "Dian " ,  /*-- U+7C18 .. U+7C1F --*/
   "Fu "   , "Jian " , "Min "  , "Kui "  , "Dai "  , "Qiao " , "Deng " , "Huang ",  /*-- U+7C20 .. U+7C27 --*/
   "Sun "  , "Lao "  , "Zan "  , "Xiao " , "Du "   , "Shi "  , "Zan "  , ""      ,  /*-- U+7C28 .. U+7C2F --*/
   "Pai "  , "Hata " , "Pai "  , "Gan "  , "Ju "   , "Du "   , "Lu "   , "Yan "  ,  /*-- U+7C30 .. U+7C37 --*/
   "Bo "   , "Dang " , "Sai "  , "Ke "   , "Long " , "Qian " , "Lian " , "Bo "   ,  /*-- U+7C38 .. U+7C3F --*/
   "Zhou " , "Lai "  , ""      , "Lan "  , "Kui "  , "Yu "   , "Yue "  , "Hao "  ,  /*-- U+7C40 .. U+7C47 --*/
   "Zhen " , "Tai "  , "Ti "   , "Mi "   , "Chou " , "Ji "   , ""      , "Hata " ,  /*-- U+7C48 .. U+7C4F --*/
   "Teng " , "Zhuan ", "Zhou " , "Fan "  , "Sou "  , "Zhou " , "Kuji " , "Zhuo " ,  /*-- U+7C50 .. U+7C57 --*/
   "Teng " , "Lu "   , "Lu "   , "Jian " , "Tuo "  , "Ying " , "Yu "   , "Lai "  ,  /*-- U+7C58 .. U+7C5F --*/
   "Long " , "Shinshi ", "Lian " , "Lan "  , "Qian " , "Yue "  , "Zhong ", "Qu "   ,  /*-- U+7C60 .. U+7C67 --*/
   "Lian " , "Bian " , "Duan " , "Zuan " , "Li "   , "Si "   , "Luo "  , "Ying " ,  /*-- U+7C68 .. U+7C6F --*/
   "Yue "  , "Zhuo " , "Xu "   , "Mi "   , "Di "   , "Fan "  , "Shen " , "Zhe "  ,  /*-- U+7C70 .. U+7C77 --*/
   "Shen " , "Nu "   , "Xie "  , "Lei "  , "Xian " , "Zi "   , "Ni "   , "Cun "  ,  /*-- U+7C78 .. U+7C7F --*/
   ""      , "Qian " , "Kume " , "Bi "   , "Ban "  , "Wu "   , "Sha "  , "Kang " ,  /*-- U+7C80 .. U+7C87 --*/
   "Rou "  , "Fen "  , "Bi "   , "Cui "  , ""      , "Li "   , "Chi "  , "Nukamiso ",  /*-- U+7C88 .. U+7C8F --*/
   "Ro "   , "Ba "   , "Li "   , "Gan "  , "Ju "   , "Po "   , "Mo "   , "Cu "   ,  /*-- U+7C90 .. U+7C97 --*/
   "Nian " , "Zhou " , "Li "   , "Su "   , "Tiao " , "Li "   , "Qi "   , "Su "   ,  /*-- U+7C98 .. U+7C9F --*/
   "Hong " , "Tong " , "Zi "   , "Ce "   , "Yue "  , "Zhou " , "Lin "  , "Zhuang ",  /*-- U+7CA0 .. U+7CA7 --*/
   "Bai "  , ""      , "Fen "  , "Ji "   , ""      , "Sukumo ", "Liang ", "Xian " ,  /*-- U+7CA8 .. U+7CAF --*/
   "Fu "   , "Liang ", "Can "  , "Geng " , "Li "   , "Yue "  , "Lu "   , "Ju "   ,  /*-- U+7CB0 .. U+7CB7 --*/
   "Qi "   , "Cui "  , "Bai "  , "Zhang ", "Lin "  , "Zong " , "Jing " , "Guo "  ,  /*-- U+7CB8 .. U+7CBF --*/
   "Kouji ", "San "  , "San "  , "Tang " , "Bian " , "Rou "  , "Mian " , "Hou "  ,  /*-- U+7CC0 .. U+7CC7 --*/
   "Xu "   , "Zong " , "Hu "   , "Jian " , "Zan "  , "Ci "   , "Li "   , "Xie "  ,  /*-- U+7CC8 .. U+7CCF --*/
   "Fu "   , "Ni "   , "Bei "  , "Gu "   , "Xiu "  , "Gao "  , "Tang " , "Qiu "  ,  /*-- U+7CD0 .. U+7CD7 --*/
   "Sukumo ", "Cao "  , "Zhuang ", "Tang " , "Mi "   , "San "  , "Fen "  , "Zao "  ,  /*-- U+7CD8 .. U+7CDF --*/
   "Kang " , "Jiang ", "Mo "   , "San "  , "San "  , "Nuo "  , "Xi "   , "Liang ",  /*-- U+7CE0 .. U+7CE7 --*/
   "Jiang ", "Kuai " , "Bo "   , "Huan " , ""      , "Zong " , "Xian " , "Nuo "  ,  /*-- U+7CE8 .. U+7CEF --*/
   "Tuan " , "Nie "  , "Li "   , "Zuo "  , "Di "   , "Nie "  , "Tiao " , "Lan "  ,  /*-- U+7CF0 .. U+7CF7 --*/
   "Mi "   , "Jiao " , "Jiu "  , "Xi "   , "Gong " , "Zheng ", "Jiu "  , "You "  ,  /*-- U+7CF8 .. U+7CFF --*/
   "Ji "   , "Cha "  , "Zhou " , "Xun "  , "Yue "  , "Hong " , "Yu "   , "He "   ,  /*-- U+7D00 .. U+7D07 --*/
   "Wan "  , "Ren "  , "Wen "  , "Wen "  , "Qiu "  , "Na "   , "Zi "   , "Tou "  ,  /*-- U+7D08 .. U+7D0F --*/
   "Niu "  , "Fou "  , "Jie "  , "Shu "  , "Chun " , "Pi "   , "Yin "  , "Sha "  ,  /*-- U+7D10 .. U+7D17 --*/
   "Hong " , "Zhi "  , "Ji "   , "Fen "  , "Yun "  , "Ren "  , "Dan "  , "Jin "  ,  /*-- U+7D18 .. U+7D1F --*/
   "Su "   , "Fang " , "Suo "  , "Cui "  , "Jiu "  , "Zha "  , "Kinu " , "Jin "  ,  /*-- U+7D20 .. U+7D27 --*/
   "Fu "   , "Zhi "  , "Ci "   , "Zi "   , "Chou " , "Hong " , "Zha "  , "Lei "  ,  /*-- U+7D28 .. U+7D2F --*/
   "Xi "   , "Fu "   , "Xie "  , "Shen " , "Bei "  , "Zhu "  , "Qu "   , "Ling " ,  /*-- U+7D30 .. U+7D37 --*/
   "Zhu "  , "Shao " , "Gan "  , "Yang " , "Fu "   , "Tuo "  , "Zhen " , "Dai "  ,  /*-- U+7D38 .. U+7D3F --*/
   "Zhuo " , "Shi "  , "Zhong ", "Xian " , "Zu "   , "Jiong ", "Ban "  , "Ju "   ,  /*-- U+7D40 .. U+7D47 --*/
   "Mo "   , "Shu "  , "Zui "  , "Wata " , "Jing " , "Ren "  , "Heng " , "Xie "  ,  /*-- U+7D48 .. U+7D4F --*/
   "Jie "  , "Zhu "  , "Chou " , "Gua "  , "Bai "  , "Jue "  , "Kuang ", "Hu "   ,  /*-- U+7D50 .. U+7D57 --*/
   "Ci "   , "Geng " , "Geng " , "Tao "  , "Xie "  , "Ku "   , "Jiao " , "Quan " ,  /*-- U+7D58 .. U+7D5F --*/
   "Gai "  , "Luo "  , "Xuan " , "Bing " , "Xian " , "Fu "   , "Gei "  , "Tong " ,  /*-- U+7D60 .. U+7D67 --*/
   "Rong " , "Tiao " , "Yin "  , "Lei "  , "Xie "  , "Quan " , "Xu "   , "Lun "  ,  /*-- U+7D68 .. U+7D6F --*/
   "Die "  , "Tong " , "Si "   , "Jiang ", "Xiang ", "Hui "  , "Jue "  , "Zhi "  ,  /*-- U+7D70 .. U+7D77 --*/
   "Jian " , "Juan " , "Chi "  , "Mian " , "Zhen " , "Lu "   , "Cheng ", "Qiu "  ,  /*-- U+7D78 .. U+7D7F --*/
   "Shu "  , "Bang " , "Tong " , "Xiao " , "Wan "  , "Qin "  , "Geng " , "Xiu "  ,  /*-- U+7D80 .. U+7D87 --*/
   "Ti "   , "Xiu "  , "Xie "  , "Hong " , "Xi "   , "Fu "   , "Ting " , "Sui "  ,  /*-- U+7D88 .. U+7D8F --*/
   "Dui "  , "Kun "  , "Fu "   , "Jing " , "Hu "   , "Zhi "  , "Yan "  , "Jiong ",  /*-- U+7D90 .. U+7D97 --*/
   "Feng " , "Ji "   , "Sok "  , "Kase " , "Zong " , "Lin "  , "Duo "  , "Li "   ,  /*-- U+7D98 .. U+7D9F --*/
   "Lu "   , "Liang ", "Chou " , "Quan " , "Shao " , "Qi "   , "Qi "   , "Zhun " ,  /*-- U+7DA0 .. U+7DA7 --*/
   "Qi "   , "Wan "  , "Qian " , "Xian " , "Shou " , "Wei "  , "Qi "   , "Tao "  ,  /*-- U+7DA8 .. U+7DAF --*/
   "Wan "  , "Gang " , "Wang " , "Beng " , "Zhui " , "Cai "  , "Guo "  , "Cui "  ,  /*-- U+7DB0 .. U+7DB7 --*/
   "Lun "  , "Liu "  , "Qi "   , "Zhan " , "Bei "  , "Chuo " , "Ling " , "Mian " ,  /*-- U+7DB8 .. U+7DBF --*/
   "Qi "   , "Qie "  , "Tan "  , "Zong " , "Gun "  , "Zou "  , "Yi "   , "Zi "   ,  /*-- U+7DC0 .. U+7DC7 --*/
   "Xing " , "Liang ", "Jin "  , "Fei "  , "Rui "  , "Min "  , "Yu "   , "Zong " ,  /*-- U+7DC8 .. U+7DCF --*/
   "Fan "  , "Lu "   , "Xu "   , "Yingl ", "Zhang ", "Kasuri ", "Xu "   , "Xiang ",  /*-- U+7DD0 .. U+7DD7 --*/
   "Jian " , "Ke "   , "Xian " , "Ruan " , "Mian " , "Qi "   , "Duan " , "Zhong ",  /*-- U+7DD8 .. U+7DDF --*/
   "Di "   , "Min "  , "Miao " , "Yuan " , "Xie "  , "Bao "  , "Si "   , "Qiu "  ,  /*-- U+7DE0 .. U+7DE7 --*/
   "Bian " , "Huan " , "Geng " , "Cong " , "Mian " , "Wei "  , "Fu "   , "Wei "  ,  /*-- U+7DE8 .. U+7DEF --*/
   "Yu "   , "Gou "  , "Miao " , "Xie "  , "Lian " , "Zong " , "Bian " , "Yun "  ,  /*-- U+7DF0 .. U+7DF7 --*/
   "Yin "  , "Ti "   , "Gua "  , "Zhi "  , "Yun "  , "Cheng ", "Chan " , "Dai "  ,  /*-- U+7DF8 .. U+7DFF --*/
   "Xia "  , "Yuan " , "Zong " , "Xu "   , "Nawa " , "Odoshi ", "Geng " , "Sen "  ,  /*-- U+7E00 .. U+7E07 --*/
   "Ying " , "Jin "  , "Yi "   , "Zhui " , "Ni "   , "Bang " , "Gu "   , "Pan "  ,  /*-- U+7E08 .. U+7E0F --*/
   "Zhou " , "Jian " , "Cuo "  , "Quan " , "Shuang ", "Yun "  , "Xia "  , "Shuai ",  /*-- U+7E10 .. U+7E17 --*/
   "Xi "   , "Rong " , "Tao "  , "Fu "   , "Yun "  , "Zhen " , "Gao "  , "Ru "   ,  /*-- U+7E18 .. U+7E1F --*/
   "Hu "   , "Zai "  , "Teng " , "Xian " , "Su "   , "Zhen " , "Zong " , "Tao "  ,  /*-- U+7E20 .. U+7E27 --*/
   "Horo " , "Cai "  , "Bi "   , "Feng " , "Cu "   , "Li "   , "Suo "  , "Yin "  ,  /*-- U+7E28 .. U+7E2F --*/
   "Xi "   , "Zong " , "Lei "  , "Zhuan ", "Qian " , "Man "  , "Zhi "  , "Lu "   ,  /*-- U+7E30 .. U+7E37 --*/
   "Mo "   , "Piao " , "Lian " , "Mi "   , "Xuan " , "Zong " , "Ji "   , "Shan " ,  /*-- U+7E38 .. U+7E3F --*/
   "Sui "  , "Fan "  , "Shuai ", "Beng " , "Yi "   , "Sao "  , "Mou "  , "Zhou " ,  /*-- U+7E40 .. U+7E47 --*/
   "Qiang ", "Hun "  , "Sem "  , "Xi "   , "Jung " , "Xiu "  , "Ran "  , "Xuan " ,  /*-- U+7E48 .. U+7E4F --*/
   "Hui "  , "Qiao " , "Zeng " , "Zuo "  , "Zhi "  , "Shan " , "San "  , "Lin "  ,  /*-- U+7E50 .. U+7E57 --*/
   "Yu "   , "Fan "  , "Liao " , "Chuo " , "Zun "  , "Jian " , "Rao "  , "Chan " ,  /*-- U+7E58 .. U+7E5F --*/
   "Rui "  , "Xiu "  , "Hui "  , "Hua "  , "Zuan " , "Xi "   , "Qiang ", "Un "   ,  /*-- U+7E60 .. U+7E67 --*/
   "Da "   , "Sheng ", "Hui "  , "Xi "   , "Se "   , "Jian " , "Jiang ", "Huan " ,  /*-- U+7E68 .. U+7E6F --*/
   "Zao "  , "Cong " , "Jie "  , "Jiao " , "Bo "   , "Chan " , "Yi "   , "Nao "  ,  /*-- U+7E70 .. U+7E77 --*/
   "Sui "  , "Yi "   , "Shai " , "Xu "   , "Ji "   , "Bin "  , "Qian " , "Lan "  ,  /*-- U+7E78 .. U+7E7F --*/
   "Pu "   , "Xun "  , "Zuan " , "Qi "   , "Peng " , "Li "   , "Mo "   , "Lei "  ,  /*-- U+7E80 .. U+7E87 --*/
   "Xie "  , "Zuan " , "Kuang ", "You "  , "Xu "   , "Lei "  , "Xian " , "Chan " ,  /*-- U+7E88 .. U+7E8F --*/
   "Kou "  , "Lu "   , "Chan " , "Ying " , "Cai "  , "Xiang ", "Xian " , "Zui "  ,  /*-- U+7E90 .. U+7E97 --*/
   "Zuan " , "Luo "  , "Xi "   , "Dao "  , "Lan "  , "Lei "  , "Lian " , "Si "   ,  /*-- U+7E98 .. U+7E9F --*/
   "Jiu "  , "Yu "   , "Hong " , "Zhou " , "Xian " , "He "   , "Yue "  , "Ji "   ,  /*-- U+7EA0 .. U+7EA7 --*/
   "Wan "  , "Kuang ", "Ji "   , "Ren "  , "Wei "  , "Yun "  , "Hong " , "Chun " ,  /*-- U+7EA8 .. U+7EAF --*/
   "Pi "   , "Sha "  , "Gang " , "Na "   , "Ren "  , "Zong " , "Lun "  , "Fen "  ,  /*-- U+7EB0 .. U+7EB7 --*/
   "Zhi "  , "Wen "  , "Fang " , "Zhu "  , "Yin "  , "Niu "  , "Shu "  , "Xian " ,  /*-- U+7EB8 .. U+7EBF --*/
   "Gan "  , "Xie "  , "Fu "   , "Lian " , "Zu "   , "Shen " , "Xi "   , "Zhi "  ,  /*-- U+7EC0 .. U+7EC7 --*/
   "Zhong ", "Zhou " , "Ban "  , "Fu "   , "Zhuo " , "Shao " , "Yi "   , "Jing " ,  /*-- U+7EC8 .. U+7ECF --*/
   "Dai "  , "Bang " , "Rong " , "Jie "  , "Ku "   , "Rao "  , "Die "  , "Heng " ,  /*-- U+7ED0 .. U+7ED7 --*/
   "Hui "  , "Gei "  , "Xuan " , "Jiang ", "Luo "  , "Jue "  , "Jiao " , "Tong " ,  /*-- U+7ED8 .. U+7EDF --*/
   "Geng " , "Xiao " , "Juan " , "Xiu "  , "Xi "   , "Sui "  , "Tao "  , "Ji "   ,  /*-- U+7EE0 .. U+7EE7 --*/
   "Ti "   , "Ji "   , "Xu "   , "Ling " , ""      , "Xu "   , "Qi "   , "Fei "  ,  /*-- U+7EE8 .. U+7EEF --*/
   "Chuo " , "Zhang ", "Gun "  , "Sheng ", "Wei "  , "Mian " , "Shou " , "Beng " ,  /*-- U+7EF0 .. U+7EF7 --*/
   "Chou " , "Tao "  , "Liu "  , "Quan " , "Zong " , "Zhan " , "Wan "  , "Lu "   ,  /*-- U+7EF8 .. U+7EFF --*/
   "Zhui " , "Zi "   , "Ke "   , "Xiang ", "Jian " , "Mian " , "Lan "  , "Ti "   ,  /*-- U+7F00 .. U+7F07 --*/
   "Miao " , "Qi "   , "Yun "  , "Hui "  , "Si "   , "Duo "  , "Duan " , "Bian " ,  /*-- U+7F08 .. U+7F0F --*/
   "Xian " , "Gou "  , "Zhui " , "Huan " , "Di "   , "Lu "   , "Bian " , "Min "  ,  /*-- U+7F10 .. U+7F17 --*/
   "Yuan " , "Jin "  , "Fu "   , "Ru "   , "Zhen " , "Feng " , "Shuai ", "Gao "  ,  /*-- U+7F18 .. U+7F1F --*/
   "Chan " , "Li "   , "Yi "   , "Jian " , "Bin "  , "Piao " , "Man "  , "Lei "  ,  /*-- U+7F20 .. U+7F27 --*/
   "Ying " , "Suo "  , "Mou "  , "Sao "  , "Xie "  , "Liao " , "Shan " , "Zeng " ,  /*-- U+7F28 .. U+7F2F --*/
   "Jiang ", "Qian " , "Zao "  , "Huan " , "Jiao " , "Zuan " , "Fou "  , "Xie "  ,  /*-- U+7F30 .. U+7F37 --*/
   "Gang " , "Fou "  , "Que "  , "Fou "  , "Kaakeru ", "Bo "   , "Ping " , "Hou "  ,  /*-- U+7F38 .. U+7F3F --*/
   ""      , "Gang " , "Ying " , "Ying " , "Qing " , "Xia "  , "Guan " , "Zun "  ,  /*-- U+7F40 .. U+7F47 --*/
   "Tan "  , "Chang ", "Qi "   , "Weng " , "Ying " , "Lei "  , "Tan "  , "Lu "   ,  /*-- U+7F48 .. U+7F4F --*/
   "Guan " , "Wang " , "Wang " , "Gang " , "Wang " , "Han "  , ""      , "Luo "  ,  /*-- U+7F50 .. U+7F57 --*/
   "Fu "   , "Mi "   , "Fa "   , "Gu "   , "Zhu "  , "Ju "   , "Mao "  , "Gu "   ,  /*-- U+7F58 .. U+7F5F --*/
   "Min "  , "Gang " , "Ba "   , "Gua "  , "Ti "   , "Juan " , "Fu "   , "Lin "  ,  /*-- U+7F60 .. U+7F67 --*/
   "Yan "  , "Zhao " , "Zui "  , "Gua "  , "Zhuo " , "Yu "   , "Zhi "  , "An "   ,  /*-- U+7F68 .. U+7F6F --*/
   "Fa "   , "Nan "  , "Shu "  , "Si "   , "Pi "   , "Ma "   , "Liu "  , "Ba "   ,  /*-- U+7F70 .. U+7F77 --*/
   "Fa "   , "Li "   , "Chao " , "Wei "  , "Bi "   , "Ji "   , "Zeng " , "Tong " ,  /*-- U+7F78 .. U+7F7F --*/
   "Liu "  , "Ji "   , "Juan " , "Mi "   , "Zhao " , "Luo "  , "Pi "   , "Ji "   ,  /*-- U+7F80 .. U+7F87 --*/
   "Ji "   , "Luan " , "Yang " , "Mie "  , "Qiang ", "Ta "   , "Mei "  , "Yang " ,  /*-- U+7F88 .. U+7F8F --*/
   "You "  , "You "  , "Fen "  , "Ba "   , "Gao "  , "Yang " , "Gu "   , "Qiang ",  /*-- U+7F90 .. U+7F97 --*/
   "Zang " , "Gao "  , "Ling " , "Yi "   , "Zhu "  , "Di "   , "Xiu "  , "Qian " ,  /*-- U+7F98 .. U+7F9F --*/
   "Yi "   , "Xian " , "Rong " , "Qun "  , "Qun "  , "Qian " , "Huan " , "Zui "  ,  /*-- U+7FA0 .. U+7FA7 --*/
   "Xian " , "Yi "   , "Yashinau ", "Qiang ", "Xian " , "Yu "   , "Geng " , "Jie "  ,  /*-- U+7FA8 .. U+7FAF --*/
   "Tang " , "Yuan " , "Xi "   , "Fan "  , "Shan " , "Fen "  , "Shan " , "Lian " ,  /*-- U+7FB0 .. U+7FB7 --*/
   "Lei "  , "Geng " , "Nou "  , "Qiang ", "Chan " , "Yu "   , "Gong " , "Yi "   ,  /*-- U+7FB8 .. U+7FBF --*/
   "Chong ", "Weng " , "Fen "  , "Hong " , "Chi "  , "Chi "  , "Cui "  , "Fu "   ,  /*-- U+7FC0 .. U+7FC7 --*/
   "Xia "  , "Pen "  , "Yi "   , "La "   , "Yi "   , "Pi "   , "Ling " , "Liu "  ,  /*-- U+7FC8 .. U+7FCF --*/
   "Zhi "  , "Qu "   , "Xi "   , "Xie "  , "Xiang ", "Xi "   , "Xi "   , "Qi "   ,  /*-- U+7FD0 .. U+7FD7 --*/
   "Qiao " , "Hui "  , "Hui "  , "Xiao " , "Se "   , "Hong " , "Jiang ", "Di "   ,  /*-- U+7FD8 .. U+7FDF --*/
   "Cui "  , "Fei "  , "Tao "  , "Sha "  , "Chi "  , "Zhu "  , "Jian " , "Xuan " ,  /*-- U+7FE0 .. U+7FE7 --*/
   "Shi "  , "Pian " , "Zong " , "Wan "  , "Hui "  , "Hou "  , "He "   , "He "   ,  /*-- U+7FE8 .. U+7FEF --*/
   "Han "  , "Ao "   , "Piao " , "Yi "   , "Lian " , "Qu "   , ""      , "Lin "  ,  /*-- U+7FF0 .. U+7FF7 --*/
   "Pen "  , "Qiao " , "Ao "   , "Fan "  , "Yi "   , "Hui "  , "Xuan " , "Dao "  ,  /*-- U+7FF8 .. U+7FFF --*/
   "Yao "  , "Lao "  , ""      , "Kao "  , "Mao "  , "Zhe "  , "Qi "   , "Gou "  ,  /*-- U+8000 .. U+8007 --*/
   "Gou "  , "Gou "  , "Die "  , "Die "  , "Er "   , "Shua " , "Ruan " , "Er "   ,  /*-- U+8008 .. U+800F --*/
   "Nai "  , "Zhuan ", "Lei "  , "Ting " , "Zi "   , "Geng " , "Chao " , "Hao "  ,  /*-- U+8010 .. U+8017 --*/
   "Yun "  , "Pa "   , "Pi "   , "Chi "  , "Si "   , "Chu "  , "Jia "  , "Ju "   ,  /*-- U+8018 .. U+801F --*/
   "He "   , "Chu "  , "Lao "  , "Lun "  , "Ji "   , "Tang " , "Ou "   , "Lou "  ,  /*-- U+8020 .. U+8027 --*/
   "Nou "  , "Gou "  , "Pang " , "Ze "   , "Lou "  , "Ji "   , "Lao "  , "Huo "  ,  /*-- U+8028 .. U+802F --*/
   "You "  , "Mo "   , "Huai " , "Er "   , "Zhe "  , "Ting " , "Ye "   , "Da "   ,  /*-- U+8030 .. U+8037 --*/
   "Song " , "Qin "  , "Yun "  , "Chi "  , "Dan "  , "Dan "  , "Hong " , "Geng " ,  /*-- U+8038 .. U+803F --*/
   "Zhi "  , ""      , "Nie "  , "Dan "  , "Zhen " , "Che "  , "Ling " , "Zheng ",  /*-- U+8040 .. U+8047 --*/
   "You "  , "Wa "   , "Liao " , "Long " , "Zhi "  , "Ning " , "Tiao " , "Er "   ,  /*-- U+8048 .. U+804F --*/
   "Ya "   , "Die "  , "Gua "  , ""      , "Lian " , "Hao "  , "Sheng ", "Lie "  ,  /*-- U+8050 .. U+8057 --*/
   "Pin "  , "Jing " , "Ju "   , "Bi "   , "Di "   , "Guo "  , "Wen "  , "Xu "   ,  /*-- U+8058 .. U+805F --*/
   "Ping " , "Cong " , "Shikato ", ""      , "Ting " , "Yu "   , "Cong " , "Kui "  ,  /*-- U+8060 .. U+8067 --*/
   "Tsuraneru ", "Kui "  , "Cong " , "Lian " , "Weng " , "Kui "  , "Lian " , "Lian " ,  /*-- U+8068 .. U+806F --*/
   "Cong " , "Ao "   , "Sheng ", "Song " , "Ting " , "Kui "  , "Nie "  , "Zhi "  ,  /*-- U+8070 .. U+8077 --*/
   "Dan "  , "Ning " , "Qie "  , "Ji "   , "Ting " , "Ting " , "Long " , "Yu "   ,  /*-- U+8078 .. U+807F --*/
   "Yu "   , "Zhao " , "Si "   , "Su "   , "Yi "   , "Su "   , "Si "   , "Zhao " ,  /*-- U+8080 .. U+8087 --*/
   "Zhao " , "Rou "  , "Yi "   , "Le "   , "Ji "   , "Qiu "  , "Ken "  , "Cao "  ,  /*-- U+8088 .. U+808F --*/
   "Ge "   , "Di "   , "Huan " , "Huang ", "Yi "   , "Ren "  , "Xiao " , "Ru "   ,  /*-- U+8090 .. U+8097 --*/
   "Zhou " , "Yuan " , "Du "   , "Gang " , "Rong " , "Gan "  , "Cha "  , "Wo "   ,  /*-- U+8098 .. U+809F --*/
   "Chang ", "Gu "   , "Zhi "  , "Han "  , "Fu "   , "Fei "  , "Fen "  , "Pei "  ,  /*-- U+80A0 .. U+80A7 --*/
   "Pang " , "Jian " , "Fang " , "Zhun " , "You "  , "Na "   , "Hang " , "Ken "  ,  /*-- U+80A8 .. U+80AF --*/
   "Ran "  , "Gong " , "Yu "   , "Wen "  , "Yao "  , "Jin "  , "Pi "   , "Qian " ,  /*-- U+80B0 .. U+80B7 --*/
   "Xi "   , "Xi "   , "Fei "  , "Ken "  , "Jing " , "Tai "  , "Shen " , "Zhong ",  /*-- U+80B8 .. U+80BF --*/
   "Zhang ", "Xie "  , "Shen " , "Wei "  , "Zhou " , "Die "  , "Dan "  , "Fei "  ,  /*-- U+80C0 .. U+80C7 --*/
   "Ba "   , "Bo "   , "Qu "   , "Tian " , "Bei "  , "Gua "  , "Tai "  , "Zi "   ,  /*-- U+80C8 .. U+80CF --*/
   "Ku "   , "Zhi "  , "Ni "   , "Ping " , "Zi "   , "Fu "   , "Pang " , "Zhen " ,  /*-- U+80D0 .. U+80D7 --*/
   "Xian " , "Zuo "  , "Pei "  , "Jia "  , "Sheng ", "Zhi "  , "Bao "  , "Mu "   ,  /*-- U+80D8 .. U+80DF --*/
   "Qu "   , "Hu "   , "Ke "   , "Yi "   , "Yin "  , "Xu "   , "Yang " , "Long " ,  /*-- U+80E0 .. U+80E7 --*/
   "Dong " , "Ka "   , "Lu "   , "Jing " , "Nu "   , "Yan "  , "Pang " , "Kua "  ,  /*-- U+80E8 .. U+80EF --*/
   "Yi "   , "Guang ", "Gai "  , "Ge "   , "Dong " , "Zhi "  , "Xiao " , "Xiong ",  /*-- U+80F0 .. U+80F7 --*/
   "Xiong ", "Er "   , "E "    , "Xing " , "Pian " , "Neng " , "Zi "   , "Gui "  ,  /*-- U+80F8 .. U+80FF --*/
   "Cheng ", "Tiao " , "Zhi "  , "Cui "  , "Mei "  , "Xie "  , "Cui "  , "Xie "  ,  /*-- U+8100 .. U+8107 --*/
   "Mo "   , "Mai "  , "Ji "   , "Obiyaakasu ", ""      , "Kuai " , "Sa "   , "Zang " ,  /*-- U+8108 .. U+810F --*/
   "Qi "   , "Nao "  , "Mi "   , "Nong " , "Luan " , "Wan "  , "Bo "   , "Wen "  ,  /*-- U+8110 .. U+8117 --*/
   "Guan " , "Qiu "  , "Jiao " , "Jing " , "Rou "  , "Heng " , "Cuo "  , "Lie "  ,  /*-- U+8118 .. U+811F --*/
   "Shan " , "Ting " , "Mei "  , "Chun " , "Shen " , "Xie "  , "De "   , "Zui "  ,  /*-- U+8120 .. U+8127 --*/
   "Cu "   , "Xiu "  , "Xin "  , "Tuo "  , "Pao "  , "Cheng ", "Nei "  , "Fu "   ,  /*-- U+8128 .. U+812F --*/
   "Dou "  , "Tuo "  , "Niao " , "Noy "  , "Pi "   , "Gu "   , "Gua "  , "Li "   ,  /*-- U+8130 .. U+8137 --*/
   "Lian " , "Zhang ", "Cui "  , "Jie "  , "Liang ", "Zhou " , "Pi "   , "Biao " ,  /*-- U+8138 .. U+813F --*/
   "Lun "  , "Pian " , "Guo "  , "Kui "  , "Chui " , "Dan "  , "Tian " , "Nei "  ,  /*-- U+8140 .. U+8147 --*/
   "Jing " , "Jie "  , "La "   , "Yi "   , "An "   , "Ren "  , "Shen " , "Chuo " ,  /*-- U+8148 .. U+814F --*/
   "Fu "   , "Fu "   , "Ju "   , "Fei "  , "Qiang ", "Wan "  , "Dong " , "Pi "   ,  /*-- U+8150 .. U+8157 --*/
   "Guo "  , "Zong " , "Ding " , "Wu "   , "Mei "  , "Ruan " , "Zhuan ", "Zhi "  ,  /*-- U+8158 .. U+815F --*/
   "Cou "  , "Gua "  , "Ou "   , "Di "   , "An "   , "Xing " , "Nao "  , "Yu "   ,  /*-- U+8160 .. U+8167 --*/
   "Chuan ", "Nan "  , "Yun "  , "Zhong ", "Rou "  , "E "    , "Sai "  , "Tu "   ,  /*-- U+8168 .. U+816F --*/
   "Yao "  , "Jian " , "Wei "  , "Jiao " , "Yu "   , "Jia "  , "Duan " , "Bi "   ,  /*-- U+8170 .. U+8177 --*/
   "Chang ", "Fu "   , "Xian " , "Ni "   , "Mian " , "Wa "   , "Teng " , "Tui "  ,  /*-- U+8178 .. U+817F --*/
   "Bang " , "Qian " , "Lu "   , "Wa "   , "Sou "  , "Tang " , "Su "   , "Zhui " ,  /*-- U+8180 .. U+8187 --*/
   "Ge "   , "Yi "   , "Bo "   , "Liao " , "Ji "   , "Pi "   , "Xie "  , "Gao "  ,  /*-- U+8188 .. U+818F --*/
   "Lu "   , "Bin "  , "Ou "   , "Chang ", "Lu "   , "Guo "  , "Pang " , "Chuai ",  /*-- U+8190 .. U+8197 --*/
   "Piao " , "Jiang ", "Fu "   , "Tang " , "Mo "   , "Xi "   , "Zhuan ", "Lu "   ,  /*-- U+8198 .. U+819F --*/
   "Jiao " , "Ying " , "Lu "   , "Zhi "  , "Tara " , "Chun " , "Lian " , "Tong " ,  /*-- U+81A0 .. U+81A7 --*/
   "Peng " , "Ni "   , "Zha "  , "Liao " , "Cui "  , "Gui "  , "Xiao " , "Teng " ,  /*-- U+81A8 .. U+81AF --*/
   "Fan "  , "Zhi "  , "Jiao " , "Shan " , "Wu "   , "Cui "  , "Run "  , "Xiang ",  /*-- U+81B0 .. U+81B7 --*/
   "Sui "  , "Fen "  , "Ying " , "Tan "  , "Zhua " , "Dan "  , "Kuai " , "Nong " ,  /*-- U+81B8 .. U+81BF --*/
   "Tun "  , "Lian " , "Bi "   , "Yong " , "Jue "  , "Chu "  , "Yi "   , "Juan " ,  /*-- U+81C0 .. U+81C7 --*/
   "La "   , "Lian " , "Sao "  , "Tun "  , "Gu "   , "Qi "   , "Cui "  , "Bin "  ,  /*-- U+81C8 .. U+81CF --*/
   "Xun "  , "Ru "   , "Huo "  , "Zang " , "Xian " , "Biao " , "Xing " , "Kuan " ,  /*-- U+81D0 .. U+81D7 --*/
   "La "   , "Yan "  , "Lu "   , "Huo "  , "Zang " , "Luo "  , "Qu "   , "Zang " ,  /*-- U+81D8 .. U+81DF --*/
   "Luan " , "Ni "   , "Zang " , "Chen " , "Qian " , "Wo "   , "Guang ", "Zang " ,  /*-- U+81E0 .. U+81E7 --*/
   "Lin "  , "Guang ", "Zi "   , "Jiao " , "Nie "  , "Chou " , "Ji "   , "Gao "  ,  /*-- U+81E8 .. U+81EF --*/
   "Chou " , "Mian " , "Nie "  , "Zhi "  , "Zhi "  , "Ge "   , "Jian " , "Die "  ,  /*-- U+81F0 .. U+81F7 --*/
   "Zhi "  , "Xiu "  , "Tai "  , "Zhen " , "Jiu "  , "Xian " , "Yu "   , "Cha "  ,  /*-- U+81F8 .. U+81FF --*/
   "Yao "  , "Yu "   , "Chong ", "Xi "   , "Xi "   , "Jiu "  , "Yu "   , "Yu "   ,  /*-- U+8200 .. U+8207 --*/
   "Xing " , "Ju "   , "Jiu "  , "Xin "  , "She "  , "She "  , "Yadoru ", "Jiu "  ,  /*-- U+8208 .. U+820F --*/
   "Shi "  , "Tan "  , "Shu "  , "Shi "  , "Tian " , "Dan "  , "Pu "   , "Pu "   ,  /*-- U+8210 .. U+8217 --*/
   "Guan " , "Hua "  , "Tan "  , "Chuan ", "Shun " , "Xia "  , "Wu "   , "Zhou " ,  /*-- U+8218 .. U+821F --*/
   "Dao "  , "Gang " , "Shan " , "Yi "   , ""      , "Pa "   , "Tai "  , "Fan "  ,  /*-- U+8220 .. U+8227 --*/
   "Ban "  , "Chuan ", "Hang " , "Fang " , "Ban "  , "Que "  , "Hesaki ", "Zhong ",  /*-- U+8228 .. U+822F --*/
   "Jian " , "Cang " , "Ling " , "Zhu "  , "Ze "   , "Duo "  , "Bo "   , "Xian " ,  /*-- U+8230 .. U+8237 --*/
   "Ge "   , "Chuan ", "Jia "  , "Lu "   , "Hong " , "Pang " , "Xi "   , ""      ,  /*-- U+8238 .. U+823F --*/
   "Fu "   , "Zao "  , "Feng " , "Li "   , "Shao " , "Yu "   , "Lang " , "Ting " ,  /*-- U+8240 .. U+8247 --*/
   ""      , "Wei "  , "Bo "   , "Meng " , "Nian " , "Ju "   , "Huang ", "Shou " ,  /*-- U+8248 .. U+824F --*/
   "Zong " , "Bian " , "Mao "  , "Die "  , ""      , "Bang " , "Cha "  , "Yi "   ,  /*-- U+8250 .. U+8257 --*/
   "Sao "  , "Cang " , "Cao "  , "Lou "  , "Dai "  , "Sori " , "Yao "  , "Tong " ,  /*-- U+8258 .. U+825F --*/
   "Yofune ", "Dang " , "Tan "  , "Lu "   , "Yi "   , "Jie "  , "Jian " , "Huo "  ,  /*-- U+8260 .. U+8267 --*/
   "Meng " , "Qi "   , "Lu "   , "Lu "   , "Chan " , "Shuang ", "Gen "  , "Liang ",  /*-- U+8268 .. U+826F --*/
   "Jian " , "Jian " , "Se "   , "Yan "  , "Fu "   , "Ping " , "Yan "  , "Yan "  ,  /*-- U+8270 .. U+8277 --*/
   "Cao "  , "Cao "  , "Yi "   , "Le "   , "Ting " , "Qiu "  , "Ai "   , "Nai "  ,  /*-- U+8278 .. U+827F --*/
   "Tiao " , "Jiao " , "Jie "  , "Peng " , "Wan "  , "Yi "   , "Chai " , "Mian " ,  /*-- U+8280 .. U+8287 --*/
   "Mie "  , "Gan "  , "Qian " , "Yu "   , "Yu "   , "Shuo " , "Qiong ", "Tu "   ,  /*-- U+8288 .. U+828F --*/
   "Xia "  , "Qi "   , "Mang " , "Zi "   , "Hui "  , "Sui "  , "Zhi "  , "Xiang ",  /*-- U+8290 .. U+8297 --*/
   "Bi "   , "Fu "   , "Tun "  , "Wei "  , "Wu "   , "Zhi "  , "Qi "   , "Shan " ,  /*-- U+8298 .. U+829F --*/
   "Wen "  , "Qian " , "Ren "  , "Fou "  , "Kou "  , "Jie "  , "Lu "   , "Xu "   ,  /*-- U+82A0 .. U+82A7 --*/
   "Ji "   , "Qin "  , "Qi "   , "Yuan " , "Fen "  , "Ba "   , "Rui "  , "Xin "  ,  /*-- U+82A8 .. U+82AF --*/
   "Ji "   , "Hua "  , "Hua "  , "Fang " , "Wu "   , "Jue "  , "Gou "  , "Zhi "  ,  /*-- U+82B0 .. U+82B7 --*/
   "Yun "  , "Qin "  , "Ao "   , "Chu "  , "Mao "  , "Ya "   , "Fei "  , "Reng " ,  /*-- U+82B8 .. U+82BF --*/
   "Hang " , "Cong " , "Yin "  , "You "  , "Bian " , "Yi "   , "Susa " , "Wei "  ,  /*-- U+82C0 .. U+82C7 --*/
   "Li "   , "Pi "   , "E "    , "Xian " , "Chang ", "Cang " , "Meng " , "Su "   ,  /*-- U+82C8 .. U+82CF --*/
   "Yi "   , "Yuan " , "Ran "  , "Ling " , "Tai "  , "Tiao " , "Di "   , "Miao " ,  /*-- U+82D0 .. U+82D7 --*/
   "Qiong ", "Li "   , "Yong " , "Ke "   , "Mu "   , "Pei "  , "Bao "  , "Gou "  ,  /*-- U+82D8 .. U+82DF --*/
   "Min "  , "Yi "   , "Yi "   , "Ju "   , "Pi "   , "Ruo "  , "Ku "   , "Zhu "  ,  /*-- U+82E0 .. U+82E7 --*/
   "Ni "   , "Bo "   , "Bing " , "Shan " , "Qiu "  , "Yao "  , "Xian " , "Ben "  ,  /*-- U+82E8 .. U+82EF --*/
   "Hong " , "Ying " , "Zha "  , "Dong " , "Ju "   , "Die "  , "Nie "  , "Gan "  ,  /*-- U+82F0 .. U+82F7 --*/
   "Hu "   , "Ping " , "Mei "  , "Fu "   , "Sheng ", "Gu "   , "Bi "   , "Wei "  ,  /*-- U+82F8 .. U+82FF --*/
   "Fu "   , "Zhuo " , "Mao "  , "Fan "  , "Qie "  , "Mao "  , "Mao "  , "Ba "   ,  /*-- U+8300 .. U+8307 --*/
   "Zi "   , "Mo "   , "Zi "   , "Di "   , "Chi "  , "Ji "   , "Jing " , "Long " ,  /*-- U+8308 .. U+830F --*/
   ""      , "Niao " , ""      , "Xue "  , "Ying " , "Qiong ", "Ge "   , "Ming " ,  /*-- U+8310 .. U+8317 --*/
   "Li "   , "Rong " , "Yin "  , "Gen "  , "Qian " , "Chai " , "Chen " , "Yu "   ,  /*-- U+8318 .. U+831F --*/
   "Xiu "  , "Zi "   , "Lie "  , "Wu "   , "Ji "   , "Kui "  , "Ce "   , "Chong ",  /*-- U+8320 .. U+8327 --*/
   "Ci "   , "Gou "  , "Guang ", "Mang " , "Chi "  , "Jiao " , "Jiao " , "Fu "   ,  /*-- U+8328 .. U+832F --*/
   "Yu "   , "Zhu "  , "Zi "   , "Jiang ", "Hui "  , "Yin "  , "Cha "  , "Fa "   ,  /*-- U+8330 .. U+8337 --*/
   "Rong " , "Ru "   , "Chong ", "Mang " , "Tong " , "Zhong ", ""      , "Zhu "  ,  /*-- U+8338 .. U+833F --*/
   "Xun "  , "Huan " , "Kua "  , "Quan " , "Gai "  , "Da "   , "Jing " , "Xing " ,  /*-- U+8340 .. U+8347 --*/
   "Quan " , "Cao "  , "Jing " , "Er "   , "An "   , "Shou " , "Chi "  , "Ren "  ,  /*-- U+8348 .. U+834F --*/
   "Jian " , "Ti "   , "Huang ", "Ping " , "Li "   , "Jin "  , "Lao "  , "Shu "  ,  /*-- U+8350 .. U+8357 --*/
   "Zhuang ", "Da "   , "Jia "  , "Rao "  , "Bi "   , "Ze "   , "Qiao " , "Hui "  ,  /*-- U+8358 .. U+835F --*/
   "Qi "   , "Dang " , ""      , "Rong " , "Hun "  , "Ying " , "Luo "  , "Ying " ,  /*-- U+8360 .. U+8367 --*/
   "Xun "  , "Jin "  , "Sun "  , "Yin "  , "Mai "  , "Hong " , "Zhou " , "Yao "  ,  /*-- U+8368 .. U+836F --*/
   "Du "   , "Wei "  , "Chu "  , "Dou "  , "Fu "   , "Ren "  , "Yin "  , "He "   ,  /*-- U+8370 .. U+8377 --*/
   "Bi "   , "Bu "   , "Yun "  , "Di "   , "Tu "   , "Sui "  , "Sui "  , "Cheng ",  /*-- U+8378 .. U+837F --*/
   "Chen " , "Wu "   , "Bie "  , "Xi "   , "Geng " , "Li "   , "Fu "   , "Zhu "  ,  /*-- U+8380 .. U+8387 --*/
   "Mo "   , "Li "   , "Zhuang ", "Ji "   , "Duo "  , "Qiu "  , "Sha "  , "Suo "  ,  /*-- U+8388 .. U+838F --*/
   "Chen " , "Feng " , "Ju "   , "Mei "  , "Meng " , "Xing " , "Jing " , "Che "  ,  /*-- U+8390 .. U+8397 --*/
   "Xin "  , "Jun "  , "Yan "  , "Ting " , "Diao " , "Cuo "  , "Wan "  , "Han "  ,  /*-- U+8398 .. U+839F --*/
   "You "  , "Cuo "  , "Jia "  , "Wang " , "You "  , "Niu "  , "Shao " , "Xian " ,  /*-- U+83A0 .. U+83A7 --*/
   "Lang " , "Fu "   , "E "    , "Mo "   , "Wen "  , "Jie "  , "Nan "  , "Mu "   ,  /*-- U+83A8 .. U+83AF --*/
   "Kan "  , "Lai "  , "Lian " , "Shi "  , "Wo "   , "Usagi ", "Lian " , "Huo "  ,  /*-- U+83B0 .. U+83B7 --*/
   "You "  , "Ying " , "Ying " , "Nuc "  , "Chun " , "Mang " , "Mang " , "Ci "   ,  /*-- U+83B8 .. U+83BF --*/
   "Wan "  , "Jing " , "Di "   , "Qu "   , "Dong " , "Jian " , "Zou "  , "Gu "   ,  /*-- U+83C0 .. U+83C7 --*/
   "La "   , "Lu "   , "Ju "   , "Wei "  , "Jun "  , "Nie "  , "Kun "  , "He "   ,  /*-- U+83C8 .. U+83CF --*/
   "Pu "   , "Zi "   , "Gao "  , "Guo "  , "Fu "   , "Lun "  , "Chang ", "Chou " ,  /*-- U+83D0 .. U+83D7 --*/
   "Song " , "Chui " , "Zhan " , "Men "  , "Cai "  , "Ba "   , "Li "   , "Tu "   ,  /*-- U+83D8 .. U+83DF --*/
   "Bo "   , "Han "  , "Bao "  , "Qin "  , "Juan " , "Xi "   , "Qin "  , "Di "   ,  /*-- U+83E0 .. U+83E7 --*/
   "Jie "  , "Pu "   , "Dang " , "Jin "  , "Zhao " , "Tai "  , "Geng " , "Hua "  ,  /*-- U+83E8 .. U+83EF --*/
   "Gu "   , "Ling " , "Fei "  , "Jin "  , "An "   , "Wang " , "Beng " , "Zhou " ,  /*-- U+83F0 .. U+83F7 --*/
   "Yan "  , "Ju "   , "Jian " , "Lin "  , "Tan "  , "Shu "  , "Tian " , "Dao "  ,  /*-- U+83F8 .. U+83FF --*/
   "Hu "   , "Qi "   , "He "   , "Cui "  , "Tao "  , "Chun " , "Bei "  , "Chang ",  /*-- U+8400 .. U+8407 --*/
   "Huan " , "Fei "  , "Lai "  , "Qi "   , "Meng " , "Ping " , "Wei "  , "Dan "  ,  /*-- U+8408 .. U+840F --*/
   "Sha "  , "Huan " , "Yan "  , "Yi "   , "Tiao " , "Qi "   , "Wan "  , "Ce "   ,  /*-- U+8410 .. U+8417 --*/
   "Nai "  , "Kutabireru ", "Tuo "  , "Jiu "  , "Tie "  , "Luo "  , ""      , ""      ,  /*-- U+8418 .. U+841F --*/
   "Meng " , ""      , "Yaji " , ""      , "Ying " , "Ying " , "Ying " , "Xiao " ,  /*-- U+8420 .. U+8427 --*/
   "Sa "   , "Qiu "  , "Ke "   , "Xiang ", "Wan "  , "Yu "   , "Yu "   , "Fu "   ,  /*-- U+8428 .. U+842F --*/
   "Lian " , "Xuan " , "Yuan " , "Nan "  , "Ze "   , "Wo "   , "Chun " , "Xiao " ,  /*-- U+8430 .. U+8437 --*/
   "Yu "   , "Pian " , "Mao "  , "An "   , "E "    , "Luo "  , "Ying " , "Huo "  ,  /*-- U+8438 .. U+843F --*/
   "Gua "  , "Jiang ", "Mian " , "Zuo "  , "Zuo "  , "Ju "   , "Bao "  , "Rou "  ,  /*-- U+8440 .. U+8447 --*/
   "Xi "   , "Xie "  , "An "   , "Qu "   , "Jian " , "Fu "   , "Lu "   , "Jing " ,  /*-- U+8448 .. U+844F --*/
   "Pen "  , "Feng " , "Hong " , "Hong " , "Hou "  , "Yan "  , "Tu "   , "Zhu "  ,  /*-- U+8450 .. U+8457 --*/
   "Zi "   , "Xiang ", "Shen " , "Ge "   , "Jie "  , "Jing " , "Mi "   , "Huang ",  /*-- U+8458 .. U+845F --*/
   "Shen " , "Pu "   , "Gai "  , "Dong " , "Zhou " , "Qian " , "Wei "  , "Bo "   ,  /*-- U+8460 .. U+8467 --*/
   "Wei "  , "Pa "   , "Ji "   , "Hu "   , "Zang " , "Jia "  , "Duan " , "Yao "  ,  /*-- U+8468 .. U+846F --*/
   "Jun "  , "Cong " , "Quan " , "Wei "  , "Xian " , "Kui "  , "Ting " , "Hun "  ,  /*-- U+8470 .. U+8477 --*/
   "Xi "   , "Shi "  , "Qi "   , "Lan "  , "Zong " , "Yao "  , "Yuan " , "Mei "  ,  /*-- U+8478 .. U+847F --*/
   "Yun "  , "Shu "  , "Di "   , "Zhuan ", "Guan " , "Sukumo ", "Xue "  , "Chan " ,  /*-- U+8480 .. U+8487 --*/
   "Kai "  , "Kui "  , ""      , "Jiang ", "Lou "  , "Wei "  , "Pai "  , ""      ,  /*-- U+8488 .. U+848F --*/
   "Sou "  , "Yin "  , "Shi "  , "Chun " , "Shi "  , "Yun "  , "Zhen " , "Lang " ,  /*-- U+8490 .. U+8497 --*/
   "Nu "   , "Meng " , "He "   , "Que "  , "Suan " , "Yuan " , "Li "   , "Ju "   ,  /*-- U+8498 .. U+849F --*/
   "Xi "   , "Pang " , "Chu "  , "Xu "   , "Tu "   , "Liu "  , "Wo "   , "Zhen " ,  /*-- U+84A0 .. U+84A7 --*/
   "Qian " , "Zu "   , "Po "   , "Cuo "  , "Yuan " , "Chu "  , "Yu "   , "Kuai " ,  /*-- U+84A8 .. U+84AF --*/
   "Pan "  , "Pu "   , "Pu "   , "Na "   , "Shuo " , "Xi "   , "Fen "  , "Yun "  ,  /*-- U+84B0 .. U+84B7 --*/
   "Zheng ", "Jian " , "Ji "   , "Ruo "  , "Cang " , "En "   , "Mi "   , "Hao "  ,  /*-- U+84B8 .. U+84BF --*/
   "Sun "  , "Zhen " , "Ming " , "Sou "  , "Xu "   , "Liu "  , "Xi "   , "Gu "   ,  /*-- U+84C0 .. U+84C7 --*/
   "Lang " , "Rong " , "Weng " , "Gai "  , "Cuo "  , "Shi "  , "Tang " , "Luo "  ,  /*-- U+84C8 .. U+84CF --*/
   "Ru "   , "Suo "  , "Xian " , "Bei "  , "Yao "  , "Gui "  , "Bi "   , "Zong " ,  /*-- U+84D0 .. U+84D7 --*/
   "Gun "  , "Za "   , "Xiu "  , "Ce "   , "Hai "  , "Lan "  , ""      , "Ji "   ,  /*-- U+84D8 .. U+84DF --*/
   "Li "   , "Can "  , "Lang " , "Yu "   , ""      , "Ying " , "Mo "   , "Diao " ,  /*-- U+84E0 .. U+84E7 --*/
   "Tiao " , "Mao "  , "Tong " , "Zhu "  , "Peng " , "An "   , "Lian " , "Cong " ,  /*-- U+84E8 .. U+84EF --*/
   "Xi "   , "Ping " , "Qiu "  , "Jin "  , "Chun " , "Jie "  , "Wei "  , "Tui "  ,  /*-- U+84F0 .. U+84F7 --*/
   "Cao "  , "Yu "   , "Yi "   , "Ji "   , "Liao " , "Bi "   , "Lu "   , "Su "   ,  /*-- U+84F8 .. U+84FF --*/
   "Bu "   , "Zhang ", "Luo "  , "Jiang ", "Man "  , "Yan "  , "Ling " , "Ji "   ,  /*-- U+8500 .. U+8507 --*/
   "Piao " , "Gun "  , "Han "  , "Di "   , "Su "   , "Lu "   , "She "  , "Shang ",  /*-- U+8508 .. U+850F --*/
   "Di "   , "Mie "  , "Xun "  , "Man "  , "Bo "   , "Di "   , "Cuo "  , "Zhe "  ,  /*-- U+8510 .. U+8517 --*/
   "Sen "  , "Xuan " , "Wei "  , "Hu "   , "Ao "   , "Mi "   , "Lou "  , "Cu "   ,  /*-- U+8518 .. U+851F --*/
   "Zhong ", "Cai "  , "Po "   , "Jiang ", "Mi "   , "Cong " , "Niao " , "Hui "  ,  /*-- U+8520 .. U+8527 --*/
   "Jun "  , "Yin "  , "Jian " , "Yan "  , "Shu "  , "Yin "  , "Kui "  , "Chen " ,  /*-- U+8528 .. U+852F --*/
   "Hu "   , "Sha "  , "Kou "  , "Qian " , "Ma "   , "Zang " , "Sonoko ", "Qiang ",  /*-- U+8530 .. U+8537 --*/
   "Dou "  , "Lian " , "Lin "  , "Kou "  , "Ai "   , "Bi "   , "Li "   , "Wei "  ,  /*-- U+8538 .. U+853F --*/
   "Ji "   , "Xun "  , "Sheng ", "Fan "  , "Meng " , "Ou "   , "Chan " , "Dian " ,  /*-- U+8540 .. U+8547 --*/
   "Xun "  , "Jiao " , "Rui "  , "Rui "  , "Lei "  , "Yu "   , "Qiao " , "Chu "  ,  /*-- U+8548 .. U+854F --*/
   "Hua "  , "Jian " , "Mai "  , "Yun "  , "Bao "  , "You "  , "Qu "   , "Lu "   ,  /*-- U+8550 .. U+8557 --*/
   "Rao "  , "Hui "  , "E "    , "Teng " , "Fei "  , "Jue "  , "Zui "  , "Fa "   ,  /*-- U+8558 .. U+855F --*/
   "Ru "   , "Fen "  , "Kui "  , "Shun " , "Rui "  , "Ya "   , "Xu "   , "Fu "   ,  /*-- U+8560 .. U+8567 --*/
   "Jue "  , "Dang " , "Wu "   , "Tong " , "Si "   , "Xiao " , "Xi "   , "Long " ,  /*-- U+8568 .. U+856F --*/
   "Yun "  , ""      , "Qi "   , "Jian " , "Yun "  , "Sun "  , "Ling " , "Yu "   ,  /*-- U+8570 .. U+8577 --*/
   "Xia "  , "Yong " , "Ji "   , "Hong " , "Si "   , "Nong " , "Lei "  , "Xuan " ,  /*-- U+8578 .. U+857F --*/
   "Yun "  , "Yu "   , "Xi "   , "Hao "  , "Bo "   , "Hao "  , "Ai "   , "Wei "  ,  /*-- U+8580 .. U+8587 --*/
   "Hui "  , "Wei "  , "Ji "   , "Ci "   , "Xiang ", "Luan " , "Mie "  , "Yi "   ,  /*-- U+8588 .. U+858F --*/
   "Leng " , "Jiang ", "Can "  , "Shen " , "Qiang ", "Lian " , "Ke "   , "Yuan " ,  /*-- U+8590 .. U+8597 --*/
   "Da "   , "Ti "   , "Tang " , "Xie "  , "Bi "   , "Zhan " , "Sun "  , "Lian " ,  /*-- U+8598 .. U+859F --*/
   "Fan "  , "Ding " , "Jie "  , "Gu "   , "Xie "  , "Shu "  , "Jian " , "Kao "  ,  /*-- U+85A0 .. U+85A7 --*/
   "Hong " , "Sa "   , "Xin "  , "Xun "  , "Yao "  , "Hie "  , "Sou "  , "Shu "  ,  /*-- U+85A8 .. U+85AF --*/
   "Xun "  , "Dui "  , "Pin "  , "Wei "  , "Neng " , "Chou " , "Mai "  , "Ru "   ,  /*-- U+85B0 .. U+85B7 --*/
   "Piao " , "Tai "  , "Qi "   , "Zao "  , "Chen " , "Zhen " , "Er "   , "Ni "   ,  /*-- U+85B8 .. U+85BF --*/
   "Ying " , "Gao "  , "Cong " , "Xiao " , "Qi "   , "Fa "   , "Jian " , "Xu "   ,  /*-- U+85C0 .. U+85C7 --*/
   "Kui "  , "Jie "  , "Bian " , "Diao " , "Mi "   , "Lan "  , "Jin "  , "Cang " ,  /*-- U+85C8 .. U+85CF --*/
   "Miao " , "Qiong ", "Qie "  , "Xian " , ""      , "Ou "   , "Xian " , "Su "   ,  /*-- U+85D0 .. U+85D7 --*/
   "Lu "   , "Yi "   , "Xu "   , "Xie "  , "Li "   , "Yi "   , "La "   , "Lei "  ,  /*-- U+85D8 .. U+85DF --*/
   "Xiao " , "Di "   , "Zhi "  , "Bei "  , "Teng " , "Yao "  , "Mo "   , "Huan " ,  /*-- U+85E0 .. U+85E7 --*/
   "Piao " , "Fan "  , "Sou "  , "Tan "  , "Tui "  , "Qiong ", "Qiao " , "Wei "  ,  /*-- U+85E8 .. U+85EF --*/
   "Liu "  , "Hui "  , ""      , "Gao "  , "Yun "  , ""      , "Li "   , "Shu "  ,  /*-- U+85F0 .. U+85F7 --*/
   "Chu "  , "Ai "   , "Lin "  , "Zao "  , "Xuan " , "Chen " , "Lai "  , "Huo "  ,  /*-- U+85F8 .. U+85FF --*/
   "Tuo "  , "Wu "   , "Rui "  , "Rui "  , "Qi "   , "Heng " , "Lu "   , "Su "   ,  /*-- U+8600 .. U+8607 --*/
   "Tui "  , "Mang " , "Yun "  , "Pin "  , "Yu "   , "Xun "  , "Ji "   , "Jiong ",  /*-- U+8608 .. U+860F --*/
   "Xian " , "Mo "   , "Hagi " , "Su "   , "Jiong ", ""      , "Nie "  , "Bo "   ,  /*-- U+8610 .. U+8617 --*/
   "Rang " , "Yi "   , "Xian " , "Yu "   , "Ju "   , "Lian " , "Lian " , "Yin "  ,  /*-- U+8618 .. U+861F --*/
   "Qiang ", "Ying " , "Long " , "Tong " , "Wei "  , "Yue "  , "Ling " , "Qu "   ,  /*-- U+8620 .. U+8627 --*/
   "Yao "  , "Fan "  , "Mi "   , "Lan "  , "Kui "  , "Lan "  , "Ji "   , "Dang " ,  /*-- U+8628 .. U+862F --*/
   "Katsura ", "Lei "  , "Lei "  , "Hua "  , "Feng " , "Zhi "  , "Wei "  , "Kui "  ,  /*-- U+8630 .. U+8637 --*/
   "Zhan " , "Huai " , "Li "   , "Ji "   , "Mi "   , "Lei "  , "Huai " , "Luo "  ,  /*-- U+8638 .. U+863F --*/
   "Ji "   , "Kui "  , "Lu "   , "Jian " , "San "  , ""      , "Lei "  , "Quan " ,  /*-- U+8640 .. U+8647 --*/
   "Xiao " , "Yi "   , "Luan " , "Men "  , "Bie "  , "Hu "   , "Hu "   , "Lu "   ,  /*-- U+8648 .. U+864F --*/
   "Nue "  , "Lu "   , "Si "   , "Xiao " , "Qian " , "Chu "  , "Hu "   , "Xu "   ,  /*-- U+8650 .. U+8657 --*/
   "Cuo "  , "Fu "   , "Xu "   , "Xu "   , "Lu "   , "Hu "   , "Yu "   , "Hao "  ,  /*-- U+8658 .. U+865F --*/
   "Jiao " , "Ju "   , "Guo "  , "Bao "  , "Yan "  , "Zhan " , "Zhan " , "Kui "  ,  /*-- U+8660 .. U+8667 --*/
   "Ban "  , "Xi "   , "Shu "  , "Chong ", "Qiu "  , "Diao " , "Ji "   , "Qiu "  ,  /*-- U+8668 .. U+866F --*/
   "Cheng ", "Shi "  , ""      , "Di "   , "Zhe "  , "She "  , "Yu "   , "Gan "  ,  /*-- U+8670 .. U+8677 --*/
   "Zi "   , "Hong " , "Hui "  , "Meng " , "Ge "   , "Sui "  , "Xia "  , "Chai " ,  /*-- U+8678 .. U+867F --*/
   "Shi "  , "Yi "   , "Ma "   , "Xiang ", "Fang " , "E "    , "Pa "   , "Chi "  ,  /*-- U+8680 .. U+8687 --*/
   "Qian " , "Wen "  , "Wen "  , "Rui "  , "Bang " , "Bi "   , "Yue "  , "Yue "  ,  /*-- U+8688 .. U+868F --*/
   "Jun "  , "Qi "   , "Ran "  , "Yin "  , "Qi "   , "Tian " , "Yuan " , "Jue "  ,  /*-- U+8690 .. U+8697 --*/
   "Hui "  , "Qin "  , "Qi "   , "Zhong ", "Ya "   , "Ci "   , "Mu "   , "Wang " ,  /*-- U+8698 .. U+869F --*/
   "Fen "  , "Fen "  , "Hang " , "Gong " , "Zao "  , "Fu "   , "Ran "  , "Jie "  ,  /*-- U+86A0 .. U+86A7 --*/
   "Fu "   , "Chi "  , "Dou "  , "Piao " , "Xian " , "Ni "   , "Te "   , "Qiu "  ,  /*-- U+86A8 .. U+86AF --*/
   "You "  , "Zha "  , "Ping " , "Chi "  , "You "  , "He "   , "Han "  , "Ju "   ,  /*-- U+86B0 .. U+86B7 --*/
   "Li "   , "Fu "   , "Ran "  , "Zha "  , "Gou "  , "Pi "   , "Bo "   , "Xian " ,  /*-- U+86B8 .. U+86BF --*/
   "Zhu "  , "Diao " , "Bie "  , "Bing " , "Gu "   , "Ran "  , "Qu "   , "She "  ,  /*-- U+86C0 .. U+86C7 --*/
   "Tie "  , "Ling " , "Gu "   , "Dan "  , "Gu "   , "Ying " , "Li "   , "Cheng ",  /*-- U+86C8 .. U+86CF --*/
   "Qu "   , "Mou "  , "Ge "   , "Ci "   , "Hui "  , "Hui "  , "Mang " , "Fu "   ,  /*-- U+86D0 .. U+86D7 --*/
   "Yang " , "Wa "   , "Lie "  , "Zhu "  , "Yi "   , "Xian " , "Kuo "  , "Jiao " ,  /*-- U+86D8 .. U+86DF --*/
   "Li "   , "Yi "   , "Ping " , "Ji "   , "Ha "   , "She "  , "Yi "   , "Wang " ,  /*-- U+86E0 .. U+86E7 --*/
   "Mo "   , "Qiong ", "Qie "  , "Gui "  , "Gong " , "Zhi "  , "Man "  , "Ebi "  ,  /*-- U+86E8 .. U+86EF --*/
   "Zhi "  , "Jia "  , "Rao "  , "Si "   , "Qi "   , "Xing " , "Lie "  , "Qiu "  ,  /*-- U+86F0 .. U+86F7 --*/
   "Shao " , "Yong " , "Jia "  , "Shui " , "Che "  , "Bai "  , "E "    , "Han "  ,  /*-- U+86F8 .. U+86FF --*/
   "Shu "  , "Xuan " , "Feng " , "Shen " , "Zhen " , "Fu "   , "Xian " , "Zhe "  ,  /*-- U+8700 .. U+8707 --*/
   "Wu "   , "Fu "   , "Li "   , "Lang " , "Bi "   , "Chu "  , "Yuan " , "You "  ,  /*-- U+8708 .. U+870F --*/
   "Jie "  , "Dan "  , "Yan "  , "Ting " , "Dian " , "Shui " , "Hui "  , "Gua "  ,  /*-- U+8710 .. U+8717 --*/
   "Zhi "  , "Song " , "Fei "  , "Ju "   , "Mi "   , "Qi "   , "Qi "   , "Yu "   ,  /*-- U+8718 .. U+871F --*/
   "Jun "  , "Zha "  , "Meng " , "Qiang ", "Si "   , "Xi "   , "Lun "  , "Li "   ,  /*-- U+8720 .. U+8727 --*/
   "Die "  , "Tiao " , "Tao "  , "Kun "  , "Gan "  , "Han "  , "Yu "   , "Bang " ,  /*-- U+8728 .. U+872F --*/
   "Fei "  , "Pi "   , "Wei "  , "Dun "  , "Yi "   , "Yuan " , "Su "   , "Quan " ,  /*-- U+8730 .. U+8737 --*/
   "Qian " , "Rui "  , "Ni "   , "Qing " , "Wei "  , "Liang ", "Guo "  , "Wan "  ,  /*-- U+8738 .. U+873F --*/
   "Dong " , "E "    , "Ban "  , "Di "   , "Wang " , "Can "  , "Yang " , "Ying " ,  /*-- U+8740 .. U+8747 --*/
   "Guo "  , "Chan " , ""      , "La "   , "Ke "   , "Ji "   , "He "   , "Ting " ,  /*-- U+8748 .. U+874F --*/
   "Mai "  , "Xu "   , "Mian " , "Yu "   , "Jie "  , "Shi "  , "Xuan " , "Huang ",  /*-- U+8750 .. U+8757 --*/
   "Yan "  , "Bian " , "Rou "  , "Wei "  , "Fu "   , "Yuan " , "Mei "  , "Wei "  ,  /*-- U+8758 .. U+875F --*/
   "Fu "   , "Ruan " , "Xie "  , "You "  , "Qiu "  , "Mao "  , "Xia "  , "Ying " ,  /*-- U+8760 .. U+8767 --*/
   "Shi "  , "Chong ", "Tang " , "Zhu "  , "Zong " , "Ti "   , "Fu "   , "Yuan " ,  /*-- U+8768 .. U+876F --*/
   "Hui "  , "Meng " , "La "   , "Du "   , "Hu "   , "Qiu "  , "Die "  , "Li "   ,  /*-- U+8770 .. U+8777 --*/
   "Gua "  , "Yun "  , "Ju "   , "Nan "  , "Lou "  , "Qun "  , "Rong " , "Ying " ,  /*-- U+8778 .. U+877F --*/
   "Jiang ", ""      , "Lang " , "Pang " , "Si "   , "Xi "   , "Ci "   , "Xi "   ,  /*-- U+8780 .. U+8787 --*/
   "Yuan " , "Weng " , "Lian " , "Sou "  , "Ban "  , "Rong " , "Rong " , "Ji "   ,  /*-- U+8788 .. U+878F --*/
   "Wu "   , "Qiu "  , "Han "  , "Qin "  , "Yi "   , "Bi "   , "Hua "  , "Tang " ,  /*-- U+8790 .. U+8797 --*/
   "Yi "   , "Du "   , "Nai "  , "He "   , "Hu "   , "Hui "  , "Ma "   , "Ming " ,  /*-- U+8798 .. U+879F --*/
   "Yi "   , "Wen "  , "Ying " , "Teng " , "Yu "   , "Cang " , "So "   , "Ebi "  ,  /*-- U+87A0 .. U+87A7 --*/
   "Man "  , ""      , "Shang ", "Zhe "  , "Cao "  , "Chi "  , "Di "   , "Ao "   ,  /*-- U+87A8 .. U+87AF --*/
   "Lu "   , "Wei "  , "Zhi "  , "Tang " , "Chen " , "Piao " , "Qu "   , "Pi "   ,  /*-- U+87B0 .. U+87B7 --*/
   "Yu "   , "Jian " , "Luo "  , "Lou "  , "Qin "  , "Zhong ", "Yin "  , "Jiang ",  /*-- U+87B8 .. U+87BF --*/
   "Shuai ", "Wen "  , "Jiao " , "Wan "  , "Zhi "  , "Zhe "  , "Ma "   , "Ma "   ,  /*-- U+87C0 .. U+87C7 --*/
   "Guo "  , "Liu "  , "Mao "  , "Xi "   , "Cong " , "Li "   , "Man "  , "Xiao " ,  /*-- U+87C8 .. U+87CF --*/
   "Kamakiri ", "Zhang ", "Mang " , "Xiang ", "Mo "   , "Zui "  , "Si "   , "Qiu "  ,  /*-- U+87D0 .. U+87D7 --*/
   "Te "   , "Zhi "  , "Peng " , "Peng " , "Jiao " , "Qu "   , "Bie "  , "Liao " ,  /*-- U+87D8 .. U+87DF --*/
   "Pan "  , "Gui "  , "Xi "   , "Ji "   , "Zhuan ", "Huang ", "Fei "  , "Lao "  ,  /*-- U+87E0 .. U+87E7 --*/
   "Jue "  , "Jue "  , "Hui "  , "Yin "  , "Chan " , "Jiao " , "Shan " , "Rao "  ,  /*-- U+87E8 .. U+87EF --*/
   "Xiao " , "Mou "  , "Chong ", "Xun "  , "Si "   , ""      , "Cheng ", "Dang " ,  /*-- U+87F0 .. U+87F7 --*/
   "Li "   , "Xie "  , "Shan " , "Yi "   , "Jing " , "Da "   , "Chan " , "Qi "   ,  /*-- U+87F8 .. U+87FF --*/
   "Ci "   , "Xiang ", "She "  , "Luo "  , "Qin "  , "Ying " , "Chai " , "Li "   ,  /*-- U+8800 .. U+8807 --*/
   "Ze "   , "Xuan " , "Lian " , "Zhu "  , "Ze "   , "Xie "  , "Mang " , "Xie "  ,  /*-- U+8808 .. U+880F --*/
   "Qi "   , "Rong " , "Jian " , "Meng " , "Hao "  , "Ruan " , "Huo "  , "Zhuo " ,  /*-- U+8810 .. U+8817 --*/
   "Jie "  , "Bin "  , "He "   , "Mie "  , "Fan "  , "Lei "  , "Jie "  , "La "   ,  /*-- U+8818 .. U+881F --*/
   "Mi "   , "Li "   , "Chun " , "Li "   , "Qiu "  , "Nie "  , "Lu "   , "Du "   ,  /*-- U+8820 .. U+8827 --*/
   "Xiao " , "Zhu "  , "Long " , "Li "   , "Long " , "Feng " , "Ye "   , "Beng " ,  /*-- U+8828 .. U+882F --*/
   "Shang ", "Gu "   , "Juan " , "Ying " , ""      , "Xi "   , "Can "  , "Qu "   ,  /*-- U+8830 .. U+8837 --*/
   "Quan " , "Du "   , "Can "  , "Man "  , "Jue "  , "Jie "  , "Zhu "  , "Zha "  ,  /*-- U+8838 .. U+883F --*/
   "Xie "  , "Huang ", "Niu "  , "Pei "  , "Nu "   , "Xin "  , "Zhong ", "Mo "   ,  /*-- U+8840 .. U+8847 --*/
   "Er "   , "Ke "   , "Mie "  , "Xi "   , "Xing " , "Yan "  , "Kan "  , "Yuan " ,  /*-- U+8848 .. U+884F --*/
   ""      , "Ling " , "Xuan " , "Shu "  , "Xian " , "Tong " , "Long " , "Jie "  ,  /*-- U+8850 .. U+8857 --*/
   "Xian " , "Ya "   , "Hu "   , "Wei "  , "Dao "  , "Chong ", "Wei "  , "Dao "  ,  /*-- U+8858 .. U+885F --*/
   "Zhun " , "Heng " , "Qu "   , "Yi "   , "Yi "   , "Bu "   , "Gan "  , "Yu "   ,  /*-- U+8860 .. U+8867 --*/
   "Biao " , "Cha "  , "Yi "   , "Shan " , "Chen " , "Fu "   , "Gun "  , "Fen "  ,  /*-- U+8868 .. U+886F --*/
   "Shuai ", "Jie "  , "Na "   , "Zhong ", "Dan "  , "Ri "   , "Zhong ", "Zhong ",  /*-- U+8870 .. U+8877 --*/
   "Xie "  , "Qi "   , "Xie "  , "Ran "  , "Zhi "  , "Ren "  , "Qin "  , "Jin "  ,  /*-- U+8878 .. U+887F --*/
   "Jun "  , "Yuan " , "Mei "  , "Chai " , "Ao "   , "Niao " , "Hui "  , "Ran "  ,  /*-- U+8880 .. U+8887 --*/
   "Jia "  , "Tuo "  , "Ling " , "Dai "  , "Bao "  , "Pao "  , "Yao "  , "Zuo "  ,  /*-- U+8888 .. U+888F --*/
   "Bi "   , "Shao " , "Tan "  , "Ju "   , "He "   , "Shu "  , "Xiu "  , "Zhen " ,  /*-- U+8890 .. U+8897 --*/
   "Yi "   , "Pa "   , "Bo "   , "Di "   , "Wa "   , "Fu "   , "Gun "  , "Zhi "  ,  /*-- U+8898 .. U+889F --*/
   "Zhi "  , "Ran "  , "Pan "  , "Yi "   , "Mao "  , "Tuo "  , "Na "   , "Kou "  ,  /*-- U+88A0 .. U+88A7 --*/
   "Xian " , "Chan " , "Qu "   , "Bei "  , "Gun "  , "Xi "   , "Ne "   , "Bo "   ,  /*-- U+88A8 .. U+88AF --*/
   "Horo " , "Fu "   , "Yi "   , "Chi "  , "Ku "   , "Ren "  , "Jiang ", "Jia "  ,  /*-- U+88B0 .. U+88B7 --*/
   "Cun "  , "Mo "   , "Jie "  , "Er "   , "Luo "  , "Ru "   , "Zhu "  , "Gui "  ,  /*-- U+88B8 .. U+88BF --*/
   "Yin "  , "Cai "  , "Lie "  , "Kamishimo ", "Yuki " , "Zhuang ", "Dang " , ""      ,  /*-- U+88C0 .. U+88C7 --*/
   "Kun "  , "Ken "  , "Niao " , "Shu "  , "Jia "  , "Kun "  , "Cheng ", "Li "   ,  /*-- U+88C8 .. U+88CF --*/
   "Juan " , "Shen " , "Pou "  , "Ge "   , "Yi "   , "Yu "   , "Zhen " , "Liu "  ,  /*-- U+88D0 .. U+88D7 --*/
   "Qiu "  , "Qun "  , "Ji "   , "Yi "   , "Bu "   , "Zhuang ", "Shui " , "Sha "  ,  /*-- U+88D8 .. U+88DF --*/
   "Qun "  , "Li "   , "Lian " , "Lian " , "Ku "   , "Jian " , "Fou "  , "Chan " ,  /*-- U+88E0 .. U+88E7 --*/
   "Bi "   , "Gun "  , "Tao "  , "Yuan " , "Ling " , "Chi "  , "Chang ", "Chou " ,  /*-- U+88E8 .. U+88EF --*/
   "Duo "  , "Biao " , "Liang ", "Chang ", "Pei "  , "Pei "  , "Fei "  , "Yuan " ,  /*-- U+88F0 .. U+88F7 --*/
   "Luo "  , "Guo "  , "Yan "  , "Du "   , "Xi "   , "Zhi "  , "Ju "   , "Qi "   ,  /*-- U+88F8 .. U+88FF --*/
   "Ji "   , "Zhi "  , "Gua "  , "Ken "  , "Che "  , "Ti "   , "Ti "   , "Fu "   ,  /*-- U+8900 .. U+8907 --*/
   "Chong ", "Xie "  , "Bian " , "Die "  , "Kun "  , "Duan " , "Xiu "  , "Xiu "  ,  /*-- U+8908 .. U+890F --*/
   "He "   , "Yuan " , "Bao "  , "Bao "  , "Fu "   , "Yu "   , "Tuan " , "Yan "  ,  /*-- U+8910 .. U+8917 --*/
   "Hui "  , "Bei "  , "Chu "  , "Lu "   , "Ena "  , "Hitoe ", "Yun "  , "Da "   ,  /*-- U+8918 .. U+891F --*/
   "Gou "  , "Da "   , "Huai " , "Rong " , "Yuan " , "Ru "   , "Nai "  , "Jiong ",  /*-- U+8920 .. U+8927 --*/
   "Suo "  , "Ban "  , "Tun "  , "Chi "  , "Sang " , "Niao " , "Ying " , "Jie "  ,  /*-- U+8928 .. U+892F --*/
   "Qian " , "Huai " , "Ku "   , "Lian " , "Bao "  , "Li "   , "Zhe "  , "Shi "  ,  /*-- U+8930 .. U+8937 --*/
   "Lu "   , "Yi "   , "Die "  , "Xie "  , "Xian " , "Wei "  , "Biao " , "Cao "  ,  /*-- U+8938 .. U+893F --*/
   "Ji "   , "Jiang ", "Sen "  , "Bao "  , "Xiang ", "Chihaya ", "Pu "   , "Jian " ,  /*-- U+8940 .. U+8947 --*/
   "Zhuan ", "Jian " , "Zui "  , "Ji "   , "Dan "  , "Za "   , "Fan "  , "Bo "   ,  /*-- U+8948 .. U+894F --*/
   "Xiang ", "Xin "  , "Bie "  , "Rao "  , "Man "  , "Lan "  , "Ao "   , "Duo "  ,  /*-- U+8950 .. U+8957 --*/
   "Gui "  , "Cao "  , "Sui "  , "Nong " , "Chan " , "Lian " , "Bi "   , "Jin "  ,  /*-- U+8958 .. U+895F --*/
   "Dang " , "Shu "  , "Tan "  , "Bi "   , "Lan "  , "Pu "   , "Ru "   , "Zhi "  ,  /*-- U+8960 .. U+8967 --*/
   ""      , "Shu "  , "Wa "   , "Shi "  , "Bai "  , "Xie "  , "Bo "   , "Chen " ,  /*-- U+8968 .. U+896F --*/
   "Lai "  , "Long " , "Xi "   , "Xian " , "Lan "  , "Zhe "  , "Dai "  , "Tasuki ",  /*-- U+8970 .. U+8977 --*/
   "Zan "  , "Shi "  , "Jian " , "Pan "  , "Yi "   , "Ran "  , "Ya "   , "Xi "   ,  /*-- U+8978 .. U+897F --*/
   "Xi "   , "Yao "  , "Feng " , "Tan "  , ""      , "Biao " , "Fu "   , "Ba "   ,  /*-- U+8980 .. U+8987 --*/
   "He "   , "Ji "   , "Ji "   , "Jian " , "Guan " , "Bian " , "Yan "  , "Gui "  ,  /*-- U+8988 .. U+898F --*/
   "Jue "  , "Pian " , "Mao "  , "Mi "   , "Mi "   , "Mie "  , "Shi "  , "Si "   ,  /*-- U+8990 .. U+8997 --*/
   "Zhan " , "Luo "  , "Jue "  , "Mi "   , "Tiao " , "Lian " , "Yao "  , "Zhi "  ,  /*-- U+8998 .. U+899F --*/
   "Jun "  , "Xi "   , "Shan " , "Wei "  , "Xi "   , "Tian " , "Yu "   , "Lan "  ,  /*-- U+89A0 .. U+89A7 --*/
   "E "    , "Du "   , "Qin "  , "Pang " , "Ji "   , "Ming " , "Ying " , "Gou "  ,  /*-- U+89A8 .. U+89AF --*/
   "Qu "   , "Zhan " , "Jin "  , "Guan " , "Deng " , "Jian " , "Luo "  , "Qu "   ,  /*-- U+89B0 .. U+89B7 --*/
   "Jian " , "Wei "  , "Jue "  , "Qu "   , "Luo "  , "Lan "  , "Shen " , "Di "   ,  /*-- U+89B8 .. U+89BF --*/
   "Guan " , "Jian " , "Guan " , "Yan "  , "Gui "  , "Mi "   , "Shi "  , "Zhan " ,  /*-- U+89C0 .. U+89C7 --*/
   "Lan "  , "Jue "  , "Ji "   , "Xi "   , "Di "   , "Tian " , "Yu "   , "Gou "  ,  /*-- U+89C8 .. U+89CF --*/
   "Jin "  , "Qu "   , "Jiao " , "Jiu "  , "Jin "  , "Cu "   , "Jue "  , "Zhi "  ,  /*-- U+89D0 .. U+89D7 --*/
   "Chao " , "Ji "   , "Gu "   , "Dan "  , "Zui "  , "Di "   , "Shang ", "Hua "  ,  /*-- U+89D8 .. U+89DF --*/
   "Quan " , "Ge "   , "Chi "  , "Jie "  , "Gui "  , "Gong " , "Hong " , "Jie "  ,  /*-- U+89E0 .. U+89E7 --*/
   "Hun "  , "Qiu "  , "Xing " , "Su "   , "Ni "   , "Ji "   , "Lu "   , "Zhi "  ,  /*-- U+89E8 .. U+89EF --*/
   "Zha "  , "Bi "   , "Xing " , "Hu "   , "Shang ", "Gong " , "Zhi "  , "Xue "  ,  /*-- U+89F0 .. U+89F7 --*/
   "Chu "  , "Xi "   , "Yi "   , "Lu "   , "Jue "  , "Xi "   , "Yan "  , "Xi "   ,  /*-- U+89F8 .. U+89FF --*/
   "Yan "  , "Yan "  , "Ding " , "Fu "   , "Qiu "  , "Qiu "  , "Jiao " , "Hong " ,  /*-- U+8A00 .. U+8A07 --*/
   "Ji "   , "Fan "  , "Xun "  , "Diao " , "Hong " , "Cha "  , "Tao "  , "Xu "   ,  /*-- U+8A08 .. U+8A0F --*/
   "Jie "  , "Yi "   , "Ren "  , "Xun "  , "Yin "  , "Shan " , "Qi "   , "Tuo "  ,  /*-- U+8A10 .. U+8A17 --*/
   "Ji "   , "Xun "  , "Yin "  , "E "    , "Fen "  , "Ya "   , "Yao "  , "Song " ,  /*-- U+8A18 .. U+8A1F --*/
   "Shen " , "Yin "  , "Xin "  , "Jue "  , "Xiao " , "Ne "   , "Chen " , "You "  ,  /*-- U+8A20 .. U+8A27 --*/
   "Zhi "  , "Xiong ", "Fang " , "Xin "  , "Chao " , "She "  , "Xian " , "Sha "  ,  /*-- U+8A28 .. U+8A2F --*/
   "Tun "  , "Xu "   , "Yi "   , "Yi "   , "Su "   , "Chi "  , "He "   , "Shen " ,  /*-- U+8A30 .. U+8A37 --*/
   "He "   , "Xu "   , "Zhen " , "Zhu "  , "Zheng ", "Gou "  , "Zi "   , "Zi "   ,  /*-- U+8A38 .. U+8A3F --*/
   "Zhan " , "Gu "   , "Fu "   , "Quan " , "Die "  , "Ling " , "Di "   , "Yang " ,  /*-- U+8A40 .. U+8A47 --*/
   "Li "   , "Nao "  , "Pan "  , "Zhou " , "Gan "  , "Yi "   , "Ju "   , "Ao "   ,  /*-- U+8A48 .. U+8A4F --*/
   "Zha "  , "Tuo "  , "Yi "   , "Qu "   , "Zhao " , "Ping " , "Bi "   , "Xiong ",  /*-- U+8A50 .. U+8A57 --*/
   "Qu "   , "Ba "   , "Da "   , "Zu "   , "Tao "  , "Zhu "  , "Ci "   , "Zhe "  ,  /*-- U+8A58 .. U+8A5F --*/
   "Yong " , "Xu "   , "Xun "  , "Yi "   , "Huang ", "He "   , "Shi "  , "Cha "  ,  /*-- U+8A60 .. U+8A67 --*/
   "Jiao " , "Shi "  , "Hen "  , "Cha "  , "Gou "  , "Gui "  , "Quan " , "Hui "  ,  /*-- U+8A68 .. U+8A6F --*/
   "Jie "  , "Hua "  , "Gai "  , "Xiang ", "Wei "  , "Shen " , "Chou " , "Tong " ,  /*-- U+8A70 .. U+8A77 --*/
   "Mi "   , "Zhan " , "Ming " , "E "    , "Hui "  , "Yan "  , "Xiong ", "Gua "  ,  /*-- U+8A78 .. U+8A7F --*/
   "Er "   , "Beng " , "Tiao " , "Chi "  , "Lei "  , "Zhu "  , "Kuang ", "Kua "  ,  /*-- U+8A80 .. U+8A87 --*/
   "Wu "   , "Yu "   , "Teng " , "Ji "   , "Zhi "  , "Ren "  , "Su "   , "Lang " ,  /*-- U+8A88 .. U+8A8F --*/
   "E "    , "Kuang ", "E "    , "Shi "  , "Ting " , "Dan "  , "Bo "   , "Chan " ,  /*-- U+8A90 .. U+8A97 --*/
   "You "  , "Heng " , "Qiao " , "Qin "  , "Shua " , "An "   , "Yu "   , "Xiao " ,  /*-- U+8A98 .. U+8A9F --*/
   "Cheng ", "Jie "  , "Xian " , "Wu "   , "Wu "   , "Gao "  , "Song " , "Pu "   ,  /*-- U+8AA0 .. U+8AA7 --*/
   "Hui "  , "Jing " , "Shuo " , "Zhen " , "Shuo " , "Du "   , "Yasashi ", "Chang ",  /*-- U+8AA8 .. U+8AAF --*/
   "Shui " , "Jie "  , "Ke "   , "Qu "   , "Cong " , "Xiao " , "Sui "  , "Wang " ,  /*-- U+8AB0 .. U+8AB7 --*/
   "Xuan " , "Fei "  , "Chi "  , "Ta "   , "Yi "   , "Na "   , "Yin "  , "Diao " ,  /*-- U+8AB8 .. U+8ABF --*/
   "Pi "   , "Chuo " , "Chan " , "Chen " , "Zhun " , "Ji "   , "Qi "   , "Tan "  ,  /*-- U+8AC0 .. U+8AC7 --*/
   "Zhui " , "Wei "  , "Ju "   , "Qing " , "Jian " , "Zheng ", "Ze "   , "Zou "  ,  /*-- U+8AC8 .. U+8ACF --*/
   "Qian " , "Zhuo " , "Liang ", "Jian " , "Zhu "  , "Hao "  , "Lun "  , "Shen " ,  /*-- U+8AD0 .. U+8AD7 --*/
   "Biao " , "Huai " , "Pian " , "Yu "   , "Die "  , "Xu "   , "Pian " , "Shi "  ,  /*-- U+8AD8 .. U+8ADF --*/
   "Xuan " , "Shi "  , "Hun "  , "Hua "  , "E "    , "Zhong ", "Di "   , "Xie "  ,  /*-- U+8AE0 .. U+8AE7 --*/
   "Fu "   , "Pu "   , "Ting " , "Jian " , "Qi "   , "Yu "   , "Zi "   , "Chuan ",  /*-- U+8AE8 .. U+8AEF --*/
   "Xi "   , "Hui "  , "Yin "  , "An "   , "Xian " , "Nan "  , "Chen " , "Feng " ,  /*-- U+8AF0 .. U+8AF7 --*/
   "Zhu "  , "Yang " , "Yan "  , "Heng " , "Xuan " , "Ge "   , "Nuo "  , "Qi "   ,  /*-- U+8AF8 .. U+8AFF --*/
   "Mou "  , "Ye "   , "Wei "  , ""      , "Teng " , "Zou "  , "Shan " , "Jian " ,  /*-- U+8B00 .. U+8B07 --*/
   "Bo "   , "Ku "   , "Huang ", "Huo "  , "Ge "   , "Ying " , "Mi "   , "Xiao " ,  /*-- U+8B08 .. U+8B0F --*/
   "Mi "   , "Xi "   , "Qiang ", "Chen " , "Nue "  , "Ti "   , "Su "   , "Bang " ,  /*-- U+8B10 .. U+8B17 --*/
   "Chi "  , "Qian " , "Shi "  , "Jiang ", "Yuan " , "Xie "  , "Xue "  , "Tao "  ,  /*-- U+8B18 .. U+8B1F --*/
   "Yao "  , "Yao "  , ""      , "Yu "   , "Biao " , "Cong " , "Qing " , "Li "   ,  /*-- U+8B20 .. U+8B27 --*/
   "Mo "   , "Mo "   , "Shang ", "Zhe "  , "Miu "  , "Jian " , "Ze "   , "Jie "  ,  /*-- U+8B28 .. U+8B2F --*/
   "Lian " , "Lou "  , "Can "  , "Ou "   , "Guan " , "Xi "   , "Zhuo " , "Ao "   ,  /*-- U+8B30 .. U+8B37 --*/
   "Ao "   , "Jin "  , "Zhe "  , "Yi "   , "Hu "   , "Jiang ", "Man "  , "Chao " ,  /*-- U+8B38 .. U+8B3F --*/
   "Han "  , "Hua "  , "Chan " , "Xu "   , "Zeng " , "Se "   , "Xi "   , "She "  ,  /*-- U+8B40 .. U+8B47 --*/
   "Dui "  , "Zheng ", "Nao "  , "Lan "  , "E "    , "Ying " , "Jue "  , "Ji "   ,  /*-- U+8B48 .. U+8B4F --*/
   "Zun "  , "Jiao " , "Bo "   , "Hui "  , "Zhuan ", "Mu "   , "Zen "  , "Zha "  ,  /*-- U+8B50 .. U+8B57 --*/
   "Shi "  , "Qiao " , "Tan "  , "Zen "  , "Pu "   , "Sheng ", "Xuan " , "Zao "  ,  /*-- U+8B58 .. U+8B5F --*/
   "Tan "  , "Dang " , "Sui "  , "Qian " , "Ji "   , "Jiao " , "Jing " , "Lian " ,  /*-- U+8B60 .. U+8B67 --*/
   "Nou "  , "Yi "   , "Ai "   , "Zhan " , "Pi "   , "Hui "  , "Hua "  , "Yi "   ,  /*-- U+8B68 .. U+8B6F --*/
   "Yi "   , "Shan " , "Rang " , "Nou "  , "Qian " , "Zhui " , "Ta "   , "Hu "   ,  /*-- U+8B70 .. U+8B77 --*/
   "Zhou " , "Hao "  , "Ye "   , "Ying " , "Jian " , "Yu "   , "Jian " , "Hui "  ,  /*-- U+8B78 .. U+8B7F --*/
   "Du "   , "Zhe "  , "Xuan " , "Zan "  , "Lei "  , "Shen " , "Wei "  , "Chan " ,  /*-- U+8B80 .. U+8B87 --*/
   "Li "   , "Yi "   , "Bian " , "Zhe "  , "Yan "  , "E "    , "Chou " , "Wei "  ,  /*-- U+8B88 .. U+8B8F --*/
   "Chou " , "Yao "  , "Chan " , "Rang " , "Yin "  , "Lan "  , "Chen " , "Huo "  ,  /*-- U+8B90 .. U+8B97 --*/
   "Zhe "  , "Huan " , "Zan "  , "Yi "   , "Dang " , "Zhan " , "Yan "  , "Du "   ,  /*-- U+8B98 .. U+8B9F --*/
   "Yan "  , "Ji "   , "Ding " , "Fu "   , "Ren "  , "Ji "   , "Jie "  , "Hong " ,  /*-- U+8BA0 .. U+8BA7 --*/
   "Tao "  , "Rang " , "Shan " , "Qi "   , "Tuo "  , "Xun "  , "Yi "   , "Xun "  ,  /*-- U+8BA8 .. U+8BAF --*/
   "Ji "   , "Ren "  , "Jiang ", "Hui "  , "Ou "   , "Ju "   , "Ya "   , "Ne "   ,  /*-- U+8BB0 .. U+8BB7 --*/
   "Xu "   , "E "    , "Lun "  , "Xiong ", "Song " , "Feng " , "She "  , "Fang " ,  /*-- U+8BB8 .. U+8BBF --*/
   "Jue "  , "Zheng ", "Gu "   , "He "   , "Ping " , "Zu "   , "Shi "  , "Xiong ",  /*-- U+8BC0 .. U+8BC7 --*/
   "Zha "  , "Su "   , "Zhen " , "Di "   , "Zou "  , "Ci "   , "Qu "   , "Zhao " ,  /*-- U+8BC8 .. U+8BCF --*/
   "Bi "   , "Yi "   , "Yi "   , "Kuang ", "Lei "  , "Shi "  , "Gua "  , "Shi "  ,  /*-- U+8BD0 .. U+8BD7 --*/
   "Jie "  , "Hui "  , "Cheng ", "Zhu "  , "Shen " , "Hua "  , "Dan "  , "Gou "  ,  /*-- U+8BD8 .. U+8BDF --*/
   "Quan " , "Gui "  , "Xun "  , "Yi "   , "Zheng ", "Gai "  , "Xiang ", "Cha "  ,  /*-- U+8BE0 .. U+8BE7 --*/
   "Hun "  , "Xu "   , "Zhou " , "Jie "  , "Wu "   , "Yu "   , "Qiao " , "Wu "   ,  /*-- U+8BE8 .. U+8BEF --*/
   "Gao "  , "You "  , "Hui "  , "Kuang ", "Shuo " , "Song " , "Ai "   , "Qing " ,  /*-- U+8BF0 .. U+8BF7 --*/
   "Zhu "  , "Zou "  , "Nuo "  , "Du "   , "Zhuo " , "Fei "  , "Ke "   , "Wei "  ,  /*-- U+8BF8 .. U+8BFF --*/
   "Yu "   , "Shui " , "Shen " , "Diao " , "Chan " , "Liang ", "Zhun " , "Sui "  ,  /*-- U+8C00 .. U+8C07 --*/
   "Tan "  , "Shen " , "Yi "   , "Mou "  , "Chen " , "Die "  , "Huang ", "Jian " ,  /*-- U+8C08 .. U+8C0F --*/
   "Xie "  , "Nue "  , "Ye "   , "Wei "  , "E "    , "Yu "   , "Xuan " , "Chan " ,  /*-- U+8C10 .. U+8C17 --*/
   "Zi "   , "An "   , "Yan "  , "Di "   , "Mi "   , "Pian " , "Xu "   , "Mo "   ,  /*-- U+8C18 .. U+8C1F --*/
   "Dang " , "Su "   , "Xie "  , "Yao "  , "Bang " , "Shi "  , "Qian " , "Mi "   ,  /*-- U+8C20 .. U+8C27 --*/
   "Jin "  , "Man "  , "Zhe "  , "Jian " , "Miu "  , "Tan "  , "Zen "  , "Qiao " ,  /*-- U+8C28 .. U+8C2F --*/
   "Lan "  , "Pu "   , "Jue "  , "Yan "  , "Qian " , "Zhan " , "Chen " , "Gu "   ,  /*-- U+8C30 .. U+8C37 --*/
   "Qian " , "Hong " , "Xia "  , "Jue "  , "Hong " , "Han "  , "Hong " , "Xi "   ,  /*-- U+8C38 .. U+8C3F --*/
   "Xi "   , "Huo "  , "Liao " , "Han "  , "Du "   , "Long " , "Dou "  , "Jiang ",  /*-- U+8C40 .. U+8C47 --*/
   "Qi "   , "Shi "  , "Li "   , "Deng " , "Wan "  , "Bi "   , "Shu "  , "Xian " ,  /*-- U+8C48 .. U+8C4F --*/
   "Feng " , "Zhi "  , "Zhi "  , "Yan "  , "Yan "  , "Shi "  , "Chu "  , "Hui "  ,  /*-- U+8C50 .. U+8C57 --*/
   "Tun "  , "Yi "   , "Tun "  , "Yi "   , "Jian " , "Ba "   , "Hou "  , "E "    ,  /*-- U+8C58 .. U+8C5F --*/
   "Cu "   , "Xiang ", "Huan " , "Jian " , "Ken "  , "Gai "  , "Qu "   , "Fu "   ,  /*-- U+8C60 .. U+8C67 --*/
   "Xi "   , "Bin "  , "Hao "  , "Yu "   , "Zhu "  , "Jia "  , ""      , "Xi "   ,  /*-- U+8C68 .. U+8C6F --*/
   "Bo "   , "Wen "  , "Huan " , "Bin "  , "Di "   , "Zong " , "Fen "  , "Yi "   ,  /*-- U+8C70 .. U+8C77 --*/
   "Zhi "  , "Bao "  , "Chai " , "Han "  , "Pi "   , "Na "   , "Pi "   , "Gou "  ,  /*-- U+8C78 .. U+8C7F --*/
   "Na "   , "You "  , "Diao " , "Mo "   , "Si "   , "Xiu "  , "Huan " , "Kun "  ,  /*-- U+8C80 .. U+8C87 --*/
   "He "   , "He "   , "Mo "   , "Han "  , "Mao "  , "Li "   , "Ni "   , "Bi "   ,  /*-- U+8C88 .. U+8C8F --*/
   "Yu "   , "Jia "  , "Tuan " , "Mao "  , "Pi "   , "Xi "   , "E "    , "Ju "   ,  /*-- U+8C90 .. U+8C97 --*/
   "Mo "   , "Chu "  , "Tan "  , "Huan " , "Jue "  , "Bei "  , "Zhen " , "Yuan " ,  /*-- U+8C98 .. U+8C9F --*/
   "Fu "   , "Cai "  , "Gong " , "Te "   , "Yi "   , "Hang " , "Wan "  , "Pin "  ,  /*-- U+8CA0 .. U+8CA7 --*/
   "Huo "  , "Fan "  , "Tan "  , "Guan " , "Ze "   , "Zhi "  , "Er "   , "Zhu "  ,  /*-- U+8CA8 .. U+8CAF --*/
   "Shi "  , "Bi "   , "Zi "   , "Er "   , "Gui "  , "Pian " , "Bian " , "Mai "  ,  /*-- U+8CB0 .. U+8CB7 --*/
   "Dai "  , "Sheng ", "Kuang ", "Fei "  , "Tie "  , "Yi "   , "Chi "  , "Mao "  ,  /*-- U+8CB8 .. U+8CBF --*/
   "He "   , "Bi "   , "Lu "   , "Ren "  , "Hui "  , "Gai "  , "Pian " , "Zi "   ,  /*-- U+8CC0 .. U+8CC7 --*/
   "Jia "  , "Xu "   , "Zei "  , "Jiao " , "Gai "  , "Zang " , "Jian " , "Ying " ,  /*-- U+8CC8 .. U+8CCF --*/
   "Xun "  , "Zhen " , "She "  , "Bin "  , "Bin "  , "Qiu "  , "She "  , "Chuan ",  /*-- U+8CD0 .. U+8CD7 --*/
   "Zang " , "Zhou " , "Lai "  , "Zan "  , "Si "   , "Chen " , "Shang ", "Tian " ,  /*-- U+8CD8 .. U+8CDF --*/
   "Pei "  , "Geng " , "Xian " , "Mai "  , "Jian " , "Sui "  , "Fu "   , "Tan "  ,  /*-- U+8CE0 .. U+8CE7 --*/
   "Cong " , "Cong " , "Zhi "  , "Ji "   , "Zhang ", "Du "   , "Jin "  , "Xiong ",  /*-- U+8CE8 .. U+8CEF --*/
   "Shun " , "Yun "  , "Bao "  , "Zai "  , "Lai "  , "Feng " , "Cang " , "Ji "   ,  /*-- U+8CF0 .. U+8CF7 --*/
   "Sheng ", "Ai "   , "Zhuan ", "Fu "   , "Gou "  , "Sai "  , "Ze "   , "Liao " ,  /*-- U+8CF8 .. U+8CFF --*/
   "Wei "  , "Bai "  , "Chen " , "Zhuan ", "Zhi "  , "Zhui " , "Biao " , "Yun "  ,  /*-- U+8D00 .. U+8D07 --*/
   "Zeng " , "Tan "  , "Zan "  , "Yan "  , ""      , "Shan " , "Wan "  , "Ying " ,  /*-- U+8D08 .. U+8D0F --*/
   "Jin "  , "Gan "  , "Xian " , "Zang " , "Bi "   , "Du "   , "Shu "  , "Yan "  ,  /*-- U+8D10 .. U+8D17 --*/
   ""      , "Xuan " , "Long " , "Gan "  , "Zang " , "Bei "  , "Zhen " , "Fu "   ,  /*-- U+8D18 .. U+8D1F --*/
   "Yuan " , "Gong " , "Cai "  , "Ze "   , "Xian " , "Bai "  , "Zhang ", "Huo "  ,  /*-- U+8D20 .. U+8D27 --*/
   "Zhi "  , "Fan "  , "Tan "  , "Pin "  , "Bian " , "Gou "  , "Zhu "  , "Guan " ,  /*-- U+8D28 .. U+8D2F --*/
   "Er "   , "Jian " , "Bi "   , "Shi "  , "Tie "  , "Gui "  , "Kuang ", "Dai "  ,  /*-- U+8D30 .. U+8D37 --*/
   "Mao "  , "Fei "  , "He "   , "Yi "   , "Zei "  , "Zhi "  , "Jia "  , "Hui "  ,  /*-- U+8D38 .. U+8D3F --*/
   "Zi "   , "Ren "  , "Lu "   , "Zang " , "Zi "   , "Gai "  , "Jin "  , "Qiu "  ,  /*-- U+8D40 .. U+8D47 --*/
   "Zhen " , "Lai "  , "She "  , "Fu "   , "Du "   , "Ji "   , "Shu "  , "Shang ",  /*-- U+8D48 .. U+8D4F --*/
   "Si "   , "Bi "   , "Zhou " , "Geng " , "Pei "  , "Tan "  , "Lai "  , "Feng " ,  /*-- U+8D50 .. U+8D57 --*/
   "Zhui " , "Fu "   , "Zhuan ", "Sai "  , "Ze "   , "Yan "  , "Zan "  , "Yun "  ,  /*-- U+8D58 .. U+8D5F --*/
   "Zeng " , "Shan " , "Ying " , "Gan "  , "Chi "  , "Xi "   , "She "  , "Nan "  ,  /*-- U+8D60 .. U+8D67 --*/
   "Xiong ", "Xi "   , "Cheng ", "He "   , "Cheng ", "Zhe "  , "Xia "  , "Tang " ,  /*-- U+8D68 .. U+8D6F --*/
   "Zou "  , "Zou "  , "Li "   , "Jiu "  , "Fu "   , "Zhao " , "Gan "  , "Qi "   ,  /*-- U+8D70 .. U+8D77 --*/
   "Shan " , "Qiong ", "Qin "  , "Xian " , "Ci "   , "Jue "  , "Qin "  , "Chi "  ,  /*-- U+8D78 .. U+8D7F --*/
   "Ci "   , "Chen " , "Chen " , "Die "  , "Ju "   , "Chao " , "Di "   , "Se "   ,  /*-- U+8D80 .. U+8D87 --*/
   "Zhan " , "Zhu "  , "Yue "  , "Qu "   , "Jie "  , "Chi "  , "Chu "  , "Gua "  ,  /*-- U+8D88 .. U+8D8F --*/
   "Xue "  , "Ci "   , "Tiao " , "Duo "  , "Lie "  , "Gan "  , "Suo "  , "Cu "   ,  /*-- U+8D90 .. U+8D97 --*/
   "Xi "   , "Zhao " , "Su "   , "Yin "  , "Ju "   , "Jian " , "Que "  , "Tang " ,  /*-- U+8D98 .. U+8D9F --*/
   "Chuo " , "Cui "  , "Lu "   , "Qu "   , "Dang " , "Qiu "  , "Zi "   , "Ti "   ,  /*-- U+8DA0 .. U+8DA7 --*/
   "Qu "   , "Chi "  , "Huang ", "Qiao " , "Qiao " , "Yao "  , "Zao "  , "Ti "   ,  /*-- U+8DA8 .. U+8DAF --*/
   ""      , "Zan "  , "Zan "  , "Zu "   , "Pa "   , "Bao "  , "Ku "   , "Ke "   ,  /*-- U+8DB0 .. U+8DB7 --*/
   "Dun "  , "Jue "  , "Fu "   , "Chen " , "Jian " , "Fang " , "Zhi "  , "Sa "   ,  /*-- U+8DB8 .. U+8DBF --*/
   "Yue "  , "Pa "   , "Qi "   , "Yue "  , "Qiang ", "Tuo "  , "Tai "  , "Yi "   ,  /*-- U+8DC0 .. U+8DC7 --*/
   "Nian " , "Ling " , "Mei "  , "Ba "   , "Die "  , "Ku "   , "Tuo "  , "Jia "  ,  /*-- U+8DC8 .. U+8DCF --*/
   "Ci "   , "Pao "  , "Qia "  , "Zhu "  , "Ju "   , "Die "  , "Zhi "  , "Fu "   ,  /*-- U+8DD0 .. U+8DD7 --*/
   "Pan "  , "Ju "   , "Shan " , "Bo "   , "Ni "   , "Ju "   , "Li "   , "Gen "  ,  /*-- U+8DD8 .. U+8DDF --*/
   "Yi "   , "Ji "   , "Dai "  , "Xian " , "Jiao " , "Duo "  , "Zhu "  , "Zhuan ",  /*-- U+8DE0 .. U+8DE7 --*/
   "Kua "  , "Zhuai ", "Gui "  , "Qiong ", "Kui "  , "Xiang ", "Chi "  , "Lu "   ,  /*-- U+8DE8 .. U+8DEF --*/
   "Beng " , "Zhi "  , "Jia "  , "Tiao " , "Cai "  , "Jian " , "Ta "   , "Qiao " ,  /*-- U+8DF0 .. U+8DF7 --*/
   "Bi "   , "Xian " , "Duo "  , "Ji "   , "Ju "   , "Ji "   , "Shu "  , "Tu "   ,  /*-- U+8DF8 .. U+8DFF --*/
   "Chu "  , "Jing " , "Nie "  , "Xiao " , "Bo "   , "Chi "  , "Qun "  , "Mou "  ,  /*-- U+8E00 .. U+8E07 --*/
   "Shu "  , "Lang " , "Yong " , "Jiao " , "Chou " , "Qiao " , ""      , "Ta "   ,  /*-- U+8E08 .. U+8E0F --*/
   "Jian " , "Qi "   , "Wo "   , "Wei "  , "Zhuo " , "Jie "  , "Ji "   , "Nie "  ,  /*-- U+8E10 .. U+8E17 --*/
   "Ju "   , "Ju "   , "Lun "  , "Lu "   , "Leng " , "Huai " , "Ju "   , "Chi "  ,  /*-- U+8E18 .. U+8E1F --*/
   "Wan "  , "Quan " , "Ti "   , "Bo "   , "Zu "   , "Qie "  , "Ji "   , "Cu "   ,  /*-- U+8E20 .. U+8E27 --*/
   "Zong " , "Cai "  , "Zong " , "Peng " , "Zhi "  , "Zheng ", "Dian " , "Zhi "  ,  /*-- U+8E28 .. U+8E2F --*/
   "Yu "   , "Duo "  , "Dun "  , "Chun " , "Yong " , "Zhong ", "Di "   , "Zhe "  ,  /*-- U+8E30 .. U+8E37 --*/
   "Chen " , "Chuai ", "Jian " , "Gua "  , "Tang " , "Ju "   , "Fu "   , "Zu "   ,  /*-- U+8E38 .. U+8E3F --*/
   "Die "  , "Pian " , "Rou "  , "Nuo "  , "Ti "   , "Cha "  , "Tui "  , "Jian " ,  /*-- U+8E40 .. U+8E47 --*/
   "Dao "  , "Cuo "  , "Xi "   , "Ta "   , "Qiang ", "Zhan " , "Dian " , "Ti "   ,  /*-- U+8E48 .. U+8E4F --*/
   "Ji "   , "Nie "  , "Man "  , "Liu "  , "Zhan " , "Bi "   , "Chong ", "Lu "   ,  /*-- U+8E50 .. U+8E57 --*/
   "Liao " , "Cu "   , "Tang " , "Dai "  , "Suo "  , "Xi "   , "Kui "  , "Ji "   ,  /*-- U+8E58 .. U+8E5F --*/
   "Zhi "  , "Qiang ", "Di "   , "Man "  , "Zong " , "Lian " , "Beng " , "Zao "  ,  /*-- U+8E60 .. U+8E67 --*/
   "Nian " , "Bie "  , "Tui "  , "Ju "   , "Deng " , "Ceng " , "Xian " , "Fan "  ,  /*-- U+8E68 .. U+8E6F --*/
   "Chu "  , "Zhong ", "Dun "  , "Bo "   , "Cu "   , "Zu "   , "Jue "  , "Jue "  ,  /*-- U+8E70 .. U+8E77 --*/
   "Lin "  , "Ta "   , "Qiao " , "Qiao " , "Pu "   , "Liao " , "Dun "  , "Cuan " ,  /*-- U+8E78 .. U+8E7F --*/
   "Kuang ", "Zao "  , "Ta "   , "Bi "   , "Bi "   , "Zhu "  , "Ju "   , "Chu "  ,  /*-- U+8E80 .. U+8E87 --*/
   "Qiao " , "Dun "  , "Chou " , "Ji "   , "Wu "   , "Yue "  , "Nian " , "Lin "  ,  /*-- U+8E88 .. U+8E8F --*/
   "Lie "  , "Zhi "  , "Li "   , "Zhi "  , "Chan " , "Chu "  , "Duan " , "Wei "  ,  /*-- U+8E90 .. U+8E97 --*/
   "Long " , "Lin "  , "Xian " , "Wei "  , "Zuan " , "Lan "  , "Xie "  , "Rang " ,  /*-- U+8E98 .. U+8E9F --*/
   "Xie "  , "Nie "  , "Ta "   , "Qu "   , "Jie "  , "Cuan " , "Zuan " , "Xi "   ,  /*-- U+8EA0 .. U+8EA7 --*/
   "Kui "  , "Jue "  , "Lin "  , "Shen " , "Gong " , "Dan "  , "Segare ", "Qu "   ,  /*-- U+8EA8 .. U+8EAF --*/
   "Ti "   , "Duo "  , "Duo "  , "Gong " , "Lang " , "Nerau ", "Luo "  , "Ai "   ,  /*-- U+8EB0 .. U+8EB7 --*/
   "Ji "   , "Ju "   , "Tang " , "Utsuke ", ""      , "Yan "  , "Shitsuke ", "Kang " ,  /*-- U+8EB8 .. U+8EBF --*/
   "Qu "   , "Lou "  , "Lao "  , "Tuo "  , "Zhi "  , "Yagate ", "Ti "   , "Dao "  ,  /*-- U+8EC0 .. U+8EC7 --*/
   "Yagate ", "Yu "   , "Che "  , "Ya "   , "Gui "  , "Jun "  , "Wei "  , "Yue "  ,  /*-- U+8EC8 .. U+8ECF --*/
   "Xin "  , "Di "   , "Xuan " , "Fan "  , "Ren "  , "Shan " , "Qiang ", "Shu "  ,  /*-- U+8ED0 .. U+8ED7 --*/
   "Tun "  , "Chen " , "Dai "  , "E "    , "Na "   , "Qi "   , "Mao "  , "Ruan " ,  /*-- U+8ED8 .. U+8EDF --*/
   "Ren "  , "Fan "  , "Zhuan ", "Hong " , "Hu "   , "Qu "   , "Huang ", "Di "   ,  /*-- U+8EE0 .. U+8EE7 --*/
   "Ling " , "Dai "  , "Ao "   , "Zhen " , "Fan "  , "Kuang ", "Ang "  , "Peng " ,  /*-- U+8EE8 .. U+8EEF --*/
   "Bei "  , "Gu "   , "Ku "   , "Pao "  , "Zhu "  , "Rong " , "E "    , "Ba "   ,  /*-- U+8EF0 .. U+8EF7 --*/
   "Zhou " , "Zhi "  , "Yao "  , "Ke "   , "Yi "   , "Qing " , "Shi "  , "Ping " ,  /*-- U+8EF8 .. U+8EFF --*/
   "Er "   , "Qiong ", "Ju "   , "Jiao " , "Guang ", "Lu "   , "Kai "  , "Quan " ,  /*-- U+8F00 .. U+8F07 --*/
   "Zhou " , "Zai "  , "Zhi "  , "She "  , "Liang ", "Yu "   , "Shao " , "You "  ,  /*-- U+8F08 .. U+8F0F --*/
   "Huan " , "Yun "  , "Zhe "  , "Wan "  , "Fu "   , "Qing " , "Zhou " , "Ni "   ,  /*-- U+8F10 .. U+8F17 --*/
   "Ling " , "Zhe "  , "Zhan " , "Liang ", "Zi "   , "Hui "  , "Wang " , "Chuo " ,  /*-- U+8F18 .. U+8F1F --*/
   "Guo "  , "Kan "  , "Yi "   , "Peng " , "Qian " , "Gun "  , "Nian " , "Pian " ,  /*-- U+8F20 .. U+8F27 --*/
   "Guan " , "Bei "  , "Lun "  , "Pai "  , "Liang ", "Ruan " , "Rou "  , "Ji "   ,  /*-- U+8F28 .. U+8F2F --*/
   "Yang " , "Xian " , "Chuan ", "Cou "  , "Qun "  , "Ge "   , "You "  , "Hong " ,  /*-- U+8F30 .. U+8F37 --*/
   "Shu "  , "Fu "   , "Zi "   , "Fu "   , "Wen "  , "Ben "  , "Zhan " , "Yu "   ,  /*-- U+8F38 .. U+8F3F --*/
   "Wen "  , "Tao "  , "Gu "   , "Zhen " , "Xia "  , "Yuan " , "Lu "   , "Jiu "  ,  /*-- U+8F40 .. U+8F47 --*/
   "Chao " , "Zhuan ", "Wei "  , "Hun "  , "Sori " , "Che "  , "Jiao " , "Zhan " ,  /*-- U+8F48 .. U+8F4F --*/
   "Pu "   , "Lao "  , "Fen "  , "Fan "  , "Lin "  , "Ge "   , "Se "   , "Kan "  ,  /*-- U+8F50 .. U+8F57 --*/
   "Huan " , "Yi "   , "Ji "   , "Dui "  , "Er "   , "Yu "   , "Xian " , "Hong " ,  /*-- U+8F58 .. U+8F5F --*/
   "Lei "  , "Pei "  , "Li "   , "Li "   , "Lu "   , "Lin "  , "Che "  , "Ya "   ,  /*-- U+8F60 .. U+8F67 --*/
   "Gui "  , "Xuan " , "Di "   , "Ren "  , "Zhuan ", "E "    , "Lun "  , "Ruan " ,  /*-- U+8F68 .. U+8F6F --*/
   "Hong " , "Ku "   , "Ke "   , "Lu "   , "Zhou " , "Zhi "  , "Yi "   , "Hu "   ,  /*-- U+8F70 .. U+8F77 --*/
   "Zhen " , "Li "   , "Yao "  , "Qing " , "Shi "  , "Zai "  , "Zhi "  , "Jiao " ,  /*-- U+8F78 .. U+8F7F --*/
   "Zhou " , "Quan " , "Lu "   , "Jiao " , "Zhe "  , "Fu "   , "Liang ", "Nian " ,  /*-- U+8F80 .. U+8F87 --*/
   "Bei "  , "Hui "  , "Gun "  , "Wang " , "Liang ", "Chuo " , "Zi "   , "Cou "  ,  /*-- U+8F88 .. U+8F8F --*/
   "Fu "   , "Ji "   , "Wen "  , "Shu "  , "Pei "  , "Yuan " , "Xia "  , "Zhan " ,  /*-- U+8F90 .. U+8F97 --*/
   "Lu "   , "Che "  , "Lin "  , "Xin "  , "Gu "   , "Ci "   , "Ci "   , "Pi "   ,  /*-- U+8F98 .. U+8F9F --*/
   "Zui "  , "Bian " , "La "   , "La "   , "Ci "   , "Xue "  , "Ban "  , "Bian " ,  /*-- U+8FA0 .. U+8FA7 --*/
   "Bian " , "Bian " , ""      , "Bian " , "Ban "  , "Ci "   , "Bian " , "Bian " ,  /*-- U+8FA8 .. U+8FAF --*/
   "Chen " , "Ru "   , "Nong " , "Nong " , "Zhen " , "Chuo " , "Chuo " , "Suberu ",  /*-- U+8FB0 .. U+8FB7 --*/
   "Reng " , "Bian " , "Bian " , "Sip "  , "Ip "   , "Liao " , "Da "   , "Chan " ,  /*-- U+8FB8 .. U+8FBF --*/
   "Gan "  , "Qian " , "Yu "   , "Yu "   , "Qi "   , "Xun "  , "Yi "   , "Guo "  ,  /*-- U+8FC0 .. U+8FC7 --*/
   "Mai "  , "Qi "   , "Za "   , "Wang " , "Jia "  , "Zhun " , "Ying " , "Ti "   ,  /*-- U+8FC8 .. U+8FCF --*/
   "Yun "  , "Jin "  , "Hang " , "Ya "   , "Fan "  , "Wu "   , "Da "   , "E "    ,  /*-- U+8FD0 .. U+8FD7 --*/
   "Huan " , "Zhe "  , "Totemo ", "Jin "  , "Yuan " , "Wei "  , "Lian " , "Chi "  ,  /*-- U+8FD8 .. U+8FDF --*/
   "Che "  , "Ni "   , "Tiao " , "Zhi "  , "Yi "   , "Jiong ", "Jia "  , "Chen " ,  /*-- U+8FE0 .. U+8FE7 --*/
   "Dai "  , "Er "   , "Di "   , "Po "   , "Wang " , "Die "  , "Ze "   , "Tao "  ,  /*-- U+8FE8 .. U+8FEF --*/
   "Shu "  , "Tuo "  , "Kep "  , "Jing " , "Hui "  , "Tong " , "You "  , "Mi "   ,  /*-- U+8FF0 .. U+8FF7 --*/
   "Beng " , "Ji "   , "Nai "  , "Yi "   , "Jie "  , "Zhui " , "Lie "  , "Xun "  ,  /*-- U+8FF8 .. U+8FFF --*/
   "Tui "  , "Song " , "Gua "  , "Tao "  , "Pang " , "Hou "  , "Ni "   , "Dun "  ,  /*-- U+9000 .. U+9007 --*/
   "Jiong ", "Xuan " , "Xun "  , "Bu "   , "You "  , "Xiao " , "Qiu "  , "Tou "  ,  /*-- U+9008 .. U+900F --*/
   "Zhu "  , "Qiu "  , "Di "   , "Di "   , "Tu "   , "Jing " , "Ti "   , "Dou "  ,  /*-- U+9010 .. U+9017 --*/
   "Yi "   , "Zhe "  , "Tong " , "Guang ", "Wu "   , "Shi "  , "Cheng ", "Su "   ,  /*-- U+9018 .. U+901F --*/
   "Zao "  , "Qun "  , "Feng " , "Lian " , "Suo "  , "Hui "  , "Li "   , "Sako " ,  /*-- U+9020 .. U+9027 --*/
   "Lai "  , "Ben "  , "Cuo "  , "Jue "  , "Beng " , "Huan " , "Dai "  , "Lu "   ,  /*-- U+9028 .. U+902F --*/
   "You "  , "Zhou " , "Jin "  , "Yu "   , "Chuo " , "Kui "  , "Wei "  , "Ti "   ,  /*-- U+9030 .. U+9037 --*/
   "Yi "   , "Da "   , "Yuan " , "Luo "  , "Bi "   , "Nuo "  , "Yu "   , "Dang " ,  /*-- U+9038 .. U+903F --*/
   "Sui "  , "Dun "  , "Sui "  , "Yan "  , "Chuan ", "Chi "  , "Ti "   , "Yu "   ,  /*-- U+9040 .. U+9047 --*/
   "Shi "  , "Zhen " , "You "  , "Yun "  , "E "    , "Bian " , "Guo "  , "E "    ,  /*-- U+9048 .. U+904F --*/
   "Xia "  , "Huang ", "Qiu "  , "Dao "  , "Da "   , "Wei "  , "Appare ", "Yi "   ,  /*-- U+9050 .. U+9057 --*/
   "Gou "  , "Yao "  , "Chu "  , "Liu "  , "Xun "  , "Ta "   , "Di "   , "Chi "  ,  /*-- U+9058 .. U+905F --*/
   "Yuan " , "Su "   , "Ta "   , "Qian " , ""      , "Yao "  , "Guan " , "Zhang ",  /*-- U+9060 .. U+9067 --*/
   "Ao "   , "Shi "  , "Ce "   , "Chi "  , "Su "   , "Zao "  , "Zhe "  , "Dun "  ,  /*-- U+9068 .. U+906F --*/
   "Di "   , "Lou "  , "Chi "  , "Cuo "  , "Lin "  , "Zun "  , "Rao "  , "Qian " ,  /*-- U+9070 .. U+9077 --*/
   "Xuan " , "Yu "   , "Yi "   , "Wu "   , "Liao " , "Ju "   , "Shi "  , "Bi "   ,  /*-- U+9078 .. U+907F --*/
   "Yao "  , "Mai "  , "Xie "  , "Sui "  , "Huan " , "Zhan " , "Teng " , "Er "   ,  /*-- U+9080 .. U+9087 --*/
   "Miao " , "Bian " , "Bian " , "La "   , "Li "   , "Yuan " , "Yao "  , "Luo "  ,  /*-- U+9088 .. U+908F --*/
   "Li "   , "Yi "   , "Ting " , "Deng " , "Qi "   , "Yong " , "Shan " , "Han "  ,  /*-- U+9090 .. U+9097 --*/
   "Yu "   , "Mang " , "Ru "   , "Qiong ", ""      , "Kuang ", "Fu "   , "Kang " ,  /*-- U+9098 .. U+909F --*/
   "Bin "  , "Fang " , "Xing " , "Na "   , "Xin "  , "Shen " , "Bang " , "Yuan " ,  /*-- U+90A0 .. U+90A7 --*/
   "Cun "  , "Huo "  , "Xie "  , "Bang " , "Wu "   , "Ju "   , "You "  , "Han "  ,  /*-- U+90A8 .. U+90AF --*/
   "Tai "  , "Qiu "  , "Bi "   , "Pei "  , "Bing " , "Shao " , "Bei "  , "Wa "   ,  /*-- U+90B0 .. U+90B7 --*/
   "Di "   , "Zou "  , "Ye "   , "Lin "  , "Kuang ", "Gui "  , "Zhu "  , "Shi "  ,  /*-- U+90B8 .. U+90BF --*/
   "Ku "   , "Yu "   , "Gai "  , "Ge "   , "Xi "   , "Zhi "  , "Ji "   , "Xun "  ,  /*-- U+90C0 .. U+90C7 --*/
   "Hou "  , "Xing " , "Jiao " , "Xi "   , "Gui "  , "Nuo "  , "Lang " , "Jia "  ,  /*-- U+90C8 .. U+90CF --*/
   "Kuai " , "Zheng ", "Otoko ", "Yun "  , "Yan "  , "Cheng ", "Dou "  , "Chi "  ,  /*-- U+90D0 .. U+90D7 --*/
   "Lu "   , "Fu "   , "Wu "   , "Fu "   , "Gao "  , "Hao "  , "Lang " , "Jia "  ,  /*-- U+90D8 .. U+90DF --*/
   "Geng " , "Jun "  , "Ying " , "Bo "   , "Xi "   , "Bei "  , "Li "   , "Yun "  ,  /*-- U+90E0 .. U+90E7 --*/
   "Bu "   , "Xiao " , "Qi "   , "Pi "   , "Qing " , "Guo "  , "Zhou " , "Tan "  ,  /*-- U+90E8 .. U+90EF --*/
   "Zou "  , "Ping " , "Lai "  , "Ni "   , "Chen " , "You "  , "Bu "   , "Xiang ",  /*-- U+90F0 .. U+90F7 --*/
   "Dan "  , "Ju "   , "Yong " , "Qiao " , "Yi "   , "Du "   , "Yan "  , "Mei "  ,  /*-- U+90F8 .. U+90FF --*/
   "Ruo "  , "Bei "  , "E "    , "Yu "   , "Juan " , "Yu "   , "Yun "  , "Hou "  ,  /*-- U+9100 .. U+9107 --*/
   "Kui "  , "Xiang ", "Xiang ", "Sou "  , "Tang " , "Ming " , "Xi "   , "Ru "   ,  /*-- U+9108 .. U+910F --*/
   "Chu "  , "Zi "   , "Zou "  , "Ju "   , "Wu "   , "Xiang ", "Yun "  , "Hao "  ,  /*-- U+9110 .. U+9117 --*/
   "Yong " , "Bi "   , "Mo "   , "Chao " , "Fu "   , "Liao " , "Yin "  , "Zhuan ",  /*-- U+9118 .. U+911F --*/
   "Hu "   , "Qiao " , "Yan "  , "Zhang ", "Fan "  , "Qiao " , "Xu "   , "Deng " ,  /*-- U+9120 .. U+9127 --*/
   "Bi "   , "Xin "  , "Bi "   , "Ceng " , "Wei "  , "Zheng ", "Mao "  , "Shan " ,  /*-- U+9128 .. U+912F --*/
   "Lin "  , "Po "   , "Dan "  , "Meng " , "Ye "   , "Cao "  , "Kuai " , "Feng " ,  /*-- U+9130 .. U+9137 --*/
   "Meng " , "Zou "  , "Kuang ", "Lian " , "Zan "  , "Chan " , "You "  , "Qi "   ,  /*-- U+9138 .. U+913F --*/
   "Yan "  , "Chan " , "Zan "  , "Ling " , "Huan " , "Xi "   , "Feng " , "Zan "  ,  /*-- U+9140 .. U+9147 --*/
   "Li "   , "You "  , "Ding " , "Qiu "  , "Zhuo " , "Pei "  , "Zhou " , "Yi "   ,  /*-- U+9148 .. U+914F --*/
   "Hang " , "Yu "   , "Jiu "  , "Yan "  , "Zui "  , "Mao "  , "Dan "  , "Xu "   ,  /*-- U+9150 .. U+9157 --*/
   "Tou "  , "Zhen " , "Fen "  , "Sakenomoto ", ""      , "Yun "  , "Tai "  , "Tian " ,  /*-- U+9158 .. U+915F --*/
   "Qia "  , "Tuo "  , "Zuo "  , "Han "  , "Gu "   , "Su "   , "Po "   , "Chou " ,  /*-- U+9160 .. U+9167 --*/
   "Zai "  , "Ming " , "Luo "  , "Chuo " , "Chou " , "You "  , "Tong " , "Zhi "  ,  /*-- U+9168 .. U+916F --*/
   "Xian " , "Jiang ", "Cheng ", "Yin "  , "Tu "   , "Xiao " , "Mei "  , "Ku "   ,  /*-- U+9170 .. U+9177 --*/
   "Suan " , "Lei "  , "Pu "   , "Zui "  , "Hai "  , "Yan "  , "Xi "   , "Niang ",  /*-- U+9178 .. U+917F --*/
   "Wei "  , "Lu "   , "Lan "  , "Yan "  , "Tao "  , "Pei "  , "Zhan " , "Chun " ,  /*-- U+9180 .. U+9187 --*/
   "Tan "  , "Zui "  , "Chuo " , "Cu "   , "Kun "  , "Ti "   , "Mian " , "Du "   ,  /*-- U+9188 .. U+918F --*/
   "Hu "   , "Xu "   , "Xing " , "Tan "  , "Jiu "  , "Chun " , "Yun "  , "Po "   ,  /*-- U+9190 .. U+9197 --*/
   "Ke "   , "Sou "  , "Mi "   , "Quan " , "Chou " , "Cuo "  , "Yun "  , "Yong " ,  /*-- U+9198 .. U+919F --*/
   "Ang "  , "Zha "  , "Hai "  , "Tang " , "Jiang ", "Piao " , "Shan " , "Yu "   ,  /*-- U+91A0 .. U+91A7 --*/
   "Li "   , "Zao "  , "Lao "  , "Yi "   , "Jiang ", "Pu "   , "Jiao " , "Xi "   ,  /*-- U+91A8 .. U+91AF --*/
   "Tan "  , "Po "   , "Nong " , "Yi "   , "Li "   , "Ju "   , "Jiao " , "Yi "   ,  /*-- U+91B0 .. U+91B7 --*/
   "Niang ", "Ru "   , "Xun "  , "Chou " , "Yan "  , "Ling " , "Mi "   , "Mi "   ,  /*-- U+91B8 .. U+91BF --*/
   "Niang ", "Xin "  , "Jiao " , "Xi "   , "Mi "   , "Yan "  , "Bian " , "Cai "  ,  /*-- U+91C0 .. U+91C7 --*/
   "Shi "  , "You "  , "Shi "  , "Shi "  , "Li "   , "Zhong ", "Ye "   , "Liang ",  /*-- U+91C8 .. U+91CF --*/
   "Li "   , "Jin "  , "Jin "  , "Qiu "  , "Yi "   , "Diao " , "Dao "  , "Zhao " ,  /*-- U+91D0 .. U+91D7 --*/
   "Ding " , "Po "   , "Qiu "  , "He "   , "Fu "   , "Zhen " , "Zhi "  , "Ba "   ,  /*-- U+91D8 .. U+91DF --*/
   "Luan " , "Fu "   , "Nai "  , "Diao " , "Shan " , "Qiao " , "Kou "  , "Chuan ",  /*-- U+91E0 .. U+91E7 --*/
   "Zi "   , "Fan "  , "Yu "   , "Hua "  , "Han "  , "Gong " , "Qi "   , "Mang " ,  /*-- U+91E8 .. U+91EF --*/
   "Ri "   , "Di "   , "Si "   , "Xi "   , "Yi "   , "Chai " , "Shi "  , "Tu "   ,  /*-- U+91F0 .. U+91F7 --*/
   "Xi "   , "Nu "   , "Qian " , "Ishiyumi ", "Jian " , "Pi "   , "Ye "   , "Yin "  ,  /*-- U+91F8 .. U+91FF --*/
   "Ba "   , "Fang " , "Chen " , "Xing " , "Tou "  , "Yue "  , "Yan "  , "Fu "   ,  /*-- U+9200 .. U+9207 --*/
   "Pi "   , "Na "   , "Xin "  , "E "    , "Jue "  , "Dun "  , "Gou "  , "Yin "  ,  /*-- U+9208 .. U+920F --*/
   "Qian " , "Ban "  , "Ji "   , "Ren "  , "Chao " , "Niu "  , "Fen "  , "Yun "  ,  /*-- U+9210 .. U+9217 --*/
   "Ji "   , "Qin "  , "Pi "   , "Guo "  , "Hong " , "Yin "  , "Jun "  , "Shi "  ,  /*-- U+9218 .. U+921F --*/
   "Yi "   , "Zhong ", "Nie "  , "Gai "  , "Ri "   , "Huo "  , "Tai "  , "Kang " ,  /*-- U+9220 .. U+9227 --*/
   "Habaki ", "Irori ", "Ngaak ", ""      , "Duo "  , "Zi "   , "Ni "   , "Tu "   ,  /*-- U+9228 .. U+922F --*/
   "Shi "  , "Min "  , "Gu "   , "E "    , "Ling " , "Bing " , "Yi "   , "Gu "   ,  /*-- U+9230 .. U+9237 --*/
   "Ba "   , "Pi "   , "Yu "   , "Si "   , "Zuo "  , "Bu "   , "You "  , "Dian " ,  /*-- U+9238 .. U+923F --*/
   "Jia "  , "Zhen " , "Shi "  , "Shi "  , "Tie "  , "Ju "   , "Zhan " , "Shi "  ,  /*-- U+9240 .. U+9247 --*/
   "She "  , "Xuan " , "Zhao " , "Bao "  , "He "   , "Bi "   , "Sheng ", "Chu "  ,  /*-- U+9248 .. U+924F --*/
   "Shi "  , "Bo "   , "Zhu "  , "Chi "  , "Za "   , "Po "   , "Tong " , "Qian " ,  /*-- U+9250 .. U+9257 --*/
   "Fu "   , "Zhai " , "Liu "  , "Qian " , "Fu "   , "Li "   , "Yue "  , "Pi "   ,  /*-- U+9258 .. U+925F --*/
   "Yang " , "Ban "  , "Bo "   , "Jie "  , "Gou "  , "Shu "  , "Zheng ", "Mu "   ,  /*-- U+9260 .. U+9267 --*/
   "Ni "   , "Nie "  , "Di "   , "Jia "  , "Mu "   , "Dan "  , "Shen " , "Yi "   ,  /*-- U+9268 .. U+926F --*/
   "Si "   , "Kuang ", "Ka "   , "Bei "  , "Jian " , "Tong " , "Xing " , "Hong " ,  /*-- U+9270 .. U+9277 --*/
   "Jiao " , "Chi "  , "Er "   , "Ge "   , "Bing " , "Shi "  , "Mou "  , "Jia "  ,  /*-- U+9278 .. U+927F --*/
   "Yin "  , "Jun "  , "Zhou " , "Chong ", "Shang ", "Tong " , "Mo "   , "Lei "  ,  /*-- U+9280 .. U+9287 --*/
   "Ji "   , "Yu "   , "Xu "   , "Ren "  , "Zun "  , "Zhi "  , "Qiong ", "Shan " ,  /*-- U+9288 .. U+928F --*/
   "Chi "  , "Xian " , "Xing " , "Quan " , "Pi "   , "Tie "  , "Zhu "  , "Hou "  ,  /*-- U+9290 .. U+9297 --*/
   "Ming " , "Kua "  , "Yao "  , "Xian " , "Xian " , "Xiu "  , "Jun "  , "Cha "  ,  /*-- U+9298 .. U+929F --*/
   "Lao "  , "Ji "   , "Pi "   , "Ru "   , "Mi "   , "Yi "   , "Yin "  , "Guang ",  /*-- U+92A0 .. U+92A7 --*/
   "An "   , "Diou " , "You "  , "Se "   , "Kao "  , "Qian " , "Luan " , "Kasugai ",  /*-- U+92A8 .. U+92AF --*/
   "Ai "   , "Diao " , "Han "  , "Rui "  , "Shi "  , "Keng " , "Qiu "  , "Xiao " ,  /*-- U+92B0 .. U+92B7 --*/
   "Zhe "  , "Xiu "  , "Zang " , "Ti "   , "Cuo "  , "Gua "  , "Gong " , "Zhong ",  /*-- U+92B8 .. U+92BF --*/
   "Dou "  , "Lu "   , "Mei "  , "Lang " , "Wan "  , "Xin "  , "Yun "  , "Bei "  ,  /*-- U+92C0 .. U+92C7 --*/
   "Wu "   , "Su "   , "Yu "   , "Chan " , "Ting " , "Bo "   , "Han "  , "Jia "  ,  /*-- U+92C8 .. U+92CF --*/
   "Hong " , "Cuan " , "Feng " , "Chan " , "Wan "  , "Zhi "  , "Si "   , "Xuan " ,  /*-- U+92D0 .. U+92D7 --*/
   "Wu "   , "Wu "   , "Tiao " , "Gong " , "Zhuo " , "Lue "  , "Xing " , "Qian " ,  /*-- U+92D8 .. U+92DF --*/
   "Shen " , "Han "  , "Lue "  , "Xie "  , "Chu "  , "Zheng ", "Ju "   , "Xian " ,  /*-- U+92E0 .. U+92E7 --*/
   "Tie "  , "Mang " , "Pu "   , "Li "   , "Pan "  , "Rui "  , "Cheng ", "Gao "  ,  /*-- U+92E8 .. U+92EF --*/
   "Li "   , "Te "   , "Pyeng ", "Zhu "  , ""      , "Tu "   , "Liu "  , "Zui "  ,  /*-- U+92F0 .. U+92F7 --*/
   "Ju "   , "Chang ", "Yuan " , "Jian " , "Gang " , "Diao " , "Tao "  , "Chang ",  /*-- U+92F8 .. U+92FF --*/
   "Lun "  , "Kua "  , "Ling " , "Bei "  , "Lu "   , "Li "   , "Qiang ", "Pou "  ,  /*-- U+9300 .. U+9307 --*/
   "Juan " , "Min "  , "Zui "  , "Peng " , "An "   , "Pi "   , "Xian " , "Ya "   ,  /*-- U+9308 .. U+930F --*/
   "Zhui " , "Lei "  , "A "    , "Kong " , "Ta "   , "Kun "  , "Du "   , "Wei "  ,  /*-- U+9310 .. U+9317 --*/
   "Chui " , "Zi "   , "Zheng ", "Ben "  , "Nie "  , "Cong " , "Qun "  , "Tan "  ,  /*-- U+9318 .. U+931F --*/
   "Ding " , "Qi "   , "Qian " , "Zhuo " , "Qi "   , "Yu "   , "Jin "  , "Guan " ,  /*-- U+9320 .. U+9327 --*/
   "Mao "  , "Chang ", "Tian " , "Xi "   , "Lian " , "Tao "  , "Gu "   , "Cuo "  ,  /*-- U+9328 .. U+932F --*/
   "Shu "  , "Zhen " , "Lu "   , "Meng " , "Lu "   , "Hua "  , "Biao " , "Ga "   ,  /*-- U+9330 .. U+9337 --*/
   "Lai "  , "Ken "  , "Kazari ", "Bu "   , "Nai "  , "Wan "  , "Zan "  , ""      ,  /*-- U+9338 .. U+933F --*/
   "De "   , "Xian " , ""      , "Huo "  , "Liang ", ""      , "Men "  , "Kai "  ,  /*-- U+9340 .. U+9347 --*/
   "Ying " , "Di "   , "Lian " , "Guo "  , "Xian " , "Du "   , "Tu "   , "Wei "  ,  /*-- U+9348 .. U+934F --*/
   "Cong " , "Fu "   , "Rou "  , "Ji "   , "E "    , "Rou "  , "Chen " , "Ti "   ,  /*-- U+9350 .. U+9357 --*/
   "Zha "  , "Hong " , "Yang " , "Duan " , "Xia "  , "Yu "   , "Keng " , "Xing " ,  /*-- U+9358 .. U+935F --*/
   "Huang ", "Wei "  , "Fu "   , "Zhao " , "Cha "  , "Qie "  , "She "  , "Hong " ,  /*-- U+9360 .. U+9367 --*/
   "Kui "  , "Tian " , "Mou "  , "Qiao " , "Qiao " , "Hou "  , "Tou "  , "Cong " ,  /*-- U+9368 .. U+936F --*/
   "Huan " , "Ye "   , "Min "  , "Jian " , "Duan " , "Jian " , "Song " , "Kui "  ,  /*-- U+9370 .. U+9377 --*/
   "Hu "   , "Xuan " , "Duo "  , "Jie "  , "Zhen " , "Bian " , "Zhong ", "Zi "   ,  /*-- U+9378 .. U+937F --*/
   "Xiu "  , "Ye "   , "Mei "  , "Pai "  , "Ai "   , "Jie "  , ""      , "Mei "  ,  /*-- U+9380 .. U+9387 --*/
   "Chuo " , "Ta "   , "Bang " , "Xia "  , "Lian " , "Suo "  , "Xi "   , "Liu "  ,  /*-- U+9388 .. U+938F --*/
   "Zu "   , "Ye "   , "Nou "  , "Weng " , "Rong " , "Tang " , "Suo "  , "Qiang ",  /*-- U+9390 .. U+9397 --*/
   "Ge "   , "Shuo " , "Chui " , "Bo "   , "Pan "  , "Sa "   , "Bi "   , "Sang " ,  /*-- U+9398 .. U+939F --*/
   "Gang " , "Zi "   , "Wu "   , "Ying " , "Huang ", "Tiao " , "Liu "  , "Kai "  ,  /*-- U+93A0 .. U+93A7 --*/
   "Sun "  , "Sha "  , "Sou "  , "Wan "  , "Hao "  , "Zhen " , "Zhen " , "Luo "  ,  /*-- U+93A8 .. U+93AF --*/
   "Yi "   , "Yuan " , "Tang " , "Nie "  , "Xi "   , "Jia "  , "Ge "   , "Ma "   ,  /*-- U+93B0 .. U+93B7 --*/
   "Juan " , "Kasugai ", "Habaki ", "Suo "  , ""      , ""      , ""      , "Na "   ,  /*-- U+93B8 .. U+93BF --*/
   "Lu "   , "Suo "  , "Ou "   , "Zu "   , "Tuan " , "Xiu "  , "Guan " , "Xuan " ,  /*-- U+93C0 .. U+93C7 --*/
   "Lian " , "Shou " , "Ao "   , "Man "  , "Mo "   , "Luo "  , "Bi "   , "Wei "  ,  /*-- U+93C8 .. U+93CF --*/
   "Liu "  , "Di "   , "Qiao " , "Cong " , "Yi "   , "Lu "   , "Ao "   , "Keng " ,  /*-- U+93D0 .. U+93D7 --*/
   "Qiang ", "Cui "  , "Qi "   , "Chang ", "Tang " , "Man "  , "Yong " , "Chan " ,  /*-- U+93D8 .. U+93DF --*/
   "Feng " , "Jing " , "Biao " , "Shu "  , "Lou "  , "Xiu "  , "Cong " , "Long " ,  /*-- U+93E0 .. U+93E7 --*/
   "Zan "  , "Jian " , "Cao "  , "Li "   , "Xia "  , "Xi "   , "Kang " , ""      ,  /*-- U+93E8 .. U+93EF --*/
   "Beng " , ""      , ""      , "Zheng ", "Lu "   , "Hua "  , "Ji "   , "Pu "   ,  /*-- U+93F0 .. U+93F7 --*/
   "Hui "  , "Qiang ", "Po "   , "Lin "  , "Suo "  , "Xiu "  , "San "  , "Cheng ",  /*-- U+93F8 .. U+93FF --*/
   "Kui "  , "Si "   , "Liu "  , "Nao "  , "Heng " , "Pie "  , "Sui "  , "Fan "  ,  /*-- U+9400 .. U+9407 --*/
   "Qiao " , "Quan " , "Yang " , "Tang " , "Xiang ", "Jue "  , "Jiao " , "Zun "  ,  /*-- U+9408 .. U+940F --*/
   "Liao " , "Jie "  , "Lao "  , "Dui "  , "Tan "  , "Zan "  , "Ji "   , "Jian " ,  /*-- U+9410 .. U+9417 --*/
   "Zhong ", "Deng " , "Ya "   , "Ying " , "Dui "  , "Jue "  , "Nou "  , "Ti "   ,  /*-- U+9418 .. U+941F --*/
   "Pu "   , "Tie "  , ""      , ""      , "Ding " , "Shan " , "Kai "  , "Jian " ,  /*-- U+9420 .. U+9427 --*/
   "Fei "  , "Sui "  , "Lu "   , "Juan " , "Hui "  , "Yu "   , "Lian " , "Zhuo " ,  /*-- U+9428 .. U+942F --*/
   "Qiao " , "Qian " , "Zhuo " , "Lei "  , "Bi "   , "Tie "  , "Huan " , "Ye "   ,  /*-- U+9430 .. U+9437 --*/
   "Duo "  , "Guo "  , "Dang " , "Ju "   , "Fen "  , "Da "   , "Bei "  , "Yi "   ,  /*-- U+9438 .. U+943F --*/
   "Ai "   , "Zong " , "Xun "  , "Diao " , "Zhu "  , "Heng " , "Zhui " , "Ji "   ,  /*-- U+9440 .. U+9447 --*/
   "Nie "  , "Ta "   , "Huo "  , "Qing " , "Bin "  , "Ying " , "Kui "  , "Ning " ,  /*-- U+9448 .. U+944F --*/
   "Xu "   , "Jian " , "Jian " , "Yari " , "Cha "  , "Zhi "  , "Mie "  , "Li "   ,  /*-- U+9450 .. U+9457 --*/
   "Lei "  , "Ji "   , "Zuan " , "Kuang ", "Shang ", "Peng " , "La "   , "Du "   ,  /*-- U+9458 .. U+945F --*/
   "Shuo " , "Chuo " , "Lu "   , "Biao " , "Bao "  , "Lu "   , ""      , ""      ,  /*-- U+9460 .. U+9467 --*/
   "Long " , "E "    , "Lu "   , "Xin "  , "Jian " , "Lan "  , "Bo "   , "Jian " ,  /*-- U+9468 .. U+946F --*/
   "Yao "  , "Chan " , "Xiang ", "Jian " , "Xi "   , "Guan " , "Cang " , "Nie "  ,  /*-- U+9470 .. U+9477 --*/
   "Lei "  , "Cuan " , "Qu "   , "Pan "  , "Luo "  , "Zuan " , "Luan " , "Zao "  ,  /*-- U+9478 .. U+947F --*/
   "Nie "  , "Jue "  , "Tang " , "Shu "  , "Lan "  , "Jin "  , "Qiu "  , "Yi "   ,  /*-- U+9480 .. U+9487 --*/
   "Zhen " , "Ding " , "Zhao " , "Po "   , "Diao " , "Tu "   , "Qian " , "Chuan ",  /*-- U+9488 .. U+948F --*/
   "Shan " , "Ji "   , "Fan "  , "Diao " , "Men "  , "Nu "   , "Xi "   , "Chai " ,  /*-- U+9490 .. U+9497 --*/
   "Xing " , "Gai "  , "Bu "   , "Tai "  , "Ju "   , "Dun "  , "Chao " , "Zhong ",  /*-- U+9498 .. U+949F --*/
   "Na "   , "Bei "  , "Gang " , "Ban "  , "Qian " , "Yao "  , "Qin "  , "Jun "  ,  /*-- U+94A0 .. U+94A7 --*/
   "Wu "   , "Gou "  , "Kang " , "Fang " , "Huo "  , "Tou "  , "Niu "  , "Ba "   ,  /*-- U+94A8 .. U+94AF --*/
   "Yu "   , "Qian " , "Zheng ", "Qian " , "Gu "   , "Bo "   , "E "    , "Po "   ,  /*-- U+94B0 .. U+94B7 --*/
   "Bu "   , "Ba "   , "Yue "  , "Zuan " , "Mu "   , "Dan "  , "Jia "  , "Dian " ,  /*-- U+94B8 .. U+94BF --*/
   "You "  , "Tie "  , "Bo "   , "Ling " , "Shuo " , "Qian " , "Liu "  , "Bao "  ,  /*-- U+94C0 .. U+94C7 --*/
   "Shi "  , "Xuan " , "She "  , "Bi "   , "Ni "   , "Pi "   , "Duo "  , "Xing " ,  /*-- U+94C8 .. U+94CF --*/
   "Kao "  , "Lao "  , "Er "   , "Mang " , "Ya "   , "You "  , "Cheng ", "Jia "  ,  /*-- U+94D0 .. U+94D7 --*/
   "Ye "   , "Nao "  , "Zhi "  , "Dang " , "Tong " , "Lu "   , "Diao " , "Yin "  ,  /*-- U+94D8 .. U+94DF --*/
   "Kai "  , "Zha "  , "Zhu "  , "Xian " , "Ting " , "Diu "  , "Xian " , "Hua "  ,  /*-- U+94E0 .. U+94E7 --*/
   "Quan " , "Sha "  , "Jia "  , "Yao "  , "Ge "   , "Ming " , "Zheng ", "Se "   ,  /*-- U+94E8 .. U+94EF --*/
   "Jiao " , "Yi "   , "Chan " , "Chong ", "Tang " , "An "   , "Yin "  , "Ru "   ,  /*-- U+94F0 .. U+94F7 --*/
   "Zhu "  , "Lao "  , "Pu "   , "Wu "   , "Lai "  , "Te "   , "Lian " , "Keng " ,  /*-- U+94F8 .. U+94FF --*/
   "Xiao " , "Suo "  , "Li "   , "Zheng ", "Chu "  , "Guo "  , "Gao "  , "Tie "  ,  /*-- U+9500 .. U+9507 --*/
   "Xiu "  , "Cuo "  , "Lue "  , "Feng " , "Xin "  , "Liu "  , "Kai "  , "Jian " ,  /*-- U+9508 .. U+950F --*/
   "Rui "  , "Ti "   , "Lang " , "Qian " , "Ju "   , "A "    , "Qiang ", "Duo "  ,  /*-- U+9510 .. U+9517 --*/
   "Tian " , "Cuo "  , "Mao "  , "Ben "  , "Qi "   , "De "   , "Kua "  , "Kun "  ,  /*-- U+9518 .. U+951F --*/
   "Chang ", "Xi "   , "Gu "   , "Luo "  , "Chui " , "Zhui " , "Jin "  , "Zhi "  ,  /*-- U+9520 .. U+9527 --*/
   "Xian " , "Juan " , "Huo "  , "Pou "  , "Tan "  , "Ding " , "Jian " , "Ju "   ,  /*-- U+9528 .. U+952F --*/
   "Meng " , "Zi "   , "Qie "  , "Ying " , "Kai "  , "Qiang ", "Song " , "E "    ,  /*-- U+9530 .. U+9537 --*/
   "Cha "  , "Qiao " , "Zhong ", "Duan " , "Sou "  , "Huang ", "Huan " , "Ai "   ,  /*-- U+9538 .. U+953F --*/
   "Du "   , "Mei "  , "Lou "  , "Zi "   , "Fei "  , "Mei "  , "Mo "   , "Zhen " ,  /*-- U+9540 .. U+9547 --*/
   "Bo "   , "Ge "   , "Nie "  , "Tang " , "Juan " , "Nie "  , "Na "   , "Liu "  ,  /*-- U+9548 .. U+954F --*/
   "Hao "  , "Bang " , "Yi "   , "Jia "  , "Bin "  , "Rong " , "Biao " , "Tang " ,  /*-- U+9550 .. U+9557 --*/
   "Man "  , "Luo "  , "Beng " , "Yong " , "Jing " , "Di "   , "Zu "   , "Xuan " ,  /*-- U+9558 .. U+955F --*/
   "Liu "  , "Tan "  , "Jue "  , "Liao " , "Pu "   , "Lu "   , "Dui "  , "Lan "  ,  /*-- U+9560 .. U+9567 --*/
   "Pu "   , "Cuan " , "Qiang ", "Deng " , "Huo "  , "Lei "  , "Huan " , "Zhuo " ,  /*-- U+9568 .. U+956F --*/
   "Lian " , "Yi "   , "Cha "  , "Biao " , "La "   , "Chan " , "Xiang ", "Chang ",  /*-- U+9570 .. U+9577 --*/
   "Chang ", "Jiu "  , "Ao "   , "Die "  , "Qu "   , "Liao " , "Mi "   , "Chang ",  /*-- U+9578 .. U+957F --*/
   "Men "  , "Ma "   , "Shuan ", "Shan " , "Huo "  , "Men "  , "Yan "  , "Bi "   ,  /*-- U+9580 .. U+9587 --*/
   "Han "  , "Bi "   , "San "  , "Kai "  , "Kang " , "Beng " , "Hong " , "Run "  ,  /*-- U+9588 .. U+958F --*/
   "San "  , "Xian " , "Xian " , "Jian " , "Min "  , "Xia "  , "Yuru " , "Dou "  ,  /*-- U+9590 .. U+9597 --*/
   "Zha "  , "Nao "  , "Jian " , "Peng " , "Xia "  , "Ling " , "Bian " , "Bi "   ,  /*-- U+9598 .. U+959F --*/
   "Run "  , "He "   , "Guan " , "Ge "   , "Ge "   , "Fa "   , "Chu "  , "Hong " ,  /*-- U+95A0 .. U+95A7 --*/
   "Gui "  , "Min "  , "Se "   , "Kun "  , "Lang " , "Lu "   , "Ting " , "Sha "  ,  /*-- U+95A8 .. U+95AF --*/
   "Ju "   , "Yue "  , "Yue "  , "Chan " , "Qu "   , "Lin "  , "Chang ", "Shai " ,  /*-- U+95B0 .. U+95B7 --*/
   "Kun "  , "Yan "  , "Min "  , "Yan "  , "E "    , "Hun "  , "Yu "   , "Wen "  ,  /*-- U+95B8 .. U+95BF --*/
   "Xiang ", "Bao "  , "Xiang ", "Qu "   , "Yao "  , "Wen "  , "Ban "  , "An "   ,  /*-- U+95C0 .. U+95C7 --*/
   "Wei "  , "Yin "  , "Kuo "  , "Que "  , "Lan "  , "Du "   , ""      , "Phwung ",  /*-- U+95C8 .. U+95CF --*/
   "Tian " , "Nie "  , "Ta "   , "Kai "  , "He "   , "Que "  , "Chuang ", "Guan " ,  /*-- U+95D0 .. U+95D7 --*/
   "Dou "  , "Qi "   , "Kui "  , "Tang " , "Guan " , "Piao " , "Kan "  , "Xi "   ,  /*-- U+95D8 .. U+95DF --*/
   "Hui "  , "Chan " , "Pi "   , "Dang " , "Huan " , "Ta "   , "Wen "  , ""      ,  /*-- U+95E0 .. U+95E7 --*/
   "Men "  , "Shuan ", "Shan " , "Yan "  , "Han "  , "Bi "   , "Wen "  , "Chuang ",  /*-- U+95E8 .. U+95EF --*/
   "Run "  , "Wei "  , "Xian " , "Hong " , "Jian " , "Min "  , "Kang " , "Men "  ,  /*-- U+95F0 .. U+95F7 --*/
   "Zha "  , "Nao "  , "Gui "  , "Wen "  , "Ta "   , "Min "  , "Lu "   , "Kai "  ,  /*-- U+95F8 .. U+95FF --*/
   "Fa "   , "Ge "   , "He "   , "Kun "  , "Jiu "  , "Yue "  , "Lang " , "Du "   ,  /*-- U+9600 .. U+9607 --*/
   "Yu "   , "Yan "  , "Chang ", "Xi "   , "Wen "  , "Hun "  , "Yan "  , "E "    ,  /*-- U+9608 .. U+960F --*/
   "Chan " , "Lan "  , "Qu "   , "Hui "  , "Kuo "  , "Que "  , "Ge "   , "Tian " ,  /*-- U+9610 .. U+9617 --*/
   "Ta "   , "Que "  , "Kan "  , "Huan " , "Fu "   , "Fu "   , "Le "   , "Dui "  ,  /*-- U+9618 .. U+961F --*/
   "Xin "  , "Qian " , "Wu "   , "Yi "   , "Tuo "  , "Yin "  , "Yang " , "Dou "  ,  /*-- U+9620 .. U+9627 --*/
   "E "    , "Sheng ", "Ban "  , "Pei "  , "Keng " , "Yun "  , "Ruan " , "Zhi "  ,  /*-- U+9628 .. U+962F --*/
   "Pi "   , "Jing " , "Fang " , "Yang " , "Yin "  , "Zhen " , "Jie "  , "Cheng ",  /*-- U+9630 .. U+9637 --*/
   "E "    , "Qu "   , "Di "   , "Zu "   , "Zuo "  , "Dian " , "Ling " , "A "    ,  /*-- U+9638 .. U+963F --*/
   "Tuo "  , "Tuo "  , "Po "   , "Bing " , "Fu "   , "Ji "   , "Lu "   , "Long " ,  /*-- U+9640 .. U+9647 --*/
   "Chen " , "Xing " , "Duo "  , "Lou "  , "Mo "   , "Jiang ", "Shu "  , "Duo "  ,  /*-- U+9648 .. U+964F --*/
   "Xian " , "Er "   , "Gui "  , "Yu "   , "Gai "  , "Shan " , "Xun "  , "Qiao " ,  /*-- U+9650 .. U+9657 --*/
   "Xing " , "Chun " , "Fu "   , "Bi "   , "Xia "  , "Shan " , "Sheng ", "Zhi "  ,  /*-- U+9658 .. U+965F --*/
   "Pu "   , "Dou "  , "Yuan " , "Zhen " , "Chu "  , "Xian " , "Tou "  , "Nie "  ,  /*-- U+9660 .. U+9667 --*/
   "Yun "  , "Xian " , "Pei "  , "Pei "  , "Zou "  , "Yi "   , "Dui "  , "Lun "  ,  /*-- U+9668 .. U+966F --*/
   "Yin "  , "Ju "   , "Chui " , "Chen " , "Pi "   , "Ling " , "Tao "  , "Xian " ,  /*-- U+9670 .. U+9677 --*/
   "Lu "   , "Sheng ", "Xian " , "Yin "  , "Zhu "  , "Yang " , "Reng " , "Shan " ,  /*-- U+9678 .. U+967F --*/
   "Chong ", "Yan "  , "Yin "  , "Yu "   , "Ti "   , "Yu "   , "Long " , "Wei "  ,  /*-- U+9680 .. U+9687 --*/
   "Wei "  , "Nie "  , "Dui "  , "Sui "  , "An "   , "Huang ", "Jie "  , "Sui "  ,  /*-- U+9688 .. U+968F --*/
   "Yin "  , "Gai "  , "Yan "  , "Hui "  , "Ge "   , "Yun "  , "Wu "   , "Wei "  ,  /*-- U+9690 .. U+9697 --*/
   "Ai "   , "Xi "   , "Tang " , "Ji "   , "Zhang ", "Dao "  , "Ao "   , "Xi "   ,  /*-- U+9698 .. U+969F --*/
   "Yin "  , ""      , "Rao "  , "Lin "  , "Tui "  , "Deng " , "Pi "   , "Sui "  ,  /*-- U+96A0 .. U+96A7 --*/
   "Sui "  , "Yu "   , "Xian " , "Fen "  , "Ni "   , "Er "   , "Ji "   , "Dao "  ,  /*-- U+96A8 .. U+96AF --*/
   "Xi "   , "Yin "  , "E "    , "Hui "  , "Long " , "Xi "   , "Li "   , "Li "   ,  /*-- U+96B0 .. U+96B7 --*/
   "Li "   , "Zhui " , "He "   , "Zhi "  , "Zhun " , "Jun "  , "Nan "  , "Yi "   ,  /*-- U+96B8 .. U+96BF --*/
   "Que "  , "Yan "  , "Qian " , "Ya "   , "Xiong ", "Ya "   , "Ji "   , "Gu "   ,  /*-- U+96C0 .. U+96C7 --*/
   "Huan " , "Zhi "  , "Gou "  , "Jun "  , "Ci "   , "Yong " , "Ju "   , "Chu "  ,  /*-- U+96C8 .. U+96CF --*/
   "Hu "   , "Za "   , "Luo "  , "Yu "   , "Chou " , "Diao " , "Sui "  , "Han "  ,  /*-- U+96D0 .. U+96D7 --*/
   "Huo "  , "Shuang ", "Guan " , "Chu "  , "Za "   , "Yong " , "Ji "   , "Xi "   ,  /*-- U+96D8 .. U+96DF --*/
   "Chou " , "Liu "  , "Li "   , "Nan "  , "Xue "  , "Za "   , "Ji "   , "Ji "   ,  /*-- U+96E0 .. U+96E7 --*/
   "Yu "   , "Yu "   , "Xue "  , "Na "   , "Fou "  , "Se "   , "Mu "   , "Wen "  ,  /*-- U+96E8 .. U+96EF --*/
   "Fen "  , "Pang " , "Yun "  , "Li "   , "Li "   , "Ang "  , "Ling " , "Lei "  ,  /*-- U+96F0 .. U+96F7 --*/
   "An "   , "Bao "  , "Meng " , "Dian " , "Dang " , "Xing " , "Wu "   , "Zhao " ,  /*-- U+96F8 .. U+96FF --*/
   "Xu "   , "Ji "   , "Mu "   , "Chen " , "Xiao " , "Zha "  , "Ting " , "Zhen " ,  /*-- U+9700 .. U+9707 --*/
   "Pei "  , "Mei "  , "Ling " , "Qi "   , "Chou " , "Huo "  , "Sha "  , "Fei "  ,  /*-- U+9708 .. U+970F --*/
   "Weng " , "Zhan " , "Yin "  , "Ni "   , "Chou " , "Tun "  , "Lin "  , ""      ,  /*-- U+9710 .. U+9717 --*/
   "Dong " , "Ying " , "Wu "   , "Ling " , "Shuang ", "Ling " , "Xia "  , "Hong " ,  /*-- U+9718 .. U+971F --*/
   "Yin "  , "Mo "   , "Mai "  , "Yun "  , "Liu "  , "Meng " , "Bin "  , "Wu "   ,  /*-- U+9720 .. U+9727 --*/
   "Wei "  , "Huo "  , "Yin "  , "Xi "   , "Yi "   , "Ai "   , "Dan "  , "Deng " ,  /*-- U+9728 .. U+972F --*/
   "Xian " , "Yu "   , "Lu "   , "Long " , "Dai "  , "Ji "   , "Pang " , "Yang " ,  /*-- U+9730 .. U+9737 --*/
   "Ba "   , "Pi "   , "Wei "  , ""      , "Xi "   , "Ji "   , "Mai "  , "Meng " ,  /*-- U+9738 .. U+973F --*/
   "Meng " , "Lei "  , "Li "   , "Huo "  , "Ai "   , "Fei "  , "Dai "  , "Long " ,  /*-- U+9740 .. U+9747 --*/
   "Ling " , "Ai "   , "Feng " , "Li "   , "Bao "  , ""      , "He "   , "He "   ,  /*-- U+9748 .. U+974F --*/
   "Bing " , "Qing " , "Qing " , "Jing " , "Tian " , "Zhen " , "Jing " , "Cheng ",  /*-- U+9750 .. U+9757 --*/
   "Qing " , "Jing " , "Jing " , "Dian " , "Jing " , "Tian " , "Fei "  , "Fei "  ,  /*-- U+9758 .. U+975F --*/
   "Kao "  , "Mi "   , "Mian " , "Mian " , "Pao "  , "Ye "   , "Tian " , "Hui "  ,  /*-- U+9760 .. U+9767 --*/
   "Ye "   , "Ge "   , "Ding " , "Cha "  , "Jian " , "Ren "  , "Di "   , "Du "   ,  /*-- U+9768 .. U+976F --*/
   "Wu "   , "Ren "  , "Qin "  , "Jin "  , "Xue "  , "Niu "  , "Ba "   , "Yin "  ,  /*-- U+9770 .. U+9777 --*/
   "Sa "   , "Na "   , "Mo "   , "Zu "   , "Da "   , "Ban "  , "Yi "   , "Yao "  ,  /*-- U+9778 .. U+977F --*/
   "Tao "  , "Tuo "  , "Jia "  , "Hong " , "Pao "  , "Yang " , "Tomo " , "Yin "  ,  /*-- U+9780 .. U+9787 --*/
   "Jia "  , "Tao "  , "Ji "   , "Xie "  , "An "   , "An "   , "Hen "  , "Gong " ,  /*-- U+9788 .. U+978F --*/
   "Kohaze ", "Da "   , "Qiao " , "Ting " , "Wan "  , "Ying " , "Sui "  , "Tiao " ,  /*-- U+9790 .. U+9797 --*/
   "Qiao " , "Xuan " , "Kong " , "Beng " , "Ta "   , "Zhang ", "Bing " , "Kuo "  ,  /*-- U+9798 .. U+979F --*/
   "Ju "   , "La "   , "Xie "  , "Rou "  , "Bang " , "Yi "   , "Qiu "  , "Qiu "  ,  /*-- U+97A0 .. U+97A7 --*/
   "He "   , "Xiao " , "Mu "   , "Ju "   , "Jian " , "Bian " , "Di "   , "Jian " ,  /*-- U+97A8 .. U+97AF --*/
   "On "   , "Tao "  , "Gou "  , "Ta "   , "Bei "  , "Xie "  , "Pan "  , "Ge "   ,  /*-- U+97B0 .. U+97B7 --*/
   "Bi "   , "Kuo "  , "Tang " , "Lou "  , "Gui "  , "Qiao " , "Xue "  , "Ji "   ,  /*-- U+97B8 .. U+97BF --*/
   "Jian " , "Jiang ", "Chan " , "Da "   , "Huo "  , "Xian " , "Qian " , "Du "   ,  /*-- U+97C0 .. U+97C7 --*/
   "Wa "   , "Jian " , "Lan "  , "Wei "  , "Ren "  , "Fu "   , "Mei "  , "Juan " ,  /*-- U+97C8 .. U+97CF --*/
   "Ge "   , "Wei "  , "Qiao " , "Han "  , "Chang ", ""      , "Rou "  , "Xun "  ,  /*-- U+97D0 .. U+97D7 --*/
   "She "  , "Wei "  , "Ge "   , "Bei "  , "Tao "  , "Gou "  , "Yun "  , ""      ,  /*-- U+97D8 .. U+97DF --*/
   "Bi "   , "Wei "  , "Hui "  , "Du "   , "Wa "   , "Du "   , "Wei "  , "Ren "  ,  /*-- U+97E0 .. U+97E7 --*/
   "Fu "   , "Han "  , "Wei "  , "Yun "  , "Tao "  , "Jiu "  , "Jiu "  , "Xian " ,  /*-- U+97E8 .. U+97EF --*/
   "Xie "  , "Xian " , "Ji "   , "Yin "  , "Za "   , "Yun "  , "Shao " , "Le "   ,  /*-- U+97F0 .. U+97F7 --*/
   "Peng " , "Heng " , "Ying " , "Yun "  , "Peng " , "Yin "  , "Yin "  , "Xiang ",  /*-- U+97F8 .. U+97FF --*/
   "Hu "   , "Ye "   , "Ding " , "Qing " , "Pan "  , "Xiang ", "Shun " , "Han "  ,  /*-- U+9800 .. U+9807 --*/
   "Xu "   , "Yi "   , "Xu "   , "Gu "   , "Song " , "Kui "  , "Qi "   , "Hang " ,  /*-- U+9808 .. U+980F --*/
   "Yu "   , "Wan "  , "Ban "  , "Dun "  , "Di "   , "Dan "  , "Pan "  , "Po "   ,  /*-- U+9810 .. U+9817 --*/
   "Ling " , "Ce "   , "Jing " , "Lei "  , "He "   , "Qiao " , "E "    , "E "    ,  /*-- U+9818 .. U+981F --*/
   "Wei "  , "Jie "  , "Gua "  , "Shen " , "Yi "   , "Shen " , "Hai "  , "Dui "  ,  /*-- U+9820 .. U+9827 --*/
   "Pian " , "Ping " , "Lei "  , "Fu "   , "Jia "  , "Tou "  , "Hui "  , "Kui "  ,  /*-- U+9828 .. U+982F --*/
   "Jia "  , "Le "   , "Tian " , "Cheng ", "Ying " , "Jun "  , "Hu "   , "Han "  ,  /*-- U+9830 .. U+9837 --*/
   "Jing " , "Tui "  , "Tui "  , "Pin "  , "Lai "  , "Tui "  , "Zi "   , "Zi "   ,  /*-- U+9838 .. U+983F --*/
   "Chui " , "Ding " , "Lai "  , "Yan "  , "Han "  , "Jian " , "Ke "   , "Cui "  ,  /*-- U+9840 .. U+9847 --*/
   "Jiong ", "Qin "  , "Yi "   , "Sai "  , "Ti "   , "E "    , "E "    , "Yan "  ,  /*-- U+9848 .. U+984F --*/
   "Hun "  , "Kan "  , "Yong " , "Zhuan ", "Yan "  , "Xian " , "Xin "  , "Yi "   ,  /*-- U+9850 .. U+9857 --*/
   "Yuan " , "Sang " , "Dian " , "Dian " , "Jiang ", "Ku "   , "Lei "  , "Liao " ,  /*-- U+9858 .. U+985F --*/
   "Piao " , "Yi "   , "Man "  , "Qi "   , "Rao "  , "Hao "  , "Qiao " , "Gu "   ,  /*-- U+9860 .. U+9867 --*/
   "Xun "  , "Qian " , "Hui "  , "Zhan " , "Ru "   , "Hong " , "Bin "  , "Xian " ,  /*-- U+9868 .. U+986F --*/
   "Pin "  , "Lu "   , "Lan "  , "Nie "  , "Quan " , "Ye "   , "Ding " , "Qing " ,  /*-- U+9870 .. U+9877 --*/
   "Han "  , "Xiang ", "Shun " , "Xu "   , "Xu "   , "Wan "  , "Gu "   , "Dun "  ,  /*-- U+9878 .. U+987F --*/
   "Qi "   , "Ban "  , "Song " , "Hang " , "Yu "   , "Lu "   , "Ling " , "Po "   ,  /*-- U+9880 .. U+9887 --*/
   "Jing " , "Jie "  , "Jia "  , "Tian " , "Han "  , "Ying " , "Jiong ", "Hai "  ,  /*-- U+9888 .. U+988F --*/
   "Yi "   , "Pin "  , "Hui "  , "Tui "  , "Han "  , "Ying " , "Ying " , "Ke "   ,  /*-- U+9890 .. U+9897 --*/
   "Ti "   , "Yong " , "E "    , "Zhuan ", "Yan "  , "E "    , "Nie "  , "Man "  ,  /*-- U+9898 .. U+989F --*/
   "Dian " , "Sang " , "Hao "  , "Lei "  , "Zhan " , "Ru "   , "Pin "  , "Quan " ,  /*-- U+98A0 .. U+98A7 --*/
   "Feng " , "Biao " , "Oroshi ", "Fu "   , "Xia "  , "Zhan " , "Biao " , "Sa "   ,  /*-- U+98A8 .. U+98AF --*/
   "Ba "   , "Tai "  , "Lie "  , "Gua "  , "Xuan " , "Shao " , "Ju "   , "Bi "   ,  /*-- U+98B0 .. U+98B7 --*/
   "Si "   , "Wei "  , "Yang " , "Yao "  , "Sou "  , "Kai "  , "Sao "  , "Fan "  ,  /*-- U+98B8 .. U+98BF --*/
   "Liu "  , "Xi "   , "Liao " , "Piao " , "Piao " , "Liu "  , "Biao " , "Biao " ,  /*-- U+98C0 .. U+98C7 --*/
   "Biao " , "Liao " , ""      , "Se "   , "Feng " , "Biao " , "Feng " , "Yang " ,  /*-- U+98C8 .. U+98CF --*/
   "Zhan " , "Biao " , "Sa "   , "Ju "   , "Si "   , "Sou "  , "Yao "  , "Liu "  ,  /*-- U+98D0 .. U+98D7 --*/
   "Piao " , "Biao " , "Biao " , "Fei "  , "Fan "  , "Fei "  , "Fei "  , "Shi "  ,  /*-- U+98D8 .. U+98DF --*/
   "Shi "  , "Can "  , "Ji "   , "Ding " , "Si "   , "Tuo "  , "Zhan " , "Sun "  ,  /*-- U+98E0 .. U+98E7 --*/
   "Xiang ", "Tun "  , "Ren "  , "Yu "   , "Juan " , "Chi "  , "Yin "  , "Fan "  ,  /*-- U+98E8 .. U+98EF --*/
   "Fan "  , "Sun "  , "Yin "  , "Zhu "  , "Yi "   , "Zhai " , "Bi "   , "Jie "  ,  /*-- U+98F0 .. U+98F7 --*/
   "Tao "  , "Liu "  , "Ci "   , "Tie "  , "Si "   , "Bao "  , "Shi "  , "Duo "  ,  /*-- U+98F8 .. U+98FF --*/
   "Hai "  , "Ren "  , "Tian " , "Jiao " , "Jia "  , "Bing " , "Yao "  , "Tong " ,  /*-- U+9900 .. U+9907 --*/
   "Ci "   , "Xiang ", "Yang " , "Yang " , "Er "   , "Yan "  , "Le "   , "Yi "   ,  /*-- U+9908 .. U+990F --*/
   "Can "  , "Bo "   , "Nei "  , "E "    , "Bu "   , "Jun "  , "Dou "  , "Su "   ,  /*-- U+9910 .. U+9917 --*/
   "Yu "   , "Shi "  , "Yao "  , "Hun "  , "Guo "  , "Shi "  , "Jian " , "Zhui " ,  /*-- U+9918 .. U+991F --*/
   "Bing " , "Xian " , "Bu "   , "Ye "   , "Tan "  , "Fei "  , "Zhang ", "Wei "  ,  /*-- U+9920 .. U+9927 --*/
   "Guan " , "E "    , "Nuan " , "Hun "  , "Hu "   , "Huang ", "Tie "  , "Hui "  ,  /*-- U+9928 .. U+992F --*/
   "Jian " , "Hou "  , "He "   , "Xing " , "Fen "  , "Wei "  , "Gu "   , "Cha "  ,  /*-- U+9930 .. U+9937 --*/
   "Song " , "Tang " , "Bo "   , "Gao "  , "Xi "   , "Kui "  , "Liu "  , "Sou "  ,  /*-- U+9938 .. U+993F --*/
   "Tao "  , "Ye "   , "Yun "  , "Mo "   , "Tang " , "Man "  , "Bi "   , "Yu "   ,  /*-- U+9940 .. U+9947 --*/
   "Xiu "  , "Jin "  , "San "  , "Kui "  , "Zhuan ", "Shan " , "Chi "  , "Dan "  ,  /*-- U+9948 .. U+994F --*/
   "Yi "   , "Ji "   , "Rao "  , "Cheng ", "Yong " , "Tao "  , "Hui "  , "Xiang ",  /*-- U+9950 .. U+9957 --*/
   "Zhan " , "Fen "  , "Hai "  , "Meng " , "Yan "  , "Mo "   , "Chan " , "Xiang ",  /*-- U+9958 .. U+995F --*/
   "Luo "  , "Zuan " , "Nang " , "Shi "  , "Ding " , "Ji "   , "Tuo "  , "Xing " ,  /*-- U+9960 .. U+9967 --*/
   "Tun "  , "Xi "   , "Ren "  , "Yu "   , "Chi "  , "Fan "  , "Yin "  , "Jian " ,  /*-- U+9968 .. U+996F --*/
   "Shi "  , "Bao "  , "Si "   , "Duo "  , "Yi "   , "Er "   , "Rao "  , "Xiang ",  /*-- U+9970 .. U+9977 --*/
   "Jia "  , "Le "   , "Jiao " , "Yi "   , "Bing " , "Bo "   , "Dou "  , "E "    ,  /*-- U+9978 .. U+997F --*/
   "Yu "   , "Nei "  , "Jun "  , "Guo "  , "Hun "  , "Xian " , "Guan " , "Cha "  ,  /*-- U+9980 .. U+9987 --*/
   "Kui "  , "Gu "   , "Sou "  , "Chan " , "Ye "   , "Mo "   , "Bo "   , "Liu "  ,  /*-- U+9988 .. U+998F --*/
   "Xiu "  , "Jin "  , "Man "  , "San "  , "Zhuan ", "Nang " , "Shou " , "Kui "  ,  /*-- U+9990 .. U+9997 --*/
   "Guo "  , "Xiang ", "Fen "  , "Ba "   , "Ni "   , "Bi "   , "Bo "   , "Tu "   ,  /*-- U+9998 .. U+999F --*/
   "Han "  , "Fei "  , "Jian " , "An "   , "Ai "   , "Fu "   , "Xian " , "Wen "  ,  /*-- U+99A0 .. U+99A7 --*/
   "Xin "  , "Fen "  , "Bin "  , "Xing " , "Ma "   , "Yu "   , "Feng " , "Han "  ,  /*-- U+99A8 .. U+99AF --*/
   "Di "   , "Tuo "  , "Tuo "  , "Chi "  , "Xun "  , "Zhu "  , "Zhi "  , "Pei "  ,  /*-- U+99B0 .. U+99B7 --*/
   "Xin "  , "Ri "   , "Sa "   , "Yin "  , "Wen "  , "Zhi "  , "Dan "  , "Lu "   ,  /*-- U+99B8 .. U+99BF --*/
   "You "  , "Bo "   , "Bao "  , "Kuai " , "Tuo "  , "Yi "   , "Qu "   , ""      ,  /*-- U+99C0 .. U+99C7 --*/
   "Qu "   , "Jiong ", "Bo "   , "Zhao " , "Yuan " , "Peng " , "Zhou " , "Ju "   ,  /*-- U+99C8 .. U+99CF --*/
   "Zhu "  , "Nu "   , "Ju "   , "Pi "   , "Zang " , "Jia "  , "Ling " , "Zhen " ,  /*-- U+99D0 .. U+99D7 --*/
   "Tai "  , "Fu "   , "Yang " , "Shi "  , "Bi "   , "Tuo "  , "Tuo "  , "Si "   ,  /*-- U+99D8 .. U+99DF --*/
   "Liu "  , "Ma "   , "Pian " , "Tao "  , "Zhi "  , "Rong " , "Teng " , "Dong " ,  /*-- U+99E0 .. U+99E7 --*/
   "Xun "  , "Quan " , "Shen " , "Jiong ", "Er "   , "Hai "  , "Bo "   , "Zhu "  ,  /*-- U+99E8 .. U+99EF --*/
   "Yin "  , "Luo "  , "Shuu " , "Dan "  , "Xie "  , "Liu "  , "Ju "   , "Song " ,  /*-- U+99F0 .. U+99F7 --*/
   "Qin "  , "Mang " , "Liang ", "Han "  , "Tu "   , "Xuan " , "Tui "  , "Jun "  ,  /*-- U+99F8 .. U+99FF --*/
   "E "    , "Cheng ", "Xin "  , "Ai "   , "Lu "   , "Zhui " , "Zhou " , "She "  ,  /*-- U+9A00 .. U+9A07 --*/
   "Pian " , "Kun "  , "Tao "  , "Lai "  , "Zong " , "Ke "   , "Qi "   , "Qi "   ,  /*-- U+9A08 .. U+9A0F --*/
   "Yan "  , "Fei "  , "Sao "  , "Yan "  , "Jie "  , "Yao "  , "Wu "   , "Pian " ,  /*-- U+9A10 .. U+9A17 --*/
   "Cong " , "Pian " , "Qian " , "Fei "  , "Huang ", "Jian " , "Huo "  , "Yu "   ,  /*-- U+9A18 .. U+9A1F --*/
   "Ti "   , "Quan " , "Xia "  , "Zong " , "Kui "  , "Rou "  , "Si "   , "Gua "  ,  /*-- U+9A20 .. U+9A27 --*/
   "Tuo "  , "Kui "  , "Sou "  , "Qian " , "Cheng ", "Zhi "  , "Liu "  , "Pang " ,  /*-- U+9A28 .. U+9A2F --*/
   "Teng " , "Xi "   , "Cao "  , "Du "   , "Yan "  , "Yuan " , "Zou "  , "Sao "  ,  /*-- U+9A30 .. U+9A37 --*/
   "Shan " , "Li "   , "Zhi "  , "Shuang ", "Lu "   , "Xi "   , "Luo "  , "Zhang ",  /*-- U+9A38 .. U+9A3F --*/
   "Mo "   , "Ao "   , "Can "  , "Piao " , "Cong " , "Qu "   , "Bi "   , "Zhi "  ,  /*-- U+9A40 .. U+9A47 --*/
   "Yu "   , "Xu "   , "Hua "  , "Bo "   , "Su "   , "Xiao " , "Lin "  , "Chan " ,  /*-- U+9A48 .. U+9A4F --*/
   "Dun "  , "Liu "  , "Tuo "  , "Zeng " , "Tan "  , "Jiao " , "Tie "  , "Yan "  ,  /*-- U+9A50 .. U+9A57 --*/
   "Luo "  , "Zhan " , "Jing " , "Yi "   , "Ye "   , "Tuo "  , "Bin "  , "Zou "  ,  /*-- U+9A58 .. U+9A5F --*/
   "Yan "  , "Peng " , "Lu "   , "Teng " , "Xiang ", "Ji "   , "Shuang ", "Ju "   ,  /*-- U+9A60 .. U+9A67 --*/
   "Xi "   , "Huan " , "Li "   , "Biao " , "Ma "   , "Yu "   , "Tuo "  , "Xun "  ,  /*-- U+9A68 .. U+9A6F --*/
   "Chi "  , "Qu "   , "Ri "   , "Bo "   , "Lu "   , "Zang " , "Shi "  , "Si "   ,  /*-- U+9A70 .. U+9A77 --*/
   "Fu "   , "Ju "   , "Zou "  , "Zhu "  , "Tuo "  , "Nu "   , "Jia "  , "Yi "   ,  /*-- U+9A78 .. U+9A7F --*/
   "Tai "  , "Xiao " , "Ma "   , "Yin "  , "Jiao " , "Hua "  , "Luo "  , "Hai "  ,  /*-- U+9A80 .. U+9A87 --*/
   "Pian " , "Biao " , "Li "   , "Cheng ", "Yan "  , "Xin "  , "Qin "  , "Jun "  ,  /*-- U+9A88 .. U+9A8F --*/
   "Qi "   , "Qi "   , "Ke "   , "Zhui " , "Zong " , "Su "   , "Can "  , "Pian " ,  /*-- U+9A90 .. U+9A97 --*/
   "Zhi "  , "Kui "  , "Sao "  , "Wu "   , "Ao "   , "Liu "  , "Qian " , "Shan " ,  /*-- U+9A98 .. U+9A9F --*/
   "Piao " , "Luo "  , "Cong " , "Chan " , "Zou "  , "Ji "   , "Shuang ", "Xiang ",  /*-- U+9AA0 .. U+9AA7 --*/
   "Gu "   , "Wei "  , "Wei "  , "Wei "  , "Yu "   , "Gan "  , "Yi "   , "Ang "  ,  /*-- U+9AA8 .. U+9AAF --*/
   "Tou "  , "Xie "  , "Bao "  , "Bi "   , "Chi "  , "Ti "   , "Di "   , "Ku "   ,  /*-- U+9AB0 .. U+9AB7 --*/
   "Hai "  , "Qiao " , "Gou "  , "Kua "  , "Ge "   , "Tui "  , "Geng " , "Pian " ,  /*-- U+9AB8 .. U+9ABF --*/
   "Bi "   , "Ke "   , "Ka "   , "Yu "   , "Sui "  , "Lou "  , "Bo "   , "Xiao " ,  /*-- U+9AC0 .. U+9AC7 --*/
   "Pang " , "Bo "   , "Ci "   , "Kuan " , "Bin "  , "Mo "   , "Liao " , "Lou "  ,  /*-- U+9AC8 .. U+9ACF --*/
   "Nao "  , "Du "   , "Zang " , "Sui "  , "Ti "   , "Bin "  , "Kuan " , "Lu "   ,  /*-- U+9AD0 .. U+9AD7 --*/
   "Gao "  , "Gao "  , "Qiao " , "Kao "  , "Qiao " , "Lao "  , "Zao "  , "Biao " ,  /*-- U+9AD8 .. U+9ADF --*/
   "Kun "  , "Kun "  , "Ti "   , "Fang " , "Xiu "  , "Ran "  , "Mao "  , "Dan "  ,  /*-- U+9AE0 .. U+9AE7 --*/
   "Kun "  , "Bin "  , "Fa "   , "Tiao " , "Peng " , "Zi "   , "Fa "   , "Ran "  ,  /*-- U+9AE8 .. U+9AEF --*/
   "Ti "   , "Pao "  , "Pi "   , "Mao "  , "Fu "   , "Er "   , "Rong " , "Qu "   ,  /*-- U+9AF0 .. U+9AF7 --*/
   "Gong " , "Xiu "  , "Gua "  , "Ji "   , "Peng " , "Zhua " , "Shao " , "Sha "  ,  /*-- U+9AF8 .. U+9AFF --*/
   "Ti "   , "Li "   , "Bin "  , "Zong " , "Ti "   , "Peng " , "Song " , "Zheng ",  /*-- U+9B00 .. U+9B07 --*/
   "Quan " , "Zong " , "Shun " , "Jian " , "Duo "  , "Hu "   , "La "   , "Jiu "  ,  /*-- U+9B08 .. U+9B0F --*/
   "Qi "   , "Lian " , "Zhen " , "Bin "  , "Peng " , "Mo "   , "San "  , "Man "  ,  /*-- U+9B10 .. U+9B17 --*/
   "Man "  , "Seng " , "Xu "   , "Lie "  , "Qian " , "Qian " , "Nong " , "Huan " ,  /*-- U+9B18 .. U+9B1F --*/
   "Kuai " , "Ning " , "Bin "  , "Lie "  , "Rang " , "Dou "  , "Dou "  , "Nao "  ,  /*-- U+9B20 .. U+9B27 --*/
   "Hong " , "Xi "   , "Dou "  , "Han "  , "Dou "  , "Dou "  , "Jiu "  , "Chang ",  /*-- U+9B28 .. U+9B2F --*/
   "Yu "   , "Yu "   , "Li "   , "Juan " , "Fu "   , "Qian " , "Gui "  , "Zong " ,  /*-- U+9B30 .. U+9B37 --*/
   "Liu "  , "Gui "  , "Shang ", "Yu "   , "Gui "  , "Mei "  , "Ji "   , "Qi "   ,  /*-- U+9B38 .. U+9B3F --*/
   "Jie "  , "Kui "  , "Hun "  , "Ba "   , "Po "   , "Mei "  , "Xu "   , "Yan "  ,  /*-- U+9B40 .. U+9B47 --*/
   "Xiao " , "Liang ", "Yu "   , "Tui "  , "Qi "   , "Wang " , "Liang ", "Wei "  ,  /*-- U+9B48 .. U+9B4F --*/
   "Jian " , "Chi "  , "Piao " , "Bi "   , "Mo "   , "Ji "   , "Xu "   , "Chou " ,  /*-- U+9B50 .. U+9B57 --*/
   "Yan "  , "Zhan " , "Yu "   , "Dao "  , "Ren "  , "Ji "   , "Eri "  , "Gong " ,  /*-- U+9B58 .. U+9B5F --*/
   "Tuo "  , "Diao " , "Ji "   , "Xu "   , "E "    , "E "    , "Sha "  , "Hang " ,  /*-- U+9B60 .. U+9B67 --*/
   "Tun "  , "Mo "   , "Jie "  , "Shen " , "Fan "  , "Yuan " , "Bi "   , "Lu "   ,  /*-- U+9B68 .. U+9B6F --*/
   "Wen "  , "Hu "   , "Lu "   , "Za "   , "Fang " , "Fen "  , "Na "   , "You "  ,  /*-- U+9B70 .. U+9B77 --*/
   "Namazu ", "Todo " , "He "   , "Xia "  , "Qu "   , "Han "  , "Pi "   , "Ling " ,  /*-- U+9B78 .. U+9B7F --*/
   "Tuo "  , "Bo "   , "Qiu "  , "Ping " , "Fu "   , "Bi "   , "Ji "   , "Wei "  ,  /*-- U+9B80 .. U+9B87 --*/
   "Ju "   , "Diao " , "Bo "   , "You "  , "Gun "  , "Pi "   , "Nian " , "Xing " ,  /*-- U+9B88 .. U+9B8F --*/
   "Tai "  , "Bao "  , "Fu "   , "Zha "  , "Ju "   , "Gu "   , "Kajika ", "Tong " ,  /*-- U+9B90 .. U+9B97 --*/
   ""      , "Ta "   , "Jie "  , "Shu "  , "Hou "  , "Xiang ", "Er "   , "An "   ,  /*-- U+9B98 .. U+9B9F --*/
   "Wei "  , "Tiao " , "Zhu "  , "Yin "  , "Lie "  , "Luo "  , "Tong " , "Yi "   ,  /*-- U+9BA0 .. U+9BA7 --*/
   "Qi "   , "Bing " , "Wei "  , "Jiao " , "Bu "   , "Gui "  , "Xian " , "Ge "   ,  /*-- U+9BA8 .. U+9BAF --*/
   "Hui "  , "Bora " , "Mate " , "Kao "  , "Gori " , "Duo "  , "Jun "  , "Ti "   ,  /*-- U+9BB0 .. U+9BB7 --*/
   "Man "  , "Xiao " , "Za "   , "Sha "  , "Qin "  , "Yu "   , "Nei "  , "Zhe "  ,  /*-- U+9BB8 .. U+9BBF --*/
   "Gun "  , "Geng " , "Su "   , "Wu "   , "Qiu "  , "Ting " , "Fu "   , "Wan "  ,  /*-- U+9BC0 .. U+9BC7 --*/
   "You "  , "Li "   , "Sha "  , "Sha "  , "Gao "  , "Meng " , "Ugui " , "Asari ",  /*-- U+9BC8 .. U+9BCF --*/
   "Subashiri ", "Kazunoko ", "Yong " , "Ni "   , "Zi "   , "Qi "   , "Qing " , "Xiang ",  /*-- U+9BD0 .. U+9BD7 --*/
   "Nei "  , "Chun " , "Ji "   , "Diao " , "Qie "  , "Gu "   , "Zhou " , "Dong " ,  /*-- U+9BD8 .. U+9BDF --*/
   "Lai "  , "Fei "  , "Ni "   , "Yi "   , "Kun "  , "Lu "   , "Jiu "  , "Chang ",  /*-- U+9BE0 .. U+9BE7 --*/
   "Jing " , "Lun "  , "Ling " , "Zou "  , "Li "   , "Meng " , "Zong " , "Zhi "  ,  /*-- U+9BE8 .. U+9BEF --*/
   "Nian " , "Shachi ", "Dojou ", "Sukesou ", "Shi "  , "Shen " , "Hun "  , "Shi "  ,  /*-- U+9BF0 .. U+9BF7 --*/
   "Hou "  , "Xing " , "Zhu "  , "La "   , "Zong " , "Ji "   , "Bian " , "Bian " ,  /*-- U+9BF8 .. U+9BFF --*/
   "Huan " , "Quan " , "Ze "   , "Wei "  , "Wei "  , "Yu "   , "Qun "  , "Rou "  ,  /*-- U+9C00 .. U+9C07 --*/
   "Die "  , "Huang ", "Lian " , "Yan "  , "Qiu "  , "Qiu "  , "Jian " , "Bi "   ,  /*-- U+9C08 .. U+9C0F --*/
   "E "    , "Yang " , "Fu "   , "Sai "  , "Jian " , "Xia "  , "Tuo "  , "Hu "   ,  /*-- U+9C10 .. U+9C17 --*/
   "Muroaji ", "Ruo "  , "Haraka ", "Wen "  , "Jian " , "Hao "  , "Wu "   , "Fang " ,  /*-- U+9C18 .. U+9C1F --*/
   "Sao "  , "Liu "  , "Ma "   , "Shi "  , "Shi "  , "Yin "  , "Z "    , "Teng " ,  /*-- U+9C20 .. U+9C27 --*/
   "Ta "   , "Yao "  , "Ge "   , "Rong " , "Qian " , "Qi "   , "Wen "  , "Ruo "  ,  /*-- U+9C28 .. U+9C2F --*/
   "Hatahata ", "Lian " , "Ao "   , "Le "   , "Hui "  , "Min "  , "Ji "   , "Tiao " ,  /*-- U+9C30 .. U+9C37 --*/
   "Qu "   , "Jian " , "Sao "  , "Man "  , "Xi "   , "Qiu "  , "Biao " , "Ji "   ,  /*-- U+9C38 .. U+9C3F --*/
   "Ji "   , "Zhu "  , "Jiang ", "Qiu "  , "Zhuan ", "Yong " , "Zhang ", "Kang " ,  /*-- U+9C40 .. U+9C47 --*/
   "Xue "  , "Bie "  , "Jue "  , "Qu "   , "Xiang ", "Bo "   , "Jiao " , "Xun "  ,  /*-- U+9C48 .. U+9C4F --*/
   "Su "   , "Huang ", "Zun "  , "Shan " , "Shan " , "Fan "  , "Jue "  , "Lin "  ,  /*-- U+9C50 .. U+9C57 --*/
   "Xun "  , "Miao " , "Xi "   , "Eso "  , "Kyou " , "Fen "  , "Guan " , "Hou "  ,  /*-- U+9C58 .. U+9C5F --*/
   "Kuai " , "Zei "  , "Sao "  , "Zhan " , "Gan "  , "Gui "  , "Sheng ", "Li "   ,  /*-- U+9C60 .. U+9C67 --*/
   "Chang ", "Hatahata ", "Shiira ", "Mutsu ", "Ru "   , "Ji "   , "Xu "   , "Huo "  ,  /*-- U+9C68 .. U+9C6F --*/
   "Shiira ", "Li "   , "Lie "  , "Li "   , "Mie "  , "Zhen " , "Xiang ", "E "    ,  /*-- U+9C70 .. U+9C77 --*/
   "Lu "   , "Guan " , "Li "   , "Xian " , "Yu "   , "Dao "  , "Ji "   , "You "  ,  /*-- U+9C78 .. U+9C7F --*/
   "Tun "  , "Lu "   , "Fang " , "Ba "   , "He "   , "Bo "   , "Ping " , "Nian " ,  /*-- U+9C80 .. U+9C87 --*/
   "Lu "   , "You "  , "Zha "  , "Fu "   , "Bo "   , "Bao "  , "Hou "  , "Pi "   ,  /*-- U+9C88 .. U+9C8F --*/
   "Tai "  , "Gui "  , "Jie "  , "Kao "  , "Wei "  , "Er "   , "Tong " , "Ze "   ,  /*-- U+9C90 .. U+9C97 --*/
   "Hou "  , "Kuai " , "Ji "   , "Jiao " , "Xian " , "Za "   , "Xiang ", "Xun "  ,  /*-- U+9C98 .. U+9C9F --*/
   "Geng " , "Li "   , "Lian " , "Jian " , "Li "   , "Shi "  , "Tiao " , "Gun "  ,  /*-- U+9CA0 .. U+9CA7 --*/
   "Sha "  , "Wan "  , "Jun "  , "Ji "   , "Yong " , "Qing " , "Ling " , "Qi "   ,  /*-- U+9CA8 .. U+9CAF --*/
   "Zou "  , "Fei "  , "Kun "  , "Chang ", "Gu "   , "Ni "   , "Nian " , "Diao " ,  /*-- U+9CB0 .. U+9CB7 --*/
   "Jing " , "Shen " , "Shi "  , "Zi "   , "Fen "  , "Die "  , "Bi "   , "Chang ",  /*-- U+9CB8 .. U+9CBF --*/
   "Shi "  , "Wen "  , "Wei "  , "Sai "  , "E "    , "Qiu "  , "Fu "   , "Huang ",  /*-- U+9CC0 .. U+9CC7 --*/
   "Quan " , "Jiang ", "Bian " , "Sao "  , "Ao "   , "Qi "   , "Ta "   , "Yin "  ,  /*-- U+9CC8 .. U+9CCF --*/
   "Yao "  , "Fang " , "Jian " , "Le "   , "Biao " , "Xue "  , "Bie "  , "Man "  ,  /*-- U+9CD0 .. U+9CD7 --*/
   "Min "  , "Yong " , "Wei "  , "Xi "   , "Jue "  , "Shan " , "Lin "  , "Zun "  ,  /*-- U+9CD8 .. U+9CDF --*/
   "Huo "  , "Gan "  , "Li "   , "Zhan " , "Guan " , "Niao " , "Yi "   , "Fu "   ,  /*-- U+9CE0 .. U+9CE7 --*/
   "Li "   , "Jiu "  , "Bu "   , "Yan "  , "Fu "   , "Diao " , "Ji "   , "Feng " ,  /*-- U+9CE8 .. U+9CEF --*/
   "Nio "  , "Gan "  , "Shi "  , "Feng " , "Ming " , "Bao "  , "Yuan " , "Zhi "  ,  /*-- U+9CF0 .. U+9CF7 --*/
   "Hu "   , "Qin "  , "Fu "   , "Fen "  , "Wen "  , "Jian " , "Shi "  , "Yu "   ,  /*-- U+9CF8 .. U+9CFF --*/
   "Fou "  , "Yiao " , "Jue "  , "Jue "  , "Pi "   , "Huan " , "Zhen " , "Bao "  ,  /*-- U+9D00 .. U+9D07 --*/
   "Yan "  , "Ya "   , "Zheng ", "Fang " , "Feng " , "Wen "  , "Ou "   , "Te "   ,  /*-- U+9D08 .. U+9D0F --*/
   "Jia "  , "Nu "   , "Ling " , "Mie "  , "Fu "   , "Tuo "  , "Wen "  , "Li "   ,  /*-- U+9D10 .. U+9D17 --*/
   "Bian " , "Zhi "  , "Ge "   , "Yuan " , "Zi "   , "Qu "   , "Xiao " , "Zhi "  ,  /*-- U+9D18 .. U+9D1F --*/
   "Dan "  , "Ju "   , "You "  , "Gu "   , "Zhong ", "Yu "   , "Yang " , "Rong " ,  /*-- U+9D20 .. U+9D27 --*/
   "Ya "   , "Tie "  , "Yu "   , "Shigi ", "Ying " , "Zhui " , "Wu "   , "Er "   ,  /*-- U+9D28 .. U+9D2F --*/
   "Gua "  , "Ai "   , "Zhi "  , "Yan "  , "Heng " , "Jiao " , "Ji "   , "Lie "  ,  /*-- U+9D30 .. U+9D37 --*/
   "Zhu "  , "Ren "  , "Yi "   , "Hong " , "Luo "  , "Ru "   , "Mou "  , "Ge "   ,  /*-- U+9D38 .. U+9D3F --*/
   "Ren "  , "Jiao " , "Xiu "  , "Zhou " , "Zhi "  , "Luo "  , "Chidori ", "Toki " ,  /*-- U+9D40 .. U+9D47 --*/
   "Ten "  , "Luan " , "Jia "  , "Ji "   , "Yu "   , "Huan " , "Tuo "  , "Bu "   ,  /*-- U+9D48 .. U+9D4F --*/
   "Wu "   , "Juan " , "Yu "   , "Bo "   , "Xun "  , "Xun "  , "Bi "   , "Xi "   ,  /*-- U+9D50 .. U+9D57 --*/
   "Jun "  , "Ju "   , "Tu "   , "Jing " , "Ti "   , "E "    , "E "    , "Kuang ",  /*-- U+9D58 .. U+9D5F --*/
   "Hu "   , "Wu "   , "Shen " , "Lai "  , "Ikaruga ", "Kakesu ", "Lu "   , "Ping " ,  /*-- U+9D60 .. U+9D67 --*/
   "Shu "  , "Fu "   , "An "   , "Zhao " , "Peng " , "Qin "  , "Qian " , "Bei "  ,  /*-- U+9D68 .. U+9D6F --*/
   "Diao " , "Lu "   , "Que "  , "Jian " , "Ju "   , "Tu "   , "Ya "   , "Yuan " ,  /*-- U+9D70 .. U+9D77 --*/
   "Qi "   , "Li "   , "Ye "   , "Zhui " , "Kong " , "Zhui " , "Kun "  , "Sheng ",  /*-- U+9D78 .. U+9D7F --*/
   "Qi "   , "Jing " , "Yi "   , "Yi "   , "Jing " , "Zi "   , "Lai "  , "Dong " ,  /*-- U+9D80 .. U+9D87 --*/
   "Qi "   , "Chun " , "Geng " , "Ju "   , "Qu "   , "Isuka ", "Kikuitadaki ", "Ji "   ,  /*-- U+9D88 .. U+9D8F --*/
   "Shu "  , ""      , "Chi "  , "Miao " , "Rou "  , "An "   , "Qiu "  , "Ti "   ,  /*-- U+9D90 .. U+9D97 --*/
   "Hu "   , "Ti "   , "E "    , "Jie "  , "Mao "  , "Fu "   , "Chun " , "Tu "   ,  /*-- U+9D98 .. U+9D9F --*/
   "Yan "  , "He "   , "Yuan " , "Pian " , "Yun "  , "Mei "  , "Hu "   , "Ying " ,  /*-- U+9DA0 .. U+9DA7 --*/
   "Dun "  , "Mu "   , "Ju "   , "Tsugumi ", "Cang " , "Fang " , "Gu "   , "Ying " ,  /*-- U+9DA8 .. U+9DAF --*/
   "Yuan " , "Xuan " , "Weng " , "Shi "  , "He "   , "Chu "  , "Tang " , "Xia "  ,  /*-- U+9DB0 .. U+9DB7 --*/
   "Ruo "  , "Liu "  , "Ji "   , "Gu "   , "Jian " , "Zhun " , "Han "  , "Zi "   ,  /*-- U+9DB8 .. U+9DBF --*/
   "Zi "   , "Ni "   , "Yao "  , "Yan "  , "Ji "   , "Li "   , "Tian " , "Kou "  ,  /*-- U+9DC0 .. U+9DC7 --*/
   "Ti "   , "Ti "   , "Ni "   , "Tu "   , "Ma "   , "Jiao " , "Gao "  , "Tian " ,  /*-- U+9DC8 .. U+9DCF --*/
   "Chen " , "Li "   , "Zhuan ", "Zhe "  , "Ao "   , "Yao "  , "Yi "   , "Ou "   ,  /*-- U+9DD0 .. U+9DD7 --*/
   "Chi "  , "Zhi "  , "Liao " , "Rong " , "Lou "  , "Bi "   , "Shuang ", "Zhuo " ,  /*-- U+9DD8 .. U+9DDF --*/
   "Yu "   , "Wu "   , "Jue "  , "Yin "  , "Quan " , "Si "   , "Jiao " , "Yi "   ,  /*-- U+9DE0 .. U+9DE7 --*/
   "Hua "  , "Bi "   , "Ying " , "Su "   , "Huang ", "Fan "  , "Jiao " , "Liao " ,  /*-- U+9DE8 .. U+9DEF --*/
   "Yan "  , "Kao "  , "Jiu "  , "Xian " , "Xian " , "Tu "   , "Mai "  , "Zun "  ,  /*-- U+9DF0 .. U+9DF7 --*/
   "Yu "   , "Ying " , "Lu "   , "Tuan " , "Xian " , "Xue "  , "Yi "   , "Pi "   ,  /*-- U+9DF8 .. U+9DFF --*/
   "Shu "  , "Luo "  , "Qi "   , "Yi "   , "Ji "   , "Zhe "  , "Yu "   , "Zhan " ,  /*-- U+9E00 .. U+9E07 --*/
   "Ye "   , "Yang " , "Pi "   , "Ning " , "Huo "  , "Mi "   , "Ying " , "Meng " ,  /*-- U+9E08 .. U+9E0F --*/
   "Di "   , "Yue "  , "Yu "   , "Lei "  , "Bao "  , "Lu "   , "He "   , "Long " ,  /*-- U+9E10 .. U+9E17 --*/
   "Shuang ", "Yue "  , "Ying " , "Guan " , "Qu "   , "Li "   , "Luan " , "Niao " ,  /*-- U+9E18 .. U+9E1F --*/
   "Jiu "  , "Ji "   , "Yuan " , "Ming " , "Shi "  , "Ou "   , "Ya "   , "Cang " ,  /*-- U+9E20 .. U+9E27 --*/
   "Bao "  , "Zhen " , "Gu "   , "Dong " , "Lu "   , "Ya "   , "Xiao " , "Yang " ,  /*-- U+9E28 .. U+9E2F --*/
   "Ling " , "Zhi "  , "Qu "   , "Yuan " , "Xue "  , "Tuo "  , "Si "   , "Zhi "  ,  /*-- U+9E30 .. U+9E37 --*/
   "Er "   , "Gua "  , "Xiu "  , "Heng " , "Zhou " , "Ge "   , "Luan " , "Hong " ,  /*-- U+9E38 .. U+9E3F --*/
   "Wu "   , "Bo "   , "Li "   , "Juan " , "Hu "   , "E "    , "Yu "   , "Xian " ,  /*-- U+9E40 .. U+9E47 --*/
   "Ti "   , "Wu "   , "Que "  , "Miao " , "An "   , "Kun "  , "Bei "  , "Peng " ,  /*-- U+9E48 .. U+9E4F --*/
   "Qian " , "Chun " , "Geng " , "Yuan " , "Su "   , "Hu "   , "He "   , "E "    ,  /*-- U+9E50 .. U+9E57 --*/
   "Gu "   , "Qiu "  , "Zi "   , "Mei "  , "Mu "   , "Ni "   , "Yao "  , "Weng " ,  /*-- U+9E58 .. U+9E5F --*/
   "Liu "  , "Ji "   , "Ni "   , "Jian " , "He "   , "Yi "   , "Ying " , "Zhe "  ,  /*-- U+9E60 .. U+9E67 --*/
   "Liao " , "Liao " , "Jiao " , "Jiu "  , "Yu "   , "Lu "   , "Xuan " , "Zhan " ,  /*-- U+9E68 .. U+9E6F --*/
   "Ying " , "Huo "  , "Meng " , "Guan " , "Shuang ", "Lu "   , "Jin "  , "Ling " ,  /*-- U+9E70 .. U+9E77 --*/
   "Jian " , "Xian " , "Cuo "  , "Jian " , "Jian " , "Yan "  , "Cuo "  , "Lu "   ,  /*-- U+9E78 .. U+9E7F --*/
   "You "  , "Cu "   , "Ji "   , "Biao " , "Cu "   , "Biao " , "Zhu "  , "Jun "  ,  /*-- U+9E80 .. U+9E87 --*/
   "Zhu "  , "Jian " , "Mi "   , "Mi "   , "Wu "   , "Liu "  , "Chen " , "Jun "  ,  /*-- U+9E88 .. U+9E8F --*/
   "Lin "  , "Ni "   , "Qi "   , "Lu "   , "Jiu "  , "Jun "  , "Jing " , "Li "   ,  /*-- U+9E90 .. U+9E97 --*/
   "Xiang ", "Yan "  , "Jia "  , "Mi "   , "Li "   , "She "  , "Zhang ", "Lin "  ,  /*-- U+9E98 .. U+9E9F --*/
   "Jing " , "Ji "   , "Ling " , "Yan "  , "Cu "   , "Mai "  , "Mai "  , "Ge "   ,  /*-- U+9EA0 .. U+9EA7 --*/
   "Chao " , "Fu "   , "Mian " , "Mian " , "Fu "   , "Pao "  , "Qu "   , "Qu "   ,  /*-- U+9EA8 .. U+9EAF --*/
   "Mou "  , "Fu "   , "Xian " , "Lai "  , "Qu "   , "Mian " , ""      , "Feng " ,  /*-- U+9EB0 .. U+9EB7 --*/
   "Fu "   , "Qu "   , "Mian " , "Ma "   , "Mo "   , "Mo "   , "Hui "  , "Ma "   ,  /*-- U+9EB8 .. U+9EBF --*/
   "Zou "  , "Nen "  , "Fen "  , "Huang ", "Huang ", "Jin "  , "Guang ", "Tian " ,  /*-- U+9EC0 .. U+9EC7 --*/
   "Tou "  , "Heng " , "Xi "   , "Kuang ", "Heng " , "Shu "  , "Li "   , "Nian " ,  /*-- U+9EC8 .. U+9ECF --*/
   "Chi "  , "Hei "  , "Hei "  , "Yi "   , "Qian " , "Dan "  , "Xi "   , "Tuan " ,  /*-- U+9ED0 .. U+9ED7 --*/
   "Mo "   , "Mo "   , "Qian " , "Dai "  , "Chu "  , "You "  , "Dian " , "Yi "   ,  /*-- U+9ED8 .. U+9EDF --*/
   "Xia "  , "Yan "  , "Qu "   , "Mei "  , "Yan "  , "Jing " , "Yu "   , "Li "   ,  /*-- U+9EE0 .. U+9EE7 --*/
   "Dang " , "Du "   , "Can "  , "Yin "  , "An "   , "Yan "  , "Tan "  , "An "   ,  /*-- U+9EE8 .. U+9EEF --*/
   "Zhen " , "Dai "  , "Can "  , "Yi "   , "Mei "  , "Dan "  , "Yan "  , "Du "   ,  /*-- U+9EF0 .. U+9EF7 --*/
   "Lu "   , "Zhi "  , "Fen "  , "Fu "   , "Fu "   , "Min "  , "Min "  , "Yuan " ,  /*-- U+9EF8 .. U+9EFF --*/
   "Cu "   , "Qu "   , "Chao " , "Wa "   , "Zhu "  , "Zhi "  , "Mang " , "Ao "   ,  /*-- U+9F00 .. U+9F07 --*/
   "Bie "  , "Tuo "  , "Bi "   , "Yuan " , "Chao " , "Tuo "  , "Ding " , "Mi "   ,  /*-- U+9F08 .. U+9F0F --*/
   "Nai "  , "Ding " , "Zi "   , "Gu "   , "Gu "   , "Dong " , "Fen "  , "Tao "  ,  /*-- U+9F10 .. U+9F17 --*/
   "Yuan " , "Pi "   , "Chang ", "Gao "  , "Qi "   , "Yuan " , "Tang " , "Teng " ,  /*-- U+9F18 .. U+9F1F --*/
   "Shu "  , "Shu "  , "Fen "  , "Fei "  , "Wen "  , "Ba "   , "Diao " , "Tuo "  ,  /*-- U+9F20 .. U+9F27 --*/
   "Tong " , "Qu "   , "Sheng ", "Shi "  , "You "  , "Shi "  , "Ting " , "Wu "   ,  /*-- U+9F28 .. U+9F2F --*/
   "Nian " , "Jing " , "Hun "  , "Ju "   , "Yan "  , "Tu "   , "Ti "   , "Xi "   ,  /*-- U+9F30 .. U+9F37 --*/
   "Xian " , "Yan "  , "Lei "  , "Bi "   , "Yao "  , "Qiu "  , "Han "  , "Wu "   ,  /*-- U+9F38 .. U+9F3F --*/
   "Wu "   , "Hou "  , "Xi "   , "Ge "   , "Zha "  , "Xiu "  , "Weng " , "Zha "  ,  /*-- U+9F40 .. U+9F47 --*/
   "Nong " , "Nang " , "Qi "   , "Zhai " , "Ji "   , "Zi "   , "Ji "   , "Ji "   ,  /*-- U+9F48 .. U+9F4F --*/
   "Qi "   , "Ji "   , "Chi "  , "Chen " , "Chen " , "He "   , "Ya "   , "Ken "  ,  /*-- U+9F50 .. U+9F57 --*/
   "Xie "  , "Pao "  , "Cuo "  , "Shi "  , "Zi "   , "Chi "  , "Nian " , "Ju "   ,  /*-- U+9F58 .. U+9F5F --*/
   "Tiao " , "Ling " , "Ling " , "Chu "  , "Quan " , "Xie "  , "Ken "  , "Nie "  ,  /*-- U+9F60 .. U+9F67 --*/
   "Jiu "  , "Yao "  , "Chuo " , "Kun "  , "Yu "   , "Chu "  , "Yi "   , "Ni "   ,  /*-- U+9F68 .. U+9F6F --*/
   "Cuo "  , "Zou "  , "Qu "   , "Nen "  , "Xian " , "Ou "   , "E "    , "Wo "   ,  /*-- U+9F70 .. U+9F77 --*/
   "Yi "   , "Chuo " , "Zou "  , "Dian " , "Chu "  , "Jin "  , "Ya "   , "Chi "  ,  /*-- U+9F78 .. U+9F7F --*/
   "Chen " , "He "   , "Ken "  , "Ju "   , "Ling " , "Pao "  , "Tiao " , "Zi "   ,  /*-- U+9F80 .. U+9F87 --*/
   "Ken "  , "Yu "   , "Chuo " , "Qu "   , "Wo "   , "Long " , "Pang " , "Gong " ,  /*-- U+9F88 .. U+9F8F --*/
   "Pang " , "Yan "  , "Long " , "Long " , "Gong " , "Kan "  , "Ta "   , "Ling " ,  /*-- U+9F90 .. U+9F97 --*/
   "Ta "   , "Long " , "Gong " , "Kan "  , "Gui "  , "Qiu "  , "Bie "  , "Gui "  ,  /*-- U+9F98 .. U+9F9F --*/
   "Yue "  , "Chui " , "He "   , "Jue "  , "Xie "  , "Yu "   , ""      , ""      ,  /*-- U+9FA0 .. U+9FA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FA8 .. U+9FAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FB0 .. U+9FB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FB8 .. U+9FBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FC0 .. U+9FC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FC8 .. U+9FCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FD0 .. U+9FD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FD8 .. U+9FDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FE0 .. U+9FE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FE8 .. U+9FEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FF0 .. U+9FF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+9FF8 .. U+9FFF --*/
   "it"    , "ix"    , "i"     , "ip"    , "iet"   , "iex"   , "ie"    , "iep"   ,  /*-- U+A000 .. U+A007 --*/
   "at"    , "ax"    , "a"     , "ap"    , "uox"   , "uo"    , "uop"   , "ot"    ,  /*-- U+A008 .. U+A00F --*/
   "ox"    , "o"     , "op"    , "ex"    , "e"     , "wu"    , "bit"   , "bix"   ,  /*-- U+A010 .. U+A017 --*/
   "bi"    , "bip"   , "biet"  , "biex"  , "bie"   , "biep"  , "bat"   , "bax"   ,  /*-- U+A018 .. U+A01F --*/
   "ba"    , "bap"   , "buox"  , "buo"   , "buop"  , "bot"   , "box"   , "bo"    ,  /*-- U+A020 .. U+A027 --*/
   "bop"   , "bex"   , "be"    , "bep"   , "but"   , "bux"   , "bu"    , "bup"   ,  /*-- U+A028 .. U+A02F --*/
   "burx"  , "bur"   , "byt"   , "byx"   , "by"    , "byp"   , "byrx"  , "byr"   ,  /*-- U+A030 .. U+A037 --*/
   "pit"   , "pix"   , "pi"    , "pip"   , "piex"  , "pie"   , "piep"  , "pat"   ,  /*-- U+A038 .. U+A03F --*/
   "pax"   , "pa"    , "pap"   , "puox"  , "puo"   , "puop"  , "pot"   , "pox"   ,  /*-- U+A040 .. U+A047 --*/
   "po"    , "pop"   , "put"   , "pux"   , "pu"    , "pup"   , "purx"  , "pur"   ,  /*-- U+A048 .. U+A04F --*/
   "pyt"   , "pyx"   , "py"    , "pyp"   , "pyrx"  , "pyr"   , "bbit"  , "bbix"  ,  /*-- U+A050 .. U+A057 --*/
   "bbi"   , "bbip"  , "bbiet" , "bbiex" , "bbie"  , "bbiep" , "bbat"  , "bbax"  ,  /*-- U+A058 .. U+A05F --*/
   "bba"   , "bbap"  , "bbuox" , "bbuo"  , "bbuop" , "bbot"  , "bbox"  , "bbo"   ,  /*-- U+A060 .. U+A067 --*/
   "bbop"  , "bbex"  , "bbe"   , "bbep"  , "bbut"  , "bbux"  , "bbu"   , "bbup"  ,  /*-- U+A068 .. U+A06F --*/
   "bburx" , "bbur"  , "bbyt"  , "bbyx"  , "bby"   , "bbyp"  , "nbit"  , "nbix"  ,  /*-- U+A070 .. U+A077 --*/
   "nbi"   , "nbip"  , "nbiex" , "nbie"  , "nbiep" , "nbat"  , "nbax"  , "nba"   ,  /*-- U+A078 .. U+A07F --*/
   "nbap"  , "nbot"  , "nbox"  , "nbo"   , "nbop"  , "nbut"  , "nbux"  , "nbu"   ,  /*-- U+A080 .. U+A087 --*/
   "nbup"  , "nburx" , "nbur"  , "nbyt"  , "nbyx"  , "nby"   , "nbyp"  , "nbyrx" ,  /*-- U+A088 .. U+A08F --*/
   "nbyr"  , "hmit"  , "hmix"  , "hmi"   , "hmip"  , "hmiex" , "hmie"  , "hmiep" ,  /*-- U+A090 .. U+A097 --*/
   "hmat"  , "hmax"  , "hma"   , "hmap"  , "hmuox" , "hmuo"  , "hmuop" , "hmot"  ,  /*-- U+A098 .. U+A09F --*/
   "hmox"  , "hmo"   , "hmop"  , "hmut"  , "hmux"  , "hmu"   , "hmup"  , "hmurx" ,  /*-- U+A0A0 .. U+A0A7 --*/
   "hmur"  , "hmyx"  , "hmy"   , "hmyp"  , "hmyrx" , "hmyr"  , "mit"   , "mix"   ,  /*-- U+A0A8 .. U+A0AF --*/
   "mi"    , "mip"   , "miex"  , "mie"   , "miep"  , "mat"   , "max"   , "ma"    ,  /*-- U+A0B0 .. U+A0B7 --*/
   "map"   , "muot"  , "muox"  , "muo"   , "muop"  , "mot"   , "mox"   , "mo"    ,  /*-- U+A0B8 .. U+A0BF --*/
   "mop"   , "mex"   , "me"    , "mut"   , "mux"   , "mu"    , "mup"   , "murx"  ,  /*-- U+A0C0 .. U+A0C7 --*/
   "mur"   , "myt"   , "myx"   , "my"    , "myp"   , "fit"   , "fix"   , "fi"    ,  /*-- U+A0C8 .. U+A0CF --*/
   "fip"   , "fat"   , "fax"   , "fa"    , "fap"   , "fox"   , "fo"    , "fop"   ,  /*-- U+A0D0 .. U+A0D7 --*/
   "fut"   , "fux"   , "fu"    , "fup"   , "furx"  , "fur"   , "fyt"   , "fyx"   ,  /*-- U+A0D8 .. U+A0DF --*/
   "fy"    , "fyp"   , "vit"   , "vix"   , "vi"    , "vip"   , "viet"  , "viex"  ,  /*-- U+A0E0 .. U+A0E7 --*/
   "vie"   , "viep"  , "vat"   , "vax"   , "va"    , "vap"   , "vot"   , "vox"   ,  /*-- U+A0E8 .. U+A0EF --*/
   "vo"    , "vop"   , "vex"   , "vep"   , "vut"   , "vux"   , "vu"    , "vup"   ,  /*-- U+A0F0 .. U+A0F7 --*/
   "vurx"  , "vur"   , "vyt"   , "vyx"   , "vy"    , "vyp"   , "vyrx"  , "vyr"   ,  /*-- U+A0F8 .. U+A0FF --*/
   "dit"   , "dix"   , "di"    , "dip"   , "diex"  , "die"   , "diep"  , "dat"   ,  /*-- U+A100 .. U+A107 --*/
   "dax"   , "da"    , "dap"   , "duox"  , "duo"   , "dot"   , "dox"   , "do"    ,  /*-- U+A108 .. U+A10F --*/
   "dop"   , "dex"   , "de"    , "dep"   , "dut"   , "dux"   , "du"    , "dup"   ,  /*-- U+A110 .. U+A117 --*/
   "durx"  , "dur"   , "tit"   , "tix"   , "ti"    , "tip"   , "tiex"  , "tie"   ,  /*-- U+A118 .. U+A11F --*/
   "tiep"  , "tat"   , "tax"   , "ta"    , "tap"   , "tuot"  , "tuox"  , "tuo"   ,  /*-- U+A120 .. U+A127 --*/
   "tuop"  , "tot"   , "tox"   , "to"    , "top"   , "tex"   , "te"    , "tep"   ,  /*-- U+A128 .. U+A12F --*/
   "tut"   , "tux"   , "tu"    , "tup"   , "turx"  , "tur"   , "ddit"  , "ddix"  ,  /*-- U+A130 .. U+A137 --*/
   "ddi"   , "ddip"  , "ddiex" , "ddie"  , "ddiep" , "ddat"  , "ddax"  , "dda"   ,  /*-- U+A138 .. U+A13F --*/
   "ddap"  , "dduox" , "dduo"  , "dduop" , "ddot"  , "ddox"  , "ddo"   , "ddop"  ,  /*-- U+A140 .. U+A147 --*/
   "ddex"  , "dde"   , "ddep"  , "ddut"  , "ddux"  , "ddu"   , "ddup"  , "ddurx" ,  /*-- U+A148 .. U+A14F --*/
   "ddur"  , "ndit"  , "ndix"  , "ndi"   , "ndip"  , "ndiex" , "ndie"  , "ndat"  ,  /*-- U+A150 .. U+A157 --*/
   "ndax"  , "nda"   , "ndap"  , "ndot"  , "ndox"  , "ndo"   , "ndop"  , "ndex"  ,  /*-- U+A158 .. U+A15F --*/
   "nde"   , "ndep"  , "ndut"  , "ndux"  , "ndu"   , "ndup"  , "ndurx" , "ndur"  ,  /*-- U+A160 .. U+A167 --*/
   "hnit"  , "hnix"  , "hni"   , "hnip"  , "hniet" , "hniex" , "hnie"  , "hniep" ,  /*-- U+A168 .. U+A16F --*/
   "hnat"  , "hnax"  , "hna"   , "hnap"  , "hnuox" , "hnuo"  , "hnot"  , "hnox"  ,  /*-- U+A170 .. U+A177 --*/
   "hnop"  , "hnex"  , "hne"   , "hnep"  , "hnut"  , "nit"   , "nix"   , "ni"    ,  /*-- U+A178 .. U+A17F --*/
   "nip"   , "niex"  , "nie"   , "niep"  , "nax"   , "na"    , "nap"   , "nuox"  ,  /*-- U+A180 .. U+A187 --*/
   "nuo"   , "nuop"  , "not"   , "nox"   , "no"    , "nop"   , "nex"   , "ne"    ,  /*-- U+A188 .. U+A18F --*/
   "nep"   , "nut"   , "nux"   , "nu"    , "nup"   , "nurx"  , "nur"   , "hlit"  ,  /*-- U+A190 .. U+A197 --*/
   "hlix"  , "hli"   , "hlip"  , "hliex" , "hlie"  , "hliep" , "hlat"  , "hlax"  ,  /*-- U+A198 .. U+A19F --*/
   "hla"   , "hlap"  , "hluox" , "hluo"  , "hluop" , "hlox"  , "hlo"   , "hlop"  ,  /*-- U+A1A0 .. U+A1A7 --*/
   "hlex"  , "hle"   , "hlep"  , "hlut"  , "hlux"  , "hlu"   , "hlup"  , "hlurx" ,  /*-- U+A1A8 .. U+A1AF --*/
   "hlur"  , "hlyt"  , "hlyx"  , "hly"   , "hlyp"  , "hlyrx" , "hlyr"  , "lit"   ,  /*-- U+A1B0 .. U+A1B7 --*/
   "lix"   , "li"    , "lip"   , "liet"  , "liex"  , "lie"   , "liep"  , "lat"   ,  /*-- U+A1B8 .. U+A1BF --*/
   "lax"   , "la"    , "lap"   , "luot"  , "luox"  , "luo"   , "luop"  , "lot"   ,  /*-- U+A1C0 .. U+A1C7 --*/
   "lox"   , "lo"    , "lop"   , "lex"   , "le"    , "lep"   , "lut"   , "lux"   ,  /*-- U+A1C8 .. U+A1CF --*/
   "lu"    , "lup"   , "lurx"  , "lur"   , "lyt"   , "lyx"   , "ly"    , "lyp"   ,  /*-- U+A1D0 .. U+A1D7 --*/
   "lyrx"  , "lyr"   , "git"   , "gix"   , "gi"    , "gip"   , "giet"  , "giex"  ,  /*-- U+A1D8 .. U+A1DF --*/
   "gie"   , "giep"  , "gat"   , "gax"   , "ga"    , "gap"   , "guot"  , "guox"  ,  /*-- U+A1E0 .. U+A1E7 --*/
   "guo"   , "guop"  , "got"   , "gox"   , "go"    , "gop"   , "get"   , "gex"   ,  /*-- U+A1E8 .. U+A1EF --*/
   "ge"    , "gep"   , "gut"   , "gux"   , "gu"    , "gup"   , "gurx"  , "gur"   ,  /*-- U+A1F0 .. U+A1F7 --*/
   "kit"   , "kix"   , "ki"    , "kip"   , "kiex"  , "kie"   , "kiep"  , "kat"   ,  /*-- U+A1F8 .. U+A1FF --*/
   "kax"   , "ka"    , "kap"   , "kuox"  , "kuo"   , "kuop"  , "kot"   , "kox"   ,  /*-- U+A200 .. U+A207 --*/
   "ko"    , "kop"   , "ket"   , "kex"   , "ke"    , "kep"   , "kut"   , "kux"   ,  /*-- U+A208 .. U+A20F --*/
   "ku"    , "kup"   , "kurx"  , "kur"   , "ggit"  , "ggix"  , "ggi"   , "ggiex" ,  /*-- U+A210 .. U+A217 --*/
   "ggie"  , "ggiep" , "ggat"  , "ggax"  , "gga"   , "ggap"  , "gguot" , "gguox" ,  /*-- U+A218 .. U+A21F --*/
   "gguo"  , "gguop" , "ggot"  , "ggox"  , "ggo"   , "ggop"  , "gget"  , "ggex"  ,  /*-- U+A220 .. U+A227 --*/
   "gge"   , "ggep"  , "ggut"  , "ggux"  , "ggu"   , "ggup"  , "ggurx" , "ggur"  ,  /*-- U+A228 .. U+A22F --*/
   "mgiex" , "mgie"  , "mgat"  , "mgax"  , "mga"   , "mgap"  , "mguox" , "mguo"  ,  /*-- U+A230 .. U+A237 --*/
   "mguop" , "mgot"  , "mgox"  , "mgo"   , "mgop"  , "mgex"  , "mge"   , "mgep"  ,  /*-- U+A238 .. U+A23F --*/
   "mgut"  , "mgux"  , "mgu"   , "mgup"  , "mgurx" , "mgur"  , "hxit"  , "hxix"  ,  /*-- U+A240 .. U+A247 --*/
   "hxi"   , "hxip"  , "hxiet" , "hxiex" , "hxie"  , "hxiep" , "hxat"  , "hxax"  ,  /*-- U+A248 .. U+A24F --*/
   "hxa"   , "hxap"  , "hxuot" , "hxuox" , "hxuo"  , "hxuop" , "hxot"  , "hxox"  ,  /*-- U+A250 .. U+A257 --*/
   "hxo"   , "hxop"  , "hxex"  , "hxe"   , "hxep"  , "ngiex" , "ngie"  , "ngiep" ,  /*-- U+A258 .. U+A25F --*/
   "ngat"  , "ngax"  , "nga"   , "ngap"  , "nguot" , "nguox" , "nguo"  , "ngot"  ,  /*-- U+A260 .. U+A267 --*/
   "ngox"  , "ngo"   , "ngop"  , "ngex"  , "nge"   , "ngep"  , "hit"   , "hiex"  ,  /*-- U+A268 .. U+A26F --*/
   "hie"   , "hat"   , "hax"   , "ha"    , "hap"   , "huot"  , "huox"  , "huo"   ,  /*-- U+A270 .. U+A277 --*/
   "huop"  , "hot"   , "hox"   , "ho"    , "hop"   , "hex"   , "he"    , "hep"   ,  /*-- U+A278 .. U+A27F --*/
   "wat"   , "wax"   , "wa"    , "wap"   , "wuox"  , "wuo"   , "wuop"  , "wox"   ,  /*-- U+A280 .. U+A287 --*/
   "wo"    , "wop"   , "wex"   , "we"    , "wep"   , "zit"   , "zix"   , "zi"    ,  /*-- U+A288 .. U+A28F --*/
   "zip"   , "ziex"  , "zie"   , "ziep"  , "zat"   , "zax"   , "za"    , "zap"   ,  /*-- U+A290 .. U+A297 --*/
   "zuox"  , "zuo"   , "zuop"  , "zot"   , "zox"   , "zo"    , "zop"   , "zex"   ,  /*-- U+A298 .. U+A29F --*/
   "ze"    , "zep"   , "zut"   , "zux"   , "zu"    , "zup"   , "zurx"  , "zur"   ,  /*-- U+A2A0 .. U+A2A7 --*/
   "zyt"   , "zyx"   , "zy"    , "zyp"   , "zyrx"  , "zyr"   , "cit"   , "cix"   ,  /*-- U+A2A8 .. U+A2AF --*/
   "ci"    , "cip"   , "ciet"  , "ciex"  , "cie"   , "ciep"  , "cat"   , "cax"   ,  /*-- U+A2B0 .. U+A2B7 --*/
   "ca"    , "cap"   , "cuox"  , "cuo"   , "cuop"  , "cot"   , "cox"   , "co"    ,  /*-- U+A2B8 .. U+A2BF --*/
   "cop"   , "cex"   , "ce"    , "cep"   , "cut"   , "cux"   , "cu"    , "cup"   ,  /*-- U+A2C0 .. U+A2C7 --*/
   "curx"  , "cur"   , "cyt"   , "cyx"   , "cy"    , "cyp"   , "cyrx"  , "cyr"   ,  /*-- U+A2C8 .. U+A2CF --*/
   "zzit"  , "zzix"  , "zzi"   , "zzip"  , "zziet" , "zziex" , "zzie"  , "zziep" ,  /*-- U+A2D0 .. U+A2D7 --*/
   "zzat"  , "zzax"  , "zza"   , "zzap"  , "zzox"  , "zzo"   , "zzop"  , "zzex"  ,  /*-- U+A2D8 .. U+A2DF --*/
   "zze"   , "zzep"  , "zzux"  , "zzu"   , "zzup"  , "zzurx" , "zzur"  , "zzyt"  ,  /*-- U+A2E0 .. U+A2E7 --*/
   "zzyx"  , "zzy"   , "zzyp"  , "zzyrx" , "zzyr"  , "nzit"  , "nzix"  , "nzi"   ,  /*-- U+A2E8 .. U+A2EF --*/
   "nzip"  , "nziex" , "nzie"  , "nziep" , "nzat"  , "nzax"  , "nza"   , "nzap"  ,  /*-- U+A2F0 .. U+A2F7 --*/
   "nzuox" , "nzuo"  , "nzox"  , "nzop"  , "nzex"  , "nze"   , "nzux"  , "nzu"   ,  /*-- U+A2F8 .. U+A2FF --*/
   "nzup"  , "nzurx" , "nzur"  , "nzyt"  , "nzyx"  , "nzy"   , "nzyp"  , "nzyrx" ,  /*-- U+A300 .. U+A307 --*/
   "nzyr"  , "sit"   , "six"   , "si"    , "sip"   , "siex"  , "sie"   , "siep"  ,  /*-- U+A308 .. U+A30F --*/
   "sat"   , "sax"   , "sa"    , "sap"   , "suox"  , "suo"   , "suop"  , "sot"   ,  /*-- U+A310 .. U+A317 --*/
   "sox"   , "so"    , "sop"   , "sex"   , "se"    , "sep"   , "sut"   , "sux"   ,  /*-- U+A318 .. U+A31F --*/
   "su"    , "sup"   , "surx"  , "sur"   , "syt"   , "syx"   , "sy"    , "syp"   ,  /*-- U+A320 .. U+A327 --*/
   "syrx"  , "syr"   , "ssit"  , "ssix"  , "ssi"   , "ssip"  , "ssiex" , "ssie"  ,  /*-- U+A328 .. U+A32F --*/
   "ssiep" , "ssat"  , "ssax"  , "ssa"   , "ssap"  , "ssot"  , "ssox"  , "sso"   ,  /*-- U+A330 .. U+A337 --*/
   "ssop"  , "ssex"  , "sse"   , "ssep"  , "ssut"  , "ssux"  , "ssu"   , "ssup"  ,  /*-- U+A338 .. U+A33F --*/
   "ssyt"  , "ssyx"  , "ssy"   , "ssyp"  , "ssyrx" , "ssyr"  , "zhat"  , "zhax"  ,  /*-- U+A340 .. U+A347 --*/
   "zha"   , "zhap"  , "zhuox" , "zhuo"  , "zhuop" , "zhot"  , "zhox"  , "zho"   ,  /*-- U+A348 .. U+A34F --*/
   "zhop"  , "zhet"  , "zhex"  , "zhe"   , "zhep"  , "zhut"  , "zhux"  , "zhu"   ,  /*-- U+A350 .. U+A357 --*/
   "zhup"  , "zhurx" , "zhur"  , "zhyt"  , "zhyx"  , "zhy"   , "zhyp"  , "zhyrx" ,  /*-- U+A358 .. U+A35F --*/
   "zhyr"  , "chat"  , "chax"  , "cha"   , "chap"  , "chuot" , "chuox" , "chuo"  ,  /*-- U+A360 .. U+A367 --*/
   "chuop" , "chot"  , "chox"  , "cho"   , "chop"  , "chet"  , "chex"  , "che"   ,  /*-- U+A368 .. U+A36F --*/
   "chep"  , "chux"  , "chu"   , "chup"  , "churx" , "chur"  , "chyt"  , "chyx"  ,  /*-- U+A370 .. U+A377 --*/
   "chy"   , "chyp"  , "chyrx" , "chyr"  , "rrax"  , "rra"   , "rruox" , "rruo"  ,  /*-- U+A378 .. U+A37F --*/
   "rrot"  , "rrox"  , "rro"   , "rrop"  , "rret"  , "rrex"  , "rre"   , "rrep"  ,  /*-- U+A380 .. U+A387 --*/
   "rrut"  , "rrux"  , "rru"   , "rrup"  , "rrurx" , "rrur"  , "rryt"  , "rryx"  ,  /*-- U+A388 .. U+A38F --*/
   "rry"   , "rryp"  , "rryrx" , "rryr"  , "nrat"  , "nrax"  , "nra"   , "nrap"  ,  /*-- U+A390 .. U+A397 --*/
   "nrox"  , "nro"   , "nrop"  , "nret"  , "nrex"  , "nre"   , "nrep"  , "nrut"  ,  /*-- U+A398 .. U+A39F --*/
   "nrux"  , "nru"   , "nrup"  , "nrurx" , "nrur"  , "nryt"  , "nryx"  , "nry"   ,  /*-- U+A3A0 .. U+A3A7 --*/
   "nryp"  , "nryrx" , "nryr"  , "shat"  , "shax"  , "sha"   , "shap"  , "shuox" ,  /*-- U+A3A8 .. U+A3AF --*/
   "shuo"  , "shuop" , "shot"  , "shox"  , "sho"   , "shop"  , "shet"  , "shex"  ,  /*-- U+A3B0 .. U+A3B7 --*/
   "she"   , "shep"  , "shut"  , "shux"  , "shu"   , "shup"  , "shurx" , "shur"  ,  /*-- U+A3B8 .. U+A3BF --*/
   "shyt"  , "shyx"  , "shy"   , "shyp"  , "shyrx" , "shyr"  , "rat"   , "rax"   ,  /*-- U+A3C0 .. U+A3C7 --*/
   "ra"    , "rap"   , "ruox"  , "ruo"   , "ruop"  , "rot"   , "rox"   , "ro"    ,  /*-- U+A3C8 .. U+A3CF --*/
   "rop"   , "rex"   , "re"    , "rep"   , "rut"   , "rux"   , "ru"    , "rup"   ,  /*-- U+A3D0 .. U+A3D7 --*/
   "rurx"  , "rur"   , "ryt"   , "ryx"   , "ry"    , "ryp"   , "ryrx"  , "ryr"   ,  /*-- U+A3D8 .. U+A3DF --*/
   "jit"   , "jix"   , "ji"    , "jip"   , "jiet"  , "jiex"  , "jie"   , "jiep"  ,  /*-- U+A3E0 .. U+A3E7 --*/
   "juot"  , "juox"  , "juo"   , "juop"  , "jot"   , "jox"   , "jo"    , "jop"   ,  /*-- U+A3E8 .. U+A3EF --*/
   "jut"   , "jux"   , "ju"    , "jup"   , "jurx"  , "jur"   , "jyt"   , "jyx"   ,  /*-- U+A3F0 .. U+A3F7 --*/
   "jy"    , "jyp"   , "jyrx"  , "jyr"   , "qit"   , "qix"   , "qi"    , "qip"   ,  /*-- U+A3F8 .. U+A3FF --*/
   "qiet"  , "qiex"  , "qie"   , "qiep"  , "quot"  , "quox"  , "quo"   , "quop"  ,  /*-- U+A400 .. U+A407 --*/
   "qot"   , "qox"   , "qo"    , "qop"   , "qut"   , "qux"   , "qu"    , "qup"   ,  /*-- U+A408 .. U+A40F --*/
   "qurx"  , "qur"   , "qyt"   , "qyx"   , "qy"    , "qyp"   , "qyrx"  , "qyr"   ,  /*-- U+A410 .. U+A417 --*/
   "jjit"  , "jjix"  , "jji"   , "jjip"  , "jjiet" , "jjiex" , "jjie"  , "jjiep" ,  /*-- U+A418 .. U+A41F --*/
   "jjuox" , "jjuo"  , "jjuop" , "jjot"  , "jjox"  , "jjo"   , "jjop"  , "jjut"  ,  /*-- U+A420 .. U+A427 --*/
   "jjux"  , "jju"   , "jjup"  , "jjurx" , "jjur"  , "jjyt"  , "jjyx"  , "jjy"   ,  /*-- U+A428 .. U+A42F --*/
   "jjyp"  , "njit"  , "njix"  , "nji"   , "njip"  , "njiet" , "njiex" , "njie"  ,  /*-- U+A430 .. U+A437 --*/
   "njiep" , "njuox" , "njuo"  , "njot"  , "njox"  , "njo"   , "njop"  , "njux"  ,  /*-- U+A438 .. U+A43F --*/
   "nju"   , "njup"  , "njurx" , "njur"  , "njyt"  , "njyx"  , "njy"   , "njyp"  ,  /*-- U+A440 .. U+A447 --*/
   "njyrx" , "njyr"  , "nyit"  , "nyix"  , "nyi"   , "nyip"  , "nyiet" , "nyiex" ,  /*-- U+A448 .. U+A44F --*/
   "nyie"  , "nyiep" , "nyuox" , "nyuo"  , "nyuop" , "nyot"  , "nyox"  , "nyo"   ,  /*-- U+A450 .. U+A457 --*/
   "nyop"  , "nyut"  , "nyux"  , "nyu"   , "nyup"  , "xit"   , "xix"   , "xi"    ,  /*-- U+A458 .. U+A45F --*/
   "xip"   , "xiet"  , "xiex"  , "xie"   , "xiep"  , "xuox"  , "xuo"   , "xot"   ,  /*-- U+A460 .. U+A467 --*/
   "xox"   , "xo"    , "xop"   , "xyt"   , "xyx"   , "xy"    , "xyp"   , "xyrx"  ,  /*-- U+A468 .. U+A46F --*/
   "xyr"   , "yit"   , "yix"   , "yi"    , "yip"   , "yiet"  , "yiex"  , "yie"   ,  /*-- U+A470 .. U+A477 --*/
   "yiep"  , "yuot"  , "yuox"  , "yuo"   , "yuop"  , "yot"   , "yox"   , "yo"    ,  /*-- U+A478 .. U+A47F --*/
   "yop"   , "yut"   , "yux"   , "yu"    , "yup"   , "yurx"  , "yur"   , "yyt"   ,  /*-- U+A480 .. U+A487 --*/
   "yyx"   , "yy"    , "yyp"   , "yyrx"  , "yyr"   , ""      , ""      , ""      ,  /*-- U+A488 .. U+A48F --*/
   "Qot"   , "Li"    , "Kit"   , "Nyip"  , "Cyp"   , "Ssi"   , "Ggop"  , "Gep"   ,  /*-- U+A490 .. U+A497 --*/
   "Mi"    , "Hxit"  , "Lyr"   , "Bbut"  , "Mop"   , "Yo"    , "Put"   , "Hxuo"  ,  /*-- U+A498 .. U+A49F --*/
   "Tat"   , "Ga"    , ""      , ""      , "Ddur"  , "Bur"   , "Gguo"  , "Nyop"  ,  /*-- U+A4A0 .. U+A4A7 --*/
   "Tu"    , "Op"    , "Jjut"  , "Zot"   , "Pyt"   , "Hmo"   , "Yit"   , "Vur"   ,  /*-- U+A4A8 .. U+A4AF --*/
   "Shy"   , "Vep"   , "Za"    , "Jo"    , ""      , "Jjy"   , "Got"   , "Jjie"  ,  /*-- U+A4B0 .. U+A4B7 --*/
   "Wo"    , "Du"    , "Shur"  , "Lie"   , "Cy"    , "Cuop"  , "Cip"   , "Hxop"  ,  /*-- U+A4B8 .. U+A4BF --*/
   "Shat"  , ""      , "Shop"  , "Che"   , "Zziet" , ""      , "Ke"    , ""      ,  /*-- U+A4C0 .. U+A4C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A4C8 .. U+A4CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A4D0 .. U+A4D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A4D8 .. U+A4DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A4E0 .. U+A4E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A4E8 .. U+A4EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A4F0 .. U+A4F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A4F8 .. U+A4FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A500 .. U+A507 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A508 .. U+A50F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A510 .. U+A517 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A518 .. U+A51F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A520 .. U+A527 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A528 .. U+A52F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A530 .. U+A537 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A538 .. U+A53F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A540 .. U+A547 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A548 .. U+A54F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A550 .. U+A557 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A558 .. U+A55F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A560 .. U+A567 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A568 .. U+A56F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A570 .. U+A577 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A578 .. U+A57F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A580 .. U+A587 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A588 .. U+A58F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A590 .. U+A597 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A598 .. U+A59F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5A0 .. U+A5A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5A8 .. U+A5AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5B0 .. U+A5B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5B8 .. U+A5BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5C0 .. U+A5C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5C8 .. U+A5CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5D0 .. U+A5D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5D8 .. U+A5DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5E0 .. U+A5E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5E8 .. U+A5EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5F0 .. U+A5F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A5F8 .. U+A5FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A600 .. U+A607 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A608 .. U+A60F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A610 .. U+A617 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A618 .. U+A61F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A620 .. U+A627 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A628 .. U+A62F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A630 .. U+A637 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A638 .. U+A63F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A640 .. U+A647 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A648 .. U+A64F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A650 .. U+A657 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A658 .. U+A65F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A660 .. U+A667 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A668 .. U+A66F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A670 .. U+A677 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A678 .. U+A67F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A680 .. U+A687 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A688 .. U+A68F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A690 .. U+A697 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A698 .. U+A69F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6A0 .. U+A6A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6A8 .. U+A6AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6B0 .. U+A6B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6B8 .. U+A6BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6C0 .. U+A6C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6C8 .. U+A6CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6D0 .. U+A6D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6D8 .. U+A6DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6E0 .. U+A6E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6E8 .. U+A6EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6F0 .. U+A6F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A6F8 .. U+A6FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A700 .. U+A707 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A708 .. U+A70F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A710 .. U+A717 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A718 .. U+A71F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A720 .. U+A727 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A728 .. U+A72F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A730 .. U+A737 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A738 .. U+A73F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A740 .. U+A747 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A748 .. U+A74F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A750 .. U+A757 --*/
   ""      , ""      , ""      , "r"     , ""      , ""      , ""      , ""      ,  /*-- U+A758 .. U+A75F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A760 .. U+A767 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A768 .. U+A76F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A770 .. U+A777 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A778 .. U+A77F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A780 .. U+A787 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A788 .. U+A78F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A790 .. U+A797 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A798 .. U+A79F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7A0 .. U+A7A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7A8 .. U+A7AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7B0 .. U+A7B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7B8 .. U+A7BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7C0 .. U+A7C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7C8 .. U+A7CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7D0 .. U+A7D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7D8 .. U+A7DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7E0 .. U+A7E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7E8 .. U+A7EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7F0 .. U+A7F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A7F8 .. U+A7FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A800 .. U+A807 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A808 .. U+A80F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A810 .. U+A817 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A818 .. U+A81F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A820 .. U+A827 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A828 .. U+A82F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A830 .. U+A837 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A838 .. U+A83F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A840 .. U+A847 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A848 .. U+A84F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A850 .. U+A857 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A858 .. U+A85F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A860 .. U+A867 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A868 .. U+A86F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A870 .. U+A877 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A878 .. U+A87F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A880 .. U+A887 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A888 .. U+A88F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A890 .. U+A897 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A898 .. U+A89F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8A0 .. U+A8A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8A8 .. U+A8AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8B0 .. U+A8B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8B8 .. U+A8BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8C0 .. U+A8C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8C8 .. U+A8CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8D0 .. U+A8D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8D8 .. U+A8DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8E0 .. U+A8E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8E8 .. U+A8EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8F0 .. U+A8F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A8F8 .. U+A8FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A900 .. U+A907 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A908 .. U+A90F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A910 .. U+A917 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A918 .. U+A91F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A920 .. U+A927 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A928 .. U+A92F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A930 .. U+A937 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A938 .. U+A93F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A940 .. U+A947 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A948 .. U+A94F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A950 .. U+A957 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A958 .. U+A95F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A960 .. U+A967 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A968 .. U+A96F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A970 .. U+A977 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A978 .. U+A97F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A980 .. U+A987 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A988 .. U+A98F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A990 .. U+A997 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A998 .. U+A99F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9A0 .. U+A9A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9A8 .. U+A9AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9B0 .. U+A9B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9B8 .. U+A9BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9C0 .. U+A9C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9C8 .. U+A9CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9D0 .. U+A9D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9D8 .. U+A9DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9E0 .. U+A9E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9E8 .. U+A9EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9F0 .. U+A9F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+A9F8 .. U+A9FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA00 .. U+AA07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA08 .. U+AA0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA10 .. U+AA17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA18 .. U+AA1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA20 .. U+AA27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA28 .. U+AA2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA30 .. U+AA37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA38 .. U+AA3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA40 .. U+AA47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA48 .. U+AA4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA50 .. U+AA57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA58 .. U+AA5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA60 .. U+AA67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA68 .. U+AA6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA70 .. U+AA77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA78 .. U+AA7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA80 .. U+AA87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA88 .. U+AA8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA90 .. U+AA97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AA98 .. U+AA9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAA0 .. U+AAA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAA8 .. U+AAAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAB0 .. U+AAB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAB8 .. U+AABF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAC0 .. U+AAC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAC8 .. U+AACF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAD0 .. U+AAD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAD8 .. U+AADF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAE0 .. U+AAE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAE8 .. U+AAEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAF0 .. U+AAF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AAF8 .. U+AAFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB00 .. U+AB07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB08 .. U+AB0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB10 .. U+AB17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB18 .. U+AB1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB20 .. U+AB27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB28 .. U+AB2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB30 .. U+AB37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB38 .. U+AB3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB40 .. U+AB47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB48 .. U+AB4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB50 .. U+AB57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB58 .. U+AB5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB60 .. U+AB67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB68 .. U+AB6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB70 .. U+AB77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB78 .. U+AB7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB80 .. U+AB87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB88 .. U+AB8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB90 .. U+AB97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+AB98 .. U+AB9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABA0 .. U+ABA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABA8 .. U+ABAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABB0 .. U+ABB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABB8 .. U+ABBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABC0 .. U+ABC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABC8 .. U+ABCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABD0 .. U+ABD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABD8 .. U+ABDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABE0 .. U+ABE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABE8 .. U+ABEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABF0 .. U+ABF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ABF8 .. U+ABFF --*/
   "ga"    , "gag"   , "gagg"  , "gags"  , "gan"   , "ganj"  , "ganh"  , "gad"   ,  /*-- U+AC00 .. U+AC07 --*/
   "gal"   , "galg"  , "galm"  , "galb"  , "gals"  , "galt"  , "galp"  , "galh"  ,  /*-- U+AC08 .. U+AC0F --*/
   "gam"   , "gab"   , "gabs"  , "gas"   , "gass"  , "gang"  , "gaj"   , "gac"   ,  /*-- U+AC10 .. U+AC17 --*/
   "gak"   , "gat"   , "gap"   , "gah"   , "gae"   , "gaeg"  , "gaegg" , "gaegs" ,  /*-- U+AC18 .. U+AC1F --*/
   "gaen"  , "gaenj" , "gaenh" , "gaed"  , "gael"  , "gaelg" , "gaelm" , "gaelb" ,  /*-- U+AC20 .. U+AC27 --*/
   "gaels" , "gaelt" , "gaelp" , "gaelh" , "gaem"  , "gaeb"  , "gaebs" , "gaes"  ,  /*-- U+AC28 .. U+AC2F --*/
   "gaess" , "gaeng" , "gaej"  , "gaec"  , "gaek"  , "gaet"  , "gaep"  , "gaeh"  ,  /*-- U+AC30 .. U+AC37 --*/
   "gya"   , "gyag"  , "gyagg" , "gyags" , "gyan"  , "gyanj" , "gyanh" , "gyad"  ,  /*-- U+AC38 .. U+AC3F --*/
   "gyal"  , "gyalg" , "gyalm" , "gyalb" , "gyals" , "gyalt" , "gyalp" , "gyalh" ,  /*-- U+AC40 .. U+AC47 --*/
   "gyam"  , "gyab"  , "gyabs" , "gyas"  , "gyass" , "gyang" , "gyaj"  , "gyac"  ,  /*-- U+AC48 .. U+AC4F --*/
   "gyak"  , "gyat"  , "gyap"  , "gyah"  , "gyae"  , "gyaeg" , "gyaegg", "gyaegs",  /*-- U+AC50 .. U+AC57 --*/
   "gyaen" , "gyaenj", "gyaenh", "gyaed" , "gyael" , "gyaelg", "gyaelm", "gyaelb",  /*-- U+AC58 .. U+AC5F --*/
   "gyaels", "gyaelt", "gyaelp", "gyaelh", "gyaem" , "gyaeb" , "gyaebs", "gyaes" ,  /*-- U+AC60 .. U+AC67 --*/
   "gyaess", "gyaeng", "gyaej" , "gyaec" , "gyaek" , "gyaet" , "gyaep" , "gyaeh" ,  /*-- U+AC68 .. U+AC6F --*/
   "geo"   , "geog"  , "geogg" , "geogs" , "geon"  , "geonj" , "geonh" , "geod"  ,  /*-- U+AC70 .. U+AC77 --*/
   "geol"  , "geolg" , "geolm" , "geolb" , "geols" , "geolt" , "geolp" , "geolh" ,  /*-- U+AC78 .. U+AC7F --*/
   "geom"  , "geob"  , "geobs" , "geos"  , "geoss" , "geong" , "geoj"  , "geoc"  ,  /*-- U+AC80 .. U+AC87 --*/
   "geok"  , "geot"  , "geop"  , "geoh"  , "ge"    , "geg"   , "gegg"  , "gegs"  ,  /*-- U+AC88 .. U+AC8F --*/
   "gen"   , "genj"  , "genh"  , "ged"   , "gel"   , "gelg"  , "gelm"  , "gelb"  ,  /*-- U+AC90 .. U+AC97 --*/
   "gels"  , "gelt"  , "gelp"  , "gelh"  , "gem"   , "geb"   , "gebs"  , "ges"   ,  /*-- U+AC98 .. U+AC9F --*/
   "gess"  , "geng"  , "gej"   , "gec"   , "gek"   , "get"   , "gep"   , "geh"   ,  /*-- U+ACA0 .. U+ACA7 --*/
   "gyeo"  , "gyeog" , "gyeogg", "gyeogs", "gyeon" , "gyeonj", "gyeonh", "gyeod" ,  /*-- U+ACA8 .. U+ACAF --*/
   "gyeol" , "gyeolg", "gyeolm", "gyeolb", "gyeols", "gyeolt", "gyeolp", "gyeolh",  /*-- U+ACB0 .. U+ACB7 --*/
   "gyeom" , "gyeob" , "gyeobs", "gyeos" , "gyeoss", "gyeong", "gyeoj" , "gyeoc" ,  /*-- U+ACB8 .. U+ACBF --*/
   "gyeok" , "gyeot" , "gyeop" , "gyeoh" , "gye"   , "gyeg"  , "gyegg" , "gyegs" ,  /*-- U+ACC0 .. U+ACC7 --*/
   "gyen"  , "gyenj" , "gyenh" , "gyed"  , "gyel"  , "gyelg" , "gyelm" , "gyelb" ,  /*-- U+ACC8 .. U+ACCF --*/
   "gyels" , "gyelt" , "gyelp" , "gyelh" , "gyem"  , "gyeb"  , "gyebs" , "gyes"  ,  /*-- U+ACD0 .. U+ACD7 --*/
   "gyess" , "gyeng" , "gyej"  , "gyec"  , "gyek"  , "gyet"  , "gyep"  , "gyeh"  ,  /*-- U+ACD8 .. U+ACDF --*/
   "go"    , "gog"   , "gogg"  , "gogs"  , "gon"   , "gonj"  , "gonh"  , "god"   ,  /*-- U+ACE0 .. U+ACE7 --*/
   "gol"   , "golg"  , "golm"  , "golb"  , "gols"  , "golt"  , "golp"  , "golh"  ,  /*-- U+ACE8 .. U+ACEF --*/
   "gom"   , "gob"   , "gobs"  , "gos"   , "goss"  , "gong"  , "goj"   , "goc"   ,  /*-- U+ACF0 .. U+ACF7 --*/
   "gok"   , "got"   , "gop"   , "goh"   , "gwa"   , "gwag"  , "gwagg" , "gwags" ,  /*-- U+ACF8 .. U+ACFF --*/
   "gwan"  , "gwanj" , "gwanh" , "gwad"  , "gwal"  , "gwalg" , "gwalm" , "gwalb" ,  /*-- U+AD00 .. U+AD07 --*/
   "gwals" , "gwalt" , "gwalp" , "gwalh" , "gwam"  , "gwab"  , "gwabs" , "gwas"  ,  /*-- U+AD08 .. U+AD0F --*/
   "gwass" , "gwang" , "gwaj"  , "gwac"  , "gwak"  , "gwat"  , "gwap"  , "gwah"  ,  /*-- U+AD10 .. U+AD17 --*/
   "gwae"  , "gwaeg" , "gwaegg", "gwaegs", "gwaen" , "gwaenj", "gwaenh", "gwaed" ,  /*-- U+AD18 .. U+AD1F --*/
   "gwael" , "gwaelg", "gwaelm", "gwaelb", "gwaels", "gwaelt", "gwaelp", "gwaelh",  /*-- U+AD20 .. U+AD27 --*/
   "gwaem" , "gwaeb" , "gwaebs", "gwaes" , "gwaess", "gwaeng", "gwaej" , "gwaec" ,  /*-- U+AD28 .. U+AD2F --*/
   "gwaek" , "gwaet" , "gwaep" , "gwaeh" , "goe"   , "goeg"  , "goegg" , "goegs" ,  /*-- U+AD30 .. U+AD37 --*/
   "goen"  , "goenj" , "goenh" , "goed"  , "goel"  , "goelg" , "goelm" , "goelb" ,  /*-- U+AD38 .. U+AD3F --*/
   "goels" , "goelt" , "goelp" , "goelh" , "goem"  , "goeb"  , "goebs" , "goes"  ,  /*-- U+AD40 .. U+AD47 --*/
   "goess" , "goeng" , "goej"  , "goec"  , "goek"  , "goet"  , "goep"  , "goeh"  ,  /*-- U+AD48 .. U+AD4F --*/
   "gyo"   , "gyog"  , "gyogg" , "gyogs" , "gyon"  , "gyonj" , "gyonh" , "gyod"  ,  /*-- U+AD50 .. U+AD57 --*/
   "gyol"  , "gyolg" , "gyolm" , "gyolb" , "gyols" , "gyolt" , "gyolp" , "gyolh" ,  /*-- U+AD58 .. U+AD5F --*/
   "gyom"  , "gyob"  , "gyobs" , "gyos"  , "gyoss" , "gyong" , "gyoj"  , "gyoc"  ,  /*-- U+AD60 .. U+AD67 --*/
   "gyok"  , "gyot"  , "gyop"  , "gyoh"  , "gu"    , "gug"   , "gugg"  , "gugs"  ,  /*-- U+AD68 .. U+AD6F --*/
   "gun"   , "gunj"  , "gunh"  , "gud"   , "gul"   , "gulg"  , "gulm"  , "gulb"  ,  /*-- U+AD70 .. U+AD77 --*/
   "guls"  , "gult"  , "gulp"  , "gulh"  , "gum"   , "gub"   , "gubs"  , "gus"   ,  /*-- U+AD78 .. U+AD7F --*/
   "guss"  , "gung"  , "guj"   , "guc"   , "guk"   , "gut"   , "gup"   , "guh"   ,  /*-- U+AD80 .. U+AD87 --*/
   "gweo"  , "gweog" , "gweogg", "gweogs", "gweon" , "gweonj", "gweonh", "gweod" ,  /*-- U+AD88 .. U+AD8F --*/
   "gweol" , "gweolg", "gweolm", "gweolb", "gweols", "gweolt", "gweolp", "gweolh",  /*-- U+AD90 .. U+AD97 --*/
   "gweom" , "gweob" , "gweobs", "gweos" , "gweoss", "gweong", "gweoj" , "gweoc" ,  /*-- U+AD98 .. U+AD9F --*/
   "gweok" , "gweot" , "gweop" , "gweoh" , "gwe"   , "gweg"  , "gwegg" , "gwegs" ,  /*-- U+ADA0 .. U+ADA7 --*/
   "gwen"  , "gwenj" , "gwenh" , "gwed"  , "gwel"  , "gwelg" , "gwelm" , "gwelb" ,  /*-- U+ADA8 .. U+ADAF --*/
   "gwels" , "gwelt" , "gwelp" , "gwelh" , "gwem"  , "gweb"  , "gwebs" , "gwes"  ,  /*-- U+ADB0 .. U+ADB7 --*/
   "gwess" , "gweng" , "gwej"  , "gwec"  , "gwek"  , "gwet"  , "gwep"  , "gweh"  ,  /*-- U+ADB8 .. U+ADBF --*/
   "gwi"   , "gwig"  , "gwigg" , "gwigs" , "gwin"  , "gwinj" , "gwinh" , "gwid"  ,  /*-- U+ADC0 .. U+ADC7 --*/
   "gwil"  , "gwilg" , "gwilm" , "gwilb" , "gwils" , "gwilt" , "gwilp" , "gwilh" ,  /*-- U+ADC8 .. U+ADCF --*/
   "gwim"  , "gwib"  , "gwibs" , "gwis"  , "gwiss" , "gwing" , "gwij"  , "gwic"  ,  /*-- U+ADD0 .. U+ADD7 --*/
   "gwik"  , "gwit"  , "gwip"  , "gwih"  , "gyu"   , "gyug"  , "gyugg" , "gyugs" ,  /*-- U+ADD8 .. U+ADDF --*/
   "gyun"  , "gyunj" , "gyunh" , "gyud"  , "gyul"  , "gyulg" , "gyulm" , "gyulb" ,  /*-- U+ADE0 .. U+ADE7 --*/
   "gyuls" , "gyult" , "gyulp" , "gyulh" , "gyum"  , "gyub"  , "gyubs" , "gyus"  ,  /*-- U+ADE8 .. U+ADEF --*/
   "gyuss" , "gyung" , "gyuj"  , "gyuc"  , "gyuk"  , "gyut"  , "gyup"  , "gyuh"  ,  /*-- U+ADF0 .. U+ADF7 --*/
   "geu"   , "geug"  , "geugg" , "geugs" , "geun"  , "geunj" , "geunh" , "geud"  ,  /*-- U+ADF8 .. U+ADFF --*/
   "geul"  , "geulg" , "geulm" , "geulb" , "geuls" , "geult" , "geulp" , "geulh" ,  /*-- U+AE00 .. U+AE07 --*/
   "geum"  , "geub"  , "geubs" , "geus"  , "geuss" , "geung" , "geuj"  , "geuc"  ,  /*-- U+AE08 .. U+AE0F --*/
   "geuk"  , "geut"  , "geup"  , "geuh"  , "gyi"   , "gyig"  , "gyigg" , "gyigs" ,  /*-- U+AE10 .. U+AE17 --*/
   "gyin"  , "gyinj" , "gyinh" , "gyid"  , "gyil"  , "gyilg" , "gyilm" , "gyilb" ,  /*-- U+AE18 .. U+AE1F --*/
   "gyils" , "gyilt" , "gyilp" , "gyilh" , "gyim"  , "gyib"  , "gyibs" , "gyis"  ,  /*-- U+AE20 .. U+AE27 --*/
   "gyiss" , "gying" , "gyij"  , "gyic"  , "gyik"  , "gyit"  , "gyip"  , "gyih"  ,  /*-- U+AE28 .. U+AE2F --*/
   "gi"    , "gig"   , "gigg"  , "gigs"  , "gin"   , "ginj"  , "ginh"  , "gid"   ,  /*-- U+AE30 .. U+AE37 --*/
   "gil"   , "gilg"  , "gilm"  , "gilb"  , "gils"  , "gilt"  , "gilp"  , "gilh"  ,  /*-- U+AE38 .. U+AE3F --*/
   "gim"   , "gib"   , "gibs"  , "gis"   , "giss"  , "ging"  , "gij"   , "gic"   ,  /*-- U+AE40 .. U+AE47 --*/
   "gik"   , "git"   , "gip"   , "gih"   , "gga"   , "ggag"  , "ggagg" , "ggags" ,  /*-- U+AE48 .. U+AE4F --*/
   "ggan"  , "gganj" , "gganh" , "ggad"  , "ggal"  , "ggalg" , "ggalm" , "ggalb" ,  /*-- U+AE50 .. U+AE57 --*/
   "ggals" , "ggalt" , "ggalp" , "ggalh" , "ggam"  , "ggab"  , "ggabs" , "ggas"  ,  /*-- U+AE58 .. U+AE5F --*/
   "ggass" , "ggang" , "ggaj"  , "ggac"  , "ggak"  , "ggat"  , "ggap"  , "ggah"  ,  /*-- U+AE60 .. U+AE67 --*/
   "ggae"  , "ggaeg" , "ggaegg", "ggaegs", "ggaen" , "ggaenj", "ggaenh", "ggaed" ,  /*-- U+AE68 .. U+AE6F --*/
   "ggael" , "ggaelg", "ggaelm", "ggaelb", "ggaels", "ggaelt", "ggaelp", "ggaelh",  /*-- U+AE70 .. U+AE77 --*/
   "ggaem" , "ggaeb" , "ggaebs", "ggaes" , "ggaess", "ggaeng", "ggaej" , "ggaec" ,  /*-- U+AE78 .. U+AE7F --*/
   "ggaek" , "ggaet" , "ggaep" , "ggaeh" , "ggya"  , "ggyag" , "ggyagg", "ggyags",  /*-- U+AE80 .. U+AE87 --*/
   "ggyan" , "ggyanj", "ggyanh", "ggyad" , "ggyal" , "ggyalg", "ggyalm", "ggyalb",  /*-- U+AE88 .. U+AE8F --*/
   "ggyals", "ggyalt", "ggyalp", "ggyalh", "ggyam" , "ggyab" , "ggyabs", "ggyas" ,  /*-- U+AE90 .. U+AE97 --*/
   "ggyass", "ggyang", "ggyaj" , "ggyac" , "ggyak" , "ggyat" , "ggyap" , "ggyah" ,  /*-- U+AE98 .. U+AE9F --*/
   "ggyae" , "ggyaeg", "ggyaegg", "ggyaegs", "ggyaen", "ggyaenj", "ggyaenh", "ggyaed",  /*-- U+AEA0 .. U+AEA7 --*/
   "ggyael", "ggyaelg", "ggyaelm", "ggyaelb", "ggyaels", "ggyaelt", "ggyaelp", "ggyaelh",  /*-- U+AEA8 .. U+AEAF --*/
   "ggyaem", "ggyaeb", "ggyaebs", "ggyaes", "ggyaess", "ggyaeng", "ggyaej", "ggyaec",  /*-- U+AEB0 .. U+AEB7 --*/
   "ggyaek", "ggyaet", "ggyaep", "ggyaeh", "ggeo"  , "ggeog" , "ggeogg", "ggeogs",  /*-- U+AEB8 .. U+AEBF --*/
   "ggeon" , "ggeonj", "ggeonh", "ggeod" , "ggeol" , "ggeolg", "ggeolm", "ggeolb",  /*-- U+AEC0 .. U+AEC7 --*/
   "ggeols", "ggeolt", "ggeolp", "ggeolh", "ggeom" , "ggeob" , "ggeobs", "ggeos" ,  /*-- U+AEC8 .. U+AECF --*/
   "ggeoss", "ggeong", "ggeoj" , "ggeoc" , "ggeok" , "ggeot" , "ggeop" , "ggeoh" ,  /*-- U+AED0 .. U+AED7 --*/
   "gge"   , "ggeg"  , "ggegg" , "ggegs" , "ggen"  , "ggenj" , "ggenh" , "gged"  ,  /*-- U+AED8 .. U+AEDF --*/
   "ggel"  , "ggelg" , "ggelm" , "ggelb" , "ggels" , "ggelt" , "ggelp" , "ggelh" ,  /*-- U+AEE0 .. U+AEE7 --*/
   "ggem"  , "ggeb"  , "ggebs" , "gges"  , "ggess" , "ggeng" , "ggej"  , "ggec"  ,  /*-- U+AEE8 .. U+AEEF --*/
   "ggek"  , "gget"  , "ggep"  , "ggeh"  , "ggyeo" , "ggyeog", "ggyeogg", "ggyeogs",  /*-- U+AEF0 .. U+AEF7 --*/
   "ggyeon", "ggyeonj", "ggyeonh", "ggyeod", "ggyeol", "ggyeolg", "ggyeolm", "ggyeolb",  /*-- U+AEF8 .. U+AEFF --*/
   "ggyeols", "ggyeolt", "ggyeolp", "ggyeolh", "ggyeom", "ggyeob", "ggyeobs", "ggyeos",  /*-- U+AF00 .. U+AF07 --*/
   "ggyeoss", "ggyeong", "ggyeoj", "ggyeoc", "ggyeok", "ggyeot", "ggyeop", "ggyeoh",  /*-- U+AF08 .. U+AF0F --*/
   "ggye"  , "ggyeg" , "ggyegg", "ggyegs", "ggyen" , "ggyenj", "ggyenh", "ggyed" ,  /*-- U+AF10 .. U+AF17 --*/
   "ggyel" , "ggyelg", "ggyelm", "ggyelb", "ggyels", "ggyelt", "ggyelp", "ggyelh",  /*-- U+AF18 .. U+AF1F --*/
   "ggyem" , "ggyeb" , "ggyebs", "ggyes" , "ggyess", "ggyeng", "ggyej" , "ggyec" ,  /*-- U+AF20 .. U+AF27 --*/
   "ggyek" , "ggyet" , "ggyep" , "ggyeh" , "ggo"   , "ggog"  , "ggogg" , "ggogs" ,  /*-- U+AF28 .. U+AF2F --*/
   "ggon"  , "ggonj" , "ggonh" , "ggod"  , "ggol"  , "ggolg" , "ggolm" , "ggolb" ,  /*-- U+AF30 .. U+AF37 --*/
   "ggols" , "ggolt" , "ggolp" , "ggolh" , "ggom"  , "ggob"  , "ggobs" , "ggos"  ,  /*-- U+AF38 .. U+AF3F --*/
   "ggoss" , "ggong" , "ggoj"  , "ggoc"  , "ggok"  , "ggot"  , "ggop"  , "ggoh"  ,  /*-- U+AF40 .. U+AF47 --*/
   "ggwa"  , "ggwag" , "ggwagg", "ggwags", "ggwan" , "ggwanj", "ggwanh", "ggwad" ,  /*-- U+AF48 .. U+AF4F --*/
   "ggwal" , "ggwalg", "ggwalm", "ggwalb", "ggwals", "ggwalt", "ggwalp", "ggwalh",  /*-- U+AF50 .. U+AF57 --*/
   "ggwam" , "ggwab" , "ggwabs", "ggwas" , "ggwass", "ggwang", "ggwaj" , "ggwac" ,  /*-- U+AF58 .. U+AF5F --*/
   "ggwak" , "ggwat" , "ggwap" , "ggwah" , "ggwae" , "ggwaeg", "ggwaegg", "ggwaegs",  /*-- U+AF60 .. U+AF67 --*/
   "ggwaen", "ggwaenj", "ggwaenh", "ggwaed", "ggwael", "ggwaelg", "ggwaelm", "ggwaelb",  /*-- U+AF68 .. U+AF6F --*/
   "ggwaels", "ggwaelt", "ggwaelp", "ggwaelh", "ggwaem", "ggwaeb", "ggwaebs", "ggwaes",  /*-- U+AF70 .. U+AF77 --*/
   "ggwaess", "ggwaeng", "ggwaej", "ggwaec", "ggwaek", "ggwaet", "ggwaep", "ggwaeh",  /*-- U+AF78 .. U+AF7F --*/
   "ggoe"  , "ggoeg" , "ggoegg", "ggoegs", "ggoen" , "ggoenj", "ggoenh", "ggoed" ,  /*-- U+AF80 .. U+AF87 --*/
   "ggoel" , "ggoelg", "ggoelm", "ggoelb", "ggoels", "ggoelt", "ggoelp", "ggoelh",  /*-- U+AF88 .. U+AF8F --*/
   "ggoem" , "ggoeb" , "ggoebs", "ggoes" , "ggoess", "ggoeng", "ggoej" , "ggoec" ,  /*-- U+AF90 .. U+AF97 --*/
   "ggoek" , "ggoet" , "ggoep" , "ggoeh" , "ggyo"  , "ggyog" , "ggyogg", "ggyogs",  /*-- U+AF98 .. U+AF9F --*/
   "ggyon" , "ggyonj", "ggyonh", "ggyod" , "ggyol" , "ggyolg", "ggyolm", "ggyolb",  /*-- U+AFA0 .. U+AFA7 --*/
   "ggyols", "ggyolt", "ggyolp", "ggyolh", "ggyom" , "ggyob" , "ggyobs", "ggyos" ,  /*-- U+AFA8 .. U+AFAF --*/
   "ggyoss", "ggyong", "ggyoj" , "ggyoc" , "ggyok" , "ggyot" , "ggyop" , "ggyoh" ,  /*-- U+AFB0 .. U+AFB7 --*/
   "ggu"   , "ggug"  , "ggugg" , "ggugs" , "ggun"  , "ggunj" , "ggunh" , "ggud"  ,  /*-- U+AFB8 .. U+AFBF --*/
   "ggul"  , "ggulg" , "ggulm" , "ggulb" , "gguls" , "ggult" , "ggulp" , "ggulh" ,  /*-- U+AFC0 .. U+AFC7 --*/
   "ggum"  , "ggub"  , "ggubs" , "ggus"  , "gguss" , "ggung" , "gguj"  , "gguc"  ,  /*-- U+AFC8 .. U+AFCF --*/
   "gguk"  , "ggut"  , "ggup"  , "gguh"  , "ggweo" , "ggweog", "ggweogg", "ggweogs",  /*-- U+AFD0 .. U+AFD7 --*/
   "ggweon", "ggweonj", "ggweonh", "ggweod", "ggweol", "ggweolg", "ggweolm", "ggweolb",  /*-- U+AFD8 .. U+AFDF --*/
   "ggweols", "ggweolt", "ggweolp", "ggweolh", "ggweom", "ggweob", "ggweobs", "ggweos",  /*-- U+AFE0 .. U+AFE7 --*/
   "ggweoss", "ggweong", "ggweoj", "ggweoc", "ggweok", "ggweot", "ggweop", "ggweoh",  /*-- U+AFE8 .. U+AFEF --*/
   "ggwe"  , "ggweg" , "ggwegg", "ggwegs", "ggwen" , "ggwenj", "ggwenh", "ggwed" ,  /*-- U+AFF0 .. U+AFF7 --*/
   "ggwel" , "ggwelg", "ggwelm", "ggwelb", "ggwels", "ggwelt", "ggwelp", "ggwelh",  /*-- U+AFF8 .. U+AFFF --*/
   "ggwem" , "ggweb" , "ggwebs", "ggwes" , "ggwess", "ggweng", "ggwej" , "ggwec" ,  /*-- U+B000 .. U+B007 --*/
   "ggwek" , "ggwet" , "ggwep" , "ggweh" , "ggwi"  , "ggwig" , "ggwigg", "ggwigs",  /*-- U+B008 .. U+B00F --*/
   "ggwin" , "ggwinj", "ggwinh", "ggwid" , "ggwil" , "ggwilg", "ggwilm", "ggwilb",  /*-- U+B010 .. U+B017 --*/
   "ggwils", "ggwilt", "ggwilp", "ggwilh", "ggwim" , "ggwib" , "ggwibs", "ggwis" ,  /*-- U+B018 .. U+B01F --*/
   "ggwiss", "ggwing", "ggwij" , "ggwic" , "ggwik" , "ggwit" , "ggwip" , "ggwih" ,  /*-- U+B020 .. U+B027 --*/
   "ggyu"  , "ggyug" , "ggyugg", "ggyugs", "ggyun" , "ggyunj", "ggyunh", "ggyud" ,  /*-- U+B028 .. U+B02F --*/
   "ggyul" , "ggyulg", "ggyulm", "ggyulb", "ggyuls", "ggyult", "ggyulp", "ggyulh",  /*-- U+B030 .. U+B037 --*/
   "ggyum" , "ggyub" , "ggyubs", "ggyus" , "ggyuss", "ggyung", "ggyuj" , "ggyuc" ,  /*-- U+B038 .. U+B03F --*/
   "ggyuk" , "ggyut" , "ggyup" , "ggyuh" , "ggeu"  , "ggeug" , "ggeugg", "ggeugs",  /*-- U+B040 .. U+B047 --*/
   "ggeun" , "ggeunj", "ggeunh", "ggeud" , "ggeul" , "ggeulg", "ggeulm", "ggeulb",  /*-- U+B048 .. U+B04F --*/
   "ggeuls", "ggeult", "ggeulp", "ggeulh", "ggeum" , "ggeub" , "ggeubs", "ggeus" ,  /*-- U+B050 .. U+B057 --*/
   "ggeuss", "ggeung", "ggeuj" , "ggeuc" , "ggeuk" , "ggeut" , "ggeup" , "ggeuh" ,  /*-- U+B058 .. U+B05F --*/
   "ggyi"  , "ggyig" , "ggyigg", "ggyigs", "ggyin" , "ggyinj", "ggyinh", "ggyid" ,  /*-- U+B060 .. U+B067 --*/
   "ggyil" , "ggyilg", "ggyilm", "ggyilb", "ggyils", "ggyilt", "ggyilp", "ggyilh",  /*-- U+B068 .. U+B06F --*/
   "ggyim" , "ggyib" , "ggyibs", "ggyis" , "ggyiss", "ggying", "ggyij" , "ggyic" ,  /*-- U+B070 .. U+B077 --*/
   "ggyik" , "ggyit" , "ggyip" , "ggyih" , "ggi"   , "ggig"  , "ggigg" , "ggigs" ,  /*-- U+B078 .. U+B07F --*/
   "ggin"  , "gginj" , "gginh" , "ggid"  , "ggil"  , "ggilg" , "ggilm" , "ggilb" ,  /*-- U+B080 .. U+B087 --*/
   "ggils" , "ggilt" , "ggilp" , "ggilh" , "ggim"  , "ggib"  , "ggibs" , "ggis"  ,  /*-- U+B088 .. U+B08F --*/
   "ggiss" , "gging" , "ggij"  , "ggic"  , "ggik"  , "ggit"  , "ggip"  , "ggih"  ,  /*-- U+B090 .. U+B097 --*/
   "na"    , "nag"   , "nagg"  , "nags"  , "nan"   , "nanj"  , "nanh"  , "nad"   ,  /*-- U+B098 .. U+B09F --*/
   "nal"   , "nalg"  , "nalm"  , "nalb"  , "nals"  , "nalt"  , "nalp"  , "nalh"  ,  /*-- U+B0A0 .. U+B0A7 --*/
   "nam"   , "nab"   , "nabs"  , "nas"   , "nass"  , "nang"  , "naj"   , "nac"   ,  /*-- U+B0A8 .. U+B0AF --*/
   "nak"   , "nat"   , "nap"   , "nah"   , "nae"   , "naeg"  , "naegg" , "naegs" ,  /*-- U+B0B0 .. U+B0B7 --*/
   "naen"  , "naenj" , "naenh" , "naed"  , "nael"  , "naelg" , "naelm" , "naelb" ,  /*-- U+B0B8 .. U+B0BF --*/
   "naels" , "naelt" , "naelp" , "naelh" , "naem"  , "naeb"  , "naebs" , "naes"  ,  /*-- U+B0C0 .. U+B0C7 --*/
   "naess" , "naeng" , "naej"  , "naec"  , "naek"  , "naet"  , "naep"  , "naeh"  ,  /*-- U+B0C8 .. U+B0CF --*/
   "nya"   , "nyag"  , "nyagg" , "nyags" , "nyan"  , "nyanj" , "nyanh" , "nyad"  ,  /*-- U+B0D0 .. U+B0D7 --*/
   "nyal"  , "nyalg" , "nyalm" , "nyalb" , "nyals" , "nyalt" , "nyalp" , "nyalh" ,  /*-- U+B0D8 .. U+B0DF --*/
   "nyam"  , "nyab"  , "nyabs" , "nyas"  , "nyass" , "nyang" , "nyaj"  , "nyac"  ,  /*-- U+B0E0 .. U+B0E7 --*/
   "nyak"  , "nyat"  , "nyap"  , "nyah"  , "nyae"  , "nyaeg" , "nyaegg", "nyaegs",  /*-- U+B0E8 .. U+B0EF --*/
   "nyaen" , "nyaenj", "nyaenh", "nyaed" , "nyael" , "nyaelg", "nyaelm", "nyaelb",  /*-- U+B0F0 .. U+B0F7 --*/
   "nyaels", "nyaelt", "nyaelp", "nyaelh", "nyaem" , "nyaeb" , "nyaebs", "nyaes" ,  /*-- U+B0F8 .. U+B0FF --*/
   "nyaess", "nyaeng", "nyaej" , "nyaec" , "nyaek" , "nyaet" , "nyaep" , "nyaeh" ,  /*-- U+B100 .. U+B107 --*/
   "neo"   , "neog"  , "neogg" , "neogs" , "neon"  , "neonj" , "neonh" , "neod"  ,  /*-- U+B108 .. U+B10F --*/
   "neol"  , "neolg" , "neolm" , "neolb" , "neols" , "neolt" , "neolp" , "neolh" ,  /*-- U+B110 .. U+B117 --*/
   "neom"  , "neob"  , "neobs" , "neos"  , "neoss" , "neong" , "neoj"  , "neoc"  ,  /*-- U+B118 .. U+B11F --*/
   "neok"  , "neot"  , "neop"  , "neoh"  , "ne"    , "neg"   , "negg"  , "negs"  ,  /*-- U+B120 .. U+B127 --*/
   "nen"   , "nenj"  , "nenh"  , "ned"   , "nel"   , "nelg"  , "nelm"  , "nelb"  ,  /*-- U+B128 .. U+B12F --*/
   "nels"  , "nelt"  , "nelp"  , "nelh"  , "nem"   , "neb"   , "nebs"  , "nes"   ,  /*-- U+B130 .. U+B137 --*/
   "ness"  , "neng"  , "nej"   , "nec"   , "nek"   , "net"   , "nep"   , "neh"   ,  /*-- U+B138 .. U+B13F --*/
   "nyeo"  , "nyeog" , "nyeogg", "nyeogs", "nyeon" , "nyeonj", "nyeonh", "nyeod" ,  /*-- U+B140 .. U+B147 --*/
   "nyeol" , "nyeolg", "nyeolm", "nyeolb", "nyeols", "nyeolt", "nyeolp", "nyeolh",  /*-- U+B148 .. U+B14F --*/
   "nyeom" , "nyeob" , "nyeobs", "nyeos" , "nyeoss", "nyeong", "nyeoj" , "nyeoc" ,  /*-- U+B150 .. U+B157 --*/
   "nyeok" , "nyeot" , "nyeop" , "nyeoh" , "nye"   , "nyeg"  , "nyegg" , "nyegs" ,  /*-- U+B158 .. U+B15F --*/
   "nyen"  , "nyenj" , "nyenh" , "nyed"  , "nyel"  , "nyelg" , "nyelm" , "nyelb" ,  /*-- U+B160 .. U+B167 --*/
   "nyels" , "nyelt" , "nyelp" , "nyelh" , "nyem"  , "nyeb"  , "nyebs" , "nyes"  ,  /*-- U+B168 .. U+B16F --*/
   "nyess" , "nyeng" , "nyej"  , "nyec"  , "nyek"  , "nyet"  , "nyep"  , "nyeh"  ,  /*-- U+B170 .. U+B177 --*/
   "no"    , "nog"   , "nogg"  , "nogs"  , "non"   , "nonj"  , "nonh"  , "nod"   ,  /*-- U+B178 .. U+B17F --*/
   "nol"   , "nolg"  , "nolm"  , "nolb"  , "nols"  , "nolt"  , "nolp"  , "nolh"  ,  /*-- U+B180 .. U+B187 --*/
   "nom"   , "nob"   , "nobs"  , "nos"   , "noss"  , "nong"  , "noj"   , "noc"   ,  /*-- U+B188 .. U+B18F --*/
   "nok"   , "not"   , "nop"   , "noh"   , "nwa"   , "nwag"  , "nwagg" , "nwags" ,  /*-- U+B190 .. U+B197 --*/
   "nwan"  , "nwanj" , "nwanh" , "nwad"  , "nwal"  , "nwalg" , "nwalm" , "nwalb" ,  /*-- U+B198 .. U+B19F --*/
   "nwals" , "nwalt" , "nwalp" , "nwalh" , "nwam"  , "nwab"  , "nwabs" , "nwas"  ,  /*-- U+B1A0 .. U+B1A7 --*/
   "nwass" , "nwang" , "nwaj"  , "nwac"  , "nwak"  , "nwat"  , "nwap"  , "nwah"  ,  /*-- U+B1A8 .. U+B1AF --*/
   "nwae"  , "nwaeg" , "nwaegg", "nwaegs", "nwaen" , "nwaenj", "nwaenh", "nwaed" ,  /*-- U+B1B0 .. U+B1B7 --*/
   "nwael" , "nwaelg", "nwaelm", "nwaelb", "nwaels", "nwaelt", "nwaelp", "nwaelh",  /*-- U+B1B8 .. U+B1BF --*/
   "nwaem" , "nwaeb" , "nwaebs", "nwaes" , "nwaess", "nwaeng", "nwaej" , "nwaec" ,  /*-- U+B1C0 .. U+B1C7 --*/
   "nwaek" , "nwaet" , "nwaep" , "nwaeh" , "noe"   , "noeg"  , "noegg" , "noegs" ,  /*-- U+B1C8 .. U+B1CF --*/
   "noen"  , "noenj" , "noenh" , "noed"  , "noel"  , "noelg" , "noelm" , "noelb" ,  /*-- U+B1D0 .. U+B1D7 --*/
   "noels" , "noelt" , "noelp" , "noelh" , "noem"  , "noeb"  , "noebs" , "noes"  ,  /*-- U+B1D8 .. U+B1DF --*/
   "noess" , "noeng" , "noej"  , "noec"  , "noek"  , "noet"  , "noep"  , "noeh"  ,  /*-- U+B1E0 .. U+B1E7 --*/
   "nyo"   , "nyog"  , "nyogg" , "nyogs" , "nyon"  , "nyonj" , "nyonh" , "nyod"  ,  /*-- U+B1E8 .. U+B1EF --*/
   "nyol"  , "nyolg" , "nyolm" , "nyolb" , "nyols" , "nyolt" , "nyolp" , "nyolh" ,  /*-- U+B1F0 .. U+B1F7 --*/
   "nyom"  , "nyob"  , "nyobs" , "nyos"  , "nyoss" , "nyong" , "nyoj"  , "nyoc"  ,  /*-- U+B1F8 .. U+B1FF --*/
   "nyok"  , "nyot"  , "nyop"  , "nyoh"  , "nu"    , "nug"   , "nugg"  , "nugs"  ,  /*-- U+B200 .. U+B207 --*/
   "nun"   , "nunj"  , "nunh"  , "nud"   , "nul"   , "nulg"  , "nulm"  , "nulb"  ,  /*-- U+B208 .. U+B20F --*/
   "nuls"  , "nult"  , "nulp"  , "nulh"  , "num"   , "nub"   , "nubs"  , "nus"   ,  /*-- U+B210 .. U+B217 --*/
   "nuss"  , "nung"  , "nuj"   , "nuc"   , "nuk"   , "nut"   , "nup"   , "nuh"   ,  /*-- U+B218 .. U+B21F --*/
   "nweo"  , "nweog" , "nweogg", "nweogs", "nweon" , "nweonj", "nweonh", "nweod" ,  /*-- U+B220 .. U+B227 --*/
   "nweol" , "nweolg", "nweolm", "nweolb", "nweols", "nweolt", "nweolp", "nweolh",  /*-- U+B228 .. U+B22F --*/
   "nweom" , "nweob" , "nweobs", "nweos" , "nweoss", "nweong", "nweoj" , "nweoc" ,  /*-- U+B230 .. U+B237 --*/
   "nweok" , "nweot" , "nweop" , "nweoh" , "nwe"   , "nweg"  , "nwegg" , "nwegs" ,  /*-- U+B238 .. U+B23F --*/
   "nwen"  , "nwenj" , "nwenh" , "nwed"  , "nwel"  , "nwelg" , "nwelm" , "nwelb" ,  /*-- U+B240 .. U+B247 --*/
   "nwels" , "nwelt" , "nwelp" , "nwelh" , "nwem"  , "nweb"  , "nwebs" , "nwes"  ,  /*-- U+B248 .. U+B24F --*/
   "nwess" , "nweng" , "nwej"  , "nwec"  , "nwek"  , "nwet"  , "nwep"  , "nweh"  ,  /*-- U+B250 .. U+B257 --*/
   "nwi"   , "nwig"  , "nwigg" , "nwigs" , "nwin"  , "nwinj" , "nwinh" , "nwid"  ,  /*-- U+B258 .. U+B25F --*/
   "nwil"  , "nwilg" , "nwilm" , "nwilb" , "nwils" , "nwilt" , "nwilp" , "nwilh" ,  /*-- U+B260 .. U+B267 --*/
   "nwim"  , "nwib"  , "nwibs" , "nwis"  , "nwiss" , "nwing" , "nwij"  , "nwic"  ,  /*-- U+B268 .. U+B26F --*/
   "nwik"  , "nwit"  , "nwip"  , "nwih"  , "nyu"   , "nyug"  , "nyugg" , "nyugs" ,  /*-- U+B270 .. U+B277 --*/
   "nyun"  , "nyunj" , "nyunh" , "nyud"  , "nyul"  , "nyulg" , "nyulm" , "nyulb" ,  /*-- U+B278 .. U+B27F --*/
   "nyuls" , "nyult" , "nyulp" , "nyulh" , "nyum"  , "nyub"  , "nyubs" , "nyus"  ,  /*-- U+B280 .. U+B287 --*/
   "nyuss" , "nyung" , "nyuj"  , "nyuc"  , "nyuk"  , "nyut"  , "nyup"  , "nyuh"  ,  /*-- U+B288 .. U+B28F --*/
   "neu"   , "neug"  , "neugg" , "neugs" , "neun"  , "neunj" , "neunh" , "neud"  ,  /*-- U+B290 .. U+B297 --*/
   "neul"  , "neulg" , "neulm" , "neulb" , "neuls" , "neult" , "neulp" , "neulh" ,  /*-- U+B298 .. U+B29F --*/
   "neum"  , "neub"  , "neubs" , "neus"  , "neuss" , "neung" , "neuj"  , "neuc"  ,  /*-- U+B2A0 .. U+B2A7 --*/
   "neuk"  , "neut"  , "neup"  , "neuh"  , "nyi"   , "nyig"  , "nyigg" , "nyigs" ,  /*-- U+B2A8 .. U+B2AF --*/
   "nyin"  , "nyinj" , "nyinh" , "nyid"  , "nyil"  , "nyilg" , "nyilm" , "nyilb" ,  /*-- U+B2B0 .. U+B2B7 --*/
   "nyils" , "nyilt" , "nyilp" , "nyilh" , "nyim"  , "nyib"  , "nyibs" , "nyis"  ,  /*-- U+B2B8 .. U+B2BF --*/
   "nyiss" , "nying" , "nyij"  , "nyic"  , "nyik"  , "nyit"  , "nyip"  , "nyih"  ,  /*-- U+B2C0 .. U+B2C7 --*/
   "ni"    , "nig"   , "nigg"  , "nigs"  , "nin"   , "ninj"  , "ninh"  , "nid"   ,  /*-- U+B2C8 .. U+B2CF --*/
   "nil"   , "nilg"  , "nilm"  , "nilb"  , "nils"  , "nilt"  , "nilp"  , "nilh"  ,  /*-- U+B2D0 .. U+B2D7 --*/
   "nim"   , "nib"   , "nibs"  , "nis"   , "niss"  , "ning"  , "nij"   , "nic"   ,  /*-- U+B2D8 .. U+B2DF --*/
   "nik"   , "nit"   , "nip"   , "nih"   , "da"    , "dag"   , "dagg"  , "dags"  ,  /*-- U+B2E0 .. U+B2E7 --*/
   "dan"   , "danj"  , "danh"  , "dad"   , "dal"   , "dalg"  , "dalm"  , "dalb"  ,  /*-- U+B2E8 .. U+B2EF --*/
   "dals"  , "dalt"  , "dalp"  , "dalh"  , "dam"   , "dab"   , "dabs"  , "das"   ,  /*-- U+B2F0 .. U+B2F7 --*/
   "dass"  , "dang"  , "daj"   , "dac"   , "dak"   , "dat"   , "dap"   , "dah"   ,  /*-- U+B2F8 .. U+B2FF --*/
   "dae"   , "daeg"  , "daegg" , "daegs" , "daen"  , "daenj" , "daenh" , "daed"  ,  /*-- U+B300 .. U+B307 --*/
   "dael"  , "daelg" , "daelm" , "daelb" , "daels" , "daelt" , "daelp" , "daelh" ,  /*-- U+B308 .. U+B30F --*/
   "daem"  , "daeb"  , "daebs" , "daes"  , "daess" , "daeng" , "daej"  , "daec"  ,  /*-- U+B310 .. U+B317 --*/
   "daek"  , "daet"  , "daep"  , "daeh"  , "dya"   , "dyag"  , "dyagg" , "dyags" ,  /*-- U+B318 .. U+B31F --*/
   "dyan"  , "dyanj" , "dyanh" , "dyad"  , "dyal"  , "dyalg" , "dyalm" , "dyalb" ,  /*-- U+B320 .. U+B327 --*/
   "dyals" , "dyalt" , "dyalp" , "dyalh" , "dyam"  , "dyab"  , "dyabs" , "dyas"  ,  /*-- U+B328 .. U+B32F --*/
   "dyass" , "dyang" , "dyaj"  , "dyac"  , "dyak"  , "dyat"  , "dyap"  , "dyah"  ,  /*-- U+B330 .. U+B337 --*/
   "dyae"  , "dyaeg" , "dyaegg", "dyaegs", "dyaen" , "dyaenj", "dyaenh", "dyaed" ,  /*-- U+B338 .. U+B33F --*/
   "dyael" , "dyaelg", "dyaelm", "dyaelb", "dyaels", "dyaelt", "dyaelp", "dyaelh",  /*-- U+B340 .. U+B347 --*/
   "dyaem" , "dyaeb" , "dyaebs", "dyaes" , "dyaess", "dyaeng", "dyaej" , "dyaec" ,  /*-- U+B348 .. U+B34F --*/
   "dyaek" , "dyaet" , "dyaep" , "dyaeh" , "deo"   , "deog"  , "deogg" , "deogs" ,  /*-- U+B350 .. U+B357 --*/
   "deon"  , "deonj" , "deonh" , "deod"  , "deol"  , "deolg" , "deolm" , "deolb" ,  /*-- U+B358 .. U+B35F --*/
   "deols" , "deolt" , "deolp" , "deolh" , "deom"  , "deob"  , "deobs" , "deos"  ,  /*-- U+B360 .. U+B367 --*/
   "deoss" , "deong" , "deoj"  , "deoc"  , "deok"  , "deot"  , "deop"  , "deoh"  ,  /*-- U+B368 .. U+B36F --*/
   "de"    , "deg"   , "degg"  , "degs"  , "den"   , "denj"  , "denh"  , "ded"   ,  /*-- U+B370 .. U+B377 --*/
   "del"   , "delg"  , "delm"  , "delb"  , "dels"  , "delt"  , "delp"  , "delh"  ,  /*-- U+B378 .. U+B37F --*/
   "dem"   , "deb"   , "debs"  , "des"   , "dess"  , "deng"  , "dej"   , "dec"   ,  /*-- U+B380 .. U+B387 --*/
   "dek"   , "det"   , "dep"   , "deh"   , "dyeo"  , "dyeog" , "dyeogg", "dyeogs",  /*-- U+B388 .. U+B38F --*/
   "dyeon" , "dyeonj", "dyeonh", "dyeod" , "dyeol" , "dyeolg", "dyeolm", "dyeolb",  /*-- U+B390 .. U+B397 --*/
   "dyeols", "dyeolt", "dyeolp", "dyeolh", "dyeom" , "dyeob" , "dyeobs", "dyeos" ,  /*-- U+B398 .. U+B39F --*/
   "dyeoss", "dyeong", "dyeoj" , "dyeoc" , "dyeok" , "dyeot" , "dyeop" , "dyeoh" ,  /*-- U+B3A0 .. U+B3A7 --*/
   "dye"   , "dyeg"  , "dyegg" , "dyegs" , "dyen"  , "dyenj" , "dyenh" , "dyed"  ,  /*-- U+B3A8 .. U+B3AF --*/
   "dyel"  , "dyelg" , "dyelm" , "dyelb" , "dyels" , "dyelt" , "dyelp" , "dyelh" ,  /*-- U+B3B0 .. U+B3B7 --*/
   "dyem"  , "dyeb"  , "dyebs" , "dyes"  , "dyess" , "dyeng" , "dyej"  , "dyec"  ,  /*-- U+B3B8 .. U+B3BF --*/
   "dyek"  , "dyet"  , "dyep"  , "dyeh"  , "do"    , "dog"   , "dogg"  , "dogs"  ,  /*-- U+B3C0 .. U+B3C7 --*/
   "don"   , "donj"  , "donh"  , "dod"   , "dol"   , "dolg"  , "dolm"  , "dolb"  ,  /*-- U+B3C8 .. U+B3CF --*/
   "dols"  , "dolt"  , "dolp"  , "dolh"  , "dom"   , "dob"   , "dobs"  , "dos"   ,  /*-- U+B3D0 .. U+B3D7 --*/
   "doss"  , "dong"  , "doj"   , "doc"   , "dok"   , "dot"   , "dop"   , "doh"   ,  /*-- U+B3D8 .. U+B3DF --*/
   "dwa"   , "dwag"  , "dwagg" , "dwags" , "dwan"  , "dwanj" , "dwanh" , "dwad"  ,  /*-- U+B3E0 .. U+B3E7 --*/
   "dwal"  , "dwalg" , "dwalm" , "dwalb" , "dwals" , "dwalt" , "dwalp" , "dwalh" ,  /*-- U+B3E8 .. U+B3EF --*/
   "dwam"  , "dwab"  , "dwabs" , "dwas"  , "dwass" , "dwang" , "dwaj"  , "dwac"  ,  /*-- U+B3F0 .. U+B3F7 --*/
   "dwak"  , "dwat"  , "dwap"  , "dwah"  , "dwae"  , "dwaeg" , "dwaegg", "dwaegs",  /*-- U+B3F8 .. U+B3FF --*/
   "dwaen" , "dwaenj", "dwaenh", "dwaed" , "dwael" , "dwaelg", "dwaelm", "dwaelb",  /*-- U+B400 .. U+B407 --*/
   "dwaels", "dwaelt", "dwaelp", "dwaelh", "dwaem" , "dwaeb" , "dwaebs", "dwaes" ,  /*-- U+B408 .. U+B40F --*/
   "dwaess", "dwaeng", "dwaej" , "dwaec" , "dwaek" , "dwaet" , "dwaep" , "dwaeh" ,  /*-- U+B410 .. U+B417 --*/
   "doe"   , "doeg"  , "doegg" , "doegs" , "doen"  , "doenj" , "doenh" , "doed"  ,  /*-- U+B418 .. U+B41F --*/
   "doel"  , "doelg" , "doelm" , "doelb" , "doels" , "doelt" , "doelp" , "doelh" ,  /*-- U+B420 .. U+B427 --*/
   "doem"  , "doeb"  , "doebs" , "does"  , "doess" , "doeng" , "doej"  , "doec"  ,  /*-- U+B428 .. U+B42F --*/
   "doek"  , "doet"  , "doep"  , "doeh"  , "dyo"   , "dyog"  , "dyogg" , "dyogs" ,  /*-- U+B430 .. U+B437 --*/
   "dyon"  , "dyonj" , "dyonh" , "dyod"  , "dyol"  , "dyolg" , "dyolm" , "dyolb" ,  /*-- U+B438 .. U+B43F --*/
   "dyols" , "dyolt" , "dyolp" , "dyolh" , "dyom"  , "dyob"  , "dyobs" , "dyos"  ,  /*-- U+B440 .. U+B447 --*/
   "dyoss" , "dyong" , "dyoj"  , "dyoc"  , "dyok"  , "dyot"  , "dyop"  , "dyoh"  ,  /*-- U+B448 .. U+B44F --*/
   "du"    , "dug"   , "dugg"  , "dugs"  , "dun"   , "dunj"  , "dunh"  , "dud"   ,  /*-- U+B450 .. U+B457 --*/
   "dul"   , "dulg"  , "dulm"  , "dulb"  , "duls"  , "dult"  , "dulp"  , "dulh"  ,  /*-- U+B458 .. U+B45F --*/
   "dum"   , "dub"   , "dubs"  , "dus"   , "duss"  , "dung"  , "duj"   , "duc"   ,  /*-- U+B460 .. U+B467 --*/
   "duk"   , "dut"   , "dup"   , "duh"   , "dweo"  , "dweog" , "dweogg", "dweogs",  /*-- U+B468 .. U+B46F --*/
   "dweon" , "dweonj", "dweonh", "dweod" , "dweol" , "dweolg", "dweolm", "dweolb",  /*-- U+B470 .. U+B477 --*/
   "dweols", "dweolt", "dweolp", "dweolh", "dweom" , "dweob" , "dweobs", "dweos" ,  /*-- U+B478 .. U+B47F --*/
   "dweoss", "dweong", "dweoj" , "dweoc" , "dweok" , "dweot" , "dweop" , "dweoh" ,  /*-- U+B480 .. U+B487 --*/
   "dwe"   , "dweg"  , "dwegg" , "dwegs" , "dwen"  , "dwenj" , "dwenh" , "dwed"  ,  /*-- U+B488 .. U+B48F --*/
   "dwel"  , "dwelg" , "dwelm" , "dwelb" , "dwels" , "dwelt" , "dwelp" , "dwelh" ,  /*-- U+B490 .. U+B497 --*/
   "dwem"  , "dweb"  , "dwebs" , "dwes"  , "dwess" , "dweng" , "dwej"  , "dwec"  ,  /*-- U+B498 .. U+B49F --*/
   "dwek"  , "dwet"  , "dwep"  , "dweh"  , "dwi"   , "dwig"  , "dwigg" , "dwigs" ,  /*-- U+B4A0 .. U+B4A7 --*/
   "dwin"  , "dwinj" , "dwinh" , "dwid"  , "dwil"  , "dwilg" , "dwilm" , "dwilb" ,  /*-- U+B4A8 .. U+B4AF --*/
   "dwils" , "dwilt" , "dwilp" , "dwilh" , "dwim"  , "dwib"  , "dwibs" , "dwis"  ,  /*-- U+B4B0 .. U+B4B7 --*/
   "dwiss" , "dwing" , "dwij"  , "dwic"  , "dwik"  , "dwit"  , "dwip"  , "dwih"  ,  /*-- U+B4B8 .. U+B4BF --*/
   "dyu"   , "dyug"  , "dyugg" , "dyugs" , "dyun"  , "dyunj" , "dyunh" , "dyud"  ,  /*-- U+B4C0 .. U+B4C7 --*/
   "dyul"  , "dyulg" , "dyulm" , "dyulb" , "dyuls" , "dyult" , "dyulp" , "dyulh" ,  /*-- U+B4C8 .. U+B4CF --*/
   "dyum"  , "dyub"  , "dyubs" , "dyus"  , "dyuss" , "dyung" , "dyuj"  , "dyuc"  ,  /*-- U+B4D0 .. U+B4D7 --*/
   "dyuk"  , "dyut"  , "dyup"  , "dyuh"  , "deu"   , "deug"  , "deugg" , "deugs" ,  /*-- U+B4D8 .. U+B4DF --*/
   "deun"  , "deunj" , "deunh" , "deud"  , "deul"  , "deulg" , "deulm" , "deulb" ,  /*-- U+B4E0 .. U+B4E7 --*/
   "deuls" , "deult" , "deulp" , "deulh" , "deum"  , "deub"  , "deubs" , "deus"  ,  /*-- U+B4E8 .. U+B4EF --*/
   "deuss" , "deung" , "deuj"  , "deuc"  , "deuk"  , "deut"  , "deup"  , "deuh"  ,  /*-- U+B4F0 .. U+B4F7 --*/
   "dyi"   , "dyig"  , "dyigg" , "dyigs" , "dyin"  , "dyinj" , "dyinh" , "dyid"  ,  /*-- U+B4F8 .. U+B4FF --*/
   "dyil"  , "dyilg" , "dyilm" , "dyilb" , "dyils" , "dyilt" , "dyilp" , "dyilh" ,  /*-- U+B500 .. U+B507 --*/
   "dyim"  , "dyib"  , "dyibs" , "dyis"  , "dyiss" , "dying" , "dyij"  , "dyic"  ,  /*-- U+B508 .. U+B50F --*/
   "dyik"  , "dyit"  , "dyip"  , "dyih"  , "di"    , "dig"   , "digg"  , "digs"  ,  /*-- U+B510 .. U+B517 --*/
   "din"   , "dinj"  , "dinh"  , "did"   , "dil"   , "dilg"  , "dilm"  , "dilb"  ,  /*-- U+B518 .. U+B51F --*/
   "dils"  , "dilt"  , "dilp"  , "dilh"  , "dim"   , "dib"   , "dibs"  , "dis"   ,  /*-- U+B520 .. U+B527 --*/
   "diss"  , "ding"  , "dij"   , "dic"   , "dik"   , "dit"   , "dip"   , "dih"   ,  /*-- U+B528 .. U+B52F --*/
   "dda"   , "ddag"  , "ddagg" , "ddags" , "ddan"  , "ddanj" , "ddanh" , "ddad"  ,  /*-- U+B530 .. U+B537 --*/
   "ddal"  , "ddalg" , "ddalm" , "ddalb" , "ddals" , "ddalt" , "ddalp" , "ddalh" ,  /*-- U+B538 .. U+B53F --*/
   "ddam"  , "ddab"  , "ddabs" , "ddas"  , "ddass" , "ddang" , "ddaj"  , "ddac"  ,  /*-- U+B540 .. U+B547 --*/
   "ddak"  , "ddat"  , "ddap"  , "ddah"  , "ddae"  , "ddaeg" , "ddaegg", "ddaegs",  /*-- U+B548 .. U+B54F --*/
   "ddaen" , "ddaenj", "ddaenh", "ddaed" , "ddael" , "ddaelg", "ddaelm", "ddaelb",  /*-- U+B550 .. U+B557 --*/
   "ddaels", "ddaelt", "ddaelp", "ddaelh", "ddaem" , "ddaeb" , "ddaebs", "ddaes" ,  /*-- U+B558 .. U+B55F --*/
   "ddaess", "ddaeng", "ddaej" , "ddaec" , "ddaek" , "ddaet" , "ddaep" , "ddaeh" ,  /*-- U+B560 .. U+B567 --*/
   "ddya"  , "ddyag" , "ddyagg", "ddyags", "ddyan" , "ddyanj", "ddyanh", "ddyad" ,  /*-- U+B568 .. U+B56F --*/
   "ddyal" , "ddyalg", "ddyalm", "ddyalb", "ddyals", "ddyalt", "ddyalp", "ddyalh",  /*-- U+B570 .. U+B577 --*/
   "ddyam" , "ddyab" , "ddyabs", "ddyas" , "ddyass", "ddyang", "ddyaj" , "ddyac" ,  /*-- U+B578 .. U+B57F --*/
   "ddyak" , "ddyat" , "ddyap" , "ddyah" , "ddyae" , "ddyaeg", "ddyaegg", "ddyaegs",  /*-- U+B580 .. U+B587 --*/
   "ddyaen", "ddyaenj", "ddyaenh", "ddyaed", "ddyael", "ddyaelg", "ddyaelm", "ddyaelb",  /*-- U+B588 .. U+B58F --*/
   "ddyaels", "ddyaelt", "ddyaelp", "ddyaelh", "ddyaem", "ddyaeb", "ddyaebs", "ddyaes",  /*-- U+B590 .. U+B597 --*/
   "ddyaess", "ddyaeng", "ddyaej", "ddyaec", "ddyaek", "ddyaet", "ddyaep", "ddyaeh",  /*-- U+B598 .. U+B59F --*/
   "ddeo"  , "ddeog" , "ddeogg", "ddeogs", "ddeon" , "ddeonj", "ddeonh", "ddeod" ,  /*-- U+B5A0 .. U+B5A7 --*/
   "ddeol" , "ddeolg", "ddeolm", "ddeolb", "ddeols", "ddeolt", "ddeolp", "ddeolh",  /*-- U+B5A8 .. U+B5AF --*/
   "ddeom" , "ddeob" , "ddeobs", "ddeos" , "ddeoss", "ddeong", "ddeoj" , "ddeoc" ,  /*-- U+B5B0 .. U+B5B7 --*/
   "ddeok" , "ddeot" , "ddeop" , "ddeoh" , "dde"   , "ddeg"  , "ddegg" , "ddegs" ,  /*-- U+B5B8 .. U+B5BF --*/
   "dden"  , "ddenj" , "ddenh" , "dded"  , "ddel"  , "ddelg" , "ddelm" , "ddelb" ,  /*-- U+B5C0 .. U+B5C7 --*/
   "ddels" , "ddelt" , "ddelp" , "ddelh" , "ddem"  , "ddeb"  , "ddebs" , "ddes"  ,  /*-- U+B5C8 .. U+B5CF --*/
   "ddess" , "ddeng" , "ddej"  , "ddec"  , "ddek"  , "ddet"  , "ddep"  , "ddeh"  ,  /*-- U+B5D0 .. U+B5D7 --*/
   "ddyeo" , "ddyeog", "ddyeogg", "ddyeogs", "ddyeon", "ddyeonj", "ddyeonh", "ddyeod",  /*-- U+B5D8 .. U+B5DF --*/
   "ddyeol", "ddyeolg", "ddyeolm", "ddyeolb", "ddyeols", "ddyeolt", "ddyeolp", "ddyeolh",  /*-- U+B5E0 .. U+B5E7 --*/
   "ddyeom", "ddyeob", "ddyeobs", "ddyeos", "ddyeoss", "ddyeong", "ddyeoj", "ddyeoc",  /*-- U+B5E8 .. U+B5EF --*/
   "ddyeok", "ddyeot", "ddyeop", "ddyeoh", "ddye"  , "ddyeg" , "ddyegg", "ddyegs",  /*-- U+B5F0 .. U+B5F7 --*/
   "ddyen" , "ddyenj", "ddyenh", "ddyed" , "ddyel" , "ddyelg", "ddyelm", "ddyelb",  /*-- U+B5F8 .. U+B5FF --*/
   "ddyels", "ddyelt", "ddyelp", "ddyelh", "ddyem" , "ddyeb" , "ddyebs", "ddyes" ,  /*-- U+B600 .. U+B607 --*/
   "ddyess", "ddyeng", "ddyej" , "ddyec" , "ddyek" , "ddyet" , "ddyep" , "ddyeh" ,  /*-- U+B608 .. U+B60F --*/
   "ddo"   , "ddog"  , "ddogg" , "ddogs" , "ddon"  , "ddonj" , "ddonh" , "ddod"  ,  /*-- U+B610 .. U+B617 --*/
   "ddol"  , "ddolg" , "ddolm" , "ddolb" , "ddols" , "ddolt" , "ddolp" , "ddolh" ,  /*-- U+B618 .. U+B61F --*/
   "ddom"  , "ddob"  , "ddobs" , "ddos"  , "ddoss" , "ddong" , "ddoj"  , "ddoc"  ,  /*-- U+B620 .. U+B627 --*/
   "ddok"  , "ddot"  , "ddop"  , "ddoh"  , "ddwa"  , "ddwag" , "ddwagg", "ddwags",  /*-- U+B628 .. U+B62F --*/
   "ddwan" , "ddwanj", "ddwanh", "ddwad" , "ddwal" , "ddwalg", "ddwalm", "ddwalb",  /*-- U+B630 .. U+B637 --*/
   "ddwals", "ddwalt", "ddwalp", "ddwalh", "ddwam" , "ddwab" , "ddwabs", "ddwas" ,  /*-- U+B638 .. U+B63F --*/
   "ddwass", "ddwang", "ddwaj" , "ddwac" , "ddwak" , "ddwat" , "ddwap" , "ddwah" ,  /*-- U+B640 .. U+B647 --*/
   "ddwae" , "ddwaeg", "ddwaegg", "ddwaegs", "ddwaen", "ddwaenj", "ddwaenh", "ddwaed",  /*-- U+B648 .. U+B64F --*/
   "ddwael", "ddwaelg", "ddwaelm", "ddwaelb", "ddwaels", "ddwaelt", "ddwaelp", "ddwaelh",  /*-- U+B650 .. U+B657 --*/
   "ddwaem", "ddwaeb", "ddwaebs", "ddwaes", "ddwaess", "ddwaeng", "ddwaej", "ddwaec",  /*-- U+B658 .. U+B65F --*/
   "ddwaek", "ddwaet", "ddwaep", "ddwaeh", "ddoe"  , "ddoeg" , "ddoegg", "ddoegs",  /*-- U+B660 .. U+B667 --*/
   "ddoen" , "ddoenj", "ddoenh", "ddoed" , "ddoel" , "ddoelg", "ddoelm", "ddoelb",  /*-- U+B668 .. U+B66F --*/
   "ddoels", "ddoelt", "ddoelp", "ddoelh", "ddoem" , "ddoeb" , "ddoebs", "ddoes" ,  /*-- U+B670 .. U+B677 --*/
   "ddoess", "ddoeng", "ddoej" , "ddoec" , "ddoek" , "ddoet" , "ddoep" , "ddoeh" ,  /*-- U+B678 .. U+B67F --*/
   "ddyo"  , "ddyog" , "ddyogg", "ddyogs", "ddyon" , "ddyonj", "ddyonh", "ddyod" ,  /*-- U+B680 .. U+B687 --*/
   "ddyol" , "ddyolg", "ddyolm", "ddyolb", "ddyols", "ddyolt", "ddyolp", "ddyolh",  /*-- U+B688 .. U+B68F --*/
   "ddyom" , "ddyob" , "ddyobs", "ddyos" , "ddyoss", "ddyong", "ddyoj" , "ddyoc" ,  /*-- U+B690 .. U+B697 --*/
   "ddyok" , "ddyot" , "ddyop" , "ddyoh" , "ddu"   , "ddug"  , "ddugg" , "ddugs" ,  /*-- U+B698 .. U+B69F --*/
   "ddun"  , "ddunj" , "ddunh" , "ddud"  , "ddul"  , "ddulg" , "ddulm" , "ddulb" ,  /*-- U+B6A0 .. U+B6A7 --*/
   "dduls" , "ddult" , "ddulp" , "ddulh" , "ddum"  , "ddub"  , "ddubs" , "ddus"  ,  /*-- U+B6A8 .. U+B6AF --*/
   "dduss" , "ddung" , "dduj"  , "dduc"  , "dduk"  , "ddut"  , "ddup"  , "dduh"  ,  /*-- U+B6B0 .. U+B6B7 --*/
   "ddweo" , "ddweog", "ddweogg", "ddweogs", "ddweon", "ddweonj", "ddweonh", "ddweod",  /*-- U+B6B8 .. U+B6BF --*/
   "ddweol", "ddweolg", "ddweolm", "ddweolb", "ddweols", "ddweolt", "ddweolp", "ddweolh",  /*-- U+B6C0 .. U+B6C7 --*/
   "ddweom", "ddweob", "ddweobs", "ddweos", "ddweoss", "ddweong", "ddweoj", "ddweoc",  /*-- U+B6C8 .. U+B6CF --*/
   "ddweok", "ddweot", "ddweop", "ddweoh", "ddwe"  , "ddweg" , "ddwegg", "ddwegs",  /*-- U+B6D0 .. U+B6D7 --*/
   "ddwen" , "ddwenj", "ddwenh", "ddwed" , "ddwel" , "ddwelg", "ddwelm", "ddwelb",  /*-- U+B6D8 .. U+B6DF --*/
   "ddwels", "ddwelt", "ddwelp", "ddwelh", "ddwem" , "ddweb" , "ddwebs", "ddwes" ,  /*-- U+B6E0 .. U+B6E7 --*/
   "ddwess", "ddweng", "ddwej" , "ddwec" , "ddwek" , "ddwet" , "ddwep" , "ddweh" ,  /*-- U+B6E8 .. U+B6EF --*/
   "ddwi"  , "ddwig" , "ddwigg", "ddwigs", "ddwin" , "ddwinj", "ddwinh", "ddwid" ,  /*-- U+B6F0 .. U+B6F7 --*/
   "ddwil" , "ddwilg", "ddwilm", "ddwilb", "ddwils", "ddwilt", "ddwilp", "ddwilh",  /*-- U+B6F8 .. U+B6FF --*/
   "ddwim" , "ddwib" , "ddwibs", "ddwis" , "ddwiss", "ddwing", "ddwij" , "ddwic" ,  /*-- U+B700 .. U+B707 --*/
   "ddwik" , "ddwit" , "ddwip" , "ddwih" , "ddyu"  , "ddyug" , "ddyugg", "ddyugs",  /*-- U+B708 .. U+B70F --*/
   "ddyun" , "ddyunj", "ddyunh", "ddyud" , "ddyul" , "ddyulg", "ddyulm", "ddyulb",  /*-- U+B710 .. U+B717 --*/
   "ddyuls", "ddyult", "ddyulp", "ddyulh", "ddyum" , "ddyub" , "ddyubs", "ddyus" ,  /*-- U+B718 .. U+B71F --*/
   "ddyuss", "ddyung", "ddyuj" , "ddyuc" , "ddyuk" , "ddyut" , "ddyup" , "ddyuh" ,  /*-- U+B720 .. U+B727 --*/
   "ddeu"  , "ddeug" , "ddeugg", "ddeugs", "ddeun" , "ddeunj", "ddeunh", "ddeud" ,  /*-- U+B728 .. U+B72F --*/
   "ddeul" , "ddeulg", "ddeulm", "ddeulb", "ddeuls", "ddeult", "ddeulp", "ddeulh",  /*-- U+B730 .. U+B737 --*/
   "ddeum" , "ddeub" , "ddeubs", "ddeus" , "ddeuss", "ddeung", "ddeuj" , "ddeuc" ,  /*-- U+B738 .. U+B73F --*/
   "ddeuk" , "ddeut" , "ddeup" , "ddeuh" , "ddyi"  , "ddyig" , "ddyigg", "ddyigs",  /*-- U+B740 .. U+B747 --*/
   "ddyin" , "ddyinj", "ddyinh", "ddyid" , "ddyil" , "ddyilg", "ddyilm", "ddyilb",  /*-- U+B748 .. U+B74F --*/
   "ddyils", "ddyilt", "ddyilp", "ddyilh", "ddyim" , "ddyib" , "ddyibs", "ddyis" ,  /*-- U+B750 .. U+B757 --*/
   "ddyiss", "ddying", "ddyij" , "ddyic" , "ddyik" , "ddyit" , "ddyip" , "ddyih" ,  /*-- U+B758 .. U+B75F --*/
   "ddi"   , "ddig"  , "ddigg" , "ddigs" , "ddin"  , "ddinj" , "ddinh" , "ddid"  ,  /*-- U+B760 .. U+B767 --*/
   "ddil"  , "ddilg" , "ddilm" , "ddilb" , "ddils" , "ddilt" , "ddilp" , "ddilh" ,  /*-- U+B768 .. U+B76F --*/
   "ddim"  , "ddib"  , "ddibs" , "ddis"  , "ddiss" , "dding" , "ddij"  , "ddic"  ,  /*-- U+B770 .. U+B777 --*/
   "ddik"  , "ddit"  , "ddip"  , "ddih"  , "ra"    , "rag"   , "ragg"  , "rags"  ,  /*-- U+B778 .. U+B77F --*/
   "ran"   , "ranj"  , "ranh"  , "rad"   , "ral"   , "ralg"  , "ralm"  , "ralb"  ,  /*-- U+B780 .. U+B787 --*/
   "rals"  , "ralt"  , "ralp"  , "ralh"  , "ram"   , "rab"   , "rabs"  , "ras"   ,  /*-- U+B788 .. U+B78F --*/
   "rass"  , "rang"  , "raj"   , "rac"   , "rak"   , "rat"   , "rap"   , "rah"   ,  /*-- U+B790 .. U+B797 --*/
   "rae"   , "raeg"  , "raegg" , "raegs" , "raen"  , "raenj" , "raenh" , "raed"  ,  /*-- U+B798 .. U+B79F --*/
   "rael"  , "raelg" , "raelm" , "raelb" , "raels" , "raelt" , "raelp" , "raelh" ,  /*-- U+B7A0 .. U+B7A7 --*/
   "raem"  , "raeb"  , "raebs" , "raes"  , "raess" , "raeng" , "raej"  , "raec"  ,  /*-- U+B7A8 .. U+B7AF --*/
   "raek"  , "raet"  , "raep"  , "raeh"  , "rya"   , "ryag"  , "ryagg" , "ryags" ,  /*-- U+B7B0 .. U+B7B7 --*/
   "ryan"  , "ryanj" , "ryanh" , "ryad"  , "ryal"  , "ryalg" , "ryalm" , "ryalb" ,  /*-- U+B7B8 .. U+B7BF --*/
   "ryals" , "ryalt" , "ryalp" , "ryalh" , "ryam"  , "ryab"  , "ryabs" , "ryas"  ,  /*-- U+B7C0 .. U+B7C7 --*/
   "ryass" , "ryang" , "ryaj"  , "ryac"  , "ryak"  , "ryat"  , "ryap"  , "ryah"  ,  /*-- U+B7C8 .. U+B7CF --*/
   "ryae"  , "ryaeg" , "ryaegg", "ryaegs", "ryaen" , "ryaenj", "ryaenh", "ryaed" ,  /*-- U+B7D0 .. U+B7D7 --*/
   "ryael" , "ryaelg", "ryaelm", "ryaelb", "ryaels", "ryaelt", "ryaelp", "ryaelh",  /*-- U+B7D8 .. U+B7DF --*/
   "ryaem" , "ryaeb" , "ryaebs", "ryaes" , "ryaess", "ryaeng", "ryaej" , "ryaec" ,  /*-- U+B7E0 .. U+B7E7 --*/
   "ryaek" , "ryaet" , "ryaep" , "ryaeh" , "reo"   , "reog"  , "reogg" , "reogs" ,  /*-- U+B7E8 .. U+B7EF --*/
   "reon"  , "reonj" , "reonh" , "reod"  , "reol"  , "reolg" , "reolm" , "reolb" ,  /*-- U+B7F0 .. U+B7F7 --*/
   "reols" , "reolt" , "reolp" , "reolh" , "reom"  , "reob"  , "reobs" , "reos"  ,  /*-- U+B7F8 .. U+B7FF --*/
   "reoss" , "reong" , "reoj"  , "reoc"  , "reok"  , "reot"  , "reop"  , "reoh"  ,  /*-- U+B800 .. U+B807 --*/
   "re"    , "reg"   , "regg"  , "regs"  , "ren"   , "renj"  , "renh"  , "red"   ,  /*-- U+B808 .. U+B80F --*/
   "rel"   , "relg"  , "relm"  , "relb"  , "rels"  , "relt"  , "relp"  , "relh"  ,  /*-- U+B810 .. U+B817 --*/
   "rem"   , "reb"   , "rebs"  , "res"   , "ress"  , "reng"  , "rej"   , "rec"   ,  /*-- U+B818 .. U+B81F --*/
   "rek"   , "ret"   , "rep"   , "reh"   , "ryeo"  , "ryeog" , "ryeogg", "ryeogs",  /*-- U+B820 .. U+B827 --*/
   "ryeon" , "ryeonj", "ryeonh", "ryeod" , "ryeol" , "ryeolg", "ryeolm", "ryeolb",  /*-- U+B828 .. U+B82F --*/
   "ryeols", "ryeolt", "ryeolp", "ryeolh", "ryeom" , "ryeob" , "ryeobs", "ryeos" ,  /*-- U+B830 .. U+B837 --*/
   "ryeoss", "ryeong", "ryeoj" , "ryeoc" , "ryeok" , "ryeot" , "ryeop" , "ryeoh" ,  /*-- U+B838 .. U+B83F --*/
   "rye"   , "ryeg"  , "ryegg" , "ryegs" , "ryen"  , "ryenj" , "ryenh" , "ryed"  ,  /*-- U+B840 .. U+B847 --*/
   "ryel"  , "ryelg" , "ryelm" , "ryelb" , "ryels" , "ryelt" , "ryelp" , "ryelh" ,  /*-- U+B848 .. U+B84F --*/
   "ryem"  , "ryeb"  , "ryebs" , "ryes"  , "ryess" , "ryeng" , "ryej"  , "ryec"  ,  /*-- U+B850 .. U+B857 --*/
   "ryek"  , "ryet"  , "ryep"  , "ryeh"  , "ro"    , "rog"   , "rogg"  , "rogs"  ,  /*-- U+B858 .. U+B85F --*/
   "ron"   , "ronj"  , "ronh"  , "rod"   , "rol"   , "rolg"  , "rolm"  , "rolb"  ,  /*-- U+B860 .. U+B867 --*/
   "rols"  , "rolt"  , "rolp"  , "rolh"  , "rom"   , "rob"   , "robs"  , "ros"   ,  /*-- U+B868 .. U+B86F --*/
   "ross"  , "rong"  , "roj"   , "roc"   , "rok"   , "rot"   , "rop"   , "roh"   ,  /*-- U+B870 .. U+B877 --*/
   "rwa"   , "rwag"  , "rwagg" , "rwags" , "rwan"  , "rwanj" , "rwanh" , "rwad"  ,  /*-- U+B878 .. U+B87F --*/
   "rwal"  , "rwalg" , "rwalm" , "rwalb" , "rwals" , "rwalt" , "rwalp" , "rwalh" ,  /*-- U+B880 .. U+B887 --*/
   "rwam"  , "rwab"  , "rwabs" , "rwas"  , "rwass" , "rwang" , "rwaj"  , "rwac"  ,  /*-- U+B888 .. U+B88F --*/
   "rwak"  , "rwat"  , "rwap"  , "rwah"  , "rwae"  , "rwaeg" , "rwaegg", "rwaegs",  /*-- U+B890 .. U+B897 --*/
   "rwaen" , "rwaenj", "rwaenh", "rwaed" , "rwael" , "rwaelg", "rwaelm", "rwaelb",  /*-- U+B898 .. U+B89F --*/
   "rwaels", "rwaelt", "rwaelp", "rwaelh", "rwaem" , "rwaeb" , "rwaebs", "rwaes" ,  /*-- U+B8A0 .. U+B8A7 --*/
   "rwaess", "rwaeng", "rwaej" , "rwaec" , "rwaek" , "rwaet" , "rwaep" , "rwaeh" ,  /*-- U+B8A8 .. U+B8AF --*/
   "roe"   , "roeg"  , "roegg" , "roegs" , "roen"  , "roenj" , "roenh" , "roed"  ,  /*-- U+B8B0 .. U+B8B7 --*/
   "roel"  , "roelg" , "roelm" , "roelb" , "roels" , "roelt" , "roelp" , "roelh" ,  /*-- U+B8B8 .. U+B8BF --*/
   "roem"  , "roeb"  , "roebs" , "roes"  , "roess" , "roeng" , "roej"  , "roec"  ,  /*-- U+B8C0 .. U+B8C7 --*/
   "roek"  , "roet"  , "roep"  , "roeh"  , "ryo"   , "ryog"  , "ryogg" , "ryogs" ,  /*-- U+B8C8 .. U+B8CF --*/
   "ryon"  , "ryonj" , "ryonh" , "ryod"  , "ryol"  , "ryolg" , "ryolm" , "ryolb" ,  /*-- U+B8D0 .. U+B8D7 --*/
   "ryols" , "ryolt" , "ryolp" , "ryolh" , "ryom"  , "ryob"  , "ryobs" , "ryos"  ,  /*-- U+B8D8 .. U+B8DF --*/
   "ryoss" , "ryong" , "ryoj"  , "ryoc"  , "ryok"  , "ryot"  , "ryop"  , "ryoh"  ,  /*-- U+B8E0 .. U+B8E7 --*/
   "ru"    , "rug"   , "rugg"  , "rugs"  , "run"   , "runj"  , "runh"  , "rud"   ,  /*-- U+B8E8 .. U+B8EF --*/
   "rul"   , "rulg"  , "rulm"  , "rulb"  , "ruls"  , "rult"  , "rulp"  , "rulh"  ,  /*-- U+B8F0 .. U+B8F7 --*/
   "rum"   , "rub"   , "rubs"  , "rus"   , "russ"  , "rung"  , "ruj"   , "ruc"   ,  /*-- U+B8F8 .. U+B8FF --*/
   "ruk"   , "rut"   , "rup"   , "ruh"   , "rweo"  , "rweog" , "rweogg", "rweogs",  /*-- U+B900 .. U+B907 --*/
   "rweon" , "rweonj", "rweonh", "rweod" , "rweol" , "rweolg", "rweolm", "rweolb",  /*-- U+B908 .. U+B90F --*/
   "rweols", "rweolt", "rweolp", "rweolh", "rweom" , "rweob" , "rweobs", "rweos" ,  /*-- U+B910 .. U+B917 --*/
   "rweoss", "rweong", "rweoj" , "rweoc" , "rweok" , "rweot" , "rweop" , "rweoh" ,  /*-- U+B918 .. U+B91F --*/
   "rwe"   , "rweg"  , "rwegg" , "rwegs" , "rwen"  , "rwenj" , "rwenh" , "rwed"  ,  /*-- U+B920 .. U+B927 --*/
   "rwel"  , "rwelg" , "rwelm" , "rwelb" , "rwels" , "rwelt" , "rwelp" , "rwelh" ,  /*-- U+B928 .. U+B92F --*/
   "rwem"  , "rweb"  , "rwebs" , "rwes"  , "rwess" , "rweng" , "rwej"  , "rwec"  ,  /*-- U+B930 .. U+B937 --*/
   "rwek"  , "rwet"  , "rwep"  , "rweh"  , "rwi"   , "rwig"  , "rwigg" , "rwigs" ,  /*-- U+B938 .. U+B93F --*/
   "rwin"  , "rwinj" , "rwinh" , "rwid"  , "rwil"  , "rwilg" , "rwilm" , "rwilb" ,  /*-- U+B940 .. U+B947 --*/
   "rwils" , "rwilt" , "rwilp" , "rwilh" , "rwim"  , "rwib"  , "rwibs" , "rwis"  ,  /*-- U+B948 .. U+B94F --*/
   "rwiss" , "rwing" , "rwij"  , "rwic"  , "rwik"  , "rwit"  , "rwip"  , "rwih"  ,  /*-- U+B950 .. U+B957 --*/
   "ryu"   , "ryug"  , "ryugg" , "ryugs" , "ryun"  , "ryunj" , "ryunh" , "ryud"  ,  /*-- U+B958 .. U+B95F --*/
   "ryul"  , "ryulg" , "ryulm" , "ryulb" , "ryuls" , "ryult" , "ryulp" , "ryulh" ,  /*-- U+B960 .. U+B967 --*/
   "ryum"  , "ryub"  , "ryubs" , "ryus"  , "ryuss" , "ryung" , "ryuj"  , "ryuc"  ,  /*-- U+B968 .. U+B96F --*/
   "ryuk"  , "ryut"  , "ryup"  , "ryuh"  , "reu"   , "reug"  , "reugg" , "reugs" ,  /*-- U+B970 .. U+B977 --*/
   "reun"  , "reunj" , "reunh" , "reud"  , "reul"  , "reulg" , "reulm" , "reulb" ,  /*-- U+B978 .. U+B97F --*/
   "reuls" , "reult" , "reulp" , "reulh" , "reum"  , "reub"  , "reubs" , "reus"  ,  /*-- U+B980 .. U+B987 --*/
   "reuss" , "reung" , "reuj"  , "reuc"  , "reuk"  , "reut"  , "reup"  , "reuh"  ,  /*-- U+B988 .. U+B98F --*/
   "ryi"   , "ryig"  , "ryigg" , "ryigs" , "ryin"  , "ryinj" , "ryinh" , "ryid"  ,  /*-- U+B990 .. U+B997 --*/
   "ryil"  , "ryilg" , "ryilm" , "ryilb" , "ryils" , "ryilt" , "ryilp" , "ryilh" ,  /*-- U+B998 .. U+B99F --*/
   "ryim"  , "ryib"  , "ryibs" , "ryis"  , "ryiss" , "rying" , "ryij"  , "ryic"  ,  /*-- U+B9A0 .. U+B9A7 --*/
   "ryik"  , "ryit"  , "ryip"  , "ryih"  , "ri"    , "rig"   , "rigg"  , "rigs"  ,  /*-- U+B9A8 .. U+B9AF --*/
   "rin"   , "rinj"  , "rinh"  , "rid"   , "ril"   , "rilg"  , "rilm"  , "rilb"  ,  /*-- U+B9B0 .. U+B9B7 --*/
   "rils"  , "rilt"  , "rilp"  , "rilh"  , "rim"   , "rib"   , "ribs"  , "ris"   ,  /*-- U+B9B8 .. U+B9BF --*/
   "riss"  , "ring"  , "rij"   , "ric"   , "rik"   , "rit"   , "rip"   , "rih"   ,  /*-- U+B9C0 .. U+B9C7 --*/
   "ma"    , "mag"   , "magg"  , "mags"  , "man"   , "manj"  , "manh"  , "mad"   ,  /*-- U+B9C8 .. U+B9CF --*/
   "mal"   , "malg"  , "malm"  , "malb"  , "mals"  , "malt"  , "malp"  , "malh"  ,  /*-- U+B9D0 .. U+B9D7 --*/
   "mam"   , "mab"   , "mabs"  , "mas"   , "mass"  , "mang"  , "maj"   , "mac"   ,  /*-- U+B9D8 .. U+B9DF --*/
   "mak"   , "mat"   , "map"   , "mah"   , "mae"   , "maeg"  , "maegg" , "maegs" ,  /*-- U+B9E0 .. U+B9E7 --*/
   "maen"  , "maenj" , "maenh" , "maed"  , "mael"  , "maelg" , "maelm" , "maelb" ,  /*-- U+B9E8 .. U+B9EF --*/
   "maels" , "maelt" , "maelp" , "maelh" , "maem"  , "maeb"  , "maebs" , "maes"  ,  /*-- U+B9F0 .. U+B9F7 --*/
   "maess" , "maeng" , "maej"  , "maec"  , "maek"  , "maet"  , "maep"  , "maeh"  ,  /*-- U+B9F8 .. U+B9FF --*/
   "mya"   , "myag"  , "myagg" , "myags" , "myan"  , "myanj" , "myanh" , "myad"  ,  /*-- U+BA00 .. U+BA07 --*/
   "myal"  , "myalg" , "myalm" , "myalb" , "myals" , "myalt" , "myalp" , "myalh" ,  /*-- U+BA08 .. U+BA0F --*/
   "myam"  , "myab"  , "myabs" , "myas"  , "myass" , "myang" , "myaj"  , "myac"  ,  /*-- U+BA10 .. U+BA17 --*/
   "myak"  , "myat"  , "myap"  , "myah"  , "myae"  , "myaeg" , "myaegg", "myaegs",  /*-- U+BA18 .. U+BA1F --*/
   "myaen" , "myaenj", "myaenh", "myaed" , "myael" , "myaelg", "myaelm", "myaelb",  /*-- U+BA20 .. U+BA27 --*/
   "myaels", "myaelt", "myaelp", "myaelh", "myaem" , "myaeb" , "myaebs", "myaes" ,  /*-- U+BA28 .. U+BA2F --*/
   "myaess", "myaeng", "myaej" , "myaec" , "myaek" , "myaet" , "myaep" , "myaeh" ,  /*-- U+BA30 .. U+BA37 --*/
   "meo"   , "meog"  , "meogg" , "meogs" , "meon"  , "meonj" , "meonh" , "meod"  ,  /*-- U+BA38 .. U+BA3F --*/
   "meol"  , "meolg" , "meolm" , "meolb" , "meols" , "meolt" , "meolp" , "meolh" ,  /*-- U+BA40 .. U+BA47 --*/
   "meom"  , "meob"  , "meobs" , "meos"  , "meoss" , "meong" , "meoj"  , "meoc"  ,  /*-- U+BA48 .. U+BA4F --*/
   "meok"  , "meot"  , "meop"  , "meoh"  , "me"    , "meg"   , "megg"  , "megs"  ,  /*-- U+BA50 .. U+BA57 --*/
   "men"   , "menj"  , "menh"  , "med"   , "mel"   , "melg"  , "melm"  , "melb"  ,  /*-- U+BA58 .. U+BA5F --*/
   "mels"  , "melt"  , "melp"  , "melh"  , "mem"   , "meb"   , "mebs"  , "mes"   ,  /*-- U+BA60 .. U+BA67 --*/
   "mess"  , "meng"  , "mej"   , "mec"   , "mek"   , "met"   , "mep"   , "meh"   ,  /*-- U+BA68 .. U+BA6F --*/
   "myeo"  , "myeog" , "myeogg", "myeogs", "myeon" , "myeonj", "myeonh", "myeod" ,  /*-- U+BA70 .. U+BA77 --*/
   "myeol" , "myeolg", "myeolm", "myeolb", "myeols", "myeolt", "myeolp", "myeolh",  /*-- U+BA78 .. U+BA7F --*/
   "myeom" , "myeob" , "myeobs", "myeos" , "myeoss", "myeong", "myeoj" , "myeoc" ,  /*-- U+BA80 .. U+BA87 --*/
   "myeok" , "myeot" , "myeop" , "myeoh" , "mye"   , "myeg"  , "myegg" , "myegs" ,  /*-- U+BA88 .. U+BA8F --*/
   "myen"  , "myenj" , "myenh" , "myed"  , "myel"  , "myelg" , "myelm" , "myelb" ,  /*-- U+BA90 .. U+BA97 --*/
   "myels" , "myelt" , "myelp" , "myelh" , "myem"  , "myeb"  , "myebs" , "myes"  ,  /*-- U+BA98 .. U+BA9F --*/
   "myess" , "myeng" , "myej"  , "myec"  , "myek"  , "myet"  , "myep"  , "myeh"  ,  /*-- U+BAA0 .. U+BAA7 --*/
   "mo"    , "mog"   , "mogg"  , "mogs"  , "mon"   , "monj"  , "monh"  , "mod"   ,  /*-- U+BAA8 .. U+BAAF --*/
   "mol"   , "molg"  , "molm"  , "molb"  , "mols"  , "molt"  , "molp"  , "molh"  ,  /*-- U+BAB0 .. U+BAB7 --*/
   "mom"   , "mob"   , "mobs"  , "mos"   , "moss"  , "mong"  , "moj"   , "moc"   ,  /*-- U+BAB8 .. U+BABF --*/
   "mok"   , "mot"   , "mop"   , "moh"   , "mwa"   , "mwag"  , "mwagg" , "mwags" ,  /*-- U+BAC0 .. U+BAC7 --*/
   "mwan"  , "mwanj" , "mwanh" , "mwad"  , "mwal"  , "mwalg" , "mwalm" , "mwalb" ,  /*-- U+BAC8 .. U+BACF --*/
   "mwals" , "mwalt" , "mwalp" , "mwalh" , "mwam"  , "mwab"  , "mwabs" , "mwas"  ,  /*-- U+BAD0 .. U+BAD7 --*/
   "mwass" , "mwang" , "mwaj"  , "mwac"  , "mwak"  , "mwat"  , "mwap"  , "mwah"  ,  /*-- U+BAD8 .. U+BADF --*/
   "mwae"  , "mwaeg" , "mwaegg", "mwaegs", "mwaen" , "mwaenj", "mwaenh", "mwaed" ,  /*-- U+BAE0 .. U+BAE7 --*/
   "mwael" , "mwaelg", "mwaelm", "mwaelb", "mwaels", "mwaelt", "mwaelp", "mwaelh",  /*-- U+BAE8 .. U+BAEF --*/
   "mwaem" , "mwaeb" , "mwaebs", "mwaes" , "mwaess", "mwaeng", "mwaej" , "mwaec" ,  /*-- U+BAF0 .. U+BAF7 --*/
   "mwaek" , "mwaet" , "mwaep" , "mwaeh" , "moe"   , "moeg"  , "moegg" , "moegs" ,  /*-- U+BAF8 .. U+BAFF --*/
   "moen"  , "moenj" , "moenh" , "moed"  , "moel"  , "moelg" , "moelm" , "moelb" ,  /*-- U+BB00 .. U+BB07 --*/
   "moels" , "moelt" , "moelp" , "moelh" , "moem"  , "moeb"  , "moebs" , "moes"  ,  /*-- U+BB08 .. U+BB0F --*/
   "moess" , "moeng" , "moej"  , "moec"  , "moek"  , "moet"  , "moep"  , "moeh"  ,  /*-- U+BB10 .. U+BB17 --*/
   "myo"   , "myog"  , "myogg" , "myogs" , "myon"  , "myonj" , "myonh" , "myod"  ,  /*-- U+BB18 .. U+BB1F --*/
   "myol"  , "myolg" , "myolm" , "myolb" , "myols" , "myolt" , "myolp" , "myolh" ,  /*-- U+BB20 .. U+BB27 --*/
   "myom"  , "myob"  , "myobs" , "myos"  , "myoss" , "myong" , "myoj"  , "myoc"  ,  /*-- U+BB28 .. U+BB2F --*/
   "myok"  , "myot"  , "myop"  , "myoh"  , "mu"    , "mug"   , "mugg"  , "mugs"  ,  /*-- U+BB30 .. U+BB37 --*/
   "mun"   , "munj"  , "munh"  , "mud"   , "mul"   , "mulg"  , "mulm"  , "mulb"  ,  /*-- U+BB38 .. U+BB3F --*/
   "muls"  , "mult"  , "mulp"  , "mulh"  , "mum"   , "mub"   , "mubs"  , "mus"   ,  /*-- U+BB40 .. U+BB47 --*/
   "muss"  , "mung"  , "muj"   , "muc"   , "muk"   , "mut"   , "mup"   , "muh"   ,  /*-- U+BB48 .. U+BB4F --*/
   "mweo"  , "mweog" , "mweogg", "mweogs", "mweon" , "mweonj", "mweonh", "mweod" ,  /*-- U+BB50 .. U+BB57 --*/
   "mweol" , "mweolg", "mweolm", "mweolb", "mweols", "mweolt", "mweolp", "mweolh",  /*-- U+BB58 .. U+BB5F --*/
   "mweom" , "mweob" , "mweobs", "mweos" , "mweoss", "mweong", "mweoj" , "mweoc" ,  /*-- U+BB60 .. U+BB67 --*/
   "mweok" , "mweot" , "mweop" , "mweoh" , "mwe"   , "mweg"  , "mwegg" , "mwegs" ,  /*-- U+BB68 .. U+BB6F --*/
   "mwen"  , "mwenj" , "mwenh" , "mwed"  , "mwel"  , "mwelg" , "mwelm" , "mwelb" ,  /*-- U+BB70 .. U+BB77 --*/
   "mwels" , "mwelt" , "mwelp" , "mwelh" , "mwem"  , "mweb"  , "mwebs" , "mwes"  ,  /*-- U+BB78 .. U+BB7F --*/
   "mwess" , "mweng" , "mwej"  , "mwec"  , "mwek"  , "mwet"  , "mwep"  , "mweh"  ,  /*-- U+BB80 .. U+BB87 --*/
   "mwi"   , "mwig"  , "mwigg" , "mwigs" , "mwin"  , "mwinj" , "mwinh" , "mwid"  ,  /*-- U+BB88 .. U+BB8F --*/
   "mwil"  , "mwilg" , "mwilm" , "mwilb" , "mwils" , "mwilt" , "mwilp" , "mwilh" ,  /*-- U+BB90 .. U+BB97 --*/
   "mwim"  , "mwib"  , "mwibs" , "mwis"  , "mwiss" , "mwing" , "mwij"  , "mwic"  ,  /*-- U+BB98 .. U+BB9F --*/
   "mwik"  , "mwit"  , "mwip"  , "mwih"  , "myu"   , "myug"  , "myugg" , "myugs" ,  /*-- U+BBA0 .. U+BBA7 --*/
   "myun"  , "myunj" , "myunh" , "myud"  , "myul"  , "myulg" , "myulm" , "myulb" ,  /*-- U+BBA8 .. U+BBAF --*/
   "myuls" , "myult" , "myulp" , "myulh" , "myum"  , "myub"  , "myubs" , "myus"  ,  /*-- U+BBB0 .. U+BBB7 --*/
   "myuss" , "myung" , "myuj"  , "myuc"  , "myuk"  , "myut"  , "myup"  , "myuh"  ,  /*-- U+BBB8 .. U+BBBF --*/
   "meu"   , "meug"  , "meugg" , "meugs" , "meun"  , "meunj" , "meunh" , "meud"  ,  /*-- U+BBC0 .. U+BBC7 --*/
   "meul"  , "meulg" , "meulm" , "meulb" , "meuls" , "meult" , "meulp" , "meulh" ,  /*-- U+BBC8 .. U+BBCF --*/
   "meum"  , "meub"  , "meubs" , "meus"  , "meuss" , "meung" , "meuj"  , "meuc"  ,  /*-- U+BBD0 .. U+BBD7 --*/
   "meuk"  , "meut"  , "meup"  , "meuh"  , "myi"   , "myig"  , "myigg" , "myigs" ,  /*-- U+BBD8 .. U+BBDF --*/
   "myin"  , "myinj" , "myinh" , "myid"  , "myil"  , "myilg" , "myilm" , "myilb" ,  /*-- U+BBE0 .. U+BBE7 --*/
   "myils" , "myilt" , "myilp" , "myilh" , "myim"  , "myib"  , "myibs" , "myis"  ,  /*-- U+BBE8 .. U+BBEF --*/
   "myiss" , "mying" , "myij"  , "myic"  , "myik"  , "myit"  , "myip"  , "myih"  ,  /*-- U+BBF0 .. U+BBF7 --*/
   "mi"    , "mig"   , "migg"  , "migs"  , "min"   , "minj"  , "minh"  , "mid"   ,  /*-- U+BBF8 .. U+BBFF --*/
   "mil"   , "milg"  , "milm"  , "milb"  , "mils"  , "milt"  , "milp"  , "milh"  ,  /*-- U+BC00 .. U+BC07 --*/
   "mim"   , "mib"   , "mibs"  , "mis"   , "miss"  , "ming"  , "mij"   , "mic"   ,  /*-- U+BC08 .. U+BC0F --*/
   "mik"   , "mit"   , "mip"   , "mih"   , "ba"    , "bag"   , "bagg"  , "bags"  ,  /*-- U+BC10 .. U+BC17 --*/
   "ban"   , "banj"  , "banh"  , "bad"   , "bal"   , "balg"  , "balm"  , "balb"  ,  /*-- U+BC18 .. U+BC1F --*/
   "bals"  , "balt"  , "balp"  , "balh"  , "bam"   , "bab"   , "babs"  , "bas"   ,  /*-- U+BC20 .. U+BC27 --*/
   "bass"  , "bang"  , "baj"   , "bac"   , "bak"   , "bat"   , "bap"   , "bah"   ,  /*-- U+BC28 .. U+BC2F --*/
   "bae"   , "baeg"  , "baegg" , "baegs" , "baen"  , "baenj" , "baenh" , "baed"  ,  /*-- U+BC30 .. U+BC37 --*/
   "bael"  , "baelg" , "baelm" , "baelb" , "baels" , "baelt" , "baelp" , "baelh" ,  /*-- U+BC38 .. U+BC3F --*/
   "baem"  , "baeb"  , "baebs" , "baes"  , "baess" , "baeng" , "baej"  , "baec"  ,  /*-- U+BC40 .. U+BC47 --*/
   "baek"  , "baet"  , "baep"  , "baeh"  , "bya"   , "byag"  , "byagg" , "byags" ,  /*-- U+BC48 .. U+BC4F --*/
   "byan"  , "byanj" , "byanh" , "byad"  , "byal"  , "byalg" , "byalm" , "byalb" ,  /*-- U+BC50 .. U+BC57 --*/
   "byals" , "byalt" , "byalp" , "byalh" , "byam"  , "byab"  , "byabs" , "byas"  ,  /*-- U+BC58 .. U+BC5F --*/
   "byass" , "byang" , "byaj"  , "byac"  , "byak"  , "byat"  , "byap"  , "byah"  ,  /*-- U+BC60 .. U+BC67 --*/
   "byae"  , "byaeg" , "byaegg", "byaegs", "byaen" , "byaenj", "byaenh", "byaed" ,  /*-- U+BC68 .. U+BC6F --*/
   "byael" , "byaelg", "byaelm", "byaelb", "byaels", "byaelt", "byaelp", "byaelh",  /*-- U+BC70 .. U+BC77 --*/
   "byaem" , "byaeb" , "byaebs", "byaes" , "byaess", "byaeng", "byaej" , "byaec" ,  /*-- U+BC78 .. U+BC7F --*/
   "byaek" , "byaet" , "byaep" , "byaeh" , "beo"   , "beog"  , "beogg" , "beogs" ,  /*-- U+BC80 .. U+BC87 --*/
   "beon"  , "beonj" , "beonh" , "beod"  , "beol"  , "beolg" , "beolm" , "beolb" ,  /*-- U+BC88 .. U+BC8F --*/
   "beols" , "beolt" , "beolp" , "beolh" , "beom"  , "beob"  , "beobs" , "beos"  ,  /*-- U+BC90 .. U+BC97 --*/
   "beoss" , "beong" , "beoj"  , "beoc"  , "beok"  , "beot"  , "beop"  , "beoh"  ,  /*-- U+BC98 .. U+BC9F --*/
   "be"    , "beg"   , "begg"  , "begs"  , "ben"   , "benj"  , "benh"  , "bed"   ,  /*-- U+BCA0 .. U+BCA7 --*/
   "bel"   , "belg"  , "belm"  , "belb"  , "bels"  , "belt"  , "belp"  , "belh"  ,  /*-- U+BCA8 .. U+BCAF --*/
   "bem"   , "beb"   , "bebs"  , "bes"   , "bess"  , "beng"  , "bej"   , "bec"   ,  /*-- U+BCB0 .. U+BCB7 --*/
   "bek"   , "bet"   , "bep"   , "beh"   , "byeo"  , "byeog" , "byeogg", "byeogs",  /*-- U+BCB8 .. U+BCBF --*/
   "byeon" , "byeonj", "byeonh", "byeod" , "byeol" , "byeolg", "byeolm", "byeolb",  /*-- U+BCC0 .. U+BCC7 --*/
   "byeols", "byeolt", "byeolp", "byeolh", "byeom" , "byeob" , "byeobs", "byeos" ,  /*-- U+BCC8 .. U+BCCF --*/
   "byeoss", "byeong", "byeoj" , "byeoc" , "byeok" , "byeot" , "byeop" , "byeoh" ,  /*-- U+BCD0 .. U+BCD7 --*/
   "bye"   , "byeg"  , "byegg" , "byegs" , "byen"  , "byenj" , "byenh" , "byed"  ,  /*-- U+BCD8 .. U+BCDF --*/
   "byel"  , "byelg" , "byelm" , "byelb" , "byels" , "byelt" , "byelp" , "byelh" ,  /*-- U+BCE0 .. U+BCE7 --*/
   "byem"  , "byeb"  , "byebs" , "byes"  , "byess" , "byeng" , "byej"  , "byec"  ,  /*-- U+BCE8 .. U+BCEF --*/
   "byek"  , "byet"  , "byep"  , "byeh"  , "bo"    , "bog"   , "bogg"  , "bogs"  ,  /*-- U+BCF0 .. U+BCF7 --*/
   "bon"   , "bonj"  , "bonh"  , "bod"   , "bol"   , "bolg"  , "bolm"  , "bolb"  ,  /*-- U+BCF8 .. U+BCFF --*/
   "bols"  , "bolt"  , "bolp"  , "bolh"  , "bom"   , "bob"   , "bobs"  , "bos"   ,  /*-- U+BD00 .. U+BD07 --*/
   "boss"  , "bong"  , "boj"   , "boc"   , "bok"   , "bot"   , "bop"   , "boh"   ,  /*-- U+BD08 .. U+BD0F --*/
   "bwa"   , "bwag"  , "bwagg" , "bwags" , "bwan"  , "bwanj" , "bwanh" , "bwad"  ,  /*-- U+BD10 .. U+BD17 --*/
   "bwal"  , "bwalg" , "bwalm" , "bwalb" , "bwals" , "bwalt" , "bwalp" , "bwalh" ,  /*-- U+BD18 .. U+BD1F --*/
   "bwam"  , "bwab"  , "bwabs" , "bwas"  , "bwass" , "bwang" , "bwaj"  , "bwac"  ,  /*-- U+BD20 .. U+BD27 --*/
   "bwak"  , "bwat"  , "bwap"  , "bwah"  , "bwae"  , "bwaeg" , "bwaegg", "bwaegs",  /*-- U+BD28 .. U+BD2F --*/
   "bwaen" , "bwaenj", "bwaenh", "bwaed" , "bwael" , "bwaelg", "bwaelm", "bwaelb",  /*-- U+BD30 .. U+BD37 --*/
   "bwaels", "bwaelt", "bwaelp", "bwaelh", "bwaem" , "bwaeb" , "bwaebs", "bwaes" ,  /*-- U+BD38 .. U+BD3F --*/
   "bwaess", "bwaeng", "bwaej" , "bwaec" , "bwaek" , "bwaet" , "bwaep" , "bwaeh" ,  /*-- U+BD40 .. U+BD47 --*/
   "boe"   , "boeg"  , "boegg" , "boegs" , "boen"  , "boenj" , "boenh" , "boed"  ,  /*-- U+BD48 .. U+BD4F --*/
   "boel"  , "boelg" , "boelm" , "boelb" , "boels" , "boelt" , "boelp" , "boelh" ,  /*-- U+BD50 .. U+BD57 --*/
   "boem"  , "boeb"  , "boebs" , "boes"  , "boess" , "boeng" , "boej"  , "boec"  ,  /*-- U+BD58 .. U+BD5F --*/
   "boek"  , "boet"  , "boep"  , "boeh"  , "byo"   , "byog"  , "byogg" , "byogs" ,  /*-- U+BD60 .. U+BD67 --*/
   "byon"  , "byonj" , "byonh" , "byod"  , "byol"  , "byolg" , "byolm" , "byolb" ,  /*-- U+BD68 .. U+BD6F --*/
   "byols" , "byolt" , "byolp" , "byolh" , "byom"  , "byob"  , "byobs" , "byos"  ,  /*-- U+BD70 .. U+BD77 --*/
   "byoss" , "byong" , "byoj"  , "byoc"  , "byok"  , "byot"  , "byop"  , "byoh"  ,  /*-- U+BD78 .. U+BD7F --*/
   "bu"    , "bug"   , "bugg"  , "bugs"  , "bun"   , "bunj"  , "bunh"  , "bud"   ,  /*-- U+BD80 .. U+BD87 --*/
   "bul"   , "bulg"  , "bulm"  , "bulb"  , "buls"  , "bult"  , "bulp"  , "bulh"  ,  /*-- U+BD88 .. U+BD8F --*/
   "bum"   , "bub"   , "bubs"  , "bus"   , "buss"  , "bung"  , "buj"   , "buc"   ,  /*-- U+BD90 .. U+BD97 --*/
   "buk"   , "but"   , "bup"   , "buh"   , "bweo"  , "bweog" , "bweogg", "bweogs",  /*-- U+BD98 .. U+BD9F --*/
   "bweon" , "bweonj", "bweonh", "bweod" , "bweol" , "bweolg", "bweolm", "bweolb",  /*-- U+BDA0 .. U+BDA7 --*/
   "bweols", "bweolt", "bweolp", "bweolh", "bweom" , "bweob" , "bweobs", "bweos" ,  /*-- U+BDA8 .. U+BDAF --*/
   "bweoss", "bweong", "bweoj" , "bweoc" , "bweok" , "bweot" , "bweop" , "bweoh" ,  /*-- U+BDB0 .. U+BDB7 --*/
   "bwe"   , "bweg"  , "bwegg" , "bwegs" , "bwen"  , "bwenj" , "bwenh" , "bwed"  ,  /*-- U+BDB8 .. U+BDBF --*/
   "bwel"  , "bwelg" , "bwelm" , "bwelb" , "bwels" , "bwelt" , "bwelp" , "bwelh" ,  /*-- U+BDC0 .. U+BDC7 --*/
   "bwem"  , "bweb"  , "bwebs" , "bwes"  , "bwess" , "bweng" , "bwej"  , "bwec"  ,  /*-- U+BDC8 .. U+BDCF --*/
   "bwek"  , "bwet"  , "bwep"  , "bweh"  , "bwi"   , "bwig"  , "bwigg" , "bwigs" ,  /*-- U+BDD0 .. U+BDD7 --*/
   "bwin"  , "bwinj" , "bwinh" , "bwid"  , "bwil"  , "bwilg" , "bwilm" , "bwilb" ,  /*-- U+BDD8 .. U+BDDF --*/
   "bwils" , "bwilt" , "bwilp" , "bwilh" , "bwim"  , "bwib"  , "bwibs" , "bwis"  ,  /*-- U+BDE0 .. U+BDE7 --*/
   "bwiss" , "bwing" , "bwij"  , "bwic"  , "bwik"  , "bwit"  , "bwip"  , "bwih"  ,  /*-- U+BDE8 .. U+BDEF --*/
   "byu"   , "byug"  , "byugg" , "byugs" , "byun"  , "byunj" , "byunh" , "byud"  ,  /*-- U+BDF0 .. U+BDF7 --*/
   "byul"  , "byulg" , "byulm" , "byulb" , "byuls" , "byult" , "byulp" , "byulh" ,  /*-- U+BDF8 .. U+BDFF --*/
   "byum"  , "byub"  , "byubs" , "byus"  , "byuss" , "byung" , "byuj"  , "byuc"  ,  /*-- U+BE00 .. U+BE07 --*/
   "byuk"  , "byut"  , "byup"  , "byuh"  , "beu"   , "beug"  , "beugg" , "beugs" ,  /*-- U+BE08 .. U+BE0F --*/
   "beun"  , "beunj" , "beunh" , "beud"  , "beul"  , "beulg" , "beulm" , "beulb" ,  /*-- U+BE10 .. U+BE17 --*/
   "beuls" , "beult" , "beulp" , "beulh" , "beum"  , "beub"  , "beubs" , "beus"  ,  /*-- U+BE18 .. U+BE1F --*/
   "beuss" , "beung" , "beuj"  , "beuc"  , "beuk"  , "beut"  , "beup"  , "beuh"  ,  /*-- U+BE20 .. U+BE27 --*/
   "byi"   , "byig"  , "byigg" , "byigs" , "byin"  , "byinj" , "byinh" , "byid"  ,  /*-- U+BE28 .. U+BE2F --*/
   "byil"  , "byilg" , "byilm" , "byilb" , "byils" , "byilt" , "byilp" , "byilh" ,  /*-- U+BE30 .. U+BE37 --*/
   "byim"  , "byib"  , "byibs" , "byis"  , "byiss" , "bying" , "byij"  , "byic"  ,  /*-- U+BE38 .. U+BE3F --*/
   "byik"  , "byit"  , "byip"  , "byih"  , "bi"    , "big"   , "bigg"  , "bigs"  ,  /*-- U+BE40 .. U+BE47 --*/
   "bin"   , "binj"  , "binh"  , "bid"   , "bil"   , "bilg"  , "bilm"  , "bilb"  ,  /*-- U+BE48 .. U+BE4F --*/
   "bils"  , "bilt"  , "bilp"  , "bilh"  , "bim"   , "bib"   , "bibs"  , "bis"   ,  /*-- U+BE50 .. U+BE57 --*/
   "biss"  , "bing"  , "bij"   , "bic"   , "bik"   , "bit"   , "bip"   , "bih"   ,  /*-- U+BE58 .. U+BE5F --*/
   "bba"   , "bbag"  , "bbagg" , "bbags" , "bban"  , "bbanj" , "bbanh" , "bbad"  ,  /*-- U+BE60 .. U+BE67 --*/
   "bbal"  , "bbalg" , "bbalm" , "bbalb" , "bbals" , "bbalt" , "bbalp" , "bbalh" ,  /*-- U+BE68 .. U+BE6F --*/
   "bbam"  , "bbab"  , "bbabs" , "bbas"  , "bbass" , "bbang" , "bbaj"  , "bbac"  ,  /*-- U+BE70 .. U+BE77 --*/
   "bbak"  , "bbat"  , "bbap"  , "bbah"  , "bbae"  , "bbaeg" , "bbaegg", "bbaegs",  /*-- U+BE78 .. U+BE7F --*/
   "bbaen" , "bbaenj", "bbaenh", "bbaed" , "bbael" , "bbaelg", "bbaelm", "bbaelb",  /*-- U+BE80 .. U+BE87 --*/
   "bbaels", "bbaelt", "bbaelp", "bbaelh", "bbaem" , "bbaeb" , "bbaebs", "bbaes" ,  /*-- U+BE88 .. U+BE8F --*/
   "bbaess", "bbaeng", "bbaej" , "bbaec" , "bbaek" , "bbaet" , "bbaep" , "bbaeh" ,  /*-- U+BE90 .. U+BE97 --*/
   "bbya"  , "bbyag" , "bbyagg", "bbyags", "bbyan" , "bbyanj", "bbyanh", "bbyad" ,  /*-- U+BE98 .. U+BE9F --*/
   "bbyal" , "bbyalg", "bbyalm", "bbyalb", "bbyals", "bbyalt", "bbyalp", "bbyalh",  /*-- U+BEA0 .. U+BEA7 --*/
   "bbyam" , "bbyab" , "bbyabs", "bbyas" , "bbyass", "bbyang", "bbyaj" , "bbyac" ,  /*-- U+BEA8 .. U+BEAF --*/
   "bbyak" , "bbyat" , "bbyap" , "bbyah" , "bbyae" , "bbyaeg", "bbyaegg", "bbyaegs",  /*-- U+BEB0 .. U+BEB7 --*/
   "bbyaen", "bbyaenj", "bbyaenh", "bbyaed", "bbyael", "bbyaelg", "bbyaelm", "bbyaelb",  /*-- U+BEB8 .. U+BEBF --*/
   "bbyaels", "bbyaelt", "bbyaelp", "bbyaelh", "bbyaem", "bbyaeb", "bbyaebs", "bbyaes",  /*-- U+BEC0 .. U+BEC7 --*/
   "bbyaess", "bbyaeng", "bbyaej", "bbyaec", "bbyaek", "bbyaet", "bbyaep", "bbyaeh",  /*-- U+BEC8 .. U+BECF --*/
   "bbeo"  , "bbeog" , "bbeogg", "bbeogs", "bbeon" , "bbeonj", "bbeonh", "bbeod" ,  /*-- U+BED0 .. U+BED7 --*/
   "bbeol" , "bbeolg", "bbeolm", "bbeolb", "bbeols", "bbeolt", "bbeolp", "bbeolh",  /*-- U+BED8 .. U+BEDF --*/
   "bbeom" , "bbeob" , "bbeobs", "bbeos" , "bbeoss", "bbeong", "bbeoj" , "bbeoc" ,  /*-- U+BEE0 .. U+BEE7 --*/
   "bbeok" , "bbeot" , "bbeop" , "bbeoh" , "bbe"   , "bbeg"  , "bbegg" , "bbegs" ,  /*-- U+BEE8 .. U+BEEF --*/
   "bben"  , "bbenj" , "bbenh" , "bbed"  , "bbel"  , "bbelg" , "bbelm" , "bbelb" ,  /*-- U+BEF0 .. U+BEF7 --*/
   "bbels" , "bbelt" , "bbelp" , "bbelh" , "bbem"  , "bbeb"  , "bbebs" , "bbes"  ,  /*-- U+BEF8 .. U+BEFF --*/
   "bbess" , "bbeng" , "bbej"  , "bbec"  , "bbek"  , "bbet"  , "bbep"  , "bbeh"  ,  /*-- U+BF00 .. U+BF07 --*/
   "bbyeo" , "bbyeog", "bbyeogg", "bbyeogs", "bbyeon", "bbyeonj", "bbyeonh", "bbyeod",  /*-- U+BF08 .. U+BF0F --*/
   "bbyeol", "bbyeolg", "bbyeolm", "bbyeolb", "bbyeols", "bbyeolt", "bbyeolp", "bbyeolh",  /*-- U+BF10 .. U+BF17 --*/
   "bbyeom", "bbyeob", "bbyeobs", "bbyeos", "bbyeoss", "bbyeong", "bbyeoj", "bbyeoc",  /*-- U+BF18 .. U+BF1F --*/
   "bbyeok", "bbyeot", "bbyeop", "bbyeoh", "bbye"  , "bbyeg" , "bbyegg", "bbyegs",  /*-- U+BF20 .. U+BF27 --*/
   "bbyen" , "bbyenj", "bbyenh", "bbyed" , "bbyel" , "bbyelg", "bbyelm", "bbyelb",  /*-- U+BF28 .. U+BF2F --*/
   "bbyels", "bbyelt", "bbyelp", "bbyelh", "bbyem" , "bbyeb" , "bbyebs", "bbyes" ,  /*-- U+BF30 .. U+BF37 --*/
   "bbyess", "bbyeng", "bbyej" , "bbyec" , "bbyek" , "bbyet" , "bbyep" , "bbyeh" ,  /*-- U+BF38 .. U+BF3F --*/
   "bbo"   , "bbog"  , "bbogg" , "bbogs" , "bbon"  , "bbonj" , "bbonh" , "bbod"  ,  /*-- U+BF40 .. U+BF47 --*/
   "bbol"  , "bbolg" , "bbolm" , "bbolb" , "bbols" , "bbolt" , "bbolp" , "bbolh" ,  /*-- U+BF48 .. U+BF4F --*/
   "bbom"  , "bbob"  , "bbobs" , "bbos"  , "bboss" , "bbong" , "bboj"  , "bboc"  ,  /*-- U+BF50 .. U+BF57 --*/
   "bbok"  , "bbot"  , "bbop"  , "bboh"  , "bbwa"  , "bbwag" , "bbwagg", "bbwags",  /*-- U+BF58 .. U+BF5F --*/
   "bbwan" , "bbwanj", "bbwanh", "bbwad" , "bbwal" , "bbwalg", "bbwalm", "bbwalb",  /*-- U+BF60 .. U+BF67 --*/
   "bbwals", "bbwalt", "bbwalp", "bbwalh", "bbwam" , "bbwab" , "bbwabs", "bbwas" ,  /*-- U+BF68 .. U+BF6F --*/
   "bbwass", "bbwang", "bbwaj" , "bbwac" , "bbwak" , "bbwat" , "bbwap" , "bbwah" ,  /*-- U+BF70 .. U+BF77 --*/
   "bbwae" , "bbwaeg", "bbwaegg", "bbwaegs", "bbwaen", "bbwaenj", "bbwaenh", "bbwaed",  /*-- U+BF78 .. U+BF7F --*/
   "bbwael", "bbwaelg", "bbwaelm", "bbwaelb", "bbwaels", "bbwaelt", "bbwaelp", "bbwaelh",  /*-- U+BF80 .. U+BF87 --*/
   "bbwaem", "bbwaeb", "bbwaebs", "bbwaes", "bbwaess", "bbwaeng", "bbwaej", "bbwaec",  /*-- U+BF88 .. U+BF8F --*/
   "bbwaek", "bbwaet", "bbwaep", "bbwaeh", "bboe"  , "bboeg" , "bboegg", "bboegs",  /*-- U+BF90 .. U+BF97 --*/
   "bboen" , "bboenj", "bboenh", "bboed" , "bboel" , "bboelg", "bboelm", "bboelb",  /*-- U+BF98 .. U+BF9F --*/
   "bboels", "bboelt", "bboelp", "bboelh", "bboem" , "bboeb" , "bboebs", "bboes" ,  /*-- U+BFA0 .. U+BFA7 --*/
   "bboess", "bboeng", "bboej" , "bboec" , "bboek" , "bboet" , "bboep" , "bboeh" ,  /*-- U+BFA8 .. U+BFAF --*/
   "bbyo"  , "bbyog" , "bbyogg", "bbyogs", "bbyon" , "bbyonj", "bbyonh", "bbyod" ,  /*-- U+BFB0 .. U+BFB7 --*/
   "bbyol" , "bbyolg", "bbyolm", "bbyolb", "bbyols", "bbyolt", "bbyolp", "bbyolh",  /*-- U+BFB8 .. U+BFBF --*/
   "bbyom" , "bbyob" , "bbyobs", "bbyos" , "bbyoss", "bbyong", "bbyoj" , "bbyoc" ,  /*-- U+BFC0 .. U+BFC7 --*/
   "bbyok" , "bbyot" , "bbyop" , "bbyoh" , "bbu"   , "bbug"  , "bbugg" , "bbugs" ,  /*-- U+BFC8 .. U+BFCF --*/
   "bbun"  , "bbunj" , "bbunh" , "bbud"  , "bbul"  , "bbulg" , "bbulm" , "bbulb" ,  /*-- U+BFD0 .. U+BFD7 --*/
   "bbuls" , "bbult" , "bbulp" , "bbulh" , "bbum"  , "bbub"  , "bbubs" , "bbus"  ,  /*-- U+BFD8 .. U+BFDF --*/
   "bbuss" , "bbung" , "bbuj"  , "bbuc"  , "bbuk"  , "bbut"  , "bbup"  , "bbuh"  ,  /*-- U+BFE0 .. U+BFE7 --*/
   "bbweo" , "bbweog", "bbweogg", "bbweogs", "bbweon", "bbweonj", "bbweonh", "bbweod",  /*-- U+BFE8 .. U+BFEF --*/
   "bbweol", "bbweolg", "bbweolm", "bbweolb", "bbweols", "bbweolt", "bbweolp", "bbweolh",  /*-- U+BFF0 .. U+BFF7 --*/
   "bbweom", "bbweob", "bbweobs", "bbweos", "bbweoss", "bbweong", "bbweoj", "bbweoc",  /*-- U+BFF8 .. U+BFFF --*/
   "bbweok", "bbweot", "bbweop", "bbweoh", "bbwe"  , "bbweg" , "bbwegg", "bbwegs",  /*-- U+C000 .. U+C007 --*/
   "bbwen" , "bbwenj", "bbwenh", "bbwed" , "bbwel" , "bbwelg", "bbwelm", "bbwelb",  /*-- U+C008 .. U+C00F --*/
   "bbwels", "bbwelt", "bbwelp", "bbwelh", "bbwem" , "bbweb" , "bbwebs", "bbwes" ,  /*-- U+C010 .. U+C017 --*/
   "bbwess", "bbweng", "bbwej" , "bbwec" , "bbwek" , "bbwet" , "bbwep" , "bbweh" ,  /*-- U+C018 .. U+C01F --*/
   "bbwi"  , "bbwig" , "bbwigg", "bbwigs", "bbwin" , "bbwinj", "bbwinh", "bbwid" ,  /*-- U+C020 .. U+C027 --*/
   "bbwil" , "bbwilg", "bbwilm", "bbwilb", "bbwils", "bbwilt", "bbwilp", "bbwilh",  /*-- U+C028 .. U+C02F --*/
   "bbwim" , "bbwib" , "bbwibs", "bbwis" , "bbwiss", "bbwing", "bbwij" , "bbwic" ,  /*-- U+C030 .. U+C037 --*/
   "bbwik" , "bbwit" , "bbwip" , "bbwih" , "bbyu"  , "bbyug" , "bbyugg", "bbyugs",  /*-- U+C038 .. U+C03F --*/
   "bbyun" , "bbyunj", "bbyunh", "bbyud" , "bbyul" , "bbyulg", "bbyulm", "bbyulb",  /*-- U+C040 .. U+C047 --*/
   "bbyuls", "bbyult", "bbyulp", "bbyulh", "bbyum" , "bbyub" , "bbyubs", "bbyus" ,  /*-- U+C048 .. U+C04F --*/
   "bbyuss", "bbyung", "bbyuj" , "bbyuc" , "bbyuk" , "bbyut" , "bbyup" , "bbyuh" ,  /*-- U+C050 .. U+C057 --*/
   "bbeu"  , "bbeug" , "bbeugg", "bbeugs", "bbeun" , "bbeunj", "bbeunh", "bbeud" ,  /*-- U+C058 .. U+C05F --*/
   "bbeul" , "bbeulg", "bbeulm", "bbeulb", "bbeuls", "bbeult", "bbeulp", "bbeulh",  /*-- U+C060 .. U+C067 --*/
   "bbeum" , "bbeub" , "bbeubs", "bbeus" , "bbeuss", "bbeung", "bbeuj" , "bbeuc" ,  /*-- U+C068 .. U+C06F --*/
   "bbeuk" , "bbeut" , "bbeup" , "bbeuh" , "bbyi"  , "bbyig" , "bbyigg", "bbyigs",  /*-- U+C070 .. U+C077 --*/
   "bbyin" , "bbyinj", "bbyinh", "bbyid" , "bbyil" , "bbyilg", "bbyilm", "bbyilb",  /*-- U+C078 .. U+C07F --*/
   "bbyils", "bbyilt", "bbyilp", "bbyilh", "bbyim" , "bbyib" , "bbyibs", "bbyis" ,  /*-- U+C080 .. U+C087 --*/
   "bbyiss", "bbying", "bbyij" , "bbyic" , "bbyik" , "bbyit" , "bbyip" , "bbyih" ,  /*-- U+C088 .. U+C08F --*/
   "bbi"   , "bbig"  , "bbigg" , "bbigs" , "bbin"  , "bbinj" , "bbinh" , "bbid"  ,  /*-- U+C090 .. U+C097 --*/
   "bbil"  , "bbilg" , "bbilm" , "bbilb" , "bbils" , "bbilt" , "bbilp" , "bbilh" ,  /*-- U+C098 .. U+C09F --*/
   "bbim"  , "bbib"  , "bbibs" , "bbis"  , "bbiss" , "bbing" , "bbij"  , "bbic"  ,  /*-- U+C0A0 .. U+C0A7 --*/
   "bbik"  , "bbit"  , "bbip"  , "bbih"  , "sa"    , "sag"   , "sagg"  , "sags"  ,  /*-- U+C0A8 .. U+C0AF --*/
   "san"   , "sanj"  , "sanh"  , "sad"   , "sal"   , "salg"  , "salm"  , "salb"  ,  /*-- U+C0B0 .. U+C0B7 --*/
   "sals"  , "salt"  , "salp"  , "salh"  , "sam"   , "sab"   , "sabs"  , "sas"   ,  /*-- U+C0B8 .. U+C0BF --*/
   "sass"  , "sang"  , "saj"   , "sac"   , "sak"   , "sat"   , "sap"   , "sah"   ,  /*-- U+C0C0 .. U+C0C7 --*/
   "sae"   , "saeg"  , "saegg" , "saegs" , "saen"  , "saenj" , "saenh" , "saed"  ,  /*-- U+C0C8 .. U+C0CF --*/
   "sael"  , "saelg" , "saelm" , "saelb" , "saels" , "saelt" , "saelp" , "saelh" ,  /*-- U+C0D0 .. U+C0D7 --*/
   "saem"  , "saeb"  , "saebs" , "saes"  , "saess" , "saeng" , "saej"  , "saec"  ,  /*-- U+C0D8 .. U+C0DF --*/
   "saek"  , "saet"  , "saep"  , "saeh"  , "sya"   , "syag"  , "syagg" , "syags" ,  /*-- U+C0E0 .. U+C0E7 --*/
   "syan"  , "syanj" , "syanh" , "syad"  , "syal"  , "syalg" , "syalm" , "syalb" ,  /*-- U+C0E8 .. U+C0EF --*/
   "syals" , "syalt" , "syalp" , "syalh" , "syam"  , "syab"  , "syabs" , "syas"  ,  /*-- U+C0F0 .. U+C0F7 --*/
   "syass" , "syang" , "syaj"  , "syac"  , "syak"  , "syat"  , "syap"  , "syah"  ,  /*-- U+C0F8 .. U+C0FF --*/
   "syae"  , "syaeg" , "syaegg", "syaegs", "syaen" , "syaenj", "syaenh", "syaed" ,  /*-- U+C100 .. U+C107 --*/
   "syael" , "syaelg", "syaelm", "syaelb", "syaels", "syaelt", "syaelp", "syaelh",  /*-- U+C108 .. U+C10F --*/
   "syaem" , "syaeb" , "syaebs", "syaes" , "syaess", "syaeng", "syaej" , "syaec" ,  /*-- U+C110 .. U+C117 --*/
   "syaek" , "syaet" , "syaep" , "syaeh" , "seo"   , "seog"  , "seogg" , "seogs" ,  /*-- U+C118 .. U+C11F --*/
   "seon"  , "seonj" , "seonh" , "seod"  , "seol"  , "seolg" , "seolm" , "seolb" ,  /*-- U+C120 .. U+C127 --*/
   "seols" , "seolt" , "seolp" , "seolh" , "seom"  , "seob"  , "seobs" , "seos"  ,  /*-- U+C128 .. U+C12F --*/
   "seoss" , "seong" , "seoj"  , "seoc"  , "seok"  , "seot"  , "seop"  , "seoh"  ,  /*-- U+C130 .. U+C137 --*/
   "se"    , "seg"   , "segg"  , "segs"  , "sen"   , "senj"  , "senh"  , "sed"   ,  /*-- U+C138 .. U+C13F --*/
   "sel"   , "selg"  , "selm"  , "selb"  , "sels"  , "selt"  , "selp"  , "selh"  ,  /*-- U+C140 .. U+C147 --*/
   "sem"   , "seb"   , "sebs"  , "ses"   , "sess"  , "seng"  , "sej"   , "sec"   ,  /*-- U+C148 .. U+C14F --*/
   "sek"   , "set"   , "sep"   , "seh"   , "syeo"  , "syeog" , "syeogg", "syeogs",  /*-- U+C150 .. U+C157 --*/
   "syeon" , "syeonj", "syeonh", "syeod" , "syeol" , "syeolg", "syeolm", "syeolb",  /*-- U+C158 .. U+C15F --*/
   "syeols", "syeolt", "syeolp", "syeolh", "syeom" , "syeob" , "syeobs", "syeos" ,  /*-- U+C160 .. U+C167 --*/
   "syeoss", "syeong", "syeoj" , "syeoc" , "syeok" , "syeot" , "syeop" , "syeoh" ,  /*-- U+C168 .. U+C16F --*/
   "sye"   , "syeg"  , "syegg" , "syegs" , "syen"  , "syenj" , "syenh" , "syed"  ,  /*-- U+C170 .. U+C177 --*/
   "syel"  , "syelg" , "syelm" , "syelb" , "syels" , "syelt" , "syelp" , "syelh" ,  /*-- U+C178 .. U+C17F --*/
   "syem"  , "syeb"  , "syebs" , "syes"  , "syess" , "syeng" , "syej"  , "syec"  ,  /*-- U+C180 .. U+C187 --*/
   "syek"  , "syet"  , "syep"  , "syeh"  , "so"    , "sog"   , "sogg"  , "sogs"  ,  /*-- U+C188 .. U+C18F --*/
   "son"   , "sonj"  , "sonh"  , "sod"   , "sol"   , "solg"  , "solm"  , "solb"  ,  /*-- U+C190 .. U+C197 --*/
   "sols"  , "solt"  , "solp"  , "solh"  , "som"   , "sob"   , "sobs"  , "sos"   ,  /*-- U+C198 .. U+C19F --*/
   "soss"  , "song"  , "soj"   , "soc"   , "sok"   , "sot"   , "sop"   , "soh"   ,  /*-- U+C1A0 .. U+C1A7 --*/
   "swa"   , "swag"  , "swagg" , "swags" , "swan"  , "swanj" , "swanh" , "swad"  ,  /*-- U+C1A8 .. U+C1AF --*/
   "swal"  , "swalg" , "swalm" , "swalb" , "swals" , "swalt" , "swalp" , "swalh" ,  /*-- U+C1B0 .. U+C1B7 --*/
   "swam"  , "swab"  , "swabs" , "swas"  , "swass" , "swang" , "swaj"  , "swac"  ,  /*-- U+C1B8 .. U+C1BF --*/
   "swak"  , "swat"  , "swap"  , "swah"  , "swae"  , "swaeg" , "swaegg", "swaegs",  /*-- U+C1C0 .. U+C1C7 --*/
   "swaen" , "swaenj", "swaenh", "swaed" , "swael" , "swaelg", "swaelm", "swaelb",  /*-- U+C1C8 .. U+C1CF --*/
   "swaels", "swaelt", "swaelp", "swaelh", "swaem" , "swaeb" , "swaebs", "swaes" ,  /*-- U+C1D0 .. U+C1D7 --*/
   "swaess", "swaeng", "swaej" , "swaec" , "swaek" , "swaet" , "swaep" , "swaeh" ,  /*-- U+C1D8 .. U+C1DF --*/
   "soe"   , "soeg"  , "soegg" , "soegs" , "soen"  , "soenj" , "soenh" , "soed"  ,  /*-- U+C1E0 .. U+C1E7 --*/
   "soel"  , "soelg" , "soelm" , "soelb" , "soels" , "soelt" , "soelp" , "soelh" ,  /*-- U+C1E8 .. U+C1EF --*/
   "soem"  , "soeb"  , "soebs" , "soes"  , "soess" , "soeng" , "soej"  , "soec"  ,  /*-- U+C1F0 .. U+C1F7 --*/
   "soek"  , "soet"  , "soep"  , "soeh"  , "syo"   , "syog"  , "syogg" , "syogs" ,  /*-- U+C1F8 .. U+C1FF --*/
   "syon"  , "syonj" , "syonh" , "syod"  , "syol"  , "syolg" , "syolm" , "syolb" ,  /*-- U+C200 .. U+C207 --*/
   "syols" , "syolt" , "syolp" , "syolh" , "syom"  , "syob"  , "syobs" , "syos"  ,  /*-- U+C208 .. U+C20F --*/
   "syoss" , "syong" , "syoj"  , "syoc"  , "syok"  , "syot"  , "syop"  , "syoh"  ,  /*-- U+C210 .. U+C217 --*/
   "su"    , "sug"   , "sugg"  , "sugs"  , "sun"   , "sunj"  , "sunh"  , "sud"   ,  /*-- U+C218 .. U+C21F --*/
   "sul"   , "sulg"  , "sulm"  , "sulb"  , "suls"  , "sult"  , "sulp"  , "sulh"  ,  /*-- U+C220 .. U+C227 --*/
   "sum"   , "sub"   , "subs"  , "sus"   , "suss"  , "sung"  , "suj"   , "suc"   ,  /*-- U+C228 .. U+C22F --*/
   "suk"   , "sut"   , "sup"   , "suh"   , "sweo"  , "sweog" , "sweogg", "sweogs",  /*-- U+C230 .. U+C237 --*/
   "sweon" , "sweonj", "sweonh", "sweod" , "sweol" , "sweolg", "sweolm", "sweolb",  /*-- U+C238 .. U+C23F --*/
   "sweols", "sweolt", "sweolp", "sweolh", "sweom" , "sweob" , "sweobs", "sweos" ,  /*-- U+C240 .. U+C247 --*/
   "sweoss", "sweong", "sweoj" , "sweoc" , "sweok" , "sweot" , "sweop" , "sweoh" ,  /*-- U+C248 .. U+C24F --*/
   "swe"   , "sweg"  , "swegg" , "swegs" , "swen"  , "swenj" , "swenh" , "swed"  ,  /*-- U+C250 .. U+C257 --*/
   "swel"  , "swelg" , "swelm" , "swelb" , "swels" , "swelt" , "swelp" , "swelh" ,  /*-- U+C258 .. U+C25F --*/
   "swem"  , "sweb"  , "swebs" , "swes"  , "swess" , "sweng" , "swej"  , "swec"  ,  /*-- U+C260 .. U+C267 --*/
   "swek"  , "swet"  , "swep"  , "sweh"  , "swi"   , "swig"  , "swigg" , "swigs" ,  /*-- U+C268 .. U+C26F --*/
   "swin"  , "swinj" , "swinh" , "swid"  , "swil"  , "swilg" , "swilm" , "swilb" ,  /*-- U+C270 .. U+C277 --*/
   "swils" , "swilt" , "swilp" , "swilh" , "swim"  , "swib"  , "swibs" , "swis"  ,  /*-- U+C278 .. U+C27F --*/
   "swiss" , "swing" , "swij"  , "swic"  , "swik"  , "swit"  , "swip"  , "swih"  ,  /*-- U+C280 .. U+C287 --*/
   "syu"   , "syug"  , "syugg" , "syugs" , "syun"  , "syunj" , "syunh" , "syud"  ,  /*-- U+C288 .. U+C28F --*/
   "syul"  , "syulg" , "syulm" , "syulb" , "syuls" , "syult" , "syulp" , "syulh" ,  /*-- U+C290 .. U+C297 --*/
   "syum"  , "syub"  , "syubs" , "syus"  , "syuss" , "syung" , "syuj"  , "syuc"  ,  /*-- U+C298 .. U+C29F --*/
   "syuk"  , "syut"  , "syup"  , "syuh"  , "seu"   , "seug"  , "seugg" , "seugs" ,  /*-- U+C2A0 .. U+C2A7 --*/
   "seun"  , "seunj" , "seunh" , "seud"  , "seul"  , "seulg" , "seulm" , "seulb" ,  /*-- U+C2A8 .. U+C2AF --*/
   "seuls" , "seult" , "seulp" , "seulh" , "seum"  , "seub"  , "seubs" , "seus"  ,  /*-- U+C2B0 .. U+C2B7 --*/
   "seuss" , "seung" , "seuj"  , "seuc"  , "seuk"  , "seut"  , "seup"  , "seuh"  ,  /*-- U+C2B8 .. U+C2BF --*/
   "syi"   , "syig"  , "syigg" , "syigs" , "syin"  , "syinj" , "syinh" , "syid"  ,  /*-- U+C2C0 .. U+C2C7 --*/
   "syil"  , "syilg" , "syilm" , "syilb" , "syils" , "syilt" , "syilp" , "syilh" ,  /*-- U+C2C8 .. U+C2CF --*/
   "syim"  , "syib"  , "syibs" , "syis"  , "syiss" , "sying" , "syij"  , "syic"  ,  /*-- U+C2D0 .. U+C2D7 --*/
   "syik"  , "syit"  , "syip"  , "syih"  , "si"    , "sig"   , "sigg"  , "sigs"  ,  /*-- U+C2D8 .. U+C2DF --*/
   "sin"   , "sinj"  , "sinh"  , "sid"   , "sil"   , "silg"  , "silm"  , "silb"  ,  /*-- U+C2E0 .. U+C2E7 --*/
   "sils"  , "silt"  , "silp"  , "silh"  , "sim"   , "sib"   , "sibs"  , "sis"   ,  /*-- U+C2E8 .. U+C2EF --*/
   "siss"  , "sing"  , "sij"   , "sic"   , "sik"   , "sit"   , "sip"   , "sih"   ,  /*-- U+C2F0 .. U+C2F7 --*/
   "ssa"   , "ssag"  , "ssagg" , "ssags" , "ssan"  , "ssanj" , "ssanh" , "ssad"  ,  /*-- U+C2F8 .. U+C2FF --*/
   "ssal"  , "ssalg" , "ssalm" , "ssalb" , "ssals" , "ssalt" , "ssalp" , "ssalh" ,  /*-- U+C300 .. U+C307 --*/
   "ssam"  , "ssab"  , "ssabs" , "ssas"  , "ssass" , "ssang" , "ssaj"  , "ssac"  ,  /*-- U+C308 .. U+C30F --*/
   "ssak"  , "ssat"  , "ssap"  , "ssah"  , "ssae"  , "ssaeg" , "ssaegg", "ssaegs",  /*-- U+C310 .. U+C317 --*/
   "ssaen" , "ssaenj", "ssaenh", "ssaed" , "ssael" , "ssaelg", "ssaelm", "ssaelb",  /*-- U+C318 .. U+C31F --*/
   "ssaels", "ssaelt", "ssaelp", "ssaelh", "ssaem" , "ssaeb" , "ssaebs", "ssaes" ,  /*-- U+C320 .. U+C327 --*/
   "ssaess", "ssaeng", "ssaej" , "ssaec" , "ssaek" , "ssaet" , "ssaep" , "ssaeh" ,  /*-- U+C328 .. U+C32F --*/
   "ssya"  , "ssyag" , "ssyagg", "ssyags", "ssyan" , "ssyanj", "ssyanh", "ssyad" ,  /*-- U+C330 .. U+C337 --*/
   "ssyal" , "ssyalg", "ssyalm", "ssyalb", "ssyals", "ssyalt", "ssyalp", "ssyalh",  /*-- U+C338 .. U+C33F --*/
   "ssyam" , "ssyab" , "ssyabs", "ssyas" , "ssyass", "ssyang", "ssyaj" , "ssyac" ,  /*-- U+C340 .. U+C347 --*/
   "ssyak" , "ssyat" , "ssyap" , "ssyah" , "ssyae" , "ssyaeg", "ssyaegg", "ssyaegs",  /*-- U+C348 .. U+C34F --*/
   "ssyaen", "ssyaenj", "ssyaenh", "ssyaed", "ssyael", "ssyaelg", "ssyaelm", "ssyaelb",  /*-- U+C350 .. U+C357 --*/
   "ssyaels", "ssyaelt", "ssyaelp", "ssyaelh", "ssyaem", "ssyaeb", "ssyaebs", "ssyaes",  /*-- U+C358 .. U+C35F --*/
   "ssyaess", "ssyaeng", "ssyaej", "ssyaec", "ssyaek", "ssyaet", "ssyaep", "ssyaeh",  /*-- U+C360 .. U+C367 --*/
   "sseo"  , "sseog" , "sseogg", "sseogs", "sseon" , "sseonj", "sseonh", "sseod" ,  /*-- U+C368 .. U+C36F --*/
   "sseol" , "sseolg", "sseolm", "sseolb", "sseols", "sseolt", "sseolp", "sseolh",  /*-- U+C370 .. U+C377 --*/
   "sseom" , "sseob" , "sseobs", "sseos" , "sseoss", "sseong", "sseoj" , "sseoc" ,  /*-- U+C378 .. U+C37F --*/
   "sseok" , "sseot" , "sseop" , "sseoh" , "sse"   , "sseg"  , "ssegg" , "ssegs" ,  /*-- U+C380 .. U+C387 --*/
   "ssen"  , "ssenj" , "ssenh" , "ssed"  , "ssel"  , "sselg" , "sselm" , "sselb" ,  /*-- U+C388 .. U+C38F --*/
   "ssels" , "sselt" , "sselp" , "sselh" , "ssem"  , "sseb"  , "ssebs" , "sses"  ,  /*-- U+C390 .. U+C397 --*/
   "ssess" , "sseng" , "ssej"  , "ssec"  , "ssek"  , "sset"  , "ssep"  , "sseh"  ,  /*-- U+C398 .. U+C39F --*/
   "ssyeo" , "ssyeog", "ssyeogg", "ssyeogs", "ssyeon", "ssyeonj", "ssyeonh", "ssyeod",  /*-- U+C3A0 .. U+C3A7 --*/
   "ssyeol", "ssyeolg", "ssyeolm", "ssyeolb", "ssyeols", "ssyeolt", "ssyeolp", "ssyeolh",  /*-- U+C3A8 .. U+C3AF --*/
   "ssyeom", "ssyeob", "ssyeobs", "ssyeos", "ssyeoss", "ssyeong", "ssyeoj", "ssyeoc",  /*-- U+C3B0 .. U+C3B7 --*/
   "ssyeok", "ssyeot", "ssyeop", "ssyeoh", "ssye"  , "ssyeg" , "ssyegg", "ssyegs",  /*-- U+C3B8 .. U+C3BF --*/
   "ssyen" , "ssyenj", "ssyenh", "ssyed" , "ssyel" , "ssyelg", "ssyelm", "ssyelb",  /*-- U+C3C0 .. U+C3C7 --*/
   "ssyels", "ssyelt", "ssyelp", "ssyelh", "ssyem" , "ssyeb" , "ssyebs", "ssyes" ,  /*-- U+C3C8 .. U+C3CF --*/
   "ssyess", "ssyeng", "ssyej" , "ssyec" , "ssyek" , "ssyet" , "ssyep" , "ssyeh" ,  /*-- U+C3D0 .. U+C3D7 --*/
   "sso"   , "ssog"  , "ssogg" , "ssogs" , "sson"  , "ssonj" , "ssonh" , "ssod"  ,  /*-- U+C3D8 .. U+C3DF --*/
   "ssol"  , "ssolg" , "ssolm" , "ssolb" , "ssols" , "ssolt" , "ssolp" , "ssolh" ,  /*-- U+C3E0 .. U+C3E7 --*/
   "ssom"  , "ssob"  , "ssobs" , "ssos"  , "ssoss" , "ssong" , "ssoj"  , "ssoc"  ,  /*-- U+C3E8 .. U+C3EF --*/
   "ssok"  , "ssot"  , "ssop"  , "ssoh"  , "sswa"  , "sswag" , "sswagg", "sswags",  /*-- U+C3F0 .. U+C3F7 --*/
   "sswan" , "sswanj", "sswanh", "sswad" , "sswal" , "sswalg", "sswalm", "sswalb",  /*-- U+C3F8 .. U+C3FF --*/
   "sswals", "sswalt", "sswalp", "sswalh", "sswam" , "sswab" , "sswabs", "sswas" ,  /*-- U+C400 .. U+C407 --*/
   "sswass", "sswang", "sswaj" , "sswac" , "sswak" , "sswat" , "sswap" , "sswah" ,  /*-- U+C408 .. U+C40F --*/
   "sswae" , "sswaeg", "sswaegg", "sswaegs", "sswaen", "sswaenj", "sswaenh", "sswaed",  /*-- U+C410 .. U+C417 --*/
   "sswael", "sswaelg", "sswaelm", "sswaelb", "sswaels", "sswaelt", "sswaelp", "sswaelh",  /*-- U+C418 .. U+C41F --*/
   "sswaem", "sswaeb", "sswaebs", "sswaes", "sswaess", "sswaeng", "sswaej", "sswaec",  /*-- U+C420 .. U+C427 --*/
   "sswaek", "sswaet", "sswaep", "sswaeh", "ssoe"  , "ssoeg" , "ssoegg", "ssoegs",  /*-- U+C428 .. U+C42F --*/
   "ssoen" , "ssoenj", "ssoenh", "ssoed" , "ssoel" , "ssoelg", "ssoelm", "ssoelb",  /*-- U+C430 .. U+C437 --*/
   "ssoels", "ssoelt", "ssoelp", "ssoelh", "ssoem" , "ssoeb" , "ssoebs", "ssoes" ,  /*-- U+C438 .. U+C43F --*/
   "ssoess", "ssoeng", "ssoej" , "ssoec" , "ssoek" , "ssoet" , "ssoep" , "ssoeh" ,  /*-- U+C440 .. U+C447 --*/
   "ssyo"  , "ssyog" , "ssyogg", "ssyogs", "ssyon" , "ssyonj", "ssyonh", "ssyod" ,  /*-- U+C448 .. U+C44F --*/
   "ssyol" , "ssyolg", "ssyolm", "ssyolb", "ssyols", "ssyolt", "ssyolp", "ssyolh",  /*-- U+C450 .. U+C457 --*/
   "ssyom" , "ssyob" , "ssyobs", "ssyos" , "ssyoss", "ssyong", "ssyoj" , "ssyoc" ,  /*-- U+C458 .. U+C45F --*/
   "ssyok" , "ssyot" , "ssyop" , "ssyoh" , "ssu"   , "ssug"  , "ssugg" , "ssugs" ,  /*-- U+C460 .. U+C467 --*/
   "ssun"  , "ssunj" , "ssunh" , "ssud"  , "ssul"  , "ssulg" , "ssulm" , "ssulb" ,  /*-- U+C468 .. U+C46F --*/
   "ssuls" , "ssult" , "ssulp" , "ssulh" , "ssum"  , "ssub"  , "ssubs" , "ssus"  ,  /*-- U+C470 .. U+C477 --*/
   "ssuss" , "ssung" , "ssuj"  , "ssuc"  , "ssuk"  , "ssut"  , "ssup"  , "ssuh"  ,  /*-- U+C478 .. U+C47F --*/
   "ssweo" , "ssweog", "ssweogg", "ssweogs", "ssweon", "ssweonj", "ssweonh", "ssweod",  /*-- U+C480 .. U+C487 --*/
   "ssweol", "ssweolg", "ssweolm", "ssweolb", "ssweols", "ssweolt", "ssweolp", "ssweolh",  /*-- U+C488 .. U+C48F --*/
   "ssweom", "ssweob", "ssweobs", "ssweos", "ssweoss", "ssweong", "ssweoj", "ssweoc",  /*-- U+C490 .. U+C497 --*/
   "ssweok", "ssweot", "ssweop", "ssweoh", "sswe"  , "ssweg" , "sswegg", "sswegs",  /*-- U+C498 .. U+C49F --*/
   "sswen" , "sswenj", "sswenh", "sswed" , "sswel" , "sswelg", "sswelm", "sswelb",  /*-- U+C4A0 .. U+C4A7 --*/
   "sswels", "sswelt", "sswelp", "sswelh", "sswem" , "ssweb" , "sswebs", "sswes" ,  /*-- U+C4A8 .. U+C4AF --*/
   "sswess", "ssweng", "sswej" , "sswec" , "sswek" , "sswet" , "sswep" , "ssweh" ,  /*-- U+C4B0 .. U+C4B7 --*/
   "sswi"  , "sswig" , "sswigg", "sswigs", "sswin" , "sswinj", "sswinh", "sswid" ,  /*-- U+C4B8 .. U+C4BF --*/
   "sswil" , "sswilg", "sswilm", "sswilb", "sswils", "sswilt", "sswilp", "sswilh",  /*-- U+C4C0 .. U+C4C7 --*/
   "sswim" , "sswib" , "sswibs", "sswis" , "sswiss", "sswing", "sswij" , "sswic" ,  /*-- U+C4C8 .. U+C4CF --*/
   "sswik" , "sswit" , "sswip" , "sswih" , "ssyu"  , "ssyug" , "ssyugg", "ssyugs",  /*-- U+C4D0 .. U+C4D7 --*/
   "ssyun" , "ssyunj", "ssyunh", "ssyud" , "ssyul" , "ssyulg", "ssyulm", "ssyulb",  /*-- U+C4D8 .. U+C4DF --*/
   "ssyuls", "ssyult", "ssyulp", "ssyulh", "ssyum" , "ssyub" , "ssyubs", "ssyus" ,  /*-- U+C4E0 .. U+C4E7 --*/
   "ssyuss", "ssyung", "ssyuj" , "ssyuc" , "ssyuk" , "ssyut" , "ssyup" , "ssyuh" ,  /*-- U+C4E8 .. U+C4EF --*/
   "sseu"  , "sseug" , "sseugg", "sseugs", "sseun" , "sseunj", "sseunh", "sseud" ,  /*-- U+C4F0 .. U+C4F7 --*/
   "sseul" , "sseulg", "sseulm", "sseulb", "sseuls", "sseult", "sseulp", "sseulh",  /*-- U+C4F8 .. U+C4FF --*/
   "sseum" , "sseub" , "sseubs", "sseus" , "sseuss", "sseung", "sseuj" , "sseuc" ,  /*-- U+C500 .. U+C507 --*/
   "sseuk" , "sseut" , "sseup" , "sseuh" , "ssyi"  , "ssyig" , "ssyigg", "ssyigs",  /*-- U+C508 .. U+C50F --*/
   "ssyin" , "ssyinj", "ssyinh", "ssyid" , "ssyil" , "ssyilg", "ssyilm", "ssyilb",  /*-- U+C510 .. U+C517 --*/
   "ssyils", "ssyilt", "ssyilp", "ssyilh", "ssyim" , "ssyib" , "ssyibs", "ssyis" ,  /*-- U+C518 .. U+C51F --*/
   "ssyiss", "ssying", "ssyij" , "ssyic" , "ssyik" , "ssyit" , "ssyip" , "ssyih" ,  /*-- U+C520 .. U+C527 --*/
   "ssi"   , "ssig"  , "ssigg" , "ssigs" , "ssin"  , "ssinj" , "ssinh" , "ssid"  ,  /*-- U+C528 .. U+C52F --*/
   "ssil"  , "ssilg" , "ssilm" , "ssilb" , "ssils" , "ssilt" , "ssilp" , "ssilh" ,  /*-- U+C530 .. U+C537 --*/
   "ssim"  , "ssib"  , "ssibs" , "ssis"  , "ssiss" , "ssing" , "ssij"  , "ssic"  ,  /*-- U+C538 .. U+C53F --*/
   "ssik"  , "ssit"  , "ssip"  , "ssih"  , "a"     , "ag"    , "agg"   , "ags"   ,  /*-- U+C540 .. U+C547 --*/
   "an"    , "anj"   , "anh"   , "ad"    , "al"    , "alg"   , "alm"   , "alb"   ,  /*-- U+C548 .. U+C54F --*/
   "als"   , "alt"   , "alp"   , "alh"   , "am"    , "ab"    , "abs"   , "as"    ,  /*-- U+C550 .. U+C557 --*/
   "ass"   , "ang"   , "aj"    , "ac"    , "ak"    , "at"    , "ap"    , "ah"    ,  /*-- U+C558 .. U+C55F --*/
   "ae"    , "aeg"   , "aegg"  , "aegs"  , "aen"   , "aenj"  , "aenh"  , "aed"   ,  /*-- U+C560 .. U+C567 --*/
   "ael"   , "aelg"  , "aelm"  , "aelb"  , "aels"  , "aelt"  , "aelp"  , "aelh"  ,  /*-- U+C568 .. U+C56F --*/
   "aem"   , "aeb"   , "aebs"  , "aes"   , "aess"  , "aeng"  , "aej"   , "aec"   ,  /*-- U+C570 .. U+C577 --*/
   "aek"   , "aet"   , "aep"   , "aeh"   , "ya"    , "yag"   , "yagg"  , "yags"  ,  /*-- U+C578 .. U+C57F --*/
   "yan"   , "yanj"  , "yanh"  , "yad"   , "yal"   , "yalg"  , "yalm"  , "yalb"  ,  /*-- U+C580 .. U+C587 --*/
   "yals"  , "yalt"  , "yalp"  , "yalh"  , "yam"   , "yab"   , "yabs"  , "yas"   ,  /*-- U+C588 .. U+C58F --*/
   "yass"  , "yang"  , "yaj"   , "yac"   , "yak"   , "yat"   , "yap"   , "yah"   ,  /*-- U+C590 .. U+C597 --*/
   "yae"   , "yaeg"  , "yaegg" , "yaegs" , "yaen"  , "yaenj" , "yaenh" , "yaed"  ,  /*-- U+C598 .. U+C59F --*/
   "yael"  , "yaelg" , "yaelm" , "yaelb" , "yaels" , "yaelt" , "yaelp" , "yaelh" ,  /*-- U+C5A0 .. U+C5A7 --*/
   "yaem"  , "yaeb"  , "yaebs" , "yaes"  , "yaess" , "yaeng" , "yaej"  , "yaec"  ,  /*-- U+C5A8 .. U+C5AF --*/
   "yaek"  , "yaet"  , "yaep"  , "yaeh"  , "eo"    , "eog"   , "eogg"  , "eogs"  ,  /*-- U+C5B0 .. U+C5B7 --*/
   "eon"   , "eonj"  , "eonh"  , "eod"   , "eol"   , "eolg"  , "eolm"  , "eolb"  ,  /*-- U+C5B8 .. U+C5BF --*/
   "eols"  , "eolt"  , "eolp"  , "eolh"  , "eom"   , "eob"   , "eobs"  , "eos"   ,  /*-- U+C5C0 .. U+C5C7 --*/
   "eoss"  , "eong"  , "eoj"   , "eoc"   , "eok"   , "eot"   , "eop"   , "eoh"   ,  /*-- U+C5C8 .. U+C5CF --*/
   "e"     , "eg"    , "egg"   , "egs"   , "en"    , "enj"   , "enh"   , "ed"    ,  /*-- U+C5D0 .. U+C5D7 --*/
   "el"    , "elg"   , "elm"   , "elb"   , "els"   , "elt"   , "elp"   , "elh"   ,  /*-- U+C5D8 .. U+C5DF --*/
   "em"    , "eb"    , "ebs"   , "es"    , "ess"   , "eng"   , "ej"    , "ec"    ,  /*-- U+C5E0 .. U+C5E7 --*/
   "ek"    , "et"    , "ep"    , "eh"    , "yeo"   , "yeog"  , "yeogg" , "yeogs" ,  /*-- U+C5E8 .. U+C5EF --*/
   "yeon"  , "yeonj" , "yeonh" , "yeod"  , "yeol"  , "yeolg" , "yeolm" , "yeolb" ,  /*-- U+C5F0 .. U+C5F7 --*/
   "yeols" , "yeolt" , "yeolp" , "yeolh" , "yeom"  , "yeob"  , "yeobs" , "yeos"  ,  /*-- U+C5F8 .. U+C5FF --*/
   "yeoss" , "yeong" , "yeoj"  , "yeoc"  , "yeok"  , "yeot"  , "yeop"  , "yeoh"  ,  /*-- U+C600 .. U+C607 --*/
   "ye"    , "yeg"   , "yegg"  , "yegs"  , "yen"   , "yenj"  , "yenh"  , "yed"   ,  /*-- U+C608 .. U+C60F --*/
   "yel"   , "yelg"  , "yelm"  , "yelb"  , "yels"  , "yelt"  , "yelp"  , "yelh"  ,  /*-- U+C610 .. U+C617 --*/
   "yem"   , "yeb"   , "yebs"  , "yes"   , "yess"  , "yeng"  , "yej"   , "yec"   ,  /*-- U+C618 .. U+C61F --*/
   "yek"   , "yet"   , "yep"   , "yeh"   , "o"     , "og"    , "ogg"   , "ogs"   ,  /*-- U+C620 .. U+C627 --*/
   "on"    , "onj"   , "onh"   , "od"    , "ol"    , "olg"   , "olm"   , "olb"   ,  /*-- U+C628 .. U+C62F --*/
   "ols"   , "olt"   , "olp"   , "olh"   , "om"    , "ob"    , "obs"   , "os"    ,  /*-- U+C630 .. U+C637 --*/
   "oss"   , "ong"   , "oj"    , "oc"    , "ok"    , "ot"    , "op"    , "oh"    ,  /*-- U+C638 .. U+C63F --*/
   "wa"    , "wag"   , "wagg"  , "wags"  , "wan"   , "wanj"  , "wanh"  , "wad"   ,  /*-- U+C640 .. U+C647 --*/
   "wal"   , "walg"  , "walm"  , "walb"  , "wals"  , "walt"  , "walp"  , "walh"  ,  /*-- U+C648 .. U+C64F --*/
   "wam"   , "wab"   , "wabs"  , "was"   , "wass"  , "wang"  , "waj"   , "wac"   ,  /*-- U+C650 .. U+C657 --*/
   "wak"   , "wat"   , "wap"   , "wah"   , "wae"   , "waeg"  , "waegg" , "waegs" ,  /*-- U+C658 .. U+C65F --*/
   "waen"  , "waenj" , "waenh" , "waed"  , "wael"  , "waelg" , "waelm" , "waelb" ,  /*-- U+C660 .. U+C667 --*/
   "waels" , "waelt" , "waelp" , "waelh" , "waem"  , "waeb"  , "waebs" , "waes"  ,  /*-- U+C668 .. U+C66F --*/
   "waess" , "waeng" , "waej"  , "waec"  , "waek"  , "waet"  , "waep"  , "waeh"  ,  /*-- U+C670 .. U+C677 --*/
   "oe"    , "oeg"   , "oegg"  , "oegs"  , "oen"   , "oenj"  , "oenh"  , "oed"   ,  /*-- U+C678 .. U+C67F --*/
   "oel"   , "oelg"  , "oelm"  , "oelb"  , "oels"  , "oelt"  , "oelp"  , "oelh"  ,  /*-- U+C680 .. U+C687 --*/
   "oem"   , "oeb"   , "oebs"  , "oes"   , "oess"  , "oeng"  , "oej"   , "oec"   ,  /*-- U+C688 .. U+C68F --*/
   "oek"   , "oet"   , "oep"   , "oeh"   , "yo"    , "yog"   , "yogg"  , "yogs"  ,  /*-- U+C690 .. U+C697 --*/
   "yon"   , "yonj"  , "yonh"  , "yod"   , "yol"   , "yolg"  , "yolm"  , "yolb"  ,  /*-- U+C698 .. U+C69F --*/
   "yols"  , "yolt"  , "yolp"  , "yolh"  , "yom"   , "yob"   , "yobs"  , "yos"   ,  /*-- U+C6A0 .. U+C6A7 --*/
   "yoss"  , "yong"  , "yoj"   , "yoc"   , "yok"   , "yot"   , "yop"   , "yoh"   ,  /*-- U+C6A8 .. U+C6AF --*/
   "u"     , "ug"    , "ugg"   , "ugs"   , "un"    , "unj"   , "unh"   , "ud"    ,  /*-- U+C6B0 .. U+C6B7 --*/
   "ul"    , "ulg"   , "ulm"   , "ulb"   , "uls"   , "ult"   , "ulp"   , "ulh"   ,  /*-- U+C6B8 .. U+C6BF --*/
   "um"    , "ub"    , "ubs"   , "us"    , "uss"   , "ung"   , "uj"    , "uc"    ,  /*-- U+C6C0 .. U+C6C7 --*/
   "uk"    , "ut"    , "up"    , "uh"    , "weo"   , "weog"  , "weogg" , "weogs" ,  /*-- U+C6C8 .. U+C6CF --*/
   "weon"  , "weonj" , "weonh" , "weod"  , "weol"  , "weolg" , "weolm" , "weolb" ,  /*-- U+C6D0 .. U+C6D7 --*/
   "weols" , "weolt" , "weolp" , "weolh" , "weom"  , "weob"  , "weobs" , "weos"  ,  /*-- U+C6D8 .. U+C6DF --*/
   "weoss" , "weong" , "weoj"  , "weoc"  , "weok"  , "weot"  , "weop"  , "weoh"  ,  /*-- U+C6E0 .. U+C6E7 --*/
   "we"    , "weg"   , "wegg"  , "wegs"  , "wen"   , "wenj"  , "wenh"  , "wed"   ,  /*-- U+C6E8 .. U+C6EF --*/
   "wel"   , "welg"  , "welm"  , "welb"  , "wels"  , "welt"  , "welp"  , "welh"  ,  /*-- U+C6F0 .. U+C6F7 --*/
   "wem"   , "web"   , "webs"  , "wes"   , "wess"  , "weng"  , "wej"   , "wec"   ,  /*-- U+C6F8 .. U+C6FF --*/
   "wek"   , "wet"   , "wep"   , "weh"   , "wi"    , "wig"   , "wigg"  , "wigs"  ,  /*-- U+C700 .. U+C707 --*/
   "win"   , "winj"  , "winh"  , "wid"   , "wil"   , "wilg"  , "wilm"  , "wilb"  ,  /*-- U+C708 .. U+C70F --*/
   "wils"  , "wilt"  , "wilp"  , "wilh"  , "wim"   , "wib"   , "wibs"  , "wis"   ,  /*-- U+C710 .. U+C717 --*/
   "wiss"  , "wing"  , "wij"   , "wic"   , "wik"   , "wit"   , "wip"   , "wih"   ,  /*-- U+C718 .. U+C71F --*/
   "yu"    , "yug"   , "yugg"  , "yugs"  , "yun"   , "yunj"  , "yunh"  , "yud"   ,  /*-- U+C720 .. U+C727 --*/
   "yul"   , "yulg"  , "yulm"  , "yulb"  , "yuls"  , "yult"  , "yulp"  , "yulh"  ,  /*-- U+C728 .. U+C72F --*/
   "yum"   , "yub"   , "yubs"  , "yus"   , "yuss"  , "yung"  , "yuj"   , "yuc"   ,  /*-- U+C730 .. U+C737 --*/
   "yuk"   , "yut"   , "yup"   , "yuh"   , "eu"    , "eug"   , "eugg"  , "eugs"  ,  /*-- U+C738 .. U+C73F --*/
   "eun"   , "eunj"  , "eunh"  , "eud"   , "eul"   , "eulg"  , "eulm"  , "eulb"  ,  /*-- U+C740 .. U+C747 --*/
   "euls"  , "eult"  , "eulp"  , "eulh"  , "eum"   , "eub"   , "eubs"  , "eus"   ,  /*-- U+C748 .. U+C74F --*/
   "euss"  , "eung"  , "euj"   , "euc"   , "euk"   , "eut"   , "eup"   , "euh"   ,  /*-- U+C750 .. U+C757 --*/
   "yi"    , "yig"   , "yigg"  , "yigs"  , "yin"   , "yinj"  , "yinh"  , "yid"   ,  /*-- U+C758 .. U+C75F --*/
   "yil"   , "yilg"  , "yilm"  , "yilb"  , "yils"  , "yilt"  , "yilp"  , "yilh"  ,  /*-- U+C760 .. U+C767 --*/
   "yim"   , "yib"   , "yibs"  , "yis"   , "yiss"  , "ying"  , "yij"   , "yic"   ,  /*-- U+C768 .. U+C76F --*/
   "yik"   , "yit"   , "yip"   , "yih"   , "i"     , "ig"    , "igg"   , "igs"   ,  /*-- U+C770 .. U+C777 --*/
   "in"    , "inj"   , "inh"   , "id"    , "il"    , "ilg"   , "ilm"   , "ilb"   ,  /*-- U+C778 .. U+C77F --*/
   "ils"   , "ilt"   , "ilp"   , "ilh"   , "im"    , "ib"    , "ibs"   , "is"    ,  /*-- U+C780 .. U+C787 --*/
   "iss"   , "ing"   , "ij"    , "ic"    , "ik"    , "it"    , "ip"    , "ih"    ,  /*-- U+C788 .. U+C78F --*/
   "ja"    , "jag"   , "jagg"  , "jags"  , "jan"   , "janj"  , "janh"  , "jad"   ,  /*-- U+C790 .. U+C797 --*/
   "jal"   , "jalg"  , "jalm"  , "jalb"  , "jals"  , "jalt"  , "jalp"  , "jalh"  ,  /*-- U+C798 .. U+C79F --*/
   "jam"   , "jab"   , "jabs"  , "jas"   , "jass"  , "jang"  , "jaj"   , "jac"   ,  /*-- U+C7A0 .. U+C7A7 --*/
   "jak"   , "jat"   , "jap"   , "jah"   , "jae"   , "jaeg"  , "jaegg" , "jaegs" ,  /*-- U+C7A8 .. U+C7AF --*/
   "jaen"  , "jaenj" , "jaenh" , "jaed"  , "jael"  , "jaelg" , "jaelm" , "jaelb" ,  /*-- U+C7B0 .. U+C7B7 --*/
   "jaels" , "jaelt" , "jaelp" , "jaelh" , "jaem"  , "jaeb"  , "jaebs" , "jaes"  ,  /*-- U+C7B8 .. U+C7BF --*/
   "jaess" , "jaeng" , "jaej"  , "jaec"  , "jaek"  , "jaet"  , "jaep"  , "jaeh"  ,  /*-- U+C7C0 .. U+C7C7 --*/
   "jya"   , "jyag"  , "jyagg" , "jyags" , "jyan"  , "jyanj" , "jyanh" , "jyad"  ,  /*-- U+C7C8 .. U+C7CF --*/
   "jyal"  , "jyalg" , "jyalm" , "jyalb" , "jyals" , "jyalt" , "jyalp" , "jyalh" ,  /*-- U+C7D0 .. U+C7D7 --*/
   "jyam"  , "jyab"  , "jyabs" , "jyas"  , "jyass" , "jyang" , "jyaj"  , "jyac"  ,  /*-- U+C7D8 .. U+C7DF --*/
   "jyak"  , "jyat"  , "jyap"  , "jyah"  , "jyae"  , "jyaeg" , "jyaegg", "jyaegs",  /*-- U+C7E0 .. U+C7E7 --*/
   "jyaen" , "jyaenj", "jyaenh", "jyaed" , "jyael" , "jyaelg", "jyaelm", "jyaelb",  /*-- U+C7E8 .. U+C7EF --*/
   "jyaels", "jyaelt", "jyaelp", "jyaelh", "jyaem" , "jyaeb" , "jyaebs", "jyaes" ,  /*-- U+C7F0 .. U+C7F7 --*/
   "jyaess", "jyaeng", "jyaej" , "jyaec" , "jyaek" , "jyaet" , "jyaep" , "jyaeh" ,  /*-- U+C7F8 .. U+C7FF --*/
   "jeo"   , "jeog"  , "jeogg" , "jeogs" , "jeon"  , "jeonj" , "jeonh" , "jeod"  ,  /*-- U+C800 .. U+C807 --*/
   "jeol"  , "jeolg" , "jeolm" , "jeolb" , "jeols" , "jeolt" , "jeolp" , "jeolh" ,  /*-- U+C808 .. U+C80F --*/
   "jeom"  , "jeob"  , "jeobs" , "jeos"  , "jeoss" , "jeong" , "jeoj"  , "jeoc"  ,  /*-- U+C810 .. U+C817 --*/
   "jeok"  , "jeot"  , "jeop"  , "jeoh"  , "je"    , "jeg"   , "jegg"  , "jegs"  ,  /*-- U+C818 .. U+C81F --*/
   "jen"   , "jenj"  , "jenh"  , "jed"   , "jel"   , "jelg"  , "jelm"  , "jelb"  ,  /*-- U+C820 .. U+C827 --*/
   "jels"  , "jelt"  , "jelp"  , "jelh"  , "jem"   , "jeb"   , "jebs"  , "jes"   ,  /*-- U+C828 .. U+C82F --*/
   "jess"  , "jeng"  , "jej"   , "jec"   , "jek"   , "jet"   , "jep"   , "jeh"   ,  /*-- U+C830 .. U+C837 --*/
   "jyeo"  , "jyeog" , "jyeogg", "jyeogs", "jyeon" , "jyeonj", "jyeonh", "jyeod" ,  /*-- U+C838 .. U+C83F --*/
   "jyeol" , "jyeolg", "jyeolm", "jyeolb", "jyeols", "jyeolt", "jyeolp", "jyeolh",  /*-- U+C840 .. U+C847 --*/
   "jyeom" , "jyeob" , "jyeobs", "jyeos" , "jyeoss", "jyeong", "jyeoj" , "jyeoc" ,  /*-- U+C848 .. U+C84F --*/
   "jyeok" , "jyeot" , "jyeop" , "jyeoh" , "jye"   , "jyeg"  , "jyegg" , "jyegs" ,  /*-- U+C850 .. U+C857 --*/
   "jyen"  , "jyenj" , "jyenh" , "jyed"  , "jyel"  , "jyelg" , "jyelm" , "jyelb" ,  /*-- U+C858 .. U+C85F --*/
   "jyels" , "jyelt" , "jyelp" , "jyelh" , "jyem"  , "jyeb"  , "jyebs" , "jyes"  ,  /*-- U+C860 .. U+C867 --*/
   "jyess" , "jyeng" , "jyej"  , "jyec"  , "jyek"  , "jyet"  , "jyep"  , "jyeh"  ,  /*-- U+C868 .. U+C86F --*/
   "jo"    , "jog"   , "jogg"  , "jogs"  , "jon"   , "jonj"  , "jonh"  , "jod"   ,  /*-- U+C870 .. U+C877 --*/
   "jol"   , "jolg"  , "jolm"  , "jolb"  , "jols"  , "jolt"  , "jolp"  , "jolh"  ,  /*-- U+C878 .. U+C87F --*/
   "jom"   , "job"   , "jobs"  , "jos"   , "joss"  , "jong"  , "joj"   , "joc"   ,  /*-- U+C880 .. U+C887 --*/
   "jok"   , "jot"   , "jop"   , "joh"   , "jwa"   , "jwag"  , "jwagg" , "jwags" ,  /*-- U+C888 .. U+C88F --*/
   "jwan"  , "jwanj" , "jwanh" , "jwad"  , "jwal"  , "jwalg" , "jwalm" , "jwalb" ,  /*-- U+C890 .. U+C897 --*/
   "jwals" , "jwalt" , "jwalp" , "jwalh" , "jwam"  , "jwab"  , "jwabs" , "jwas"  ,  /*-- U+C898 .. U+C89F --*/
   "jwass" , "jwang" , "jwaj"  , "jwac"  , "jwak"  , "jwat"  , "jwap"  , "jwah"  ,  /*-- U+C8A0 .. U+C8A7 --*/
   "jwae"  , "jwaeg" , "jwaegg", "jwaegs", "jwaen" , "jwaenj", "jwaenh", "jwaed" ,  /*-- U+C8A8 .. U+C8AF --*/
   "jwael" , "jwaelg", "jwaelm", "jwaelb", "jwaels", "jwaelt", "jwaelp", "jwaelh",  /*-- U+C8B0 .. U+C8B7 --*/
   "jwaem" , "jwaeb" , "jwaebs", "jwaes" , "jwaess", "jwaeng", "jwaej" , "jwaec" ,  /*-- U+C8B8 .. U+C8BF --*/
   "jwaek" , "jwaet" , "jwaep" , "jwaeh" , "joe"   , "joeg"  , "joegg" , "joegs" ,  /*-- U+C8C0 .. U+C8C7 --*/
   "joen"  , "joenj" , "joenh" , "joed"  , "joel"  , "joelg" , "joelm" , "joelb" ,  /*-- U+C8C8 .. U+C8CF --*/
   "joels" , "joelt" , "joelp" , "joelh" , "joem"  , "joeb"  , "joebs" , "joes"  ,  /*-- U+C8D0 .. U+C8D7 --*/
   "joess" , "joeng" , "joej"  , "joec"  , "joek"  , "joet"  , "joep"  , "joeh"  ,  /*-- U+C8D8 .. U+C8DF --*/
   "jyo"   , "jyog"  , "jyogg" , "jyogs" , "jyon"  , "jyonj" , "jyonh" , "jyod"  ,  /*-- U+C8E0 .. U+C8E7 --*/
   "jyol"  , "jyolg" , "jyolm" , "jyolb" , "jyols" , "jyolt" , "jyolp" , "jyolh" ,  /*-- U+C8E8 .. U+C8EF --*/
   "jyom"  , "jyob"  , "jyobs" , "jyos"  , "jyoss" , "jyong" , "jyoj"  , "jyoc"  ,  /*-- U+C8F0 .. U+C8F7 --*/
   "jyok"  , "jyot"  , "jyop"  , "jyoh"  , "ju"    , "jug"   , "jugg"  , "jugs"  ,  /*-- U+C8F8 .. U+C8FF --*/
   "jun"   , "junj"  , "junh"  , "jud"   , "jul"   , "julg"  , "julm"  , "julb"  ,  /*-- U+C900 .. U+C907 --*/
   "juls"  , "jult"  , "julp"  , "julh"  , "jum"   , "jub"   , "jubs"  , "jus"   ,  /*-- U+C908 .. U+C90F --*/
   "juss"  , "jung"  , "juj"   , "juc"   , "juk"   , "jut"   , "jup"   , "juh"   ,  /*-- U+C910 .. U+C917 --*/
   "jweo"  , "jweog" , "jweogg", "jweogs", "jweon" , "jweonj", "jweonh", "jweod" ,  /*-- U+C918 .. U+C91F --*/
   "jweol" , "jweolg", "jweolm", "jweolb", "jweols", "jweolt", "jweolp", "jweolh",  /*-- U+C920 .. U+C927 --*/
   "jweom" , "jweob" , "jweobs", "jweos" , "jweoss", "jweong", "jweoj" , "jweoc" ,  /*-- U+C928 .. U+C92F --*/
   "jweok" , "jweot" , "jweop" , "jweoh" , "jwe"   , "jweg"  , "jwegg" , "jwegs" ,  /*-- U+C930 .. U+C937 --*/
   "jwen"  , "jwenj" , "jwenh" , "jwed"  , "jwel"  , "jwelg" , "jwelm" , "jwelb" ,  /*-- U+C938 .. U+C93F --*/
   "jwels" , "jwelt" , "jwelp" , "jwelh" , "jwem"  , "jweb"  , "jwebs" , "jwes"  ,  /*-- U+C940 .. U+C947 --*/
   "jwess" , "jweng" , "jwej"  , "jwec"  , "jwek"  , "jwet"  , "jwep"  , "jweh"  ,  /*-- U+C948 .. U+C94F --*/
   "jwi"   , "jwig"  , "jwigg" , "jwigs" , "jwin"  , "jwinj" , "jwinh" , "jwid"  ,  /*-- U+C950 .. U+C957 --*/
   "jwil"  , "jwilg" , "jwilm" , "jwilb" , "jwils" , "jwilt" , "jwilp" , "jwilh" ,  /*-- U+C958 .. U+C95F --*/
   "jwim"  , "jwib"  , "jwibs" , "jwis"  , "jwiss" , "jwing" , "jwij"  , "jwic"  ,  /*-- U+C960 .. U+C967 --*/
   "jwik"  , "jwit"  , "jwip"  , "jwih"  , "jyu"   , "jyug"  , "jyugg" , "jyugs" ,  /*-- U+C968 .. U+C96F --*/
   "jyun"  , "jyunj" , "jyunh" , "jyud"  , "jyul"  , "jyulg" , "jyulm" , "jyulb" ,  /*-- U+C970 .. U+C977 --*/
   "jyuls" , "jyult" , "jyulp" , "jyulh" , "jyum"  , "jyub"  , "jyubs" , "jyus"  ,  /*-- U+C978 .. U+C97F --*/
   "jyuss" , "jyung" , "jyuj"  , "jyuc"  , "jyuk"  , "jyut"  , "jyup"  , "jyuh"  ,  /*-- U+C980 .. U+C987 --*/
   "jeu"   , "jeug"  , "jeugg" , "jeugs" , "jeun"  , "jeunj" , "jeunh" , "jeud"  ,  /*-- U+C988 .. U+C98F --*/
   "jeul"  , "jeulg" , "jeulm" , "jeulb" , "jeuls" , "jeult" , "jeulp" , "jeulh" ,  /*-- U+C990 .. U+C997 --*/
   "jeum"  , "jeub"  , "jeubs" , "jeus"  , "jeuss" , "jeung" , "jeuj"  , "jeuc"  ,  /*-- U+C998 .. U+C99F --*/
   "jeuk"  , "jeut"  , "jeup"  , "jeuh"  , "jyi"   , "jyig"  , "jyigg" , "jyigs" ,  /*-- U+C9A0 .. U+C9A7 --*/
   "jyin"  , "jyinj" , "jyinh" , "jyid"  , "jyil"  , "jyilg" , "jyilm" , "jyilb" ,  /*-- U+C9A8 .. U+C9AF --*/
   "jyils" , "jyilt" , "jyilp" , "jyilh" , "jyim"  , "jyib"  , "jyibs" , "jyis"  ,  /*-- U+C9B0 .. U+C9B7 --*/
   "jyiss" , "jying" , "jyij"  , "jyic"  , "jyik"  , "jyit"  , "jyip"  , "jyih"  ,  /*-- U+C9B8 .. U+C9BF --*/
   "ji"    , "jig"   , "jigg"  , "jigs"  , "jin"   , "jinj"  , "jinh"  , "jid"   ,  /*-- U+C9C0 .. U+C9C7 --*/
   "jil"   , "jilg"  , "jilm"  , "jilb"  , "jils"  , "jilt"  , "jilp"  , "jilh"  ,  /*-- U+C9C8 .. U+C9CF --*/
   "jim"   , "jib"   , "jibs"  , "jis"   , "jiss"  , "jing"  , "jij"   , "jic"   ,  /*-- U+C9D0 .. U+C9D7 --*/
   "jik"   , "jit"   , "jip"   , "jih"   , "jja"   , "jjag"  , "jjagg" , "jjags" ,  /*-- U+C9D8 .. U+C9DF --*/
   "jjan"  , "jjanj" , "jjanh" , "jjad"  , "jjal"  , "jjalg" , "jjalm" , "jjalb" ,  /*-- U+C9E0 .. U+C9E7 --*/
   "jjals" , "jjalt" , "jjalp" , "jjalh" , "jjam"  , "jjab"  , "jjabs" , "jjas"  ,  /*-- U+C9E8 .. U+C9EF --*/
   "jjass" , "jjang" , "jjaj"  , "jjac"  , "jjak"  , "jjat"  , "jjap"  , "jjah"  ,  /*-- U+C9F0 .. U+C9F7 --*/
   "jjae"  , "jjaeg" , "jjaegg", "jjaegs", "jjaen" , "jjaenj", "jjaenh", "jjaed" ,  /*-- U+C9F8 .. U+C9FF --*/
   "jjael" , "jjaelg", "jjaelm", "jjaelb", "jjaels", "jjaelt", "jjaelp", "jjaelh",  /*-- U+CA00 .. U+CA07 --*/
   "jjaem" , "jjaeb" , "jjaebs", "jjaes" , "jjaess", "jjaeng", "jjaej" , "jjaec" ,  /*-- U+CA08 .. U+CA0F --*/
   "jjaek" , "jjaet" , "jjaep" , "jjaeh" , "jjya"  , "jjyag" , "jjyagg", "jjyags",  /*-- U+CA10 .. U+CA17 --*/
   "jjyan" , "jjyanj", "jjyanh", "jjyad" , "jjyal" , "jjyalg", "jjyalm", "jjyalb",  /*-- U+CA18 .. U+CA1F --*/
   "jjyals", "jjyalt", "jjyalp", "jjyalh", "jjyam" , "jjyab" , "jjyabs", "jjyas" ,  /*-- U+CA20 .. U+CA27 --*/
   "jjyass", "jjyang", "jjyaj" , "jjyac" , "jjyak" , "jjyat" , "jjyap" , "jjyah" ,  /*-- U+CA28 .. U+CA2F --*/
   "jjyae" , "jjyaeg", "jjyaegg", "jjyaegs", "jjyaen", "jjyaenj", "jjyaenh", "jjyaed",  /*-- U+CA30 .. U+CA37 --*/
   "jjyael", "jjyaelg", "jjyaelm", "jjyaelb", "jjyaels", "jjyaelt", "jjyaelp", "jjyaelh",  /*-- U+CA38 .. U+CA3F --*/
   "jjyaem", "jjyaeb", "jjyaebs", "jjyaes", "jjyaess", "jjyaeng", "jjyaej", "jjyaec",  /*-- U+CA40 .. U+CA47 --*/
   "jjyaek", "jjyaet", "jjyaep", "jjyaeh", "jjeo"  , "jjeog" , "jjeogg", "jjeogs",  /*-- U+CA48 .. U+CA4F --*/
   "jjeon" , "jjeonj", "jjeonh", "jjeod" , "jjeol" , "jjeolg", "jjeolm", "jjeolb",  /*-- U+CA50 .. U+CA57 --*/
   "jjeols", "jjeolt", "jjeolp", "jjeolh", "jjeom" , "jjeob" , "jjeobs", "jjeos" ,  /*-- U+CA58 .. U+CA5F --*/
   "jjeoss", "jjeong", "jjeoj" , "jjeoc" , "jjeok" , "jjeot" , "jjeop" , "jjeoh" ,  /*-- U+CA60 .. U+CA67 --*/
   "jje"   , "jjeg"  , "jjegg" , "jjegs" , "jjen"  , "jjenj" , "jjenh" , "jjed"  ,  /*-- U+CA68 .. U+CA6F --*/
   "jjel"  , "jjelg" , "jjelm" , "jjelb" , "jjels" , "jjelt" , "jjelp" , "jjelh" ,  /*-- U+CA70 .. U+CA77 --*/
   "jjem"  , "jjeb"  , "jjebs" , "jjes"  , "jjess" , "jjeng" , "jjej"  , "jjec"  ,  /*-- U+CA78 .. U+CA7F --*/
   "jjek"  , "jjet"  , "jjep"  , "jjeh"  , "jjyeo" , "jjyeog", "jjyeogg", "jjyeogs",  /*-- U+CA80 .. U+CA87 --*/
   "jjyeon", "jjyeonj", "jjyeonh", "jjyeod", "jjyeol", "jjyeolg", "jjyeolm", "jjyeolb",  /*-- U+CA88 .. U+CA8F --*/
   "jjyeols", "jjyeolt", "jjyeolp", "jjyeolh", "jjyeom", "jjyeob", "jjyeobs", "jjyeos",  /*-- U+CA90 .. U+CA97 --*/
   "jjyeoss", "jjyeong", "jjyeoj", "jjyeoc", "jjyeok", "jjyeot", "jjyeop", "jjyeoh",  /*-- U+CA98 .. U+CA9F --*/
   "jjye"  , "jjyeg" , "jjyegg", "jjyegs", "jjyen" , "jjyenj", "jjyenh", "jjyed" ,  /*-- U+CAA0 .. U+CAA7 --*/
   "jjyel" , "jjyelg", "jjyelm", "jjyelb", "jjyels", "jjyelt", "jjyelp", "jjyelh",  /*-- U+CAA8 .. U+CAAF --*/
   "jjyem" , "jjyeb" , "jjyebs", "jjyes" , "jjyess", "jjyeng", "jjyej" , "jjyec" ,  /*-- U+CAB0 .. U+CAB7 --*/
   "jjyek" , "jjyet" , "jjyep" , "jjyeh" , "jjo"   , "jjog"  , "jjogg" , "jjogs" ,  /*-- U+CAB8 .. U+CABF --*/
   "jjon"  , "jjonj" , "jjonh" , "jjod"  , "jjol"  , "jjolg" , "jjolm" , "jjolb" ,  /*-- U+CAC0 .. U+CAC7 --*/
   "jjols" , "jjolt" , "jjolp" , "jjolh" , "jjom"  , "jjob"  , "jjobs" , "jjos"  ,  /*-- U+CAC8 .. U+CACF --*/
   "jjoss" , "jjong" , "jjoj"  , "jjoc"  , "jjok"  , "jjot"  , "jjop"  , "jjoh"  ,  /*-- U+CAD0 .. U+CAD7 --*/
   "jjwa"  , "jjwag" , "jjwagg", "jjwags", "jjwan" , "jjwanj", "jjwanh", "jjwad" ,  /*-- U+CAD8 .. U+CADF --*/
   "jjwal" , "jjwalg", "jjwalm", "jjwalb", "jjwals", "jjwalt", "jjwalp", "jjwalh",  /*-- U+CAE0 .. U+CAE7 --*/
   "jjwam" , "jjwab" , "jjwabs", "jjwas" , "jjwass", "jjwang", "jjwaj" , "jjwac" ,  /*-- U+CAE8 .. U+CAEF --*/
   "jjwak" , "jjwat" , "jjwap" , "jjwah" , "jjwae" , "jjwaeg", "jjwaegg", "jjwaegs",  /*-- U+CAF0 .. U+CAF7 --*/
   "jjwaen", "jjwaenj", "jjwaenh", "jjwaed", "jjwael", "jjwaelg", "jjwaelm", "jjwaelb",  /*-- U+CAF8 .. U+CAFF --*/
   "jjwaels", "jjwaelt", "jjwaelp", "jjwaelh", "jjwaem", "jjwaeb", "jjwaebs", "jjwaes",  /*-- U+CB00 .. U+CB07 --*/
   "jjwaess", "jjwaeng", "jjwaej", "jjwaec", "jjwaek", "jjwaet", "jjwaep", "jjwaeh",  /*-- U+CB08 .. U+CB0F --*/
   "jjoe"  , "jjoeg" , "jjoegg", "jjoegs", "jjoen" , "jjoenj", "jjoenh", "jjoed" ,  /*-- U+CB10 .. U+CB17 --*/
   "jjoel" , "jjoelg", "jjoelm", "jjoelb", "jjoels", "jjoelt", "jjoelp", "jjoelh",  /*-- U+CB18 .. U+CB1F --*/
   "jjoem" , "jjoeb" , "jjoebs", "jjoes" , "jjoess", "jjoeng", "jjoej" , "jjoec" ,  /*-- U+CB20 .. U+CB27 --*/
   "jjoek" , "jjoet" , "jjoep" , "jjoeh" , "jjyo"  , "jjyog" , "jjyogg", "jjyogs",  /*-- U+CB28 .. U+CB2F --*/
   "jjyon" , "jjyonj", "jjyonh", "jjyod" , "jjyol" , "jjyolg", "jjyolm", "jjyolb",  /*-- U+CB30 .. U+CB37 --*/
   "jjyols", "jjyolt", "jjyolp", "jjyolh", "jjyom" , "jjyob" , "jjyobs", "jjyos" ,  /*-- U+CB38 .. U+CB3F --*/
   "jjyoss", "jjyong", "jjyoj" , "jjyoc" , "jjyok" , "jjyot" , "jjyop" , "jjyoh" ,  /*-- U+CB40 .. U+CB47 --*/
   "jju"   , "jjug"  , "jjugg" , "jjugs" , "jjun"  , "jjunj" , "jjunh" , "jjud"  ,  /*-- U+CB48 .. U+CB4F --*/
   "jjul"  , "jjulg" , "jjulm" , "jjulb" , "jjuls" , "jjult" , "jjulp" , "jjulh" ,  /*-- U+CB50 .. U+CB57 --*/
   "jjum"  , "jjub"  , "jjubs" , "jjus"  , "jjuss" , "jjung" , "jjuj"  , "jjuc"  ,  /*-- U+CB58 .. U+CB5F --*/
   "jjuk"  , "jjut"  , "jjup"  , "jjuh"  , "jjweo" , "jjweog", "jjweogg", "jjweogs",  /*-- U+CB60 .. U+CB67 --*/
   "jjweon", "jjweonj", "jjweonh", "jjweod", "jjweol", "jjweolg", "jjweolm", "jjweolb",  /*-- U+CB68 .. U+CB6F --*/
   "jjweols", "jjweolt", "jjweolp", "jjweolh", "jjweom", "jjweob", "jjweobs", "jjweos",  /*-- U+CB70 .. U+CB77 --*/
   "jjweoss", "jjweong", "jjweoj", "jjweoc", "jjweok", "jjweot", "jjweop", "jjweoh",  /*-- U+CB78 .. U+CB7F --*/
   "jjwe"  , "jjweg" , "jjwegg", "jjwegs", "jjwen" , "jjwenj", "jjwenh", "jjwed" ,  /*-- U+CB80 .. U+CB87 --*/
   "jjwel" , "jjwelg", "jjwelm", "jjwelb", "jjwels", "jjwelt", "jjwelp", "jjwelh",  /*-- U+CB88 .. U+CB8F --*/
   "jjwem" , "jjweb" , "jjwebs", "jjwes" , "jjwess", "jjweng", "jjwej" , "jjwec" ,  /*-- U+CB90 .. U+CB97 --*/
   "jjwek" , "jjwet" , "jjwep" , "jjweh" , "jjwi"  , "jjwig" , "jjwigg", "jjwigs",  /*-- U+CB98 .. U+CB9F --*/
   "jjwin" , "jjwinj", "jjwinh", "jjwid" , "jjwil" , "jjwilg", "jjwilm", "jjwilb",  /*-- U+CBA0 .. U+CBA7 --*/
   "jjwils", "jjwilt", "jjwilp", "jjwilh", "jjwim" , "jjwib" , "jjwibs", "jjwis" ,  /*-- U+CBA8 .. U+CBAF --*/
   "jjwiss", "jjwing", "jjwij" , "jjwic" , "jjwik" , "jjwit" , "jjwip" , "jjwih" ,  /*-- U+CBB0 .. U+CBB7 --*/
   "jjyu"  , "jjyug" , "jjyugg", "jjyugs", "jjyun" , "jjyunj", "jjyunh", "jjyud" ,  /*-- U+CBB8 .. U+CBBF --*/
   "jjyul" , "jjyulg", "jjyulm", "jjyulb", "jjyuls", "jjyult", "jjyulp", "jjyulh",  /*-- U+CBC0 .. U+CBC7 --*/
   "jjyum" , "jjyub" , "jjyubs", "jjyus" , "jjyuss", "jjyung", "jjyuj" , "jjyuc" ,  /*-- U+CBC8 .. U+CBCF --*/
   "jjyuk" , "jjyut" , "jjyup" , "jjyuh" , "jjeu"  , "jjeug" , "jjeugg", "jjeugs",  /*-- U+CBD0 .. U+CBD7 --*/
   "jjeun" , "jjeunj", "jjeunh", "jjeud" , "jjeul" , "jjeulg", "jjeulm", "jjeulb",  /*-- U+CBD8 .. U+CBDF --*/
   "jjeuls", "jjeult", "jjeulp", "jjeulh", "jjeum" , "jjeub" , "jjeubs", "jjeus" ,  /*-- U+CBE0 .. U+CBE7 --*/
   "jjeuss", "jjeung", "jjeuj" , "jjeuc" , "jjeuk" , "jjeut" , "jjeup" , "jjeuh" ,  /*-- U+CBE8 .. U+CBEF --*/
   "jjyi"  , "jjyig" , "jjyigg", "jjyigs", "jjyin" , "jjyinj", "jjyinh", "jjyid" ,  /*-- U+CBF0 .. U+CBF7 --*/
   "jjyil" , "jjyilg", "jjyilm", "jjyilb", "jjyils", "jjyilt", "jjyilp", "jjyilh",  /*-- U+CBF8 .. U+CBFF --*/
   "jjyim" , "jjyib" , "jjyibs", "jjyis" , "jjyiss", "jjying", "jjyij" , "jjyic" ,  /*-- U+CC00 .. U+CC07 --*/
   "jjyik" , "jjyit" , "jjyip" , "jjyih" , "jji"   , "jjig"  , "jjigg" , "jjigs" ,  /*-- U+CC08 .. U+CC0F --*/
   "jjin"  , "jjinj" , "jjinh" , "jjid"  , "jjil"  , "jjilg" , "jjilm" , "jjilb" ,  /*-- U+CC10 .. U+CC17 --*/
   "jjils" , "jjilt" , "jjilp" , "jjilh" , "jjim"  , "jjib"  , "jjibs" , "jjis"  ,  /*-- U+CC18 .. U+CC1F --*/
   "jjiss" , "jjing" , "jjij"  , "jjic"  , "jjik"  , "jjit"  , "jjip"  , "jjih"  ,  /*-- U+CC20 .. U+CC27 --*/
   "ca"    , "cag"   , "cagg"  , "cags"  , "can"   , "canj"  , "canh"  , "cad"   ,  /*-- U+CC28 .. U+CC2F --*/
   "cal"   , "calg"  , "calm"  , "calb"  , "cals"  , "calt"  , "calp"  , "calh"  ,  /*-- U+CC30 .. U+CC37 --*/
   "cam"   , "cab"   , "cabs"  , "cas"   , "cass"  , "cang"  , "caj"   , "cac"   ,  /*-- U+CC38 .. U+CC3F --*/
   "cak"   , "cat"   , "cap"   , "cah"   , "cae"   , "caeg"  , "caegg" , "caegs" ,  /*-- U+CC40 .. U+CC47 --*/
   "caen"  , "caenj" , "caenh" , "caed"  , "cael"  , "caelg" , "caelm" , "caelb" ,  /*-- U+CC48 .. U+CC4F --*/
   "caels" , "caelt" , "caelp" , "caelh" , "caem"  , "caeb"  , "caebs" , "caes"  ,  /*-- U+CC50 .. U+CC57 --*/
   "caess" , "caeng" , "caej"  , "caec"  , "caek"  , "caet"  , "caep"  , "caeh"  ,  /*-- U+CC58 .. U+CC5F --*/
   "cya"   , "cyag"  , "cyagg" , "cyags" , "cyan"  , "cyanj" , "cyanh" , "cyad"  ,  /*-- U+CC60 .. U+CC67 --*/
   "cyal"  , "cyalg" , "cyalm" , "cyalb" , "cyals" , "cyalt" , "cyalp" , "cyalh" ,  /*-- U+CC68 .. U+CC6F --*/
   "cyam"  , "cyab"  , "cyabs" , "cyas"  , "cyass" , "cyang" , "cyaj"  , "cyac"  ,  /*-- U+CC70 .. U+CC77 --*/
   "cyak"  , "cyat"  , "cyap"  , "cyah"  , "cyae"  , "cyaeg" , "cyaegg", "cyaegs",  /*-- U+CC78 .. U+CC7F --*/
   "cyaen" , "cyaenj", "cyaenh", "cyaed" , "cyael" , "cyaelg", "cyaelm", "cyaelb",  /*-- U+CC80 .. U+CC87 --*/
   "cyaels", "cyaelt", "cyaelp", "cyaelh", "cyaem" , "cyaeb" , "cyaebs", "cyaes" ,  /*-- U+CC88 .. U+CC8F --*/
   "cyaess", "cyaeng", "cyaej" , "cyaec" , "cyaek" , "cyaet" , "cyaep" , "cyaeh" ,  /*-- U+CC90 .. U+CC97 --*/
   "ceo"   , "ceog"  , "ceogg" , "ceogs" , "ceon"  , "ceonj" , "ceonh" , "ceod"  ,  /*-- U+CC98 .. U+CC9F --*/
   "ceol"  , "ceolg" , "ceolm" , "ceolb" , "ceols" , "ceolt" , "ceolp" , "ceolh" ,  /*-- U+CCA0 .. U+CCA7 --*/
   "ceom"  , "ceob"  , "ceobs" , "ceos"  , "ceoss" , "ceong" , "ceoj"  , "ceoc"  ,  /*-- U+CCA8 .. U+CCAF --*/
   "ceok"  , "ceot"  , "ceop"  , "ceoh"  , "ce"    , "ceg"   , "cegg"  , "cegs"  ,  /*-- U+CCB0 .. U+CCB7 --*/
   "cen"   , "cenj"  , "cenh"  , "ced"   , "cel"   , "celg"  , "celm"  , "celb"  ,  /*-- U+CCB8 .. U+CCBF --*/
   "cels"  , "celt"  , "celp"  , "celh"  , "cem"   , "ceb"   , "cebs"  , "ces"   ,  /*-- U+CCC0 .. U+CCC7 --*/
   "cess"  , "ceng"  , "cej"   , "cec"   , "cek"   , "cet"   , "cep"   , "ceh"   ,  /*-- U+CCC8 .. U+CCCF --*/
   "cyeo"  , "cyeog" , "cyeogg", "cyeogs", "cyeon" , "cyeonj", "cyeonh", "cyeod" ,  /*-- U+CCD0 .. U+CCD7 --*/
   "cyeol" , "cyeolg", "cyeolm", "cyeolb", "cyeols", "cyeolt", "cyeolp", "cyeolh",  /*-- U+CCD8 .. U+CCDF --*/
   "cyeom" , "cyeob" , "cyeobs", "cyeos" , "cyeoss", "cyeong", "cyeoj" , "cyeoc" ,  /*-- U+CCE0 .. U+CCE7 --*/
   "cyeok" , "cyeot" , "cyeop" , "cyeoh" , "cye"   , "cyeg"  , "cyegg" , "cyegs" ,  /*-- U+CCE8 .. U+CCEF --*/
   "cyen"  , "cyenj" , "cyenh" , "cyed"  , "cyel"  , "cyelg" , "cyelm" , "cyelb" ,  /*-- U+CCF0 .. U+CCF7 --*/
   "cyels" , "cyelt" , "cyelp" , "cyelh" , "cyem"  , "cyeb"  , "cyebs" , "cyes"  ,  /*-- U+CCF8 .. U+CCFF --*/
   "cyess" , "cyeng" , "cyej"  , "cyec"  , "cyek"  , "cyet"  , "cyep"  , "cyeh"  ,  /*-- U+CD00 .. U+CD07 --*/
   "co"    , "cog"   , "cogg"  , "cogs"  , "con"   , "conj"  , "conh"  , "cod"   ,  /*-- U+CD08 .. U+CD0F --*/
   "col"   , "colg"  , "colm"  , "colb"  , "cols"  , "colt"  , "colp"  , "colh"  ,  /*-- U+CD10 .. U+CD17 --*/
   "com"   , "cob"   , "cobs"  , "cos"   , "coss"  , "cong"  , "coj"   , "coc"   ,  /*-- U+CD18 .. U+CD1F --*/
   "cok"   , "cot"   , "cop"   , "coh"   , "cwa"   , "cwag"  , "cwagg" , "cwags" ,  /*-- U+CD20 .. U+CD27 --*/
   "cwan"  , "cwanj" , "cwanh" , "cwad"  , "cwal"  , "cwalg" , "cwalm" , "cwalb" ,  /*-- U+CD28 .. U+CD2F --*/
   "cwals" , "cwalt" , "cwalp" , "cwalh" , "cwam"  , "cwab"  , "cwabs" , "cwas"  ,  /*-- U+CD30 .. U+CD37 --*/
   "cwass" , "cwang" , "cwaj"  , "cwac"  , "cwak"  , "cwat"  , "cwap"  , "cwah"  ,  /*-- U+CD38 .. U+CD3F --*/
   "cwae"  , "cwaeg" , "cwaegg", "cwaegs", "cwaen" , "cwaenj", "cwaenh", "cwaed" ,  /*-- U+CD40 .. U+CD47 --*/
   "cwael" , "cwaelg", "cwaelm", "cwaelb", "cwaels", "cwaelt", "cwaelp", "cwaelh",  /*-- U+CD48 .. U+CD4F --*/
   "cwaem" , "cwaeb" , "cwaebs", "cwaes" , "cwaess", "cwaeng", "cwaej" , "cwaec" ,  /*-- U+CD50 .. U+CD57 --*/
   "cwaek" , "cwaet" , "cwaep" , "cwaeh" , "coe"   , "coeg"  , "coegg" , "coegs" ,  /*-- U+CD58 .. U+CD5F --*/
   "coen"  , "coenj" , "coenh" , "coed"  , "coel"  , "coelg" , "coelm" , "coelb" ,  /*-- U+CD60 .. U+CD67 --*/
   "coels" , "coelt" , "coelp" , "coelh" , "coem"  , "coeb"  , "coebs" , "coes"  ,  /*-- U+CD68 .. U+CD6F --*/
   "coess" , "coeng" , "coej"  , "coec"  , "coek"  , "coet"  , "coep"  , "coeh"  ,  /*-- U+CD70 .. U+CD77 --*/
   "cyo"   , "cyog"  , "cyogg" , "cyogs" , "cyon"  , "cyonj" , "cyonh" , "cyod"  ,  /*-- U+CD78 .. U+CD7F --*/
   "cyol"  , "cyolg" , "cyolm" , "cyolb" , "cyols" , "cyolt" , "cyolp" , "cyolh" ,  /*-- U+CD80 .. U+CD87 --*/
   "cyom"  , "cyob"  , "cyobs" , "cyos"  , "cyoss" , "cyong" , "cyoj"  , "cyoc"  ,  /*-- U+CD88 .. U+CD8F --*/
   "cyok"  , "cyot"  , "cyop"  , "cyoh"  , "cu"    , "cug"   , "cugg"  , "cugs"  ,  /*-- U+CD90 .. U+CD97 --*/
   "cun"   , "cunj"  , "cunh"  , "cud"   , "cul"   , "culg"  , "culm"  , "culb"  ,  /*-- U+CD98 .. U+CD9F --*/
   "culs"  , "cult"  , "culp"  , "culh"  , "cum"   , "cub"   , "cubs"  , "cus"   ,  /*-- U+CDA0 .. U+CDA7 --*/
   "cuss"  , "cung"  , "cuj"   , "cuc"   , "cuk"   , "cut"   , "cup"   , "cuh"   ,  /*-- U+CDA8 .. U+CDAF --*/
   "cweo"  , "cweog" , "cweogg", "cweogs", "cweon" , "cweonj", "cweonh", "cweod" ,  /*-- U+CDB0 .. U+CDB7 --*/
   "cweol" , "cweolg", "cweolm", "cweolb", "cweols", "cweolt", "cweolp", "cweolh",  /*-- U+CDB8 .. U+CDBF --*/
   "cweom" , "cweob" , "cweobs", "cweos" , "cweoss", "cweong", "cweoj" , "cweoc" ,  /*-- U+CDC0 .. U+CDC7 --*/
   "cweok" , "cweot" , "cweop" , "cweoh" , "cwe"   , "cweg"  , "cwegg" , "cwegs" ,  /*-- U+CDC8 .. U+CDCF --*/
   "cwen"  , "cwenj" , "cwenh" , "cwed"  , "cwel"  , "cwelg" , "cwelm" , "cwelb" ,  /*-- U+CDD0 .. U+CDD7 --*/
   "cwels" , "cwelt" , "cwelp" , "cwelh" , "cwem"  , "cweb"  , "cwebs" , "cwes"  ,  /*-- U+CDD8 .. U+CDDF --*/
   "cwess" , "cweng" , "cwej"  , "cwec"  , "cwek"  , "cwet"  , "cwep"  , "cweh"  ,  /*-- U+CDE0 .. U+CDE7 --*/
   "cwi"   , "cwig"  , "cwigg" , "cwigs" , "cwin"  , "cwinj" , "cwinh" , "cwid"  ,  /*-- U+CDE8 .. U+CDEF --*/
   "cwil"  , "cwilg" , "cwilm" , "cwilb" , "cwils" , "cwilt" , "cwilp" , "cwilh" ,  /*-- U+CDF0 .. U+CDF7 --*/
   "cwim"  , "cwib"  , "cwibs" , "cwis"  , "cwiss" , "cwing" , "cwij"  , "cwic"  ,  /*-- U+CDF8 .. U+CDFF --*/
   "cwik"  , "cwit"  , "cwip"  , "cwih"  , "cyu"   , "cyug"  , "cyugg" , "cyugs" ,  /*-- U+CE00 .. U+CE07 --*/
   "cyun"  , "cyunj" , "cyunh" , "cyud"  , "cyul"  , "cyulg" , "cyulm" , "cyulb" ,  /*-- U+CE08 .. U+CE0F --*/
   "cyuls" , "cyult" , "cyulp" , "cyulh" , "cyum"  , "cyub"  , "cyubs" , "cyus"  ,  /*-- U+CE10 .. U+CE17 --*/
   "cyuss" , "cyung" , "cyuj"  , "cyuc"  , "cyuk"  , "cyut"  , "cyup"  , "cyuh"  ,  /*-- U+CE18 .. U+CE1F --*/
   "ceu"   , "ceug"  , "ceugg" , "ceugs" , "ceun"  , "ceunj" , "ceunh" , "ceud"  ,  /*-- U+CE20 .. U+CE27 --*/
   "ceul"  , "ceulg" , "ceulm" , "ceulb" , "ceuls" , "ceult" , "ceulp" , "ceulh" ,  /*-- U+CE28 .. U+CE2F --*/
   "ceum"  , "ceub"  , "ceubs" , "ceus"  , "ceuss" , "ceung" , "ceuj"  , "ceuc"  ,  /*-- U+CE30 .. U+CE37 --*/
   "ceuk"  , "ceut"  , "ceup"  , "ceuh"  , "cyi"   , "cyig"  , "cyigg" , "cyigs" ,  /*-- U+CE38 .. U+CE3F --*/
   "cyin"  , "cyinj" , "cyinh" , "cyid"  , "cyil"  , "cyilg" , "cyilm" , "cyilb" ,  /*-- U+CE40 .. U+CE47 --*/
   "cyils" , "cyilt" , "cyilp" , "cyilh" , "cyim"  , "cyib"  , "cyibs" , "cyis"  ,  /*-- U+CE48 .. U+CE4F --*/
   "cyiss" , "cying" , "cyij"  , "cyic"  , "cyik"  , "cyit"  , "cyip"  , "cyih"  ,  /*-- U+CE50 .. U+CE57 --*/
   "ci"    , "cig"   , "cigg"  , "cigs"  , "cin"   , "cinj"  , "cinh"  , "cid"   ,  /*-- U+CE58 .. U+CE5F --*/
   "cil"   , "cilg"  , "cilm"  , "cilb"  , "cils"  , "cilt"  , "cilp"  , "cilh"  ,  /*-- U+CE60 .. U+CE67 --*/
   "cim"   , "cib"   , "cibs"  , "cis"   , "ciss"  , "cing"  , "cij"   , "cic"   ,  /*-- U+CE68 .. U+CE6F --*/
   "cik"   , "cit"   , "cip"   , "cih"   , "ka"    , "kag"   , "kagg"  , "kags"  ,  /*-- U+CE70 .. U+CE77 --*/
   "kan"   , "kanj"  , "kanh"  , "kad"   , "kal"   , "kalg"  , "kalm"  , "kalb"  ,  /*-- U+CE78 .. U+CE7F --*/
   "kals"  , "kalt"  , "kalp"  , "kalh"  , "kam"   , "kab"   , "kabs"  , "kas"   ,  /*-- U+CE80 .. U+CE87 --*/
   "kass"  , "kang"  , "kaj"   , "kac"   , "kak"   , "kat"   , "kap"   , "kah"   ,  /*-- U+CE88 .. U+CE8F --*/
   "kae"   , "kaeg"  , "kaegg" , "kaegs" , "kaen"  , "kaenj" , "kaenh" , "kaed"  ,  /*-- U+CE90 .. U+CE97 --*/
   "kael"  , "kaelg" , "kaelm" , "kaelb" , "kaels" , "kaelt" , "kaelp" , "kaelh" ,  /*-- U+CE98 .. U+CE9F --*/
   "kaem"  , "kaeb"  , "kaebs" , "kaes"  , "kaess" , "kaeng" , "kaej"  , "kaec"  ,  /*-- U+CEA0 .. U+CEA7 --*/
   "kaek"  , "kaet"  , "kaep"  , "kaeh"  , "kya"   , "kyag"  , "kyagg" , "kyags" ,  /*-- U+CEA8 .. U+CEAF --*/
   "kyan"  , "kyanj" , "kyanh" , "kyad"  , "kyal"  , "kyalg" , "kyalm" , "kyalb" ,  /*-- U+CEB0 .. U+CEB7 --*/
   "kyals" , "kyalt" , "kyalp" , "kyalh" , "kyam"  , "kyab"  , "kyabs" , "kyas"  ,  /*-- U+CEB8 .. U+CEBF --*/
   "kyass" , "kyang" , "kyaj"  , "kyac"  , "kyak"  , "kyat"  , "kyap"  , "kyah"  ,  /*-- U+CEC0 .. U+CEC7 --*/
   "kyae"  , "kyaeg" , "kyaegg", "kyaegs", "kyaen" , "kyaenj", "kyaenh", "kyaed" ,  /*-- U+CEC8 .. U+CECF --*/
   "kyael" , "kyaelg", "kyaelm", "kyaelb", "kyaels", "kyaelt", "kyaelp", "kyaelh",  /*-- U+CED0 .. U+CED7 --*/
   "kyaem" , "kyaeb" , "kyaebs", "kyaes" , "kyaess", "kyaeng", "kyaej" , "kyaec" ,  /*-- U+CED8 .. U+CEDF --*/
   "kyaek" , "kyaet" , "kyaep" , "kyaeh" , "keo"   , "keog"  , "keogg" , "keogs" ,  /*-- U+CEE0 .. U+CEE7 --*/
   "keon"  , "keonj" , "keonh" , "keod"  , "keol"  , "keolg" , "keolm" , "keolb" ,  /*-- U+CEE8 .. U+CEEF --*/
   "keols" , "keolt" , "keolp" , "keolh" , "keom"  , "keob"  , "keobs" , "keos"  ,  /*-- U+CEF0 .. U+CEF7 --*/
   "keoss" , "keong" , "keoj"  , "keoc"  , "keok"  , "keot"  , "keop"  , "keoh"  ,  /*-- U+CEF8 .. U+CEFF --*/
   "ke"    , "keg"   , "kegg"  , "kegs"  , "ken"   , "kenj"  , "kenh"  , "ked"   ,  /*-- U+CF00 .. U+CF07 --*/
   "kel"   , "kelg"  , "kelm"  , "kelb"  , "kels"  , "kelt"  , "kelp"  , "kelh"  ,  /*-- U+CF08 .. U+CF0F --*/
   "kem"   , "keb"   , "kebs"  , "kes"   , "kess"  , "keng"  , "kej"   , "kec"   ,  /*-- U+CF10 .. U+CF17 --*/
   "kek"   , "ket"   , "kep"   , "keh"   , "kyeo"  , "kyeog" , "kyeogg", "kyeogs",  /*-- U+CF18 .. U+CF1F --*/
   "kyeon" , "kyeonj", "kyeonh", "kyeod" , "kyeol" , "kyeolg", "kyeolm", "kyeolb",  /*-- U+CF20 .. U+CF27 --*/
   "kyeols", "kyeolt", "kyeolp", "kyeolh", "kyeom" , "kyeob" , "kyeobs", "kyeos" ,  /*-- U+CF28 .. U+CF2F --*/
   "kyeoss", "kyeong", "kyeoj" , "kyeoc" , "kyeok" , "kyeot" , "kyeop" , "kyeoh" ,  /*-- U+CF30 .. U+CF37 --*/
   "kye"   , "kyeg"  , "kyegg" , "kyegs" , "kyen"  , "kyenj" , "kyenh" , "kyed"  ,  /*-- U+CF38 .. U+CF3F --*/
   "kyel"  , "kyelg" , "kyelm" , "kyelb" , "kyels" , "kyelt" , "kyelp" , "kyelh" ,  /*-- U+CF40 .. U+CF47 --*/
   "kyem"  , "kyeb"  , "kyebs" , "kyes"  , "kyess" , "kyeng" , "kyej"  , "kyec"  ,  /*-- U+CF48 .. U+CF4F --*/
   "kyek"  , "kyet"  , "kyep"  , "kyeh"  , "ko"    , "kog"   , "kogg"  , "kogs"  ,  /*-- U+CF50 .. U+CF57 --*/
   "kon"   , "konj"  , "konh"  , "kod"   , "kol"   , "kolg"  , "kolm"  , "kolb"  ,  /*-- U+CF58 .. U+CF5F --*/
   "kols"  , "kolt"  , "kolp"  , "kolh"  , "kom"   , "kob"   , "kobs"  , "kos"   ,  /*-- U+CF60 .. U+CF67 --*/
   "koss"  , "kong"  , "koj"   , "koc"   , "kok"   , "kot"   , "kop"   , "koh"   ,  /*-- U+CF68 .. U+CF6F --*/
   "kwa"   , "kwag"  , "kwagg" , "kwags" , "kwan"  , "kwanj" , "kwanh" , "kwad"  ,  /*-- U+CF70 .. U+CF77 --*/
   "kwal"  , "kwalg" , "kwalm" , "kwalb" , "kwals" , "kwalt" , "kwalp" , "kwalh" ,  /*-- U+CF78 .. U+CF7F --*/
   "kwam"  , "kwab"  , "kwabs" , "kwas"  , "kwass" , "kwang" , "kwaj"  , "kwac"  ,  /*-- U+CF80 .. U+CF87 --*/
   "kwak"  , "kwat"  , "kwap"  , "kwah"  , "kwae"  , "kwaeg" , "kwaegg", "kwaegs",  /*-- U+CF88 .. U+CF8F --*/
   "kwaen" , "kwaenj", "kwaenh", "kwaed" , "kwael" , "kwaelg", "kwaelm", "kwaelb",  /*-- U+CF90 .. U+CF97 --*/
   "kwaels", "kwaelt", "kwaelp", "kwaelh", "kwaem" , "kwaeb" , "kwaebs", "kwaes" ,  /*-- U+CF98 .. U+CF9F --*/
   "kwaess", "kwaeng", "kwaej" , "kwaec" , "kwaek" , "kwaet" , "kwaep" , "kwaeh" ,  /*-- U+CFA0 .. U+CFA7 --*/
   "koe"   , "koeg"  , "koegg" , "koegs" , "koen"  , "koenj" , "koenh" , "koed"  ,  /*-- U+CFA8 .. U+CFAF --*/
   "koel"  , "koelg" , "koelm" , "koelb" , "koels" , "koelt" , "koelp" , "koelh" ,  /*-- U+CFB0 .. U+CFB7 --*/
   "koem"  , "koeb"  , "koebs" , "koes"  , "koess" , "koeng" , "koej"  , "koec"  ,  /*-- U+CFB8 .. U+CFBF --*/
   "koek"  , "koet"  , "koep"  , "koeh"  , "kyo"   , "kyog"  , "kyogg" , "kyogs" ,  /*-- U+CFC0 .. U+CFC7 --*/
   "kyon"  , "kyonj" , "kyonh" , "kyod"  , "kyol"  , "kyolg" , "kyolm" , "kyolb" ,  /*-- U+CFC8 .. U+CFCF --*/
   "kyols" , "kyolt" , "kyolp" , "kyolh" , "kyom"  , "kyob"  , "kyobs" , "kyos"  ,  /*-- U+CFD0 .. U+CFD7 --*/
   "kyoss" , "kyong" , "kyoj"  , "kyoc"  , "kyok"  , "kyot"  , "kyop"  , "kyoh"  ,  /*-- U+CFD8 .. U+CFDF --*/
   "ku"    , "kug"   , "kugg"  , "kugs"  , "kun"   , "kunj"  , "kunh"  , "kud"   ,  /*-- U+CFE0 .. U+CFE7 --*/
   "kul"   , "kulg"  , "kulm"  , "kulb"  , "kuls"  , "kult"  , "kulp"  , "kulh"  ,  /*-- U+CFE8 .. U+CFEF --*/
   "kum"   , "kub"   , "kubs"  , "kus"   , "kuss"  , "kung"  , "kuj"   , "kuc"   ,  /*-- U+CFF0 .. U+CFF7 --*/
   "kuk"   , "kut"   , "kup"   , "kuh"   , "kweo"  , "kweog" , "kweogg", "kweogs",  /*-- U+CFF8 .. U+CFFF --*/
   "kweon" , "kweonj", "kweonh", "kweod" , "kweol" , "kweolg", "kweolm", "kweolb",  /*-- U+D000 .. U+D007 --*/
   "kweols", "kweolt", "kweolp", "kweolh", "kweom" , "kweob" , "kweobs", "kweos" ,  /*-- U+D008 .. U+D00F --*/
   "kweoss", "kweong", "kweoj" , "kweoc" , "kweok" , "kweot" , "kweop" , "kweoh" ,  /*-- U+D010 .. U+D017 --*/
   "kwe"   , "kweg"  , "kwegg" , "kwegs" , "kwen"  , "kwenj" , "kwenh" , "kwed"  ,  /*-- U+D018 .. U+D01F --*/
   "kwel"  , "kwelg" , "kwelm" , "kwelb" , "kwels" , "kwelt" , "kwelp" , "kwelh" ,  /*-- U+D020 .. U+D027 --*/
   "kwem"  , "kweb"  , "kwebs" , "kwes"  , "kwess" , "kweng" , "kwej"  , "kwec"  ,  /*-- U+D028 .. U+D02F --*/
   "kwek"  , "kwet"  , "kwep"  , "kweh"  , "kwi"   , "kwig"  , "kwigg" , "kwigs" ,  /*-- U+D030 .. U+D037 --*/
   "kwin"  , "kwinj" , "kwinh" , "kwid"  , "kwil"  , "kwilg" , "kwilm" , "kwilb" ,  /*-- U+D038 .. U+D03F --*/
   "kwils" , "kwilt" , "kwilp" , "kwilh" , "kwim"  , "kwib"  , "kwibs" , "kwis"  ,  /*-- U+D040 .. U+D047 --*/
   "kwiss" , "kwing" , "kwij"  , "kwic"  , "kwik"  , "kwit"  , "kwip"  , "kwih"  ,  /*-- U+D048 .. U+D04F --*/
   "kyu"   , "kyug"  , "kyugg" , "kyugs" , "kyun"  , "kyunj" , "kyunh" , "kyud"  ,  /*-- U+D050 .. U+D057 --*/
   "kyul"  , "kyulg" , "kyulm" , "kyulb" , "kyuls" , "kyult" , "kyulp" , "kyulh" ,  /*-- U+D058 .. U+D05F --*/
   "kyum"  , "kyub"  , "kyubs" , "kyus"  , "kyuss" , "kyung" , "kyuj"  , "kyuc"  ,  /*-- U+D060 .. U+D067 --*/
   "kyuk"  , "kyut"  , "kyup"  , "kyuh"  , "keu"   , "keug"  , "keugg" , "keugs" ,  /*-- U+D068 .. U+D06F --*/
   "keun"  , "keunj" , "keunh" , "keud"  , "keul"  , "keulg" , "keulm" , "keulb" ,  /*-- U+D070 .. U+D077 --*/
   "keuls" , "keult" , "keulp" , "keulh" , "keum"  , "keub"  , "keubs" , "keus"  ,  /*-- U+D078 .. U+D07F --*/
   "keuss" , "keung" , "keuj"  , "keuc"  , "keuk"  , "keut"  , "keup"  , "keuh"  ,  /*-- U+D080 .. U+D087 --*/
   "kyi"   , "kyig"  , "kyigg" , "kyigs" , "kyin"  , "kyinj" , "kyinh" , "kyid"  ,  /*-- U+D088 .. U+D08F --*/
   "kyil"  , "kyilg" , "kyilm" , "kyilb" , "kyils" , "kyilt" , "kyilp" , "kyilh" ,  /*-- U+D090 .. U+D097 --*/
   "kyim"  , "kyib"  , "kyibs" , "kyis"  , "kyiss" , "kying" , "kyij"  , "kyic"  ,  /*-- U+D098 .. U+D09F --*/
   "kyik"  , "kyit"  , "kyip"  , "kyih"  , "ki"    , "kig"   , "kigg"  , "kigs"  ,  /*-- U+D0A0 .. U+D0A7 --*/
   "kin"   , "kinj"  , "kinh"  , "kid"   , "kil"   , "kilg"  , "kilm"  , "kilb"  ,  /*-- U+D0A8 .. U+D0AF --*/
   "kils"  , "kilt"  , "kilp"  , "kilh"  , "kim"   , "kib"   , "kibs"  , "kis"   ,  /*-- U+D0B0 .. U+D0B7 --*/
   "kiss"  , "king"  , "kij"   , "kic"   , "kik"   , "kit"   , "kip"   , "kih"   ,  /*-- U+D0B8 .. U+D0BF --*/
   "ta"    , "tag"   , "tagg"  , "tags"  , "tan"   , "tanj"  , "tanh"  , "tad"   ,  /*-- U+D0C0 .. U+D0C7 --*/
   "tal"   , "talg"  , "talm"  , "talb"  , "tals"  , "talt"  , "talp"  , "talh"  ,  /*-- U+D0C8 .. U+D0CF --*/
   "tam"   , "tab"   , "tabs"  , "tas"   , "tass"  , "tang"  , "taj"   , "tac"   ,  /*-- U+D0D0 .. U+D0D7 --*/
   "tak"   , "tat"   , "tap"   , "tah"   , "tae"   , "taeg"  , "taegg" , "taegs" ,  /*-- U+D0D8 .. U+D0DF --*/
   "taen"  , "taenj" , "taenh" , "taed"  , "tael"  , "taelg" , "taelm" , "taelb" ,  /*-- U+D0E0 .. U+D0E7 --*/
   "taels" , "taelt" , "taelp" , "taelh" , "taem"  , "taeb"  , "taebs" , "taes"  ,  /*-- U+D0E8 .. U+D0EF --*/
   "taess" , "taeng" , "taej"  , "taec"  , "taek"  , "taet"  , "taep"  , "taeh"  ,  /*-- U+D0F0 .. U+D0F7 --*/
   "tya"   , "tyag"  , "tyagg" , "tyags" , "tyan"  , "tyanj" , "tyanh" , "tyad"  ,  /*-- U+D0F8 .. U+D0FF --*/
   "tyal"  , "tyalg" , "tyalm" , "tyalb" , "tyals" , "tyalt" , "tyalp" , "tyalh" ,  /*-- U+D100 .. U+D107 --*/
   "tyam"  , "tyab"  , "tyabs" , "tyas"  , "tyass" , "tyang" , "tyaj"  , "tyac"  ,  /*-- U+D108 .. U+D10F --*/
   "tyak"  , "tyat"  , "tyap"  , "tyah"  , "tyae"  , "tyaeg" , "tyaegg", "tyaegs",  /*-- U+D110 .. U+D117 --*/
   "tyaen" , "tyaenj", "tyaenh", "tyaed" , "tyael" , "tyaelg", "tyaelm", "tyaelb",  /*-- U+D118 .. U+D11F --*/
   "tyaels", "tyaelt", "tyaelp", "tyaelh", "tyaem" , "tyaeb" , "tyaebs", "tyaes" ,  /*-- U+D120 .. U+D127 --*/
   "tyaess", "tyaeng", "tyaej" , "tyaec" , "tyaek" , "tyaet" , "tyaep" , "tyaeh" ,  /*-- U+D128 .. U+D12F --*/
   "teo"   , "teog"  , "teogg" , "teogs" , "teon"  , "teonj" , "teonh" , "teod"  ,  /*-- U+D130 .. U+D137 --*/
   "teol"  , "teolg" , "teolm" , "teolb" , "teols" , "teolt" , "teolp" , "teolh" ,  /*-- U+D138 .. U+D13F --*/
   "teom"  , "teob"  , "teobs" , "teos"  , "teoss" , "teong" , "teoj"  , "teoc"  ,  /*-- U+D140 .. U+D147 --*/
   "teok"  , "teot"  , "teop"  , "teoh"  , "te"    , "teg"   , "tegg"  , "tegs"  ,  /*-- U+D148 .. U+D14F --*/
   "ten"   , "tenj"  , "tenh"  , "ted"   , "tel"   , "telg"  , "telm"  , "telb"  ,  /*-- U+D150 .. U+D157 --*/
   "tels"  , "telt"  , "telp"  , "telh"  , "tem"   , "teb"   , "tebs"  , "tes"   ,  /*-- U+D158 .. U+D15F --*/
   "tess"  , "teng"  , "tej"   , "tec"   , "tek"   , "tet"   , "tep"   , "teh"   ,  /*-- U+D160 .. U+D167 --*/
   "tyeo"  , "tyeog" , "tyeogg", "tyeogs", "tyeon" , "tyeonj", "tyeonh", "tyeod" ,  /*-- U+D168 .. U+D16F --*/
   "tyeol" , "tyeolg", "tyeolm", "tyeolb", "tyeols", "tyeolt", "tyeolp", "tyeolh",  /*-- U+D170 .. U+D177 --*/
   "tyeom" , "tyeob" , "tyeobs", "tyeos" , "tyeoss", "tyeong", "tyeoj" , "tyeoc" ,  /*-- U+D178 .. U+D17F --*/
   "tyeok" , "tyeot" , "tyeop" , "tyeoh" , "tye"   , "tyeg"  , "tyegg" , "tyegs" ,  /*-- U+D180 .. U+D187 --*/
   "tyen"  , "tyenj" , "tyenh" , "tyed"  , "tyel"  , "tyelg" , "tyelm" , "tyelb" ,  /*-- U+D188 .. U+D18F --*/
   "tyels" , "tyelt" , "tyelp" , "tyelh" , "tyem"  , "tyeb"  , "tyebs" , "tyes"  ,  /*-- U+D190 .. U+D197 --*/
   "tyess" , "tyeng" , "tyej"  , "tyec"  , "tyek"  , "tyet"  , "tyep"  , "tyeh"  ,  /*-- U+D198 .. U+D19F --*/
   "to"    , "tog"   , "togg"  , "togs"  , "ton"   , "tonj"  , "tonh"  , "tod"   ,  /*-- U+D1A0 .. U+D1A7 --*/
   "tol"   , "tolg"  , "tolm"  , "tolb"  , "tols"  , "tolt"  , "tolp"  , "tolh"  ,  /*-- U+D1A8 .. U+D1AF --*/
   "tom"   , "tob"   , "tobs"  , "tos"   , "toss"  , "tong"  , "toj"   , "toc"   ,  /*-- U+D1B0 .. U+D1B7 --*/
   "tok"   , "tot"   , "top"   , "toh"   , "twa"   , "twag"  , "twagg" , "twags" ,  /*-- U+D1B8 .. U+D1BF --*/
   "twan"  , "twanj" , "twanh" , "twad"  , "twal"  , "twalg" , "twalm" , "twalb" ,  /*-- U+D1C0 .. U+D1C7 --*/
   "twals" , "twalt" , "twalp" , "twalh" , "twam"  , "twab"  , "twabs" , "twas"  ,  /*-- U+D1C8 .. U+D1CF --*/
   "twass" , "twang" , "twaj"  , "twac"  , "twak"  , "twat"  , "twap"  , "twah"  ,  /*-- U+D1D0 .. U+D1D7 --*/
   "twae"  , "twaeg" , "twaegg", "twaegs", "twaen" , "twaenj", "twaenh", "twaed" ,  /*-- U+D1D8 .. U+D1DF --*/
   "twael" , "twaelg", "twaelm", "twaelb", "twaels", "twaelt", "twaelp", "twaelh",  /*-- U+D1E0 .. U+D1E7 --*/
   "twaem" , "twaeb" , "twaebs", "twaes" , "twaess", "twaeng", "twaej" , "twaec" ,  /*-- U+D1E8 .. U+D1EF --*/
   "twaek" , "twaet" , "twaep" , "twaeh" , "toe"   , "toeg"  , "toegg" , "toegs" ,  /*-- U+D1F0 .. U+D1F7 --*/
   "toen"  , "toenj" , "toenh" , "toed"  , "toel"  , "toelg" , "toelm" , "toelb" ,  /*-- U+D1F8 .. U+D1FF --*/
   "toels" , "toelt" , "toelp" , "toelh" , "toem"  , "toeb"  , "toebs" , "toes"  ,  /*-- U+D200 .. U+D207 --*/
   "toess" , "toeng" , "toej"  , "toec"  , "toek"  , "toet"  , "toep"  , "toeh"  ,  /*-- U+D208 .. U+D20F --*/
   "tyo"   , "tyog"  , "tyogg" , "tyogs" , "tyon"  , "tyonj" , "tyonh" , "tyod"  ,  /*-- U+D210 .. U+D217 --*/
   "tyol"  , "tyolg" , "tyolm" , "tyolb" , "tyols" , "tyolt" , "tyolp" , "tyolh" ,  /*-- U+D218 .. U+D21F --*/
   "tyom"  , "tyob"  , "tyobs" , "tyos"  , "tyoss" , "tyong" , "tyoj"  , "tyoc"  ,  /*-- U+D220 .. U+D227 --*/
   "tyok"  , "tyot"  , "tyop"  , "tyoh"  , "tu"    , "tug"   , "tugg"  , "tugs"  ,  /*-- U+D228 .. U+D22F --*/
   "tun"   , "tunj"  , "tunh"  , "tud"   , "tul"   , "tulg"  , "tulm"  , "tulb"  ,  /*-- U+D230 .. U+D237 --*/
   "tuls"  , "tult"  , "tulp"  , "tulh"  , "tum"   , "tub"   , "tubs"  , "tus"   ,  /*-- U+D238 .. U+D23F --*/
   "tuss"  , "tung"  , "tuj"   , "tuc"   , "tuk"   , "tut"   , "tup"   , "tuh"   ,  /*-- U+D240 .. U+D247 --*/
   "tweo"  , "tweog" , "tweogg", "tweogs", "tweon" , "tweonj", "tweonh", "tweod" ,  /*-- U+D248 .. U+D24F --*/
   "tweol" , "tweolg", "tweolm", "tweolb", "tweols", "tweolt", "tweolp", "tweolh",  /*-- U+D250 .. U+D257 --*/
   "tweom" , "tweob" , "tweobs", "tweos" , "tweoss", "tweong", "tweoj" , "tweoc" ,  /*-- U+D258 .. U+D25F --*/
   "tweok" , "tweot" , "tweop" , "tweoh" , "twe"   , "tweg"  , "twegg" , "twegs" ,  /*-- U+D260 .. U+D267 --*/
   "twen"  , "twenj" , "twenh" , "twed"  , "twel"  , "twelg" , "twelm" , "twelb" ,  /*-- U+D268 .. U+D26F --*/
   "twels" , "twelt" , "twelp" , "twelh" , "twem"  , "tweb"  , "twebs" , "twes"  ,  /*-- U+D270 .. U+D277 --*/
   "twess" , "tweng" , "twej"  , "twec"  , "twek"  , "twet"  , "twep"  , "tweh"  ,  /*-- U+D278 .. U+D27F --*/
   "twi"   , "twig"  , "twigg" , "twigs" , "twin"  , "twinj" , "twinh" , "twid"  ,  /*-- U+D280 .. U+D287 --*/
   "twil"  , "twilg" , "twilm" , "twilb" , "twils" , "twilt" , "twilp" , "twilh" ,  /*-- U+D288 .. U+D28F --*/
   "twim"  , "twib"  , "twibs" , "twis"  , "twiss" , "twing" , "twij"  , "twic"  ,  /*-- U+D290 .. U+D297 --*/
   "twik"  , "twit"  , "twip"  , "twih"  , "tyu"   , "tyug"  , "tyugg" , "tyugs" ,  /*-- U+D298 .. U+D29F --*/
   "tyun"  , "tyunj" , "tyunh" , "tyud"  , "tyul"  , "tyulg" , "tyulm" , "tyulb" ,  /*-- U+D2A0 .. U+D2A7 --*/
   "tyuls" , "tyult" , "tyulp" , "tyulh" , "tyum"  , "tyub"  , "tyubs" , "tyus"  ,  /*-- U+D2A8 .. U+D2AF --*/
   "tyuss" , "tyung" , "tyuj"  , "tyuc"  , "tyuk"  , "tyut"  , "tyup"  , "tyuh"  ,  /*-- U+D2B0 .. U+D2B7 --*/
   "teu"   , "teug"  , "teugg" , "teugs" , "teun"  , "teunj" , "teunh" , "teud"  ,  /*-- U+D2B8 .. U+D2BF --*/
   "teul"  , "teulg" , "teulm" , "teulb" , "teuls" , "teult" , "teulp" , "teulh" ,  /*-- U+D2C0 .. U+D2C7 --*/
   "teum"  , "teub"  , "teubs" , "teus"  , "teuss" , "teung" , "teuj"  , "teuc"  ,  /*-- U+D2C8 .. U+D2CF --*/
   "teuk"  , "teut"  , "teup"  , "teuh"  , "tyi"   , "tyig"  , "tyigg" , "tyigs" ,  /*-- U+D2D0 .. U+D2D7 --*/
   "tyin"  , "tyinj" , "tyinh" , "tyid"  , "tyil"  , "tyilg" , "tyilm" , "tyilb" ,  /*-- U+D2D8 .. U+D2DF --*/
   "tyils" , "tyilt" , "tyilp" , "tyilh" , "tyim"  , "tyib"  , "tyibs" , "tyis"  ,  /*-- U+D2E0 .. U+D2E7 --*/
   "tyiss" , "tying" , "tyij"  , "tyic"  , "tyik"  , "tyit"  , "tyip"  , "tyih"  ,  /*-- U+D2E8 .. U+D2EF --*/
   "ti"    , "tig"   , "tigg"  , "tigs"  , "tin"   , "tinj"  , "tinh"  , "tid"   ,  /*-- U+D2F0 .. U+D2F7 --*/
   "til"   , "tilg"  , "tilm"  , "tilb"  , "tils"  , "tilt"  , "tilp"  , "tilh"  ,  /*-- U+D2F8 .. U+D2FF --*/
   "tim"   , "tib"   , "tibs"  , "tis"   , "tiss"  , "ting"  , "tij"   , "tic"   ,  /*-- U+D300 .. U+D307 --*/
   "tik"   , "tit"   , "tip"   , "tih"   , "pa"    , "pag"   , "pagg"  , "pags"  ,  /*-- U+D308 .. U+D30F --*/
   "pan"   , "panj"  , "panh"  , "pad"   , "pal"   , "palg"  , "palm"  , "palb"  ,  /*-- U+D310 .. U+D317 --*/
   "pals"  , "palt"  , "palp"  , "palh"  , "pam"   , "pab"   , "pabs"  , "pas"   ,  /*-- U+D318 .. U+D31F --*/
   "pass"  , "pang"  , "paj"   , "pac"   , "pak"   , "pat"   , "pap"   , "pah"   ,  /*-- U+D320 .. U+D327 --*/
   "pae"   , "paeg"  , "paegg" , "paegs" , "paen"  , "paenj" , "paenh" , "paed"  ,  /*-- U+D328 .. U+D32F --*/
   "pael"  , "paelg" , "paelm" , "paelb" , "paels" , "paelt" , "paelp" , "paelh" ,  /*-- U+D330 .. U+D337 --*/
   "paem"  , "paeb"  , "paebs" , "paes"  , "paess" , "paeng" , "paej"  , "paec"  ,  /*-- U+D338 .. U+D33F --*/
   "paek"  , "paet"  , "paep"  , "paeh"  , "pya"   , "pyag"  , "pyagg" , "pyags" ,  /*-- U+D340 .. U+D347 --*/
   "pyan"  , "pyanj" , "pyanh" , "pyad"  , "pyal"  , "pyalg" , "pyalm" , "pyalb" ,  /*-- U+D348 .. U+D34F --*/
   "pyals" , "pyalt" , "pyalp" , "pyalh" , "pyam"  , "pyab"  , "pyabs" , "pyas"  ,  /*-- U+D350 .. U+D357 --*/
   "pyass" , "pyang" , "pyaj"  , "pyac"  , "pyak"  , "pyat"  , "pyap"  , "pyah"  ,  /*-- U+D358 .. U+D35F --*/
   "pyae"  , "pyaeg" , "pyaegg", "pyaegs", "pyaen" , "pyaenj", "pyaenh", "pyaed" ,  /*-- U+D360 .. U+D367 --*/
   "pyael" , "pyaelg", "pyaelm", "pyaelb", "pyaels", "pyaelt", "pyaelp", "pyaelh",  /*-- U+D368 .. U+D36F --*/
   "pyaem" , "pyaeb" , "pyaebs", "pyaes" , "pyaess", "pyaeng", "pyaej" , "pyaec" ,  /*-- U+D370 .. U+D377 --*/
   "pyaek" , "pyaet" , "pyaep" , "pyaeh" , "peo"   , "peog"  , "peogg" , "peogs" ,  /*-- U+D378 .. U+D37F --*/
   "peon"  , "peonj" , "peonh" , "peod"  , "peol"  , "peolg" , "peolm" , "peolb" ,  /*-- U+D380 .. U+D387 --*/
   "peols" , "peolt" , "peolp" , "peolh" , "peom"  , "peob"  , "peobs" , "peos"  ,  /*-- U+D388 .. U+D38F --*/
   "peoss" , "peong" , "peoj"  , "peoc"  , "peok"  , "peot"  , "peop"  , "peoh"  ,  /*-- U+D390 .. U+D397 --*/
   "pe"    , "peg"   , "pegg"  , "pegs"  , "pen"   , "penj"  , "penh"  , "ped"   ,  /*-- U+D398 .. U+D39F --*/
   "pel"   , "pelg"  , "pelm"  , "pelb"  , "pels"  , "pelt"  , "pelp"  , "pelh"  ,  /*-- U+D3A0 .. U+D3A7 --*/
   "pem"   , "peb"   , "pebs"  , "pes"   , "pess"  , "peng"  , "pej"   , "pec"   ,  /*-- U+D3A8 .. U+D3AF --*/
   "pek"   , "pet"   , "pep"   , "peh"   , "pyeo"  , "pyeog" , "pyeogg", "pyeogs",  /*-- U+D3B0 .. U+D3B7 --*/
   "pyeon" , "pyeonj", "pyeonh", "pyeod" , "pyeol" , "pyeolg", "pyeolm", "pyeolb",  /*-- U+D3B8 .. U+D3BF --*/
   "pyeols", "pyeolt", "pyeolp", "pyeolh", "pyeom" , "pyeob" , "pyeobs", "pyeos" ,  /*-- U+D3C0 .. U+D3C7 --*/
   "pyeoss", "pyeong", "pyeoj" , "pyeoc" , "pyeok" , "pyeot" , "pyeop" , "pyeoh" ,  /*-- U+D3C8 .. U+D3CF --*/
   "pye"   , "pyeg"  , "pyegg" , "pyegs" , "pyen"  , "pyenj" , "pyenh" , "pyed"  ,  /*-- U+D3D0 .. U+D3D7 --*/
   "pyel"  , "pyelg" , "pyelm" , "pyelb" , "pyels" , "pyelt" , "pyelp" , "pyelh" ,  /*-- U+D3D8 .. U+D3DF --*/
   "pyem"  , "pyeb"  , "pyebs" , "pyes"  , "pyess" , "pyeng" , "pyej"  , "pyec"  ,  /*-- U+D3E0 .. U+D3E7 --*/
   "pyek"  , "pyet"  , "pyep"  , "pyeh"  , "po"    , "pog"   , "pogg"  , "pogs"  ,  /*-- U+D3E8 .. U+D3EF --*/
   "pon"   , "ponj"  , "ponh"  , "pod"   , "pol"   , "polg"  , "polm"  , "polb"  ,  /*-- U+D3F0 .. U+D3F7 --*/
   "pols"  , "polt"  , "polp"  , "polh"  , "pom"   , "pob"   , "pobs"  , "pos"   ,  /*-- U+D3F8 .. U+D3FF --*/
   "poss"  , "pong"  , "poj"   , "poc"   , "pok"   , "pot"   , "pop"   , "poh"   ,  /*-- U+D400 .. U+D407 --*/
   "pwa"   , "pwag"  , "pwagg" , "pwags" , "pwan"  , "pwanj" , "pwanh" , "pwad"  ,  /*-- U+D408 .. U+D40F --*/
   "pwal"  , "pwalg" , "pwalm" , "pwalb" , "pwals" , "pwalt" , "pwalp" , "pwalh" ,  /*-- U+D410 .. U+D417 --*/
   "pwam"  , "pwab"  , "pwabs" , "pwas"  , "pwass" , "pwang" , "pwaj"  , "pwac"  ,  /*-- U+D418 .. U+D41F --*/
   "pwak"  , "pwat"  , "pwap"  , "pwah"  , "pwae"  , "pwaeg" , "pwaegg", "pwaegs",  /*-- U+D420 .. U+D427 --*/
   "pwaen" , "pwaenj", "pwaenh", "pwaed" , "pwael" , "pwaelg", "pwaelm", "pwaelb",  /*-- U+D428 .. U+D42F --*/
   "pwaels", "pwaelt", "pwaelp", "pwaelh", "pwaem" , "pwaeb" , "pwaebs", "pwaes" ,  /*-- U+D430 .. U+D437 --*/
   "pwaess", "pwaeng", "pwaej" , "pwaec" , "pwaek" , "pwaet" , "pwaep" , "pwaeh" ,  /*-- U+D438 .. U+D43F --*/
   "poe"   , "poeg"  , "poegg" , "poegs" , "poen"  , "poenj" , "poenh" , "poed"  ,  /*-- U+D440 .. U+D447 --*/
   "poel"  , "poelg" , "poelm" , "poelb" , "poels" , "poelt" , "poelp" , "poelh" ,  /*-- U+D448 .. U+D44F --*/
   "poem"  , "poeb"  , "poebs" , "poes"  , "poess" , "poeng" , "poej"  , "poec"  ,  /*-- U+D450 .. U+D457 --*/
   "poek"  , "poet"  , "poep"  , "poeh"  , "pyo"   , "pyog"  , "pyogg" , "pyogs" ,  /*-- U+D458 .. U+D45F --*/
   "pyon"  , "pyonj" , "pyonh" , "pyod"  , "pyol"  , "pyolg" , "pyolm" , "pyolb" ,  /*-- U+D460 .. U+D467 --*/
   "pyols" , "pyolt" , "pyolp" , "pyolh" , "pyom"  , "pyob"  , "pyobs" , "pyos"  ,  /*-- U+D468 .. U+D46F --*/
   "pyoss" , "pyong" , "pyoj"  , "pyoc"  , "pyok"  , "pyot"  , "pyop"  , "pyoh"  ,  /*-- U+D470 .. U+D477 --*/
   "pu"    , "pug"   , "pugg"  , "pugs"  , "pun"   , "punj"  , "punh"  , "pud"   ,  /*-- U+D478 .. U+D47F --*/
   "pul"   , "pulg"  , "pulm"  , "pulb"  , "puls"  , "pult"  , "pulp"  , "pulh"  ,  /*-- U+D480 .. U+D487 --*/
   "pum"   , "pub"   , "pubs"  , "pus"   , "puss"  , "pung"  , "puj"   , "puc"   ,  /*-- U+D488 .. U+D48F --*/
   "puk"   , "put"   , "pup"   , "puh"   , "pweo"  , "pweog" , "pweogg", "pweogs",  /*-- U+D490 .. U+D497 --*/
   "pweon" , "pweonj", "pweonh", "pweod" , "pweol" , "pweolg", "pweolm", "pweolb",  /*-- U+D498 .. U+D49F --*/
   "pweols", "pweolt", "pweolp", "pweolh", "pweom" , "pweob" , "pweobs", "pweos" ,  /*-- U+D4A0 .. U+D4A7 --*/
   "pweoss", "pweong", "pweoj" , "pweoc" , "pweok" , "pweot" , "pweop" , "pweoh" ,  /*-- U+D4A8 .. U+D4AF --*/
   "pwe"   , "pweg"  , "pwegg" , "pwegs" , "pwen"  , "pwenj" , "pwenh" , "pwed"  ,  /*-- U+D4B0 .. U+D4B7 --*/
   "pwel"  , "pwelg" , "pwelm" , "pwelb" , "pwels" , "pwelt" , "pwelp" , "pwelh" ,  /*-- U+D4B8 .. U+D4BF --*/
   "pwem"  , "pweb"  , "pwebs" , "pwes"  , "pwess" , "pweng" , "pwej"  , "pwec"  ,  /*-- U+D4C0 .. U+D4C7 --*/
   "pwek"  , "pwet"  , "pwep"  , "pweh"  , "pwi"   , "pwig"  , "pwigg" , "pwigs" ,  /*-- U+D4C8 .. U+D4CF --*/
   "pwin"  , "pwinj" , "pwinh" , "pwid"  , "pwil"  , "pwilg" , "pwilm" , "pwilb" ,  /*-- U+D4D0 .. U+D4D7 --*/
   "pwils" , "pwilt" , "pwilp" , "pwilh" , "pwim"  , "pwib"  , "pwibs" , "pwis"  ,  /*-- U+D4D8 .. U+D4DF --*/
   "pwiss" , "pwing" , "pwij"  , "pwic"  , "pwik"  , "pwit"  , "pwip"  , "pwih"  ,  /*-- U+D4E0 .. U+D4E7 --*/
   "pyu"   , "pyug"  , "pyugg" , "pyugs" , "pyun"  , "pyunj" , "pyunh" , "pyud"  ,  /*-- U+D4E8 .. U+D4EF --*/
   "pyul"  , "pyulg" , "pyulm" , "pyulb" , "pyuls" , "pyult" , "pyulp" , "pyulh" ,  /*-- U+D4F0 .. U+D4F7 --*/
   "pyum"  , "pyub"  , "pyubs" , "pyus"  , "pyuss" , "pyung" , "pyuj"  , "pyuc"  ,  /*-- U+D4F8 .. U+D4FF --*/
   "pyuk"  , "pyut"  , "pyup"  , "pyuh"  , "peu"   , "peug"  , "peugg" , "peugs" ,  /*-- U+D500 .. U+D507 --*/
   "peun"  , "peunj" , "peunh" , "peud"  , "peul"  , "peulg" , "peulm" , "peulb" ,  /*-- U+D508 .. U+D50F --*/
   "peuls" , "peult" , "peulp" , "peulh" , "peum"  , "peub"  , "peubs" , "peus"  ,  /*-- U+D510 .. U+D517 --*/
   "peuss" , "peung" , "peuj"  , "peuc"  , "peuk"  , "peut"  , "peup"  , "peuh"  ,  /*-- U+D518 .. U+D51F --*/
   "pyi"   , "pyig"  , "pyigg" , "pyigs" , "pyin"  , "pyinj" , "pyinh" , "pyid"  ,  /*-- U+D520 .. U+D527 --*/
   "pyil"  , "pyilg" , "pyilm" , "pyilb" , "pyils" , "pyilt" , "pyilp" , "pyilh" ,  /*-- U+D528 .. U+D52F --*/
   "pyim"  , "pyib"  , "pyibs" , "pyis"  , "pyiss" , "pying" , "pyij"  , "pyic"  ,  /*-- U+D530 .. U+D537 --*/
   "pyik"  , "pyit"  , "pyip"  , "pyih"  , "pi"    , "pig"   , "pigg"  , "pigs"  ,  /*-- U+D538 .. U+D53F --*/
   "pin"   , "pinj"  , "pinh"  , "pid"   , "pil"   , "pilg"  , "pilm"  , "pilb"  ,  /*-- U+D540 .. U+D547 --*/
   "pils"  , "pilt"  , "pilp"  , "pilh"  , "pim"   , "pib"   , "pibs"  , "pis"   ,  /*-- U+D548 .. U+D54F --*/
   "piss"  , "ping"  , "pij"   , "pic"   , "pik"   , "pit"   , "pip"   , "pih"   ,  /*-- U+D550 .. U+D557 --*/
   "ha"    , "hag"   , "hagg"  , "hags"  , "han"   , "hanj"  , "hanh"  , "had"   ,  /*-- U+D558 .. U+D55F --*/
   "hal"   , "halg"  , "halm"  , "halb"  , "hals"  , "halt"  , "halp"  , "halh"  ,  /*-- U+D560 .. U+D567 --*/
   "ham"   , "hab"   , "habs"  , "has"   , "hass"  , "hang"  , "haj"   , "hac"   ,  /*-- U+D568 .. U+D56F --*/
   "hak"   , "hat"   , "hap"   , "hah"   , "hae"   , "haeg"  , "haegg" , "haegs" ,  /*-- U+D570 .. U+D577 --*/
   "haen"  , "haenj" , "haenh" , "haed"  , "hael"  , "haelg" , "haelm" , "haelb" ,  /*-- U+D578 .. U+D57F --*/
   "haels" , "haelt" , "haelp" , "haelh" , "haem"  , "haeb"  , "haebs" , "haes"  ,  /*-- U+D580 .. U+D587 --*/
   "haess" , "haeng" , "haej"  , "haec"  , "haek"  , "haet"  , "haep"  , "haeh"  ,  /*-- U+D588 .. U+D58F --*/
   "hya"   , "hyag"  , "hyagg" , "hyags" , "hyan"  , "hyanj" , "hyanh" , "hyad"  ,  /*-- U+D590 .. U+D597 --*/
   "hyal"  , "hyalg" , "hyalm" , "hyalb" , "hyals" , "hyalt" , "hyalp" , "hyalh" ,  /*-- U+D598 .. U+D59F --*/
   "hyam"  , "hyab"  , "hyabs" , "hyas"  , "hyass" , "hyang" , "hyaj"  , "hyac"  ,  /*-- U+D5A0 .. U+D5A7 --*/
   "hyak"  , "hyat"  , "hyap"  , "hyah"  , "hyae"  , "hyaeg" , "hyaegg", "hyaegs",  /*-- U+D5A8 .. U+D5AF --*/
   "hyaen" , "hyaenj", "hyaenh", "hyaed" , "hyael" , "hyaelg", "hyaelm", "hyaelb",  /*-- U+D5B0 .. U+D5B7 --*/
   "hyaels", "hyaelt", "hyaelp", "hyaelh", "hyaem" , "hyaeb" , "hyaebs", "hyaes" ,  /*-- U+D5B8 .. U+D5BF --*/
   "hyaess", "hyaeng", "hyaej" , "hyaec" , "hyaek" , "hyaet" , "hyaep" , "hyaeh" ,  /*-- U+D5C0 .. U+D5C7 --*/
   "heo"   , "heog"  , "heogg" , "heogs" , "heon"  , "heonj" , "heonh" , "heod"  ,  /*-- U+D5C8 .. U+D5CF --*/
   "heol"  , "heolg" , "heolm" , "heolb" , "heols" , "heolt" , "heolp" , "heolh" ,  /*-- U+D5D0 .. U+D5D7 --*/
   "heom"  , "heob"  , "heobs" , "heos"  , "heoss" , "heong" , "heoj"  , "heoc"  ,  /*-- U+D5D8 .. U+D5DF --*/
   "heok"  , "heot"  , "heop"  , "heoh"  , "he"    , "heg"   , "hegg"  , "hegs"  ,  /*-- U+D5E0 .. U+D5E7 --*/
   "hen"   , "henj"  , "henh"  , "hed"   , "hel"   , "helg"  , "helm"  , "helb"  ,  /*-- U+D5E8 .. U+D5EF --*/
   "hels"  , "helt"  , "help"  , "helh"  , "hem"   , "heb"   , "hebs"  , "hes"   ,  /*-- U+D5F0 .. U+D5F7 --*/
   "hess"  , "heng"  , "hej"   , "hec"   , "hek"   , "het"   , "hep"   , "heh"   ,  /*-- U+D5F8 .. U+D5FF --*/
   "hyeo"  , "hyeog" , "hyeogg", "hyeogs", "hyeon" , "hyeonj", "hyeonh", "hyeod" ,  /*-- U+D600 .. U+D607 --*/
   "hyeol" , "hyeolg", "hyeolm", "hyeolb", "hyeols", "hyeolt", "hyeolp", "hyeolh",  /*-- U+D608 .. U+D60F --*/
   "hyeom" , "hyeob" , "hyeobs", "hyeos" , "hyeoss", "hyeong", "hyeoj" , "hyeoc" ,  /*-- U+D610 .. U+D617 --*/
   "hyeok" , "hyeot" , "hyeop" , "hyeoh" , "hye"   , "hyeg"  , "hyegg" , "hyegs" ,  /*-- U+D618 .. U+D61F --*/
   "hyen"  , "hyenj" , "hyenh" , "hyed"  , "hyel"  , "hyelg" , "hyelm" , "hyelb" ,  /*-- U+D620 .. U+D627 --*/
   "hyels" , "hyelt" , "hyelp" , "hyelh" , "hyem"  , "hyeb"  , "hyebs" , "hyes"  ,  /*-- U+D628 .. U+D62F --*/
   "hyess" , "hyeng" , "hyej"  , "hyec"  , "hyek"  , "hyet"  , "hyep"  , "hyeh"  ,  /*-- U+D630 .. U+D637 --*/
   "ho"    , "hog"   , "hogg"  , "hogs"  , "hon"   , "honj"  , "honh"  , "hod"   ,  /*-- U+D638 .. U+D63F --*/
   "hol"   , "holg"  , "holm"  , "holb"  , "hols"  , "holt"  , "holp"  , "holh"  ,  /*-- U+D640 .. U+D647 --*/
   "hom"   , "hob"   , "hobs"  , "hos"   , "hoss"  , "hong"  , "hoj"   , "hoc"   ,  /*-- U+D648 .. U+D64F --*/
   "hok"   , "hot"   , "hop"   , "hoh"   , "hwa"   , "hwag"  , "hwagg" , "hwags" ,  /*-- U+D650 .. U+D657 --*/
   "hwan"  , "hwanj" , "hwanh" , "hwad"  , "hwal"  , "hwalg" , "hwalm" , "hwalb" ,  /*-- U+D658 .. U+D65F --*/
   "hwals" , "hwalt" , "hwalp" , "hwalh" , "hwam"  , "hwab"  , "hwabs" , "hwas"  ,  /*-- U+D660 .. U+D667 --*/
   "hwass" , "hwang" , "hwaj"  , "hwac"  , "hwak"  , "hwat"  , "hwap"  , "hwah"  ,  /*-- U+D668 .. U+D66F --*/
   "hwae"  , "hwaeg" , "hwaegg", "hwaegs", "hwaen" , "hwaenj", "hwaenh", "hwaed" ,  /*-- U+D670 .. U+D677 --*/
   "hwael" , "hwaelg", "hwaelm", "hwaelb", "hwaels", "hwaelt", "hwaelp", "hwaelh",  /*-- U+D678 .. U+D67F --*/
   "hwaem" , "hwaeb" , "hwaebs", "hwaes" , "hwaess", "hwaeng", "hwaej" , "hwaec" ,  /*-- U+D680 .. U+D687 --*/
   "hwaek" , "hwaet" , "hwaep" , "hwaeh" , "hoe"   , "hoeg"  , "hoegg" , "hoegs" ,  /*-- U+D688 .. U+D68F --*/
   "hoen"  , "hoenj" , "hoenh" , "hoed"  , "hoel"  , "hoelg" , "hoelm" , "hoelb" ,  /*-- U+D690 .. U+D697 --*/
   "hoels" , "hoelt" , "hoelp" , "hoelh" , "hoem"  , "hoeb"  , "hoebs" , "hoes"  ,  /*-- U+D698 .. U+D69F --*/
   "hoess" , "hoeng" , "hoej"  , "hoec"  , "hoek"  , "hoet"  , "hoep"  , "hoeh"  ,  /*-- U+D6A0 .. U+D6A7 --*/
   "hyo"   , "hyog"  , "hyogg" , "hyogs" , "hyon"  , "hyonj" , "hyonh" , "hyod"  ,  /*-- U+D6A8 .. U+D6AF --*/
   "hyol"  , "hyolg" , "hyolm" , "hyolb" , "hyols" , "hyolt" , "hyolp" , "hyolh" ,  /*-- U+D6B0 .. U+D6B7 --*/
   "hyom"  , "hyob"  , "hyobs" , "hyos"  , "hyoss" , "hyong" , "hyoj"  , "hyoc"  ,  /*-- U+D6B8 .. U+D6BF --*/
   "hyok"  , "hyot"  , "hyop"  , "hyoh"  , "hu"    , "hug"   , "hugg"  , "hugs"  ,  /*-- U+D6C0 .. U+D6C7 --*/
   "hun"   , "hunj"  , "hunh"  , "hud"   , "hul"   , "hulg"  , "hulm"  , "hulb"  ,  /*-- U+D6C8 .. U+D6CF --*/
   "huls"  , "hult"  , "hulp"  , "hulh"  , "hum"   , "hub"   , "hubs"  , "hus"   ,  /*-- U+D6D0 .. U+D6D7 --*/
   "huss"  , "hung"  , "huj"   , "huc"   , "huk"   , "hut"   , "hup"   , "huh"   ,  /*-- U+D6D8 .. U+D6DF --*/
   "hweo"  , "hweog" , "hweogg", "hweogs", "hweon" , "hweonj", "hweonh", "hweod" ,  /*-- U+D6E0 .. U+D6E7 --*/
   "hweol" , "hweolg", "hweolm", "hweolb", "hweols", "hweolt", "hweolp", "hweolh",  /*-- U+D6E8 .. U+D6EF --*/
   "hweom" , "hweob" , "hweobs", "hweos" , "hweoss", "hweong", "hweoj" , "hweoc" ,  /*-- U+D6F0 .. U+D6F7 --*/
   "hweok" , "hweot" , "hweop" , "hweoh" , "hwe"   , "hweg"  , "hwegg" , "hwegs" ,  /*-- U+D6F8 .. U+D6FF --*/
   "hwen"  , "hwenj" , "hwenh" , "hwed"  , "hwel"  , "hwelg" , "hwelm" , "hwelb" ,  /*-- U+D700 .. U+D707 --*/
   "hwels" , "hwelt" , "hwelp" , "hwelh" , "hwem"  , "hweb"  , "hwebs" , "hwes"  ,  /*-- U+D708 .. U+D70F --*/
   "hwess" , "hweng" , "hwej"  , "hwec"  , "hwek"  , "hwet"  , "hwep"  , "hweh"  ,  /*-- U+D710 .. U+D717 --*/
   "hwi"   , "hwig"  , "hwigg" , "hwigs" , "hwin"  , "hwinj" , "hwinh" , "hwid"  ,  /*-- U+D718 .. U+D71F --*/
   "hwil"  , "hwilg" , "hwilm" , "hwilb" , "hwils" , "hwilt" , "hwilp" , "hwilh" ,  /*-- U+D720 .. U+D727 --*/
   "hwim"  , "hwib"  , "hwibs" , "hwis"  , "hwiss" , "hwing" , "hwij"  , "hwic"  ,  /*-- U+D728 .. U+D72F --*/
   "hwik"  , "hwit"  , "hwip"  , "hwih"  , "hyu"   , "hyug"  , "hyugg" , "hyugs" ,  /*-- U+D730 .. U+D737 --*/
   "hyun"  , "hyunj" , "hyunh" , "hyud"  , "hyul"  , "hyulg" , "hyulm" , "hyulb" ,  /*-- U+D738 .. U+D73F --*/
   "hyuls" , "hyult" , "hyulp" , "hyulh" , "hyum"  , "hyub"  , "hyubs" , "hyus"  ,  /*-- U+D740 .. U+D747 --*/
   "hyuss" , "hyung" , "hyuj"  , "hyuc"  , "hyuk"  , "hyut"  , "hyup"  , "hyuh"  ,  /*-- U+D748 .. U+D74F --*/
   "heu"   , "heug"  , "heugg" , "heugs" , "heun"  , "heunj" , "heunh" , "heud"  ,  /*-- U+D750 .. U+D757 --*/
   "heul"  , "heulg" , "heulm" , "heulb" , "heuls" , "heult" , "heulp" , "heulh" ,  /*-- U+D758 .. U+D75F --*/
   "heum"  , "heub"  , "heubs" , "heus"  , "heuss" , "heung" , "heuj"  , "heuc"  ,  /*-- U+D760 .. U+D767 --*/
   "heuk"  , "heut"  , "heup"  , "heuh"  , "hyi"   , "hyig"  , "hyigg" , "hyigs" ,  /*-- U+D768 .. U+D76F --*/
   "hyin"  , "hyinj" , "hyinh" , "hyid"  , "hyil"  , "hyilg" , "hyilm" , "hyilb" ,  /*-- U+D770 .. U+D777 --*/
   "hyils" , "hyilt" , "hyilp" , "hyilh" , "hyim"  , "hyib"  , "hyibs" , "hyis"  ,  /*-- U+D778 .. U+D77F --*/
   "hyiss" , "hying" , "hyij"  , "hyic"  , "hyik"  , "hyit"  , "hyip"  , "hyih"  ,  /*-- U+D780 .. U+D787 --*/
   "hi"    , "hig"   , "higg"  , "higs"  , "hin"   , "hinj"  , "hinh"  , "hid"   ,  /*-- U+D788 .. U+D78F --*/
   "hil"   , "hilg"  , "hilm"  , "hilb"  , "hils"  , "hilt"  , "hilp"  , "hilh"  ,  /*-- U+D790 .. U+D797 --*/
   "him"   , "hib"   , "hibs"  , "his"   , "hiss"  , "hing"  , "hij"   , "hic"   ,  /*-- U+D798 .. U+D79F --*/
   "hik"   , "hit"   , "hip"   , "hih"   , ""      , ""      , ""      , ""      ,  /*-- U+D7A0 .. U+D7A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7A8 .. U+D7AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7B0 .. U+D7B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7B8 .. U+D7BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7C0 .. U+D7C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7C8 .. U+D7CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7D0 .. U+D7D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7D8 .. U+D7DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7E0 .. U+D7E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7E8 .. U+D7EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7F0 .. U+D7F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D7F8 .. U+D7FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D800 .. U+D807 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D808 .. U+D80F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D810 .. U+D817 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D818 .. U+D81F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D820 .. U+D827 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D828 .. U+D82F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D830 .. U+D837 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D838 .. U+D83F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D840 .. U+D847 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D848 .. U+D84F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D850 .. U+D857 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D858 .. U+D85F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D860 .. U+D867 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D868 .. U+D86F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D870 .. U+D877 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D878 .. U+D87F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D880 .. U+D887 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D888 .. U+D88F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D890 .. U+D897 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D898 .. U+D89F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8A0 .. U+D8A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8A8 .. U+D8AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8B0 .. U+D8B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8B8 .. U+D8BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8C0 .. U+D8C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8C8 .. U+D8CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8D0 .. U+D8D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8D8 .. U+D8DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8E0 .. U+D8E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8E8 .. U+D8EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8F0 .. U+D8F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D8F8 .. U+D8FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D900 .. U+D907 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D908 .. U+D90F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D910 .. U+D917 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D918 .. U+D91F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D920 .. U+D927 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D928 .. U+D92F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D930 .. U+D937 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D938 .. U+D93F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D940 .. U+D947 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D948 .. U+D94F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D950 .. U+D957 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D958 .. U+D95F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D960 .. U+D967 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D968 .. U+D96F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D970 .. U+D977 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D978 .. U+D97F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D980 .. U+D987 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D988 .. U+D98F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D990 .. U+D997 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D998 .. U+D99F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9A0 .. U+D9A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9A8 .. U+D9AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9B0 .. U+D9B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9B8 .. U+D9BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9C0 .. U+D9C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9C8 .. U+D9CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9D0 .. U+D9D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9D8 .. U+D9DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9E0 .. U+D9E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9E8 .. U+D9EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9F0 .. U+D9F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+D9F8 .. U+D9FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA00 .. U+DA07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA08 .. U+DA0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA10 .. U+DA17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA18 .. U+DA1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA20 .. U+DA27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA28 .. U+DA2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA30 .. U+DA37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA38 .. U+DA3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA40 .. U+DA47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA48 .. U+DA4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA50 .. U+DA57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA58 .. U+DA5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA60 .. U+DA67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA68 .. U+DA6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA70 .. U+DA77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA78 .. U+DA7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA80 .. U+DA87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA88 .. U+DA8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA90 .. U+DA97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DA98 .. U+DA9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAA0 .. U+DAA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAA8 .. U+DAAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAB0 .. U+DAB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAB8 .. U+DABF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAC0 .. U+DAC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAC8 .. U+DACF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAD0 .. U+DAD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAD8 .. U+DADF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAE0 .. U+DAE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAE8 .. U+DAEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAF0 .. U+DAF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DAF8 .. U+DAFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB00 .. U+DB07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB08 .. U+DB0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB10 .. U+DB17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB18 .. U+DB1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB20 .. U+DB27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB28 .. U+DB2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB30 .. U+DB37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB38 .. U+DB3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB40 .. U+DB47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB48 .. U+DB4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB50 .. U+DB57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB58 .. U+DB5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB60 .. U+DB67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB68 .. U+DB6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB70 .. U+DB77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB78 .. U+DB7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB80 .. U+DB87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB88 .. U+DB8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB90 .. U+DB97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DB98 .. U+DB9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBA0 .. U+DBA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBA8 .. U+DBAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBB0 .. U+DBB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBB8 .. U+DBBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBC0 .. U+DBC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBC8 .. U+DBCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBD0 .. U+DBD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBD8 .. U+DBDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBE0 .. U+DBE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBE8 .. U+DBEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBF0 .. U+DBF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DBF8 .. U+DBFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC00 .. U+DC07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC08 .. U+DC0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC10 .. U+DC17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC18 .. U+DC1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC20 .. U+DC27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC28 .. U+DC2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC30 .. U+DC37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC38 .. U+DC3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC40 .. U+DC47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC48 .. U+DC4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC50 .. U+DC57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC58 .. U+DC5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC60 .. U+DC67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC68 .. U+DC6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC70 .. U+DC77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC78 .. U+DC7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC80 .. U+DC87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC88 .. U+DC8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC90 .. U+DC97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DC98 .. U+DC9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCA0 .. U+DCA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCA8 .. U+DCAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCB0 .. U+DCB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCB8 .. U+DCBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCC0 .. U+DCC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCC8 .. U+DCCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCD0 .. U+DCD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCD8 .. U+DCDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCE0 .. U+DCE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCE8 .. U+DCEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCF0 .. U+DCF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DCF8 .. U+DCFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD00 .. U+DD07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD08 .. U+DD0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD10 .. U+DD17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD18 .. U+DD1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD20 .. U+DD27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD28 .. U+DD2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD30 .. U+DD37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD38 .. U+DD3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD40 .. U+DD47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD48 .. U+DD4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD50 .. U+DD57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD58 .. U+DD5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD60 .. U+DD67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD68 .. U+DD6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD70 .. U+DD77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD78 .. U+DD7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD80 .. U+DD87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD88 .. U+DD8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD90 .. U+DD97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DD98 .. U+DD9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDA0 .. U+DDA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDA8 .. U+DDAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDB0 .. U+DDB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDB8 .. U+DDBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDC0 .. U+DDC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDC8 .. U+DDCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDD0 .. U+DDD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDD8 .. U+DDDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDE0 .. U+DDE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDE8 .. U+DDEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDF0 .. U+DDF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DDF8 .. U+DDFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE00 .. U+DE07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE08 .. U+DE0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE10 .. U+DE17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE18 .. U+DE1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE20 .. U+DE27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE28 .. U+DE2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE30 .. U+DE37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE38 .. U+DE3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE40 .. U+DE47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE48 .. U+DE4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE50 .. U+DE57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE58 .. U+DE5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE60 .. U+DE67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE68 .. U+DE6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE70 .. U+DE77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE78 .. U+DE7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE80 .. U+DE87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE88 .. U+DE8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE90 .. U+DE97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DE98 .. U+DE9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEA0 .. U+DEA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEA8 .. U+DEAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEB0 .. U+DEB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEB8 .. U+DEBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEC0 .. U+DEC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEC8 .. U+DECF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DED0 .. U+DED7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DED8 .. U+DEDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEE0 .. U+DEE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEE8 .. U+DEEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEF0 .. U+DEF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DEF8 .. U+DEFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF00 .. U+DF07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF08 .. U+DF0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF10 .. U+DF17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF18 .. U+DF1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF20 .. U+DF27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF28 .. U+DF2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF30 .. U+DF37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF38 .. U+DF3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF40 .. U+DF47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF48 .. U+DF4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF50 .. U+DF57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF58 .. U+DF5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF60 .. U+DF67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF68 .. U+DF6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF70 .. U+DF77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF78 .. U+DF7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF80 .. U+DF87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF88 .. U+DF8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF90 .. U+DF97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DF98 .. U+DF9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFA0 .. U+DFA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFA8 .. U+DFAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFB0 .. U+DFB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFB8 .. U+DFBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFC0 .. U+DFC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFC8 .. U+DFCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFD0 .. U+DFD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFD8 .. U+DFDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFE0 .. U+DFE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFE8 .. U+DFEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFF0 .. U+DFF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+DFF8 .. U+DFFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E000 .. U+E007 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E008 .. U+E00F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E010 .. U+E017 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E018 .. U+E01F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E020 .. U+E027 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E028 .. U+E02F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E030 .. U+E037 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E038 .. U+E03F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E040 .. U+E047 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E048 .. U+E04F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E050 .. U+E057 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E058 .. U+E05F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E060 .. U+E067 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E068 .. U+E06F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E070 .. U+E077 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E078 .. U+E07F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E080 .. U+E087 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E088 .. U+E08F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E090 .. U+E097 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E098 .. U+E09F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0A0 .. U+E0A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0A8 .. U+E0AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0B0 .. U+E0B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0B8 .. U+E0BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0C0 .. U+E0C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0C8 .. U+E0CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0D0 .. U+E0D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0D8 .. U+E0DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0E0 .. U+E0E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0E8 .. U+E0EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0F0 .. U+E0F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E0F8 .. U+E0FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E100 .. U+E107 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E108 .. U+E10F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E110 .. U+E117 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E118 .. U+E11F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E120 .. U+E127 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E128 .. U+E12F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E130 .. U+E137 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E138 .. U+E13F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E140 .. U+E147 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E148 .. U+E14F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E150 .. U+E157 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E158 .. U+E15F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E160 .. U+E167 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E168 .. U+E16F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E170 .. U+E177 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E178 .. U+E17F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E180 .. U+E187 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E188 .. U+E18F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E190 .. U+E197 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E198 .. U+E19F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1A0 .. U+E1A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1A8 .. U+E1AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1B0 .. U+E1B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1B8 .. U+E1BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1C0 .. U+E1C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1C8 .. U+E1CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1D0 .. U+E1D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1D8 .. U+E1DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1E0 .. U+E1E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1E8 .. U+E1EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1F0 .. U+E1F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E1F8 .. U+E1FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E200 .. U+E207 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E208 .. U+E20F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E210 .. U+E217 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E218 .. U+E21F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E220 .. U+E227 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E228 .. U+E22F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E230 .. U+E237 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E238 .. U+E23F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E240 .. U+E247 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E248 .. U+E24F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E250 .. U+E257 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E258 .. U+E25F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E260 .. U+E267 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E268 .. U+E26F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E270 .. U+E277 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E278 .. U+E27F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E280 .. U+E287 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E288 .. U+E28F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E290 .. U+E297 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E298 .. U+E29F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2A0 .. U+E2A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2A8 .. U+E2AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2B0 .. U+E2B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2B8 .. U+E2BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2C0 .. U+E2C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2C8 .. U+E2CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2D0 .. U+E2D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2D8 .. U+E2DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2E0 .. U+E2E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2E8 .. U+E2EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2F0 .. U+E2F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E2F8 .. U+E2FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E300 .. U+E307 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E308 .. U+E30F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E310 .. U+E317 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E318 .. U+E31F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E320 .. U+E327 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E328 .. U+E32F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E330 .. U+E337 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E338 .. U+E33F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E340 .. U+E347 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E348 .. U+E34F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E350 .. U+E357 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E358 .. U+E35F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E360 .. U+E367 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E368 .. U+E36F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E370 .. U+E377 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E378 .. U+E37F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E380 .. U+E387 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E388 .. U+E38F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E390 .. U+E397 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E398 .. U+E39F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3A0 .. U+E3A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3A8 .. U+E3AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3B0 .. U+E3B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3B8 .. U+E3BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3C0 .. U+E3C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3C8 .. U+E3CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3D0 .. U+E3D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3D8 .. U+E3DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3E0 .. U+E3E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3E8 .. U+E3EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3F0 .. U+E3F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E3F8 .. U+E3FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E400 .. U+E407 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E408 .. U+E40F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E410 .. U+E417 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E418 .. U+E41F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E420 .. U+E427 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E428 .. U+E42F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E430 .. U+E437 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E438 .. U+E43F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E440 .. U+E447 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E448 .. U+E44F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E450 .. U+E457 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E458 .. U+E45F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E460 .. U+E467 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E468 .. U+E46F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E470 .. U+E477 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E478 .. U+E47F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E480 .. U+E487 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E488 .. U+E48F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E490 .. U+E497 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E498 .. U+E49F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4A0 .. U+E4A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4A8 .. U+E4AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4B0 .. U+E4B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4B8 .. U+E4BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4C0 .. U+E4C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4C8 .. U+E4CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4D0 .. U+E4D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4D8 .. U+E4DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4E0 .. U+E4E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4E8 .. U+E4EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4F0 .. U+E4F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E4F8 .. U+E4FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E500 .. U+E507 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E508 .. U+E50F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E510 .. U+E517 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E518 .. U+E51F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E520 .. U+E527 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E528 .. U+E52F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E530 .. U+E537 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E538 .. U+E53F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E540 .. U+E547 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E548 .. U+E54F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E550 .. U+E557 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E558 .. U+E55F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E560 .. U+E567 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E568 .. U+E56F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E570 .. U+E577 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E578 .. U+E57F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E580 .. U+E587 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E588 .. U+E58F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E590 .. U+E597 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E598 .. U+E59F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5A0 .. U+E5A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5A8 .. U+E5AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5B0 .. U+E5B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5B8 .. U+E5BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5C0 .. U+E5C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5C8 .. U+E5CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5D0 .. U+E5D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5D8 .. U+E5DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5E0 .. U+E5E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5E8 .. U+E5EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5F0 .. U+E5F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E5F8 .. U+E5FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E600 .. U+E607 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E608 .. U+E60F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E610 .. U+E617 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E618 .. U+E61F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E620 .. U+E627 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E628 .. U+E62F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E630 .. U+E637 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E638 .. U+E63F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E640 .. U+E647 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E648 .. U+E64F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E650 .. U+E657 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E658 .. U+E65F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E660 .. U+E667 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E668 .. U+E66F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E670 .. U+E677 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E678 .. U+E67F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E680 .. U+E687 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E688 .. U+E68F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E690 .. U+E697 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E698 .. U+E69F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6A0 .. U+E6A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6A8 .. U+E6AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6B0 .. U+E6B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6B8 .. U+E6BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6C0 .. U+E6C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6C8 .. U+E6CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6D0 .. U+E6D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6D8 .. U+E6DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6E0 .. U+E6E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6E8 .. U+E6EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6F0 .. U+E6F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E6F8 .. U+E6FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E700 .. U+E707 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E708 .. U+E70F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E710 .. U+E717 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E718 .. U+E71F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E720 .. U+E727 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E728 .. U+E72F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E730 .. U+E737 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E738 .. U+E73F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E740 .. U+E747 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E748 .. U+E74F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E750 .. U+E757 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E758 .. U+E75F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E760 .. U+E767 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E768 .. U+E76F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E770 .. U+E777 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E778 .. U+E77F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E780 .. U+E787 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E788 .. U+E78F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E790 .. U+E797 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E798 .. U+E79F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7A0 .. U+E7A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7A8 .. U+E7AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7B0 .. U+E7B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7B8 .. U+E7BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7C0 .. U+E7C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7C8 .. U+E7CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7D0 .. U+E7D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7D8 .. U+E7DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7E0 .. U+E7E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7E8 .. U+E7EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7F0 .. U+E7F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E7F8 .. U+E7FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E800 .. U+E807 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E808 .. U+E80F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E810 .. U+E817 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E818 .. U+E81F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E820 .. U+E827 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E828 .. U+E82F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E830 .. U+E837 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E838 .. U+E83F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E840 .. U+E847 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E848 .. U+E84F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E850 .. U+E857 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E858 .. U+E85F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E860 .. U+E867 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E868 .. U+E86F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E870 .. U+E877 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E878 .. U+E87F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E880 .. U+E887 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E888 .. U+E88F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E890 .. U+E897 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E898 .. U+E89F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8A0 .. U+E8A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8A8 .. U+E8AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8B0 .. U+E8B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8B8 .. U+E8BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8C0 .. U+E8C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8C8 .. U+E8CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8D0 .. U+E8D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8D8 .. U+E8DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8E0 .. U+E8E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8E8 .. U+E8EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8F0 .. U+E8F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E8F8 .. U+E8FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E900 .. U+E907 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E908 .. U+E90F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E910 .. U+E917 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E918 .. U+E91F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E920 .. U+E927 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E928 .. U+E92F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E930 .. U+E937 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E938 .. U+E93F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E940 .. U+E947 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E948 .. U+E94F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E950 .. U+E957 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E958 .. U+E95F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E960 .. U+E967 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E968 .. U+E96F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E970 .. U+E977 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E978 .. U+E97F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E980 .. U+E987 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E988 .. U+E98F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E990 .. U+E997 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E998 .. U+E99F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9A0 .. U+E9A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9A8 .. U+E9AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9B0 .. U+E9B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9B8 .. U+E9BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9C0 .. U+E9C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9C8 .. U+E9CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9D0 .. U+E9D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9D8 .. U+E9DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9E0 .. U+E9E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9E8 .. U+E9EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9F0 .. U+E9F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+E9F8 .. U+E9FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA00 .. U+EA07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA08 .. U+EA0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA10 .. U+EA17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA18 .. U+EA1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA20 .. U+EA27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA28 .. U+EA2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA30 .. U+EA37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA38 .. U+EA3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA40 .. U+EA47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA48 .. U+EA4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA50 .. U+EA57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA58 .. U+EA5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA60 .. U+EA67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA68 .. U+EA6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA70 .. U+EA77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA78 .. U+EA7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA80 .. U+EA87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA88 .. U+EA8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA90 .. U+EA97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EA98 .. U+EA9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAA0 .. U+EAA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAA8 .. U+EAAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAB0 .. U+EAB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAB8 .. U+EABF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAC0 .. U+EAC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAC8 .. U+EACF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAD0 .. U+EAD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAD8 .. U+EADF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAE0 .. U+EAE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAE8 .. U+EAEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAF0 .. U+EAF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EAF8 .. U+EAFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB00 .. U+EB07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB08 .. U+EB0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB10 .. U+EB17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB18 .. U+EB1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB20 .. U+EB27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB28 .. U+EB2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB30 .. U+EB37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB38 .. U+EB3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB40 .. U+EB47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB48 .. U+EB4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB50 .. U+EB57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB58 .. U+EB5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB60 .. U+EB67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB68 .. U+EB6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB70 .. U+EB77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB78 .. U+EB7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB80 .. U+EB87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB88 .. U+EB8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB90 .. U+EB97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EB98 .. U+EB9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBA0 .. U+EBA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBA8 .. U+EBAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBB0 .. U+EBB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBB8 .. U+EBBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBC0 .. U+EBC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBC8 .. U+EBCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBD0 .. U+EBD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBD8 .. U+EBDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBE0 .. U+EBE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBE8 .. U+EBEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBF0 .. U+EBF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EBF8 .. U+EBFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC00 .. U+EC07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC08 .. U+EC0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC10 .. U+EC17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC18 .. U+EC1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC20 .. U+EC27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC28 .. U+EC2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC30 .. U+EC37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC38 .. U+EC3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC40 .. U+EC47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC48 .. U+EC4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC50 .. U+EC57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC58 .. U+EC5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC60 .. U+EC67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC68 .. U+EC6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC70 .. U+EC77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC78 .. U+EC7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC80 .. U+EC87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC88 .. U+EC8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC90 .. U+EC97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EC98 .. U+EC9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECA0 .. U+ECA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECA8 .. U+ECAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECB0 .. U+ECB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECB8 .. U+ECBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECC0 .. U+ECC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECC8 .. U+ECCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECD0 .. U+ECD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECD8 .. U+ECDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECE0 .. U+ECE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECE8 .. U+ECEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECF0 .. U+ECF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ECF8 .. U+ECFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED00 .. U+ED07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED08 .. U+ED0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED10 .. U+ED17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED18 .. U+ED1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED20 .. U+ED27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED28 .. U+ED2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED30 .. U+ED37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED38 .. U+ED3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED40 .. U+ED47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED48 .. U+ED4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED50 .. U+ED57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED58 .. U+ED5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED60 .. U+ED67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED68 .. U+ED6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED70 .. U+ED77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED78 .. U+ED7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED80 .. U+ED87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED88 .. U+ED8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED90 .. U+ED97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+ED98 .. U+ED9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDA0 .. U+EDA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDA8 .. U+EDAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDB0 .. U+EDB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDB8 .. U+EDBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDC0 .. U+EDC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDC8 .. U+EDCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDD0 .. U+EDD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDD8 .. U+EDDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDE0 .. U+EDE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDE8 .. U+EDEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDF0 .. U+EDF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EDF8 .. U+EDFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE00 .. U+EE07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE08 .. U+EE0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE10 .. U+EE17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE18 .. U+EE1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE20 .. U+EE27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE28 .. U+EE2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE30 .. U+EE37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE38 .. U+EE3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE40 .. U+EE47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE48 .. U+EE4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE50 .. U+EE57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE58 .. U+EE5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE60 .. U+EE67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE68 .. U+EE6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE70 .. U+EE77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE78 .. U+EE7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE80 .. U+EE87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE88 .. U+EE8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE90 .. U+EE97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EE98 .. U+EE9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEA0 .. U+EEA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEA8 .. U+EEAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEB0 .. U+EEB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEB8 .. U+EEBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEC0 .. U+EEC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEC8 .. U+EECF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EED0 .. U+EED7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EED8 .. U+EEDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEE0 .. U+EEE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEE8 .. U+EEEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEF0 .. U+EEF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EEF8 .. U+EEFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF00 .. U+EF07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF08 .. U+EF0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF10 .. U+EF17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF18 .. U+EF1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF20 .. U+EF27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF28 .. U+EF2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF30 .. U+EF37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF38 .. U+EF3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF40 .. U+EF47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF48 .. U+EF4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF50 .. U+EF57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF58 .. U+EF5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF60 .. U+EF67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF68 .. U+EF6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF70 .. U+EF77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF78 .. U+EF7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF80 .. U+EF87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF88 .. U+EF8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF90 .. U+EF97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EF98 .. U+EF9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFA0 .. U+EFA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFA8 .. U+EFAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFB0 .. U+EFB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFB8 .. U+EFBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFC0 .. U+EFC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFC8 .. U+EFCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFD0 .. U+EFD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFD8 .. U+EFDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFE0 .. U+EFE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFE8 .. U+EFEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFF0 .. U+EFF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+EFF8 .. U+EFFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F000 .. U+F007 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F008 .. U+F00F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F010 .. U+F017 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F018 .. U+F01F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F020 .. U+F027 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F028 .. U+F02F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F030 .. U+F037 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F038 .. U+F03F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F040 .. U+F047 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F048 .. U+F04F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F050 .. U+F057 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F058 .. U+F05F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F060 .. U+F067 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F068 .. U+F06F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F070 .. U+F077 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F078 .. U+F07F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F080 .. U+F087 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F088 .. U+F08F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F090 .. U+F097 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F098 .. U+F09F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0A0 .. U+F0A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0A8 .. U+F0AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0B0 .. U+F0B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0B8 .. U+F0BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0C0 .. U+F0C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0C8 .. U+F0CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0D0 .. U+F0D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0D8 .. U+F0DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0E0 .. U+F0E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0E8 .. U+F0EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0F0 .. U+F0F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F0F8 .. U+F0FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F100 .. U+F107 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F108 .. U+F10F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F110 .. U+F117 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F118 .. U+F11F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F120 .. U+F127 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F128 .. U+F12F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F130 .. U+F137 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F138 .. U+F13F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F140 .. U+F147 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F148 .. U+F14F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F150 .. U+F157 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F158 .. U+F15F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F160 .. U+F167 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F168 .. U+F16F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F170 .. U+F177 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F178 .. U+F17F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F180 .. U+F187 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F188 .. U+F18F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F190 .. U+F197 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F198 .. U+F19F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1A0 .. U+F1A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1A8 .. U+F1AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1B0 .. U+F1B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1B8 .. U+F1BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1C0 .. U+F1C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1C8 .. U+F1CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1D0 .. U+F1D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1D8 .. U+F1DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1E0 .. U+F1E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1E8 .. U+F1EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1F0 .. U+F1F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F1F8 .. U+F1FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F200 .. U+F207 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F208 .. U+F20F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F210 .. U+F217 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F218 .. U+F21F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F220 .. U+F227 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F228 .. U+F22F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F230 .. U+F237 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F238 .. U+F23F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F240 .. U+F247 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F248 .. U+F24F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F250 .. U+F257 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F258 .. U+F25F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F260 .. U+F267 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F268 .. U+F26F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F270 .. U+F277 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F278 .. U+F27F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F280 .. U+F287 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F288 .. U+F28F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F290 .. U+F297 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F298 .. U+F29F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2A0 .. U+F2A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2A8 .. U+F2AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2B0 .. U+F2B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2B8 .. U+F2BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2C0 .. U+F2C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2C8 .. U+F2CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2D0 .. U+F2D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2D8 .. U+F2DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2E0 .. U+F2E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2E8 .. U+F2EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2F0 .. U+F2F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F2F8 .. U+F2FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F300 .. U+F307 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F308 .. U+F30F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F310 .. U+F317 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F318 .. U+F31F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F320 .. U+F327 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F328 .. U+F32F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F330 .. U+F337 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F338 .. U+F33F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F340 .. U+F347 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F348 .. U+F34F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F350 .. U+F357 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F358 .. U+F35F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F360 .. U+F367 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F368 .. U+F36F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F370 .. U+F377 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F378 .. U+F37F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F380 .. U+F387 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F388 .. U+F38F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F390 .. U+F397 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F398 .. U+F39F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3A0 .. U+F3A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3A8 .. U+F3AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3B0 .. U+F3B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3B8 .. U+F3BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3C0 .. U+F3C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3C8 .. U+F3CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3D0 .. U+F3D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3D8 .. U+F3DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3E0 .. U+F3E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3E8 .. U+F3EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3F0 .. U+F3F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F3F8 .. U+F3FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F400 .. U+F407 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F408 .. U+F40F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F410 .. U+F417 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F418 .. U+F41F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F420 .. U+F427 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F428 .. U+F42F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F430 .. U+F437 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F438 .. U+F43F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F440 .. U+F447 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F448 .. U+F44F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F450 .. U+F457 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F458 .. U+F45F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F460 .. U+F467 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F468 .. U+F46F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F470 .. U+F477 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F478 .. U+F47F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F480 .. U+F487 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F488 .. U+F48F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F490 .. U+F497 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F498 .. U+F49F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4A0 .. U+F4A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4A8 .. U+F4AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4B0 .. U+F4B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4B8 .. U+F4BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4C0 .. U+F4C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4C8 .. U+F4CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4D0 .. U+F4D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4D8 .. U+F4DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4E0 .. U+F4E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4E8 .. U+F4EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4F0 .. U+F4F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F4F8 .. U+F4FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F500 .. U+F507 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F508 .. U+F50F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F510 .. U+F517 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F518 .. U+F51F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F520 .. U+F527 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F528 .. U+F52F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F530 .. U+F537 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F538 .. U+F53F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F540 .. U+F547 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F548 .. U+F54F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F550 .. U+F557 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F558 .. U+F55F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F560 .. U+F567 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F568 .. U+F56F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F570 .. U+F577 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F578 .. U+F57F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F580 .. U+F587 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F588 .. U+F58F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F590 .. U+F597 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F598 .. U+F59F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5A0 .. U+F5A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5A8 .. U+F5AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5B0 .. U+F5B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5B8 .. U+F5BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5C0 .. U+F5C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5C8 .. U+F5CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5D0 .. U+F5D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5D8 .. U+F5DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5E0 .. U+F5E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5E8 .. U+F5EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5F0 .. U+F5F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F5F8 .. U+F5FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F600 .. U+F607 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F608 .. U+F60F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F610 .. U+F617 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F618 .. U+F61F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F620 .. U+F627 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F628 .. U+F62F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F630 .. U+F637 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F638 .. U+F63F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F640 .. U+F647 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F648 .. U+F64F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F650 .. U+F657 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F658 .. U+F65F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F660 .. U+F667 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F668 .. U+F66F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F670 .. U+F677 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F678 .. U+F67F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F680 .. U+F687 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F688 .. U+F68F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F690 .. U+F697 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F698 .. U+F69F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6A0 .. U+F6A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6A8 .. U+F6AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6B0 .. U+F6B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6B8 .. U+F6BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6C0 .. U+F6C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6C8 .. U+F6CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6D0 .. U+F6D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6D8 .. U+F6DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6E0 .. U+F6E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6E8 .. U+F6EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6F0 .. U+F6F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F6F8 .. U+F6FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F700 .. U+F707 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F708 .. U+F70F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F710 .. U+F717 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F718 .. U+F71F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F720 .. U+F727 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F728 .. U+F72F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F730 .. U+F737 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F738 .. U+F73F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F740 .. U+F747 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F748 .. U+F74F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F750 .. U+F757 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F758 .. U+F75F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F760 .. U+F767 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F768 .. U+F76F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F770 .. U+F777 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F778 .. U+F77F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F780 .. U+F787 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F788 .. U+F78F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F790 .. U+F797 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F798 .. U+F79F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7A0 .. U+F7A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7A8 .. U+F7AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7B0 .. U+F7B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7B8 .. U+F7BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7C0 .. U+F7C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7C8 .. U+F7CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7D0 .. U+F7D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7D8 .. U+F7DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7E0 .. U+F7E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7E8 .. U+F7EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7F0 .. U+F7F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F7F8 .. U+F7FF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F800 .. U+F807 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F808 .. U+F80F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F810 .. U+F817 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F818 .. U+F81F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F820 .. U+F827 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F828 .. U+F82F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F830 .. U+F837 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F838 .. U+F83F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F840 .. U+F847 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F848 .. U+F84F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F850 .. U+F857 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F858 .. U+F85F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F860 .. U+F867 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F868 .. U+F86F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F870 .. U+F877 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F878 .. U+F87F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F880 .. U+F887 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F888 .. U+F88F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F890 .. U+F897 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F898 .. U+F89F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8A0 .. U+F8A7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8A8 .. U+F8AF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8B0 .. U+F8B7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8B8 .. U+F8BF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8C0 .. U+F8C7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8C8 .. U+F8CF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8D0 .. U+F8D7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8D8 .. U+F8DF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8E0 .. U+F8E7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8E8 .. U+F8EF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8F0 .. U+F8F7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+F8F8 .. U+F8FF --*/
   "Kay "  , "Kayng ", "Ke "   , "Ko "   , "Kol "  , "Koc "  , "Kwi "  , "Kwi "  ,  /*-- U+F900 .. U+F907 --*/
   "Kyun " , "Kul "  , "Kum "  , "Na "   , "Na "   , "Na "   , "La "   , "Na "   ,  /*-- U+F908 .. U+F90F --*/
   "Na "   , "Na "   , "Na "   , "Na "   , "Nak "  , "Nak "  , "Nak "  , "Nak "  ,  /*-- U+F910 .. U+F917 --*/
   "Nak "  , "Nak "  , "Nak "  , "Nan "  , "Nan "  , "Nan "  , "Nan "  , "Nan "  ,  /*-- U+F918 .. U+F91F --*/
   "Nan "  , "Nam "  , "Nam "  , "Nam "  , "Nam "  , "Nap "  , "Nap "  , "Nap "  ,  /*-- U+F920 .. U+F927 --*/
   "Nang " , "Nang " , "Nang " , "Nang " , "Nang " , "Nay "  , "Nayng ", "No "   ,  /*-- U+F928 .. U+F92F --*/
   "No "   , "No "   , "No "   , "No "   , "No "   , "No "   , "No "   , "No "   ,  /*-- U+F930 .. U+F937 --*/
   "No "   , "No "   , "No "   , "Nok "  , "Nok "  , "Nok "  , "Nok "  , "Nok "  ,  /*-- U+F938 .. U+F93F --*/
   "Nok "  , "Non "  , "Nong " , "Nong " , "Nong " , "Nong " , "Noy "  , "Noy "  ,  /*-- U+F940 .. U+F947 --*/
   "Noy "  , "Noy "  , "Nwu "  , "Nwu "  , "Nwu "  , "Nwu "  , "Nwu "  , "Nwu "  ,  /*-- U+F948 .. U+F94F --*/
   "Nwu "  , "Nwu "  , "Nuk "  , "Nuk "  , "Num "  , "Nung " , "Nung " , "Nung " ,  /*-- U+F950 .. U+F957 --*/
   "Nung " , "Nung " , "Twu "  , "La "   , "Lak "  , "Lak "  , "Lan "  , "Lyeng ",  /*-- U+F958 .. U+F95F --*/
   "Lo "   , "Lyul " , "Li "   , "Pey "  , "Pen "  , "Pyen " , "Pwu "  , "Pwul " ,  /*-- U+F960 .. U+F967 --*/
   "Pi "   , "Sak "  , "Sak "  , "Sam "  , "Sayk " , "Sayng ", "Sep "  , "Sey "  ,  /*-- U+F968 .. U+F96F --*/
   "Sway " , "Sin "  , "Sim "  , "Sip "  , "Ya "   , "Yak "  , "Yak "  , "Yang " ,  /*-- U+F970 .. U+F977 --*/
   "Yang " , "Yang " , "Yang " , "Yang " , "Yang " , "Yang " , "Yang " , "Ye "   ,  /*-- U+F978 .. U+F97F --*/
   "Ye "   , "Ye "   , "Ye "   , "Ye "   , "Ye "   , "Ye "   , "Ye "   , "Ye "   ,  /*-- U+F980 .. U+F987 --*/
   "Ye "   , "Ye "   , "Yek "  , "Yek "  , "Yek "  , "Yek "  , "Yen "  , "Yen "  ,  /*-- U+F988 .. U+F98F --*/
   "Yen "  , "Yen "  , "Yen "  , "Yen "  , "Yen "  , "Yen "  , "Yen "  , "Yen "  ,  /*-- U+F990 .. U+F997 --*/
   "Yen "  , "Yen "  , "Yen "  , "Yen "  , "Yel "  , "Yel "  , "Yel "  , "Yel "  ,  /*-- U+F998 .. U+F99F --*/
   "Yel "  , "Yel "  , "Yem "  , "Yem "  , "Yem "  , "Yem "  , "Yem "  , "Yep "  ,  /*-- U+F9A0 .. U+F9A7 --*/
   "Yeng " , "Yeng " , "Yeng " , "Yeng " , "Yeng " , "Yeng " , "Yeng " , "Yeng " ,  /*-- U+F9A8 .. U+F9AF --*/
   "Yeng " , "Yeng " , "Yeng " , "Yeng " , "Yeng " , "Yey "  , "Yey "  , "Yey "  ,  /*-- U+F9B0 .. U+F9B7 --*/
   "Yey "  , "O "    , "Yo "   , "Yo "   , "Yo "   , "Yo "   , "Yo "   , "Yo "   ,  /*-- U+F9B8 .. U+F9BF --*/
   "Yo "   , "Yo "   , "Yo "   , "Yo "   , "Yong " , "Wun "  , "Wen "  , "Yu "   ,  /*-- U+F9C0 .. U+F9C7 --*/
   "Yu "   , "Yu "   , "Yu "   , "Yu "   , "Yu "   , "Yu "   , "Yu "   , "Yu "   ,  /*-- U+F9C8 .. U+F9CF --*/
   "Yu "   , "Yuk "  , "Yuk "  , "Yuk "  , "Yun "  , "Yun "  , "Yun "  , "Yun "  ,  /*-- U+F9D0 .. U+F9D7 --*/
   "Yul "  , "Yul "  , "Yul "  , "Yul "  , "Yung " , "I "    , "I "    , "I "    ,  /*-- U+F9D8 .. U+F9DF --*/
   "I "    , "I "    , "I "    , "I "    , "I "    , "I "    , "I "    , "I "    ,  /*-- U+F9E0 .. U+F9E7 --*/
   "I "    , "I "    , "I "    , "Ik "   , "Ik "   , "In "   , "In "   , "In "   ,  /*-- U+F9E8 .. U+F9EF --*/
   "In "   , "In "   , "In "   , "In "   , "Im "   , "Im "   , "Im "   , "Ip "   ,  /*-- U+F9F0 .. U+F9F7 --*/
   "Ip "   , "Ip "   , "Cang " , "Cek "  , "Ci "   , "Cip "  , "Cha "  , "Chek " ,  /*-- U+F9F8 .. U+F9FF --*/
   "Chey " , "Thak " , "Thak " , "Thang ", "Thayk ", "Thong ", "Pho "  , "Phok " ,  /*-- U+FA00 .. U+FA07 --*/
   "Hang " , "Hang " , "Hyen " , "Hwak " , "Wu "   , "Huo "  , ""      , ""      ,  /*-- U+FA08 .. U+FA0F --*/
   "Zhong ", ""      , "Qing " , ""      , ""      , "Xi "   , "Zhu "  , "Yi "   ,  /*-- U+FA10 .. U+FA17 --*/
   "Li "   , "Shen " , "Xiang ", "Fu "   , "Jing " , "Jing " , "Yu "   , ""      ,  /*-- U+FA18 .. U+FA1F --*/
   "Hagi " , ""      , "Zhu "  , ""      , ""      , "Yi "   , "Du "   , ""      ,  /*-- U+FA20 .. U+FA27 --*/
   ""      , ""      , "Fan "  , "Si "   , "Guan " , ""      , ""      , ""      ,  /*-- U+FA28 .. U+FA2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA30 .. U+FA37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA38 .. U+FA3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA40 .. U+FA47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA48 .. U+FA4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA50 .. U+FA57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA58 .. U+FA5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA60 .. U+FA67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA68 .. U+FA6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA70 .. U+FA77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA78 .. U+FA7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA80 .. U+FA87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA88 .. U+FA8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA90 .. U+FA97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FA98 .. U+FA9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAA0 .. U+FAA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAA8 .. U+FAAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAB0 .. U+FAB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAB8 .. U+FABF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAC0 .. U+FAC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAC8 .. U+FACF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAD0 .. U+FAD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAD8 .. U+FADF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAE0 .. U+FAE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAE8 .. U+FAEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAF0 .. U+FAF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FAF8 .. U+FAFF --*/
   "ff"    , "fi"    , "fl"    , "ffi"   , "ffl"   , "st"    , "st"    , ""      ,  /*-- U+FB00 .. U+FB07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB08 .. U+FB0F --*/
   ""      , ""      , ""      , "mn"    , "me"    , "mi"    , "vn"    , "mkh"   ,  /*-- U+FB10 .. U+FB17 --*/
   ""      , ""      , ""      , ""      , ""      , "yi"    , ""      , "ay"    ,  /*-- U+FB18 .. U+FB1F --*/
   "`"     , ""      , "d"     , "h"     , "k"     , "l"     , "m"     , "m"     ,  /*-- U+FB20 .. U+FB27 --*/
   "t"     , "+"     , "sh"    , "s"     , "sh"    , "s"     , "a"     , "a"     ,  /*-- U+FB28 .. U+FB2F --*/
   ""      , "b"     , "g"     , "d"     , "h"     , "v"     , "z"     , ""      ,  /*-- U+FB30 .. U+FB37 --*/
   "t"     , "y"     , "k"     , "k"     , "l"     , ""      , "l"     , ""      ,  /*-- U+FB38 .. U+FB3F --*/
   "n"     , "n"     , ""      , "p"     , "p"     , ""      , "ts"    , "ts"    ,  /*-- U+FB40 .. U+FB47 --*/
   "r"     , "sh"    , "t"     , "vo"    , "b"     , "k"     , "p"     , "l"     ,  /*-- U+FB48 .. U+FB4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB50 .. U+FB57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB58 .. U+FB5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB60 .. U+FB67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB68 .. U+FB6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB70 .. U+FB77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB78 .. U+FB7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB80 .. U+FB87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB88 .. U+FB8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB90 .. U+FB97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FB98 .. U+FB9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBA0 .. U+FBA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBA8 .. U+FBAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBB0 .. U+FBB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBB8 .. U+FBBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBC0 .. U+FBC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBC8 .. U+FBCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBD0 .. U+FBD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBD8 .. U+FBDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBE0 .. U+FBE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBE8 .. U+FBEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBF0 .. U+FBF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FBF8 .. U+FBFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC00 .. U+FC07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC08 .. U+FC0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC10 .. U+FC17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC18 .. U+FC1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC20 .. U+FC27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC28 .. U+FC2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC30 .. U+FC37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC38 .. U+FC3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC40 .. U+FC47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC48 .. U+FC4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC50 .. U+FC57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC58 .. U+FC5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC60 .. U+FC67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC68 .. U+FC6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC70 .. U+FC77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC78 .. U+FC7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC80 .. U+FC87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC88 .. U+FC8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC90 .. U+FC97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FC98 .. U+FC9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCA0 .. U+FCA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCA8 .. U+FCAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCB0 .. U+FCB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCB8 .. U+FCBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCC0 .. U+FCC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCC8 .. U+FCCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCD0 .. U+FCD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCD8 .. U+FCDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCE0 .. U+FCE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCE8 .. U+FCEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCF0 .. U+FCF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FCF8 .. U+FCFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD00 .. U+FD07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD08 .. U+FD0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD10 .. U+FD17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD18 .. U+FD1F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD20 .. U+FD27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD28 .. U+FD2F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD30 .. U+FD37 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD38 .. U+FD3F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD40 .. U+FD47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD48 .. U+FD4F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD50 .. U+FD57 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD58 .. U+FD5F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD60 .. U+FD67 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD68 .. U+FD6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD70 .. U+FD77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD78 .. U+FD7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD80 .. U+FD87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD88 .. U+FD8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD90 .. U+FD97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FD98 .. U+FD9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDA0 .. U+FDA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDA8 .. U+FDAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDB0 .. U+FDB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDB8 .. U+FDBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDC0 .. U+FDC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDC8 .. U+FDCF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDD0 .. U+FDD7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDD8 .. U+FDDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDE0 .. U+FDE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDE8 .. U+FDEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDF0 .. U+FDF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FDF8 .. U+FDFF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE00 .. U+FE07 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE08 .. U+FE0F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE10 .. U+FE17 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE18 .. U+FE1F --*/
   ""      , ""      , ""      , "~"     , ""      , ""      , ""      , ""      ,  /*-- U+FE20 .. U+FE27 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE28 .. U+FE2F --*/
   ".."    , "--"    , "-"     , "_"     , "_"     , "("     , ") "    , "{"     ,  /*-- U+FE30 .. U+FE37 --*/
   "} "    , "["     , "] "    , "[("    , ")] "   , "<<"    , ">> "   , "<"     ,  /*-- U+FE38 .. U+FE3F --*/
   "> "    , "["     , "] "    , "{"     , "}"     , ""      , ""      , ""      ,  /*-- U+FE40 .. U+FE47 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE48 .. U+FE4F --*/
   ","     , ","     , "."     , ""      , ";"     , ":"     , "?"     , "!"     ,  /*-- U+FE50 .. U+FE57 --*/
   "-"     , "("     , ")"     , "{"     , "}"     , "{"     , "}"     , "#"     ,  /*-- U+FE58 .. U+FE5F --*/
   "&"     , "*"     , "+"     , "-"     , "<"     , ">"     , "="     , ""      ,  /*-- U+FE60 .. U+FE67 --*/
   "\\"    , "$"     , "%"     , "@"     , ""      , ""      , ""      , ""      ,  /*-- U+FE68 .. U+FE6F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE70 .. U+FE77 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE78 .. U+FE7F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE80 .. U+FE87 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE88 .. U+FE8F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE90 .. U+FE97 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FE98 .. U+FE9F --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEA0 .. U+FEA7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEA8 .. U+FEAF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEB0 .. U+FEB7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEB8 .. U+FEBF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEC0 .. U+FEC7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEC8 .. U+FECF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FED0 .. U+FED7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FED8 .. U+FEDF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEE0 .. U+FEE7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEE8 .. U+FEEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEF0 .. U+FEF7 --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FEF8 .. U+FEFF --*/
   ""      , "!"     , "\""    , "#"     , "$"     , "%"     , "&"     , "'"     ,  /*-- U+FF00 .. U+FF07 --*/
   "("     , ")"     , "*"     , "+"     , ","     , "-"     , "."     , "/"     ,  /*-- U+FF08 .. U+FF0F --*/
   "0"     , "1"     , "2"     , "3"     , "4"     , "5"     , "6"     , "7"     ,  /*-- U+FF10 .. U+FF17 --*/
   "8"     , "9"     , ":"     , ";"     , "<"     , "="     , ">"     , "?"     ,  /*-- U+FF18 .. U+FF1F --*/
   "@"     , "A"     , "B"     , "C"     , "D"     , "E"     , "F"     , "G"     ,  /*-- U+FF20 .. U+FF27 --*/
   "H"     , "I"     , "J"     , "K"     , "L"     , "M"     , "N"     , "O"     ,  /*-- U+FF28 .. U+FF2F --*/
   "P"     , "Q"     , "R"     , "S"     , "T"     , "U"     , "V"     , "W"     ,  /*-- U+FF30 .. U+FF37 --*/
   "X"     , "Y"     , "Z"     , "["     , "\\"    , "]"     , "^"     , "_"     ,  /*-- U+FF38 .. U+FF3F --*/
   "`"     , "a"     , "b"     , "c"     , "d"     , "e"     , "f"     , "g"     ,  /*-- U+FF40 .. U+FF47 --*/
   "h"     , "i"     , "j"     , "k"     , "l"     , "m"     , "n"     , "o"     ,  /*-- U+FF48 .. U+FF4F --*/
   "p"     , "q"     , "r"     , "s"     , "t"     , "u"     , "v"     , "w"     ,  /*-- U+FF50 .. U+FF57 --*/
   "x"     , "y"     , "z"     , "{"     , "|"     , "}"     , "~"     , ""      ,  /*-- U+FF58 .. U+FF5F --*/
   ""      , "."     , "["     , "]"     , ","     , "*"     , "wo"    , "a"     ,  /*-- U+FF60 .. U+FF67 --*/
   "i"     , "u"     , "e"     , "o"     , "ya"    , "yu"    , "yo"    , "tu"    ,  /*-- U+FF68 .. U+FF6F --*/
   "+"     , "a"     , "i"     , "u"     , "e"     , "o"     , "ka"    , "ki"    ,  /*-- U+FF70 .. U+FF77 --*/
   "ku"    , "ke"    , "ko"    , "sa"    , "si"    , "su"    , "se"    , "so"    ,  /*-- U+FF78 .. U+FF7F --*/
   "ta"    , "ti"    , "tu"    , "te"    , "to"    , "na"    , "ni"    , "nu"    ,  /*-- U+FF80 .. U+FF87 --*/
   "ne"    , "no"    , "ha"    , "hi"    , "hu"    , "he"    , "ho"    , "ma"    ,  /*-- U+FF88 .. U+FF8F --*/
   "mi"    , "mu"    , "me"    , "mo"    , "ya"    , "yu"    , "yo"    , "ra"    ,  /*-- U+FF90 .. U+FF97 --*/
   "ri"    , "ru"    , "re"    , "ro"    , "wa"    , "n"     , ":"     , ";"     ,  /*-- U+FF98 .. U+FF9F --*/
   ""      , "g"     , "gg"    , "gs"    , "n"     , "nj"    , "nh"    , "d"     ,  /*-- U+FFA0 .. U+FFA7 --*/
   "dd"    , "r"     , "lg"    , "lm"    , "lb"    , "ls"    , "lt"    , "lp"    ,  /*-- U+FFA8 .. U+FFAF --*/
   "rh"    , "m"     , "b"     , "bb"    , "bs"    , "s"     , "ss"    , ""      ,  /*-- U+FFB0 .. U+FFB7 --*/
   "j"     , "jj"    , "c"     , "k"     , "t"     , "p"     , "h"     , ""      ,  /*-- U+FFB8 .. U+FFBF --*/
   ""      , ""      , "a"     , "ae"    , "ya"    , "yae"   , "eo"    , "e"     ,  /*-- U+FFC0 .. U+FFC7 --*/
   ""      , ""      , "yeo"   , "ye"    , "o"     , "wa"    , "wae"   , "oe"    ,  /*-- U+FFC8 .. U+FFCF --*/
   ""      , ""      , "yo"    , "u"     , "weo"   , "we"    , "wi"    , "yu"    ,  /*-- U+FFD0 .. U+FFD7 --*/
   ""      , ""      , "eu"    , "yi"    , "i"     , ""      , ""      , ""      ,  /*-- U+FFD8 .. U+FFDF --*/
   "/C"    , "PS"    , "!"     , "-"     , "|"     , "Y="    , "W="    , ""      ,  /*-- U+FFE0 .. U+FFE7 --*/
   "|"     , "-"     , "|"     , "-"     , "|"     , "#"     , "O"     , ""      ,  /*-- U+FFE8 .. U+FFEF --*/
   ""      , ""      , ""      , ""      , ""      , ""      , ""      , ""      ,  /*-- U+FFF0 .. U+FFF7 --*/
   ""      , "{"     , "|"     , "}"     , "@"     , ""      , ""      , ""         /*-- U+FFF8 .. U+FFFF --*/
  }
};
